@@ -5,10 +5,8 @@
 
 #include "osl/game_playing/searchPlayer.h"
 #include "osl/game_playing/gameState.h"
-#include "osl/state/numEffectState.h"
 #include "osl/search/alphaBeta2.h" /* for EVAL_CLASS */
-#include "osl/record/csaRecord.h"
-#include "osl/record/csaString.h"
+#include "osl/csa.h"
 #include "osl/misc/perfmon.h"
 #include <iostream>
 
@@ -31,12 +29,12 @@ void benchmark(osl::game_playing::SearchPlayer& player, const std::string& filen
 			  "P9-RY-HI *  *  * +KI *  * +KY\n"
 			  "P+00KA00KI00KI00FU00FU\n"
 			  "P-00GI00FU00FU\n"
-			  "+\n").getInitialState());
-  vector<Move> moves;
+			  "+\n").initialState());
+  std::vector<Move> moves;
   if (! filename.empty()) {
-    CsaFile file(filename);
-    nstate = NumEffectState(file.getInitialState());
-    moves = file.getRecord().getMoves();
+    CsaFileMinimal file(filename);
+    nstate = NumEffectState(file.initialState());
+    moves = file.moves();
   }
   std::cerr << "benchmark start " << filename << "\n" << nstate << "\n";
   GameState state(nstate);
@@ -44,7 +42,7 @@ void benchmark(osl::game_playing::SearchPlayer& player, const std::string& filen
   const Move best_move
     = player.selectBestMove(state, 0, 0, seconds).move;
   const unsigned long long cycles = clock.stop();
-  std::cout << record::csa::show(best_move) << "\n";
+  std::cout << csa::show(best_move) << "\n";
 
   const osl::search::CountRecorder& recorder = player.recorder();
   const unsigned int nodes = recorder.nodeCount();
@@ -55,7 +53,7 @@ void benchmark(osl::game_playing::SearchPlayer& player, const std::string& filen
   if (! moves.empty()) {
     std::cerr << "  recorded ";
     for (size_t i=0; i<moves.size(); ++i) 
-      std::cerr << " " << record::csa::show(moves[i]);
+      std::cerr << " " << csa::show(moves[i]);
     std::cerr << "\n";
   }
 }
