@@ -7,10 +7,8 @@
 // - setoption Thread を無視 (-N x は可)
 // - setoption USI_Hash を無視 (常に最大を利用)
 
-#include "osl/record/usi.h"
-#include "osl/record/opening/openingBook.h"
-#include "osl/record/csaIOError.h"
-#include "osl/state/numEffectState.h"
+#include "osl/usi.h"
+#include "osl/book/openingBook.h"
 #include "osl/game_playing/usiState.h"
 #include "osl/game_playing/speculativeSearchPlayer.h"
 #include "osl/game_playing/alphaBetaPlayer.h"
@@ -22,28 +20,22 @@
 #include "osl/search/usiReporter.h"
 #include "osl/checkmate/dfpn.h"
 #include "osl/checkmate/dfpnParallel.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/eval/progressEval.h"
 #include "osl/rating/featureSet.h"
-#include "osl/progress/ml/newProgress.h"
-#include "osl/move_generator/legalMoves.h"
+#include "osl/progress.h"
 #include "osl/move_probability/featureSet.h"
 #include "osl/oslConfig.h"
 #include "osl/sennichite.h"
-#include "osl/enter_king/enterKing.h"
-#include "osl/misc/pointerQueue.h"
-#include "osl/misc/ctime.h"
-#include "osl/misc/ncores.h"
-#include <boost/scoped_ptr.hpp>
-#include <boost/thread/thread.hpp>
-#include <boost/thread/mutex.hpp>
+#include "osl/enterKing.h"
 #include <boost/program_options.hpp>
-#include <boost/foreach.hpp>
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/asio.hpp>
 #include <boost/iostreams/concepts.hpp>
 #include <boost/iostreams/stream.hpp>
+#include <condition_variable>
+#include <future>
 namespace po = boost::program_options;
 #include <string>
 #include <sstream>
@@ -109,8 +101,8 @@ bool new_move_probability = true;
 std::string udp_log = "";
 boost::asio::io_service io_service;
 using boost::asio::ip::udp;
-boost::scoped_ptr<udp::socket> udp_socket;
-boost::scoped_ptr<udp::endpoint> udp_endpoint;
+std::unique_ptr<udp::socket> udp_socket;
+std::unique_ptr<udp::endpoint> udp_endpoint;
 std::string hostname = "";
 
 bool is_verbose()
@@ -131,27 +123,27 @@ void send_udp_log(std::string line)
 		      ignored_error);
 }
 
-volatile int go_count = 0;
-volatile int bestmove_count = 0;
-volatile int search_count = 0;
-volatile bool last_go_is_checkmate = false;
-volatile bool stop_checkmate = false;
-boost::mutex go_stop_mutex;
-boost::condition go_stop_condition;
+std::atomic_int go_count(0);
+std::atomic_int bestmove_count(0);
+std::atomic_int search_count(0);
+std::atomic_bool last_go_is_checkmate(false);
+std::atomic_bool stop_checkmate(false);
+std::mutex go_stop_mutex;
+std::condition_variable go_stop_condition;
 
-boost::scoped_ptr<std::ofstream> csa_stream;
-boost::scoped_ptr<game_playing::CsaLogger> csa_logger;
+std::unique_ptr<std::ofstream> csa_stream;
+std::unique_ptr<game_playing::CsaLogger> csa_logger;
 struct StopWatch
 {
-  MilliSeconds prev;
+  time_point prev;
   void init()
   {
-    prev = MilliSeconds::now();
+    prev = clock::now();
   }
   int elapsedCSA() 
   {
-    MilliSeconds now = MilliSeconds::now();
-    int result = std::max(1, (int)floor((now - prev).toSeconds()));
+    time_point now = clock::now();
+    int result = std::max(1, (int)floor(toSeconds(now - prev)));
     prev = now;
     return result;
   }
@@ -161,12 +153,12 @@ class StatefulPlayer
 {
   UsiState usi_state;
   game_playing::GameState state;
-  boost::scoped_ptr<game_playing::ComputerPlayer> player;
+  std::unique_ptr<game_playing::ComputerPlayer> player;
   CArray<int,2> initial_time;
   Player my_turn;
   std::ostream& os;
 public:
-  mutable boost::mutex mutex;
+  mutable std::mutex mutex;
   StatefulPlayer(const UsiState& initial_state,
 		 game_playing::ComputerPlayer *p,
 		 Player turn, std::ostream& o)
@@ -180,7 +172,7 @@ public:
       else
 	csa_logger->init("human", "gpsshogi", state.state());
     }
-    BOOST_FOREACH(Move m, usi_state.moves) {
+    for (Move m: usi_state.moves) {
       state.pushMove(m);
       player->pushMove(m);
       if (csa_logger)
@@ -201,14 +193,14 @@ public:
       if (! ignore_moves.empty())
 	player->setRootIgnoreMoves(&ignore_moves, false);
       {
-	boost::mutex::scoped_lock lk(go_stop_mutex);
+	std::lock_guard<std::mutex> lk(go_stop_mutex);
 	++search_count;
 	go_stop_condition.notify_all();
       }
       if (byoyomi_extension > 0) {
 	assert(byoyomi > 0);
-	const osl::MilliSeconds::Interval b(byoyomi);
-	const osl::MilliSeconds::Interval bmax(byoyomi_extension);
+	const osl::milliseconds b(byoyomi);
+	const osl::milliseconds bmax(byoyomi_extension);
 	osl::search::TimeAssigned msec(b, bmax);
 	if (osl::game_playing::ComputerPlayerSelectBestMoveInTime *p
 	    = dynamic_cast<osl::game_playing::ComputerPlayerSelectBestMoveInTime *>(player.get()))
@@ -230,28 +222,28 @@ public:
       throw;
     }
     if (ret.move.isNormal()) {
-      boost::mutex::scoped_lock lk(mutex);
+      std::lock_guard<std::mutex> lk(mutex);
       usi_state.moves.push_back(ret.move);
       state.pushMove(ret.move);
       player->pushMove(ret.move);
       if (csa_logger)
 	csa_logger->pushMove(ret, stop_watch.elapsedCSA());
     } else {
-      boost::mutex::scoped_lock lk(mutex);
+      std::lock_guard<std::mutex> lk(mutex);
       usi_state.aborted = true;
     }
     player->setRootIgnoreMoves(0, false);
     ignore_moves.clear();
-    std::string result = "bestmove " + record::usi::show(ret.move);
+    std::string result = "bestmove " + usi::show(ret.move);
     {
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << result << "\n" << std::flush;
     }
     if (is_verbose())
       std::cerr << "sent: " << result << "\n";
     send_udp_log(result);
     suspend_reading = false;
-    boost::mutex::scoped_lock lk(go_stop_mutex);
+    std::lock_guard<std::mutex> lk(go_stop_mutex);
     ++bestmove_count;
     go_stop_condition.notify_all();
   }
@@ -260,7 +252,7 @@ public:
     if (csa_logger)
       csa_logger->pushMove(move, stop_watch.elapsedCSA());
     {
-      boost::mutex::scoped_lock lk(mutex);
+      std::lock_guard<std::mutex> lk(mutex);
       usi_state.moves.push_back(move);
       state.pushMove(move);
       player->pushMove(move);
@@ -270,7 +262,7 @@ public:
   }
   const UsiState current() const
   {
-    boost::mutex::scoped_lock lk(mutex);
+    std::lock_guard<std::mutex> lk(mutex);
     return usi_state;
   }
   void stopSearchNow()
@@ -282,25 +274,77 @@ public:
     usi_state.aborted = true;
   }
 };
-boost::scoped_ptr<StatefulPlayer> player;
+std::unique_ptr<StatefulPlayer> player;
 
-struct Queue : osl::misc::PointerQueue<Move>
+struct Queue 
 {
-  void pop(Move& move) 
-  {
+  typedef std::deque<std::shared_ptr<Move> > queue_t;
+  queue_t data;
+  typedef std::mutex Mutex;
+  mutable Mutex mutex;
+  std::atomic_bool finish;
+  std::condition_variable condition;
+
+  Queue() : finish(false) {
+  }
+  ~Queue() {
+    if (! finish)
+      quit();
+  }
+  size_t size() const {
+    std::lock_guard<Mutex> lk(mutex);
+    return data.size();
+  }
+  void push_back(std::shared_ptr<Move>&& ptr) {
+    std::lock_guard<Mutex> lk(mutex);
+    data.push_back(std::shared_ptr<Move>());
+    data.back().swap(ptr);
+    condition.notify_one();
+  }
+private:
+  std::shared_ptr<Move> pop_front_in_lock()
+    {
+      if (! data.empty())
+      {
+	std::shared_ptr<Move> result = data.front();
+	data.pop_front();
+	return result;
+      }
+      return std::shared_ptr<Move>();
+    }
+public:
+  std::shared_ptr<Move> pop_front_non_block() {
+    std::lock_guard<Mutex> lk(mutex);
+    return pop_front_in_lock();
+  }
+  std::shared_ptr<Move> pop_front() {
+    while (! finish) {
+      std::unique_lock<Mutex> lk(mutex);
+      std::shared_ptr<Move> result = pop_front_in_lock();
+      if (result.get() || finish)
+	return result;
+      condition.wait(lk);
+    }
+    return std::shared_ptr<Move>();
+  }
+  void quit(int seconds=0) {
+    finish = true;
+    if (seconds > 0)
+      std::this_thread::sleep_for(std::chrono::seconds(seconds));
+    std::unique_lock<Mutex> lk(mutex);
+    condition.notify_all();
+  }
+  void pop(Move& move)  {
     move = *pop_front();
   }
-  bool pop_if_present(Move& move) 
-  {
-    boost::shared_ptr<Move> ret = pop_front_non_block();
+  bool pop_if_present(Move& move)  {
+    std::shared_ptr<Move> ret = pop_front_non_block();
     if (ret)
       move = *ret;
-    return ret;
+    return ret.get() != nullptr;
   }
-  void push(Move move)
-  {
-    boost::shared_ptr<Move> ptr(new Move(move));
-    push_back(ptr);
+  void push(Move move) {
+    push_back(std::make_shared<Move>(move));
   }
 };
 
@@ -336,8 +380,8 @@ struct ThreadRun
   static bool goodAlignment();
 };
 
-boost::scoped_ptr<UsiState> input_state;
-boost::scoped_ptr<boost::thread> search_thread;
+std::unique_ptr<UsiState> input_state;
+std::unique_ptr<std::thread> search_thread;
 
 game_playing::ComputerPlayer *makePlayer(Player turn, const SimpleState&, std::ostream&);
 Player input_turn() 
@@ -371,9 +415,9 @@ void do_search(std::ostream& os)
   } 
   game_playing::ComputerPlayer *searcher = makePlayer(turn, input_state->initial_state, os);
   player.reset(new StatefulPlayer(*input_state, searcher, turn, os));
-  search_thread.reset(new boost::thread(ThreadRun()));  
+  search_thread.reset(new std::thread(ThreadRun()));  
 
-  boost::mutex::scoped_lock lk(go_stop_mutex);
+  std::unique_lock<std::mutex> lk(go_stop_mutex);
   while (go_count > search_count)
     go_stop_condition.wait(lk);
 }
@@ -385,10 +429,10 @@ struct GoMate
   NumEffectState& state;
   PathEncoding path;
   Move& checkmate_move;
-  vector<Move>& pv;
+  std::vector<Move>& pv;
   ProofDisproof& result;
   GoMate(checkmate::DfpnParallel& d, NumEffectState& s, PathEncoding p, 
-	 Move& c, vector<Move>& v, ProofDisproof& r)
+	 Move& c, std::vector<Move>& v, ProofDisproof& r)
     : dfpn(d), state(s), path(p), checkmate_move(c), pv(v), result(r)
   {
   }
@@ -407,13 +451,13 @@ struct GoMateThread
   {
     NotifyLock()
     {
-      boost::mutex::scoped_lock lk(go_stop_mutex);
+      std::lock_guard<std::mutex> lk(go_stop_mutex);
       ++search_count;
       go_stop_condition.notify_all();
     }
     ~NotifyLock()
     {
-      boost::mutex::scoped_lock lk(go_stop_mutex);
+      std::lock_guard<std::mutex> lk(go_stop_mutex);
       ++bestmove_count;
       go_stop_condition.notify_all();
       stop_checkmate = false;
@@ -435,7 +479,7 @@ void GoMateThread::operator()()
   if (state.kingSquare(state.turn()).isPieceStand()) {
     const char *msg = "checkmate notimplemented";
     {
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << msg << "\n";
     }
     send_udp_log(msg);
@@ -448,28 +492,29 @@ void GoMateThread::operator()()
 #endif
   const PathEncoding path(state.turn());
   Move checkmate_move;
-  vector<Move> pv;
-  ProofDisproof result;
+  std::vector<Move> pv;
   if (debug)
     std::cerr << state;
-#ifdef OSL_DFPN_SMP
-  checkmate::DfpnParallel dfpn(std::min(OslConfig::numCPUs(), 8));
-#else
-  checkmate::Dfpn dfpn;
-#endif
+  checkmate::DfpnParallel dfpn(std::min(OslConfig::concurrency(), 8));
   dfpn.setTable(&table);
-  MilliSeconds start = MilliSeconds::now();
-#ifdef OSL_DFPN_SMP
-  boost::thread thread(GoMate(dfpn, state, path, checkmate_move, pv, result));
+  time_point start = clock::now();
+
+  auto future = std::async
+    (std::launch::async,
+     [&](){ return dfpn.hasCheckmateMove
+	   (state, HashKey(state), path, 
+	    std::numeric_limits<size_t>::max(), checkmate_move, Move(), &pv); });
+
   double wait = 450;
   for (int i=0; true; ++i) {
-    if (thread.timed_join(boost::posix_time::milliseconds((size_t)wait)))
+    if (future.wait_for(std::chrono::milliseconds((int)wait))
+	!=std::future_status::timeout)
       break;
-    double elapsed = start.elapsedSeconds();
+    double elapsed = elapsedSeconds(start);
     size_t node_count = dfpn.nodeCount();
     if (i % 4 == 0) {
       double memory = OslConfig::memoryUseRatio();
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << "info time " << static_cast<int>(elapsed*1000)
 	 << " nodes " << node_count << " nps " << static_cast<int>(node_count/elapsed)
 	 << " hashfull " << static_cast<int>(memory*1000) << "\n";
@@ -479,35 +524,14 @@ void GoMateThread::operator()()
     wait = std::min((seconds*0.94-elapsed)*1000 - 100, 250.0);
   }
   dfpn.stopNow();
-  thread.join();
-#else  
-  size_t step = 100000, total = 0;
-  double scale = 1.0; 
-  for (size_t limit = step; true; limit = static_cast<size_t>(step*scale)) {
-    result = dfpn.
-      hasCheckmateMove(state, HashKey(state), path, limit, checkmate_move, Move(), &pv);
-    double elapsed = start.elapsedSeconds();
-    double memory = OslConfig::memoryUseRatio();
-    uint64_t node_count = dfpn.nodeCount();
-    boost::mutex::scoped_lock lk(OslConfig::lock_io);
-    os << "info time " << static_cast<int>(elapsed*1000)
-       << " nodes " << total+node_count << " nps " << static_cast<int>(node_count/elapsed)
-       << " hashfull " << static_cast<int>(memory*1000) << "\n";
-    if (result.isFinal() || elapsed >= seconds || memory > 0.9 || stop_checkmate)
-      break;
-    total += limit;
-    // estimate: total * std::min(seconds/elapsed, 1.0/memory)
-    // next: (estimate - total) / 2 + total
-    scale = (total * std::min(seconds/elapsed, 1.0/memory) - total) / 2.0 / step;
-    scale = std::max(std::min(16.0, scale), 0.1);
-  }
-#endif
+  ProofDisproof result = future.get();
+
   if (is_verbose())
-    std::cerr << "elapsed " << start.elapsedSeconds() << "\n";
+    std::cerr << "elapsed " << elapsedSeconds(start) << "\n";
   if (! result.isFinal()) {
     const char *msg = "checkmate timeout";
     {
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << msg << "\n" << std::flush;
     }
     send_udp_log(msg);
@@ -516,7 +540,7 @@ void GoMateThread::operator()()
   if (! result.isCheckmateSuccess()) {
     const char *msg = "checkmate nomate";
     {
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << msg << "\n" << std::flush;
     }
     send_udp_log(msg);
@@ -524,9 +548,9 @@ void GoMateThread::operator()()
   }
   std::string msg = "checkmate";
   for (size_t i=0; i<pv.size(); ++i)
-    msg += " " + record::usi::show(pv[i]);
+    msg += " " + usi::show(pv[i]);
   {
-    boost::mutex::scoped_lock lk(OslConfig::lock_io);
+    std::lock_guard<std::mutex> lk(OslConfig::lock_io);
     os << msg << "\n" << std::flush;
   }
   send_udp_log(msg);
@@ -534,12 +558,12 @@ void GoMateThread::operator()()
 
 void do_checkmate(double seconds, std::ostream& os)
 {
-  boost::shared_ptr<boost::thread> (new boost::thread(GoMateThread(seconds, os)));
+  std::thread(GoMateThread(seconds, os)).detach();
 }
 
 void play_by_book(int depth_limit, std::ostream& os)
 {
-  static osl::record::opening::WeightedBook book(OslConfig::openingBook());
+  static osl::book::WeightedBook book(OslConfig::openingBook());
   if (HashKey(input_state->initial_state)
       == HashKey(SimpleState(HIRATE))
       && (int)input_state->moves.size() < depth_limit)
@@ -547,7 +571,7 @@ void play_by_book(int depth_limit, std::ostream& os)
     game_playing::GameState state(input_state->initial_state);
     game_playing::WeightTracer tracer
       (book, is_verbose(), book_width_root, book_width);
-    BOOST_FOREACH(Move m, input_state->moves) {
+    for (Move m: input_state->moves) {
       tracer.update(m);
       state.pushMove(m);
     }
@@ -555,9 +579,9 @@ void play_by_book(int depth_limit, std::ostream& os)
       const Move best_move = tracer.selectMove();
       if (best_move.isNormal()
 	  && (! state.isIllegal(best_move))) {
-	std::string result = "bestmove " + record::usi::show(best_move);
+	std::string result = "bestmove " + usi::show(best_move);
 	{
-	  boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	  std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	  os << result << "\n" << std::flush;
 	}
 	if (is_verbose())
@@ -569,7 +593,7 @@ void play_by_book(int depth_limit, std::ostream& os)
   }
   const char *msg = "bestmove pass";
   {
-    boost::mutex::scoped_lock lk(OslConfig::lock_io);
+    std::lock_guard<std::mutex> lk(OslConfig::lock_io);
     os << msg << "\n" << std::flush;
   }
   if (is_verbose())
@@ -584,7 +608,7 @@ void play_declare_win(std::ostream& os)
   const std::string msg = std::string("bestmove ")
     + (can_declare_win ? "win" : "pass");
   {
-    boost::mutex::scoped_lock lk(OslConfig::lock_io);
+    std::lock_guard<std::mutex> lk(OslConfig::lock_io);
     os << msg << "\n" << std::flush;
   }
   if (is_verbose())
@@ -663,8 +687,8 @@ void read_config_file()
 #  ifndef MINIMAL
 	OslConfig::setNumCPUs(value);
 #  else
-	if (value != OslConfig::numCPUs())
-	  std::cerr << "ignored Thread config " << value << ' ' << OslConfig::numCPUs()
+	if (value != OslConfig::concurrency())
+	  std::cerr << "ignored Thread config " << value << ' ' << OslConfig::concurrency()
 		    << "\n";
 #  endif
       }
@@ -686,7 +710,7 @@ void write_config_file()
   os << "ErrorLogFile " << error_log_file << "\n";
   os << "Verbose " << verbose << "\n";
   os << "UsiOutputPawnValue " << OslConfig::usiOutputPawnValue() << "\n";
-  os << "Thread " << OslConfig::numCPUs() << "\n";
+  os << "Thread " << OslConfig::concurrency() << "\n";
 }
 
 void setOption(std::string& line) 
@@ -787,9 +811,9 @@ void setOption(std::string& line)
 #ifndef MINIMAL
       OslConfig::setNumCPUs(value);
 #else
-      if (value != OslConfig::numCPUs())
+      if (value != OslConfig::concurrency())
 	std::cerr << "ignored Thread config " << value 
-		  << " v.s. " << OslConfig::numCPUs()
+		  << " v.s. " << OslConfig::concurrency()
 		  << "\n";
 #endif
     } else {
@@ -802,7 +826,7 @@ void setOption(std::string& line)
 void do_stop() 
 {
   {
-    boost::mutex::scoped_lock lk(go_stop_mutex);
+    std::lock_guard<std::mutex> lk(go_stop_mutex);
     if (go_count <= bestmove_count) {
       std::cerr << "warning stop ignored (go " << go_count
 		<< " times, bestmove " << bestmove_count << " times)\n";
@@ -815,7 +839,7 @@ void do_stop()
     player->stopSearchNow();
     player->needRestartNext();
   }
-  boost::mutex::scoped_lock lk(go_stop_mutex);
+  std::unique_lock<std::mutex> lk(go_stop_mutex);
   while (go_count > bestmove_count)
     go_stop_condition.wait(lk);
 }
@@ -865,11 +889,11 @@ void play(std::istream& is, std::ostream& os)
   os << "option name Verbose type spin default " << verbose << " min 0 max 1\n";
   os << "option name UsiOutputPawnValue type spin default " << OslConfig::usiOutputPawnValue() << " min 100 max 10000\n";
 #  ifdef OSL_SMP
-  os << "option name Thread type spin default " << OslConfig::numCPUs() << " min 1 max "
-     << std::max(1, osl::misc::ncores()) << "\n";
+  os << "option name Thread type spin default " << OslConfig::concurrency() << " min 1 max "
+     << std::max(1u, std::thread::hardware_concurrency()) << "\n";
 #  endif
   os << "usiok\n" << std::flush;
-  boost::scoped_ptr<std::ofstream> input_log_stream;
+  std::unique_ptr<std::ofstream> input_log_stream;
   if (input_log_file != "") {
     input_log_stream.reset(new std::ofstream(input_log_file.c_str()));
     *input_log_stream << line << "\n" << std::flush;
@@ -892,7 +916,7 @@ void play(std::istream& is, std::ostream& os)
       if (show_date) {
 	const time_t now = time(0);
 	char ctime_buf[64];
-	std::cerr << osl::ctime_r(&now, ctime_buf);
+	std::cerr << ctime_r(&now, ctime_buf);
       }
       std::cerr << "recv: " << line << "\n" << std::flush;
     }
@@ -937,13 +961,13 @@ void play(std::istream& is, std::ostream& os)
 
     // extended commands
     if (line.find("sleep") == 0) {
-      boost::this_thread::sleep(boost::posix_time::seconds(60));
+      std::this_thread::sleep_for(std::chrono::seconds(60));
       continue;
     }
 
     if (lightweight_commands.hasImmediateResponse(line, response)) {
       {
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << response << "\n" << std::flush;
       }
       send_udp_log(response);
@@ -953,7 +977,7 @@ void play(std::istream& is, std::ostream& os)
     // search related commands 
     // do not read next search command while previous search is in progress
     while (read_from_file && suspend_reading)
-      boost::this_thread::sleep(boost::posix_time::milliseconds(200));
+      std::this_thread::sleep_for(std::chrono::milliseconds(200));
 
     if (line.find("position") == 0) {
       try {
@@ -969,7 +993,7 @@ void play(std::istream& is, std::ostream& os)
       continue;
     }
     if (line.find("go") == 0) {
-      boost::mutex::scoped_lock lk(go_stop_mutex);
+      std::unique_lock<std::mutex> lk(go_stop_mutex);
       OslConfig::setDfpnMaxDepth(256);
       while (go_count > bestmove_count) {
 	std::cerr << "delay go (go " << go_count
@@ -985,7 +1009,7 @@ void play(std::istream& is, std::ostream& os)
       if (is >> millisec)
 	seconds = std::max(std::min(seconds, millisec/1000.0), 0.5);
       {
-	boost::mutex::scoped_lock lk(go_stop_mutex);
+	std::lock_guard<std::mutex> lk(go_stop_mutex);
 	++go_count;
 	last_go_is_checkmate = true;
 	OslConfig::setDfpnMaxDepth(1600);
@@ -1034,7 +1058,7 @@ void play(std::istream& is, std::ostream& os)
       }
       suspend_reading = true;
       do_search(os);
-      boost::mutex::scoped_lock lk(go_stop_mutex);
+      std::lock_guard<std::mutex> lk(go_stop_mutex);
       ++go_count;
       continue;
     }
@@ -1058,14 +1082,14 @@ void play(std::istream& is, std::ostream& os)
       if (input_state) {
 	NumEffectState state(input_state->currentState());
 	const osl::progress::Effect5x3 progress(state);
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << "answer progress " << progress.progress16().value()
 	   << ' ' << progress.progress16(BLACK).value()
 	   << ' ' << progress.progress16(WHITE).value()
 	   << "\n";
       }
       else {
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << "error position not specified\n";
       }
       continue;
@@ -1074,7 +1098,7 @@ void play(std::istream& is, std::ostream& os)
       if (input_state) {
 	NumEffectState state(input_state->currentState());
 	const osl::eval::ml::OpenMidEndingEval eval(state);
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << "answer eval " << eval.value()
 	   << ' ' << eval.captureValue(osl::newPtypeO(osl::WHITE,osl::PAWN))/2
 	   << ' ' << eval.progressIndependentValue()
@@ -1085,7 +1109,7 @@ void play(std::istream& is, std::ostream& os)
 	   << "\n";
       }
       else {
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << "error position not specified\n";
       }
       continue;
@@ -1097,16 +1121,16 @@ void play(std::istream& is, std::ostream& os)
 	int amount, byoyomi, elapsed;
 	if (is >> dummy >> dummy >> amount >> byoyomi >> elapsed) {
 	  osl::game_playing::GameState state(input_state->initial_state);
-	  BOOST_FOREACH(Move m, input_state->moves) 
+	  for (Move m: input_state->moves) 
 	    state.pushMove(m);
 	  const osl::search::TimeAssigned assigned
 	    = osl::game_playing::SearchPlayer::assignTime(state, amount, elapsed, byoyomi, 0);
-	  boost::mutex::scoped_lock lk(OslConfig::lock_io);
-	  os << "answer searchtime " << assigned.standard.value()
-	     << ' ' << assigned.max.value() << "\n";
+	  std::lock_guard<std::mutex> lk(OslConfig::lock_io);
+	  os << "answer searchtime " << assigned.standard.count()
+	     << ' ' << assigned.max.count() << "\n";
 	}
 	else {
-	  boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	  std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	  os << "error in arguments";
 	}
       }
@@ -1116,7 +1140,7 @@ void play(std::istream& is, std::ostream& os)
       continue;      
     }
     if (line.find("query") == 0) {
-      boost::mutex::scoped_lock lk(OslConfig::lock_io);
+      std::lock_guard<std::mutex> lk(OslConfig::lock_io);
       os << "error unknown query\n";
       continue;      
     }    
@@ -1125,17 +1149,17 @@ void play(std::istream& is, std::ostream& os)
       try {
 	input_state->openFile(line.substr(5));
       }
-      catch (record::csa::CsaIOError& e) {
+      catch (CsaIOError& e) {
 	std::cerr << e.what() << "\n";
 	ok = false;
       }
       if (ok) {
-	boost::mutex::scoped_lock lk(OslConfig::lock_io);
+	std::lock_guard<std::mutex> lk(OslConfig::lock_io);
 	os << "position "
-	   << record::usi::show(input_state->initial_state)
+	   << usi::show(input_state->initial_state)
 	   << " moves";
-	BOOST_FOREACH(Move move, input_state->moves)
-	  os << " " << record::usi::show(move);
+	for (Move move: input_state->moves)
+	  os << " " << usi::show(move);
 	os << "\n";
 	os << "openok\n";	
       }
@@ -1158,11 +1182,12 @@ void play(std::istream& is, std::ostream& os)
     queue.push(Move());
     search_thread->join();
   }
-  boost::this_thread::sleep(boost::posix_time::seconds(sleep_seconds));
+  std::this_thread::sleep_for(std::chrono::seconds(sleep_seconds));
 }
 
 int main(int argc, char **argv)
 {
+  OslConfig::setUp();
   int num_benchmark, benchmark_seconds;
   po::options_description options("Options");
   std::string io_stream;
@@ -1264,9 +1289,9 @@ int main(int argc, char **argv)
       || vm.count("benchmark-single")
       || num_benchmark) {
 #ifdef OSL_SMP
-    if (num_cpus > 0 && num_cpus != OslConfig::numCPUs()
+    if (num_cpus > 0 && num_cpus != OslConfig::concurrency()
 	&& ! vm.count("profile")) {
-      std::cerr << "set num-cpus " << OslConfig::numCPUs() << " => " << num_cpus << "\n";
+      std::cerr << "set num-cpus " << OslConfig::concurrency() << " => " << num_cpus << "\n";
       OslConfig::setNumCPUs(num_cpus);
     }
 #endif
@@ -1299,8 +1324,8 @@ int main(int argc, char **argv)
   OslConfig::setSearchExactValueInOneReply(true); // todo: option
   read_config_file();
 #ifdef OSL_SMP
-  if (num_cpus > 0 && num_cpus != OslConfig::numCPUs()) {
-    std::cerr << "set num-cpus " << OslConfig::numCPUs() << " => " << num_cpus << "\n";
+  if (num_cpus > 0 && num_cpus != OslConfig::concurrency()) {
+    std::cerr << "set num-cpus " << OslConfig::concurrency() << " => " << num_cpus << "\n";
     OslConfig::setNumCPUs(num_cpus);
   }
 #endif
@@ -1322,14 +1347,14 @@ int main(int argc, char **argv)
       boost::system::error_code ec;      
       while (socket.connect(server, ec)) {
 	std::cerr << "." << std::flush;
-	boost::this_thread::sleep(boost::posix_time::seconds(15));
+	std::this_thread::sleep_for(std::chrono::seconds(15));
       }
       std::cerr << "\n" << std::flush;
       boost::iostreams::stream<tcp_istream> is(socket);
       boost::iostreams::stream<tcp_ostream> os(socket);
       play(is, os);
       // fall back to reconnect in case of server down
-      boost::this_thread::sleep(boost::posix_time::seconds(15));
+      std::this_thread::sleep_for(std::chrono::seconds(15));
     }
   }
   else if (io_stream != "") 
@@ -1358,7 +1383,7 @@ bool ThreadRun::goodAlignment()
 
 game_playing::ComputerPlayer *makePlayer(Player turn, const SimpleState& initial_state, std::ostream& os)
 {
-  static osl::record::opening::WeightedBook book(OslConfig::openingBook());
+  static osl::book::WeightedBook book(OslConfig::openingBook());
   game_playing::SearchPlayer *search_player = new game_playing::AlphaBeta2OpenMidEndingEvalPlayer;
   dynamic_cast<game_playing::AlphaBeta2OpenMidEndingEvalPlayer&>(*search_player)
     .enableMultiPV(multi_pv_width);
@@ -1379,7 +1404,7 @@ game_playing::ComputerPlayer *makePlayer(Player turn, const SimpleState& initial
     search_player->setNodeCountHardLimit(node_count_hard_limit);
 #endif
   const bool extended_usi = OslConfig::usiMode() == OslConfig::ExtendedUSI;
-  boost::shared_ptr<UsiMonitor> monitor(new UsiMonitor(extended_usi, os));
+  std::shared_ptr<UsiMonitor> monitor(new UsiMonitor(extended_usi, os));
   if (udp_socket)
     monitor->setUdpLogging(hostname, udp_socket.get(), udp_endpoint.get());
 
@@ -1387,7 +1412,7 @@ game_playing::ComputerPlayer *makePlayer(Player turn, const SimpleState& initial
   bool use_book = book_depth > 0;
   {
     const SimpleState usual(HIRATE);
-    if (! (record::CompactBoard(initial_state) == record::CompactBoard(usual)))
+    if (! (book::CompactBoard(initial_state) == book::CompactBoard(usual)))
       use_book = false;
   }
   game_playing::ComputerPlayer *result = search_player;
