@@ -162,7 +162,7 @@ sub read_or_gameend ($)
 	do
 	{
 	    push(@skipped, $line);
-	    if ($line =~ /^\#(WIN|LOSE|DRAW|CHUDAN)/) {
+	    if ($line =~ /^\#(WIN|LOSE|DRAW|CHUDAN|MAX_MOVES)/) {
 		if ($line =~ /^\#WIN/) {
 		    $this->chat_com("kachi-mashita");
 		} elsif ($line =~ /^\#DRAW/) {
@@ -326,6 +326,7 @@ sub wait_opponent ($$@)
     my $line;
     my $timeleft = 0;
     my $byoyomi = 0;
+    my $inc_per_move = 0;
     my $sente_name = "unknown";
     my $gote_name  = "unknown";
 
@@ -377,6 +378,10 @@ sub wait_opponent ($$@)
 	    $byoyomi -= int(POSIX::floor($byoyomi / 10))
 		if ($byoyomi / 10 > 0);
 	}
+	elsif ($line =~ /^Increment:(.+)/)
+	{
+	    $inc_per_move = $1;
+	}
 	elsif ($line =~ /^BEGIN Position/)
 	{
 	    print STDERR "SYSTEM:$line";
@@ -427,7 +432,8 @@ sub wait_opponent ($$@)
     }
     $this->{last_eval} = 0;
     $this->{totaltime} = $timeleft;
-    $this->{byoyomi} = $byoyomi;
+    $this->{byoyomi} = $byoyomi || $inc_per_move; # todo
+    $this->{inc_per_move} = $inc_per_move;
     $this->{opname} = ($sente ? $gote_name : $sente_name);
     return ($sente, $csafilename, $this->{opname},
 	    $timeleft, $byoyomi);
