@@ -3,7 +3,7 @@ use strict;
 use IPC::Open2;
 use IO::Handle;
 use IO::Select;
-require("ctime.pl");
+use POSIX qw(strftime);
 
 BEGIN {
   $| = 1;
@@ -115,8 +115,9 @@ sub send ($$)
 {
     my ($this, $message) = @_;
     my ($writer, $logger) = ($this->{writer}, $this->{logger});
-    print STDERR "TGPS:$message",&ctime(time);
-    print $logger "TGPS:$message",&ctime(time)
+    my $now = strftime("%Y %b %d %a %H:%M:%S %z\n", localtime);
+    print STDERR "TGPS:$message",$now;
+    print $logger "TGPS:$message",$now
 	if ($this->{logger});
     print $writer "$message"
 	|| $this->respawn_in_write();
@@ -143,9 +144,10 @@ sub read ($)
     my ($this) = @_;
     my ($reader, $logger) = ($this->{reader}, $this->{logger});
     my $line = <$reader>;
+    my $now = strftime("%Y %b %d %a %H:%M:%S %z\n", localtime);
     if (defined $line) {
-	print STDERR "FGPS:$line",&ctime(time);
-	print $logger "FGPS:$line",&ctime(time)
+	print STDERR "FGPS:$line",$now;
+	print $logger "FGPS:$line",$now
 	    if ($this->{logger});
     } else {
 	warn "prog_read failed";
