@@ -41,6 +41,7 @@ $table_size = $ENV{TABLE_SIZE}
 my $table_record_limit = 200;	# for 8GB
 $table_record_limit = $ENV{TABLE_RECORD_LIMIT}
     if ($ENV{TABLE_RECORD_LIMIT});
+my $force_byoyomi = $ENV{FORCE_BYOYOMI} || 0;
 my $gps_opts = ($ENV{GPSOPTS} ? $ENV{GPSOPTS} : "");
 my $gps_opts_human = $gps_opts;
 $gps_opts_human =~ s/-P / /;
@@ -117,6 +118,8 @@ for (my $i=0; $loop_limit < 0 || $i<$loop_limit; ++$i) {
 	$client->game_chat("$opname san, yoroshiku onegai-shimasu");
 	$byoyomi-= 5 if ($byoyomi >= 30);
     }
+    $byoyomi = $force_byoyomi
+  if $force_byoyomi > 0 && $byoyomi > $force_byoyomi;
     my $time_string = GpsShogi::make_time_string();
     my $logfilename = "$logfile_basename$time_string-$opname-comm.log";
     my $log_handle;
