@@ -5,7 +5,6 @@
 
 #include "osl/game_playing/searchPlayer.h"
 #include "osl/oslConfig.h"
-#include "osl/misc/ncores.h"
 #include <boost/program_options.hpp>
 namespace po = boost::program_options;
 
@@ -30,7 +29,7 @@ struct SearchOptions
 #  ifdef OSL_NCPUS
     const int num_cpus_default = OSL_NCPUS;
 #  else
-    const int num_cpus_default = osl::misc::ncores();
+    const int num_cpus_default = std::thread::hardware_concurrency();
 #  endif
 #endif
     options.add_options()
@@ -98,6 +97,7 @@ struct EvalOptions
   std::string eval_type;
   std::string eval_filename;
   std::string progress_filename;
+  std::string usi_proxy;
   unsigned int eval_random;
 
   po::options_description options;
@@ -118,6 +118,8 @@ struct EvalOptions
        po::value<unsigned int>(&eval_random)->default_value(0),
        "add random value generated by normal distribution of a given standard deviation, to evaluation values")
 #endif
+      ("usi-proxy", po::value<std::string>(&usi_proxy)->default_value(""),
+       "path to gpsfish")
       ;
   }
 };
