@@ -1,8 +1,10 @@
 #!/usr/bin/perl -w
 use strict;
 use Time::HiRes;
+use Time::Piece;
 use Getopt::Std;
 use network::CsaFileSession;
+use Sys::Hostname;
 
 my %options;
 getopts("s:d:k",\%options);
@@ -13,15 +15,17 @@ my $keep_alive = $options{k} || 0;
 
 my $session = new CsaFileSession($dir, $id);
 
-print STDERR "wait for $dir/$id\n";
+my $now = Time::Piece::localtime;
+# print STDERR $now->datetime." wait for $dir/$id\n";
 my $sleep_count = 0;
 while (1) {
   if (my $message = $session->try_read()) {
     print $message."\n";
-    print STDERR "wait for $dir/".$session->id()."\n";
+#    my $now = Time::Piece::localtime;
+#    print STDERR $now->dir." wait for $dir/".$session->id()."\n";
   } else {
-    Time::HiRes::usleep(50*1000);
-    $sleep_count += 50;
+    Time::HiRes::usleep(5*1000);
+    $sleep_count += 5;
     if ($keep_alive && $sleep_count >= 60*1000) {
       print "\n";
       $sleep_count = 0;
