@@ -2,7 +2,7 @@
 use strict;
 use Getopt::Std;
 use network::CsaFileSession;
-require("ctime.pl");
+use Time::Piece;
 
 my %options;
 getopts("s:d:",\%options);
@@ -18,6 +18,7 @@ while (<>) {
     print STDERR "(nop)\n";
     next;
   }
-  print STDERR "read $_ " . &ctime(time);
+#  my $now = Time::Piece::localtime;
+#  print STDERR $now->datetime." > $_\n";
   $session->write($_);
 }
