@@ -4,10 +4,7 @@
 #include <QPixmap>
 #include <QMouseEvent>
 
-#include "osl/piece.h"
-#include "osl/ptype.h"
-#include "osl/player.h"
-#include "osl/square.h"
+#include "osl/basic_type.h"
 
 class QResizeEvent;
 
@@ -47,10 +44,10 @@ namespace gpsshogi
       osl::Piece selectedPiece;
       QPoint mousePoint;
       qreal scale_mult;
-      static const int STAND_SIZE = 80;
-      static const int BOX_SIZE = 40;
-      static const int BLACK_STAND_X = STAND_SIZE + BOX_SIZE * 9 + 20;
-      static const int MARGIN_HEAD = BOX_SIZE;
+      static const int STAND_SIZE;
+      static const int BOX_SIZE;
+      static const int BLACK_STAND_X;
+      static const int MARGIN_HEAD;
 
       bool isOnBoard(int x, int f) const;
     };
