@@ -1,9 +1,8 @@
 #ifndef GPSSHOGI_GUI_BOARD_H
 #define GPSSHOGI_GUI_BOARD_H
 #include "gpsshogi/gui/abstractBoard.h"
-#include "osl/state/numEffectState.h"
-#include "osl/container/moveVector.h"
-#include "osl/hash/hashKey.h"
+#include "osl/numEffectState.h"
+#include "osl/hashKey.h"
 
 namespace osl
 {
@@ -28,7 +27,7 @@ namespace gpsshogi
       Board(const osl::NumEffectState& state, QWidget *parent = 0);
       void toggleOrientation();
       void setView(bool sente);
-      const osl::state::NumEffectState& getState() const {
+      const osl::NumEffectState& getState() const {
 	return state;
       }
       void setManualMovement(bool enable) {
@@ -71,7 +70,7 @@ namespace gpsshogi
 			 MoveSet& pv, HashSet& visited, int level);
     public slots:
       void move(osl::Move m);
-      void setState(const osl::state::NumEffectState& state, osl::Move last_move=osl::Move());
+      void setState(const osl::NumEffectState& state, osl::Move last_move=osl::Move());
     signals:
       void moved(osl::Move);
       void statusChanged();
@@ -85,7 +84,7 @@ namespace gpsshogi
 	return !senteView;
       }
       bool senteView;
-      osl::state::NumEffectState state;
+      osl::NumEffectState state;
     private:
       bool allowManualMovement;
       osl::Move last_move;
