@@ -2,8 +2,7 @@
 #define GPSSHOGI_GUI_EDITBOARD2_H
 
 #include "gpsshogi/gui/abstractBoard.h"
-#include "osl/misc/carray.h"
-#include "osl/state/simpleState.h"
+#include "osl/numEffectState.h"
 
 class QKeyEvent;
 
@@ -17,8 +16,8 @@ namespace gpsshogi
     public:
       EditBoard2(QWidget *parent = 0);
       // throws an exception
-      osl::state::SimpleState getState();
-      void setState(const osl::state::SimpleState &state);
+      osl::SimpleState getState();
+      void setState(const osl::SimpleState &state);
       void moveReserve(osl::Player, osl::Ptype, osl::Square);
       void reserveToStand(osl::Player);
       void setTurn(osl::Player);
@@ -36,8 +35,8 @@ namespace gpsshogi
       void keyReleaseEvent(QKeyEvent *);
     private:
       template<osl::Ptype ptype> void initPieces();
-      osl::misc::CArray<osl::Piece, osl::Square::SIZE> board;
-      osl::misc::CArray<osl::Piece, osl::Piece::SIZE> pieces;
+      osl::CArray<osl::Piece, osl::Square::SIZE> board;
+      osl::CArray<osl::Piece, osl::Piece::SIZE> pieces;
       int modifiers;
       osl::Player turn;
     };
