@@ -1,6 +1,6 @@
 #ifndef GPSSHOGI_GUI_UTIL_H
 #define GPSSHOGI_GUI_UTIL_H
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include <qstring.h>
 
 namespace gpsshogi
