@@ -12,7 +12,7 @@ namespace gpsshogi
 {
   class EvalDB
   {
-    boost::scoped_ptr<dbm::DBMWrapper> db;
+    std::unique_ptr<dbm::DBMWrapper> db;
   public:
     EvalDB(const char *filename, bool readonly);
     ~EvalDB();
