@@ -12,7 +12,7 @@ namespace gpsshogi
 {
   class RecordDB
   {
-    boost::scoped_ptr<dbm::DBMWrapper> db;
+    std::unique_ptr<dbm::DBMWrapper> db;
   public:
     RecordDB(const char *filename, bool readonly);
     ~RecordDB();
