@@ -4,14 +4,11 @@
 #include <qcursor.h>
 
 #include "gpsshogi/gui/board.h"
-#include "osl/record/opening/bookInMemory.h"
+#include "osl/book/bookInMemory.h"
 #include "osl/state/historyState.h"
 #include "osl/search/simpleHashTable.h"
 #include "osl/search/simpleHashRecord.h"
-#include "osl/move_generator/legalMoves.h"
-#include "osl/pieceStand.h"
-#include "osl/stl/hash_set.h"
-#include <boost/foreach.hpp>
+#include <unordered_set>
 
 #if QT_VERSION >= 0x040000
 #include <QMouseEvent>
@@ -22,7 +19,7 @@ bool gpsshogi::gui::Board::highlight_enabled = false;
 bool gpsshogi::gui::Board::highlight_book = false;
 bool gpsshogi::gui::Board::arrow_enabled = false;
 
-gpsshogi::gui::Board::Board(const osl::state::NumEffectState& state,
+gpsshogi::gui::Board::Board(const osl::NumEffectState& state,
 			    QWidget *parent)
   : AbstractBoard(parent),
     senteView(true), state(state), allowManualMovement(true),
@@ -166,7 +163,7 @@ Board::move(osl::Move m)
 }
 
 void gpsshogi::gui::
-Board::setState(const osl::state::NumEffectState& sstate, osl::Move l)
+Board::setState(const osl::NumEffectState& sstate, osl::Move l)
 {
   if (!(state == sstate))
   {
@@ -228,10 +225,12 @@ osl::Piece gpsshogi::gui::Board::getStandPiece(osl::Player p, osl::Ptype ptype)
   return osl::Piece::EMPTY();
 }
 
-struct gpsshogi::gui::Board::MoveSet : public osl::hash_set<osl::Move>
+struct gpsshogi::gui::Board::MoveSet
+  : public std::unordered_set<osl::Move,std::hash<osl::Move>>
 {
 };
-struct gpsshogi::gui::Board::HashSet : public osl::hash_set<osl::HashKey>
+struct gpsshogi::gui::Board::HashSet
+  : public std::unordered_set<osl::HashKey,std::hash<osl::HashKey>>
 {
 };
 
@@ -241,7 +240,7 @@ void gpsshogi::gui::Board::paintEvent(QPaintEvent *pe)
   painter.scale(scale_mult, scale_mult);
   if (effect != NONE)
   {
-    osl::state::NumEffectState nState(state);
+    osl::NumEffectState nState(state);
     for (int x = 1; x <= 9; x++)
     {
       for (int y = 1; y <= 9; y++)
@@ -278,7 +277,7 @@ void gpsshogi::gui::Board::paintEvent(QPaintEvent *pe)
   }
   if (highlight_book)
   {
-    BOOST_FOREACH(osl::Move move, book_moves) {
+    for (osl::Move move: book_moves) {
       if (last_move.isNormal() && move.to() == last_move.to())
 	continue;
       QPoint point = positionToPoint(move.to());
@@ -287,7 +286,7 @@ void gpsshogi::gui::Board::paintEvent(QPaintEvent *pe)
     }
     
     painter.setPen(QPen(QColor("green"), 2));
-    BOOST_FOREACH(osl::Move move, book_moves) {
+    for (osl::Move move: book_moves) {
       drawArrow(painter, move, false);
     }
   }
@@ -330,8 +329,8 @@ Board::showRecursive(QPainter& painter, osl::HistoryState& state,
     painter.setPen(wpen);
   }
   osl::MoveVector moves;
-  osl::LegalMoves::generate(state, moves);
-  BOOST_FOREACH(osl::Move move, moves) {
+  static_cast<const osl::NumEffectState&>(state).generateLegal(moves);
+  for (osl::Move move: moves) {
     if (move == best_move)
       continue;
     state.makeMove(move);
