@@ -46,7 +46,7 @@ QString gpsshogi::gui::
 Util::moveToString(osl::Move m, const osl::NumEffectState& state,
 		   osl::Move last_move)
 {
-  std::string euc = osl::record::ki2::show(m, state, last_move);
+  std::string euc = osl::ki2::show(m, state, last_move);
   for (size_t i=0; euc.size() < 14; ++i)
     euc += K_SPACE;
   QTextCodec *codec = QTextCodec::codecForName("EUC-JP");
