@@ -188,15 +188,17 @@ function DisplayTable(display_id, csa_id, move_length, board) {
 	  close.setAttribute("class", "clickable");
 	  csa_body.innerHTML = "<pre>sfen "
 	+state.toUsiCsaStyle()
+        .replace(/\+NG/g, "+S") // N+G=NG
 	.replace(/\+FU/g, "P").replace(/\+KY/g, "L").replace(/\+KE/g, "N")
 	.replace(/\+GI/g, "S").replace(/\+KI/g, "G").replace(/\+KA/g, "B")
 	.replace(/\+HI/g, "R").replace(/\+TO/g, "+P").replace(/\+NY/g, "+L")
-	.replace(/\+NK/g, "+N").replace(/\+NG/g, "+S").replace(/\+UM/g, "+B")
+	.replace(/\+NK/g, "+N").replace(/\+UM/g, "+B")
 	.replace(/\+RY/g, "+R").replace(/\+OU/g, "K")
+	.replace(/-NG/g, "+s")
 	.replace(/-FU/g, "p").replace(/-KY/g, "l").replace(/-KE/g, "n")
 	.replace(/-GI/g, "s").replace(/-KI/g, "g").replace(/-KA/g, "b")
 	.replace(/-HI/g, "r").replace(/-TO/g, "+p").replace(/-NY/g, "+l")
-	.replace(/-NK/g, "+n").replace(/-NG/g, "+s").replace(/-UM/g, "+b")
+	.replace(/-NK/g, "+n").replace(/-UM/g, "+b")
 	.replace(/-RY/g, "+r").replace(/-OU/g, "k")
 	.replace(/ \*  \*  \*  \*  \*  \*  \*  \*  \* /g, "9")
 	.replace(/ \*  \*  \*  \*  \*  \*  \*  \* /g, "8")
