@@ -80,7 +80,7 @@ function promote(ptype) {
 }
 
 function getImage(name) {
-  var base = "images/";
+  var base = "/shogi/view/images/";
   return base + name + ".png";
 }
 
@@ -534,7 +534,9 @@ function parseCsaBoard(body) {
   var comments = new Array();
   var move_comments = new Array();
   for (var i in lines) {
-    var line = lines[i];
+   var elements = lines[i].split(",");
+   for (var j in elements) {
+   var line = elements[j];
     if (line.charAt(0) == 'P') {
       var code = line.charAt(1) - '0';
       if (0 < code && code < 10) {
@@ -614,6 +616,7 @@ function parseCsaBoard(body) {
     } else if (line.substr(0, 7) == "$EVENT:") {
       board.setEvent(line.substring(7, line.length));
     }
+   }
   }
   board.setMoves(moves);
   board.setTimes(times);
