@@ -1,4 +1,5 @@
 #!/bin/sh -
+umask 002
 event=LATEST
 HOME=/home/shogi-server
 cd $HOME/www/$event
@@ -12,9 +13,10 @@ cp players-floodgate.html rating/players-floodgate-$today.html
 cp players-floodgate14.html rating/players-floodgate14-$today.html
 cp players-others.yaml rating/players-others-$today.yaml
 cp players-others.html rating/players-others-$today.html
-if cat floodgate-results.txt others-results.txt | $HOME/bin/mk_rate-from-grep > tmp-daily.yaml; then
-  mv tmp-daily.yaml players.yaml
-fi
+#2012-08 replaced by symlink: players.yaml => players-floodgate.yaml
+#if cat floodgate-results.txt others-results.txt | $HOME/bin/mk_rate-from-grep > tmp-daily.yaml; then
+#  mv tmp-daily.yaml players.yaml
+#fi
 cd rating
 $HOME/bin/players_graph.rb --output-dir g *floodgate14-*.yaml
 #
