@@ -1,4 +1,5 @@
 #!/bin/sh -
+umask 002
 today=`date "+%Y%m%d"`
 HOME=/home/shogi-server
 renice 20 $$ >/dev/null 2>&1
@@ -11,11 +12,10 @@ go () {
   # rating
   cd $HOME/www/
   rm tmp.yaml 2>/dev/null
-  if $HOME/bin/mk_rate-from-grep --fixed-rate-player gps_normal --fixed-rate 2150 < x/floodgate-results.txt > tmp.yaml; then
+  if sort x/floodgate-results.txt | uniq | $HOME/bin/mk_rate --fixed-rate-player gpsfish_normal_1c --fixed-rate 2800 > tmp.yaml; then
       cp -p tmp.yaml $event/current-floodgate.yaml
   fi
-#  if ruby1.9 $HOME/bin/csa-file-filter --within 14 tmp/floodgate | $HOME/bin/mk_rate --half-life-ignore 14 --fixed-rate-player gps_normal --fixed-rate 2150 > tmp.yaml; then
-  if $HOME/bin/mk_rate-from-grep --ignore 14 --half-life-ignore 14 --fixed-rate-player gps_normal --fixed-rate 2150 < x/floodgate-results.txt > tmp.yaml; then
+  if sort x/floodgate-results.txt | uniq | $HOME/bin/mk_rate --ignore 14 --half-life-ignore 14 --fixed-rate-player gpsfish_normal_1c --fixed-rate 2800 > tmp.yaml; then
       cp -p tmp.yaml $event/current-floodgate14.yaml
       mv tmp.yaml $event/rating/players-floodgate14-$today.yaml
   fi
