@@ -171,7 +171,7 @@ sub get_records ($) {
     my ($file, $sente, $gote, $moves, $time_black, $time_white,
 	$result, $reason) = split(/\s+/,$line,8);
     next
-      unless $file =~ /^($ire)\+($ire\-[0-9]+-[0-9]+)[\+:]($ire)[\+:]($ire)[\+:]([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})\.csa$/o;
+      unless $file =~ /^($ire)\+($ire\-[0-9]+-[0-9]+F?)[\+:]($ire)[\+:]($ire)[\+:]([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})\.csa$/o;
     my $record = { event => $1, game => $2, sente => $3, gote => $4,
 		   year => $5, month => $6, date => $7, hour => $8,
 		   minute => $9, second => $10, file => "$5/$6/$7/$file"
