@@ -43,7 +43,7 @@ class DownloadManager
 #    ^http://www.geocities.jp/
 
   def initialize(url)
-    @url = url.gsub("<", "&lt;").gsub(">", "&gt;");
+    @url = url.lines.first.gsub("<", "&lt;").gsub(">", "&gt;");
   end
 
   def h_url
@@ -65,10 +65,17 @@ class DownloadManager
   end
 
   def download_contents
-    kifu = open(@url, "Accept" => "text/plain") do |f|
-      f.read
+    # Optimize for local files
+    if %r!^http://wdoor\.c\.u-tokyo\.ac\.jp/(shogi/LATEST/\d{4}/\d{2}/\d{2}/[\w@\.\+\-]+\.csa)$! =~ @url
+      file = File.join("/var/www", $1)
+      kifu = open(file) {|f| f.read} 
+      return kifu
+    else
+      kifu = open(@url, "Accept" => "text/plain") do |f|
+        f.read
+      end
+      return kifu
     end
-    return kifu
   end
 
   def kifu_download
