@@ -2,7 +2,7 @@
 use strict;
 use FileHandle;
 
-my $prepare_rating = "/home/shogi-server/bin/mk_rate-grep";
+my $prepare_rating = "/home/shogi-server/bin/mk_game_results";
 
 my %finished;
 my %playing;
@@ -110,16 +110,25 @@ sub add_record ($$$) {
 }
 
 sub update ($$$) {
+    my @list = ();
+
     %playing = ();
     my ($dir, $verbose, $refresh_playing) = @_;
     opendir(DIR, $dir) || warn "opendir $dir !";
-    while (my $file=readdir(DIR)) {
+    @list = readdir(DIR);
+    closedir(DIR)
+      || warn "closedir $dir: $!";
+    foreach my $file (sort @list) {
 	next
 	    if $file =~ /^\./;
+	if ( -d "$dir/$file" ) {
+	    print STDERR "$dir/$file\n";
+            update("$dir/$file", $verbose, $refresh_playing);
+        }
 	next
 	    if -z $file;
 	next
-	    unless $file =~ /^($ire)\+($ire\-[0-9]+-[0-9]+)[\+:]($ire)[\+:]($ire)[\+:]([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})\.csa$/;
+	    unless $file =~ /^($ire)\+($ire\-[0-9]+-[0-9]+F?)[\+:]($ire)[\+:]($ire)[\+:]([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})([0-9]{2})\.csa$/;
 	my $record = { event => $1, game => $2, sente => $3, gote => $4,
 		       year => $5, month => $6, date => $7, hour => $8,
 		       minute => $9, second => $10, file => "$file"
@@ -136,8 +145,6 @@ sub update ($$$) {
 	    $playing{$file} = $record;
 	}
     }
-    closedir(DIR)
-      || warn "closedir $dir: $!";
     my $playing_fh;
     if ($refresh_playing) {
       $playing_fh = (new FileHandle "> playing.txt") || die "open $!";
