@@ -5,16 +5,14 @@
 #include "osl/rating/bradleyTerry.h"
 #include "osl/rating/ratingEnv.h"
 #include "osl/checkmate/immediateCheckmate.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/record/kisen.h"
 #include "osl/record/csaRecord.h"
 #include "osl/stat/average.h"
 #include "osl/stat/histogram.h"
 
 #include <boost/program_options.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <algorithm>
 #include <string>
 #include <iostream>
@@ -105,7 +103,7 @@ int main(int argc, char **argv)
 /* ------------------------------------------------------------------------- */
 
 void verify(const FeatureSet& f,
-	    NumEffectState& state, const vector<Move>& moves,
+	    NumEffectState& state, const std::vector<Move>& moves,
 	    stat::Average& order, stat::Histogram& order_hist)
 {
   RatingEnv env;
@@ -114,7 +112,7 @@ void verify(const FeatureSet& f,
     const Player turn = state.turn();
     if (moves.size() > 10 && j<2)
       goto next;
-    if (! EffectUtil::isKingInCheck(turn, state)
+    if (! state.inCheck(turn)
 	&& ImmediateCheckmate::hasCheckmateMove(turn, state))
       break;
       
@@ -134,13 +132,13 @@ void verify(const FeatureSet& f,
 	  total += exp(my_moves[i].rating()/400.0*log(10));
 	for (size_t i=0; i<my_moves.size(); ++i) {
 	  const double prob = exp(my_moves[i].rating()/400.0*log(10)) / total;
-	  std::cerr << i << " " << record::csa::show(my_moves[i].move()) << " rate " << my_moves[i].rating()
+	  std::cerr << i << " " << csa::show(my_moves[i].move()) << " rate " << my_moves[i].rating()
 		    << " prob " << prob*100.0 << " rp " << -100*log(prob)/log(2) << "\n";
 	}
       }
     }
   next:
-    ApplyMoveOfTurn::doMove(state, moves[j]);
+    state.makeMove(moves[j]);
     env.update(state, moves[j]);
   }
 }
@@ -151,42 +149,44 @@ void verify(const FeatureSet& f)
   stat::Average order;
   stat::Histogram order_hist(10,10);
   if (! csa_filename.empty()) {
-    record::csa::CsaFile csa(csa_filename);
-    NumEffectState state(csa.getInitialState());
-    const vector<Move> moves = csa.getRecord().getMoves();
+    csa::CsaFileMinimal csa(csa_filename);
+    NumEffectState state(csa.initialState());
+    const auto moves = csa.moves();
     verify(f, state, moves, order, order_hist);
   }
   else {
     KisenFile kisen_file(kisen_filename.c_str());
-    KisenIpxFile ipx(BradleyTerry::makeIpx(kisen_filename));
+    KisenIpxFile ipx(KisenFile::ipxFileName(kisen_filename));
     if (num_records==0)
       num_records=kisen_file.size()-kisen_start;
     int skip = 0;
     for (size_t i=kisen_start; i<num_records+kisen_start; i++) {
-      if (ipx.getRating(i, BLACK) < min_rating 
-	  || ipx.getRating(i, WHITE) < min_rating) {
+      if (ipx.rating(i, BLACK) < min_rating 
+	  || ipx.rating(i, WHITE) < min_rating) {
 	++skip;
 	continue;
       }
-      NumEffectState state(kisen_file.getInitialState());
-      const vector<Move> moves=kisen_file.getMoves(i);
+      NumEffectState state(kisen_file.initialState());
+      const auto moves=kisen_file.moves(i);
       verify(f, state, moves, order, order_hist);
     }
     std::cerr << "skip " << skip << " / " << num_records << "\n";
   }
-  std::cerr << order.getAverage() << "\n";
+  std::cerr << order.average() << "\n";
   order_hist.show(std::cerr);
 }
 
 void analyze()
 {
-  boost::scoped_ptr<FeatureSet> f;
+  std::unique_ptr<FeatureSet> f;
   if (feature_type == "standard") 
     f.reset(new StandardFeatureSet(true));
   else if (feature_type == "capture")
     f.reset(new CaptureSet(true));
+#if 0
   else if (feature_type == "tactical")
     f.reset(new TacticalSet(true));
+#endif
   else {
     std::cerr << "unknown feature set " << feature_type << "\n";
     return;
