@@ -1738,7 +1738,7 @@ struct Rank9Effect : public Base
 
 struct IrlsEval : public Base
 {
-  boost::scoped_ptr<gpsshogi::Eval> eval;
+  std::unique_ptr<gpsshogi::Eval> eval;
   IrlsEval(const std::string &name)
   {
     eval.reset(gpsshogi::EvalFactory::newEval(name));
@@ -1969,7 +1969,7 @@ int main(int argc, char **argv)
     return 1;
   }
 
-  boost::scoped_ptr<Base> out(newBase(output));
+  std::unique_ptr<Base> out(newBase(output));
  
   if (!out)
   {
