@@ -157,7 +157,7 @@ int main(int argc, char **argv)
 	osl::search::AlphaBeta2<ome_eval_t> search(state, checkmate_searcher, &table, recorder);
 	osl::search::MoveWithComment additional_info;
 	osl::Move best_move = search.computeBestMoveIteratively
-	  (l, 200, 400, 1000000, osl::search::TimeAssigned(osl::MilliSeconds::Interval(60*1000)),
+	  (l, 200, 400, 1000000, osl::search::TimeAssigned(osl::milliseconds(60*1000)),
 	   &additional_info);
 	std::cout << additional_info.value << " " << osl::record::csa::show(best_move)
 		  << " " << search.nodeCount() << " ";
