@@ -3,9 +3,8 @@
 #include "eval/eval.h"
 #include "eval/evalFactory.h"
 #include "eval/progress.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/progress.h"
 #include "osl/oslConfig.h"
-#include <boost/scoped_ptr.hpp>
 #include <boost/program_options.hpp>
 #include <iostream>
 
@@ -13,7 +12,7 @@ namespace po = boost::program_options;
 using namespace osl;
 using namespace gpsshogi;
 
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
+std::unique_ptr<gpsshogi::Eval> my_eval;
 std::string eval_type, filename, csa_filename, feature_name;
 int feature_index;
 
