@@ -10,18 +10,16 @@
 #include "pvGenerator.h"
 #include "rotateRecord.h"
 #include "osl/record/kisen.h"
-#include "osl/state/numEffectState.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/numEffectState.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress.h"
 #include "osl/misc/milliSeconds.h"
-#include "osl/misc/ncores.h"
 
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <boost/program_options.hpp>
-#include <boost/thread/thread.hpp>
-#include <boost/tuple/tuple.hpp>
-#include <ext/algorithm>
+#include <thread>
+#include <tuple>
+#include <algorithm>
 #include <vector>
 #include <algorithm>
 #include <valarray>
@@ -47,7 +45,7 @@ void analyze_loss(const std::string& output_prefix,
 		  const std::string& gradient_filename,
 		  size_t num_records_loss_analyses);
 
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
+std::unique_ptr<gpsshogi::Eval> my_eval;
 std::string eval_type;
 size_t num_iteration, num_iteration_internal;
 double lambda = 100;
@@ -59,7 +57,7 @@ size_t num_cpus;
 std::string pv_base;
 int watch_threshold, watch_threshold_seed;
 
-boost::scoped_ptr<RotateRecord> rotate_record;
+std::unique_ptr<RotateRecord> rotate_record;
 
 int main(int argc, char **argv)
 {
@@ -155,11 +153,12 @@ int main(int argc, char **argv)
     std::cerr << options << std::endl;
     return 0;
   }
-  if (num_cpus == 0 || (int)num_cpus > osl::misc::ncores()) {
+  if (num_cpus == 0 || (int)num_cpus > std::thread::hardware_concurrency()) {
     std::cerr << "do you really have so many cpus? " << num_cpus << "\n";
     return 1;
   }    
 
+  OslConfig::setUp();
   if (!osl::eval::ml::OpenMidEndingEval::setUp()) {
     std::cerr << "OpenMidEndingEval set up failed";
     // fall through as this might not be fatal depending on eval type used
@@ -204,12 +203,12 @@ stat::Average errors[MaxThreads];
 /** feature の出現率 */
 valarray_t frequency[MaxThreads];
 /** feature の出現回数 */
-vector<size_t> count;
+std::vector<size_t> count;
 /** feature の出現棋譜数. [0] を合計に代用 */
 valarray_t count_by_record[MaxThreads];
 long long total[MaxThreads];
 /** 監視対象の重み */
-vector<int> watch_list;
+std::vector<int> watch_list;
 
 struct ProcessPVBase
 {
@@ -239,17 +238,17 @@ void ProcessPVBase::operator()() const
   PVVector pv_best, pv;
 
   int cur_record=-1, cur_position=-1;
-  NumEffectState state(kisen_file.getInitialState());
-  vector<Move> moves;
+  NumEffectState state(kisen_file.initialState());
+  std::vector<Move> moves;
 
   while (pr.newPosition(record, position)) {
     ++num_position;
     if (record != cur_record) {
       cur_record = record;
-      moves = kisen_file.getMoves(cur_record);
+      moves = kisen_file.moves(cur_record);
       finishRecord();
       cur_position = 0;
-      state = NumEffectState(kisen_file.getInitialState());
+      state = NumEffectState(kisen_file.initialState());
     }
     assert(position > cur_position || cur_position == 0);
     while (position > cur_position) {
@@ -279,7 +278,7 @@ void ProcessPVBase::operator()() const
 struct ProcessPVCount : public ProcessPVBase
 {
   mutable InstanceData instance;
-  mutable vector<size_t> count_work;
+  mutable std::vector<size_t> count_work;
   explicit ProcessPVCount(int tid) : ProcessPVBase(tid, 0), count_work(my_eval->dimension())
   {
   }
@@ -293,7 +292,7 @@ struct ProcessPVCount : public ProcessPVBase
 
 void ProcessPVCount::processInstance(double turn_coef, MoveData& selected, MoveData& sibling) const
 {
-  assert(__gnu_cxx::is_sorted(selected.diffs.begin(), selected.diffs.end()));
+  assert(std::is_sorted(selected.diffs.begin(), selected.diffs.end()));
   std::sort(sibling.diffs.begin(), sibling.diffs.end());
   instance.clear();
   Analyzer::makeInstanceSorted(turn_coef, selected.diffs, sibling.diffs,
@@ -327,7 +326,7 @@ double sigmoid_alpha()
 
 struct ProcessPV : public ProcessPVBase
 {
-  boost::shared_ptr<valarray_t> w;
+  std::shared_ptr<valarray_t> w;
   mutable double agsum, adot;
   mutable MoveData selected;
   ProcessPV(int tid, const valarray_t& iw) 
@@ -382,16 +381,16 @@ void LossOfPV::operator()() const
   PVVector pv_best, pv;
 
   int cur_record=-1, cur_position=-1, record_done=0;
-  NumEffectState state(kisen_file.getInitialState());
-  vector<Move> moves;
+  NumEffectState state(kisen_file.initialState());
+  std::vector<Move> moves;
 
   while (pr.newPosition(record, position)) {
     ++num_position;
     if (record != cur_record) {
       cur_record = record;
-      moves = kisen_file.getMoves(cur_record);
+      moves = kisen_file.moves(cur_record);
       cur_position = 0;
-      state = NumEffectState(kisen_file.getInitialState());
+      state = NumEffectState(kisen_file.initialState());
       ++record_done;
       if (limit_records > 0 && record_done >= limit_records)
 	break;
@@ -460,9 +459,9 @@ public:
       gradient[i] = 0.0;
       errors[i].clear();
     }
-    boost::ptr_vector<boost::thread> threads;
+    boost::ptr_vector<std::thread> threads;
     for (size_t i=0; i<num_cpus; ++i)
-      threads.push_back(new boost::thread(ProcessPV(i, w)));
+      threads.push_back(new std::thread(ProcessPV(i, w)));
     for (size_t i=0; i<num_cpus; ++i)
       threads[i].join();
 
@@ -473,7 +472,7 @@ public:
       if (i)
 	errors[0].merge(errors[i]);
     }
-    error = errors[0].getAverage();
+    error = errors[0].average();
   }
   double computeLoss(const valarray_t& w, size_t limit_records)
   {
@@ -482,9 +481,9 @@ public:
       gradient[i] = 0.0;
       errors[i].clear();
     }
-    boost::ptr_vector<boost::thread> threads;
+    boost::ptr_vector<std::thread> threads;
     for (size_t i=0; i<num_cpus; ++i)
-      threads.push_back(new boost::thread(LossOfPV(i, limit_records/num_cpus)));
+      threads.push_back(new std::thread(LossOfPV(i, limit_records/num_cpus)));
     for (size_t i=0; i<num_cpus; ++i)
       threads[i].join();
 
@@ -492,7 +491,7 @@ public:
       if (i)
 	errors[0].merge(errors[i]);
     }
-    return errors[0].getAverage();
+    return errors[0].average();
   }
   double lastError() const { return prev_error; }
 };
@@ -507,9 +506,9 @@ void count_all()
     count_by_record[i].resize(my_eval->dimension());
     count_by_record[i] = 0.0;
   }
-  boost::ptr_vector<boost::thread> threads;
+  boost::ptr_vector<std::thread> threads;
   for (size_t i=0; i<num_cpus; ++i)
-    threads.push_back(new boost::thread(ProcessPVCount(i)));
+    threads.push_back(new std::thread(ProcessPVCount(i)));
   for (size_t i=0; i<num_cpus; ++i) {
     threads[i].join();
     if (i == 0)
@@ -561,7 +560,7 @@ struct AggregateStream
   }
 };
 
-boost::tuple<double,double,double> run_cross_validation(int cross_start, int cross_num, int max_progress, bool allow_skip)
+std::tuple<double,double,double> run_cross_validation(int cross_start, int cross_num, int max_progress, bool allow_skip)
 {
   const KisenAnalyzer::OtherConfig config = 
     {
@@ -569,7 +568,7 @@ boost::tuple<double,double,double> run_cross_validation(int cross_start, int cro
       max_progress, position_randomness,
       min_rating, my_eval.get()
     };
-  boost::ptr_vector<boost::thread> threads;
+  boost::ptr_vector<std::thread> threads;
       
   std::vector<std::string> csa_files;
   KisenAnalyzer::RecordConfig cross_configs[MaxThreads];
@@ -577,7 +576,7 @@ boost::tuple<double,double,double> run_cross_validation(int cross_start, int cro
 			       kisen_filenames, min_rating, csa_files);
   for (size_t j=0; j<num_cpus; ++j) {
     cross_configs[j].allow_skip_in_cross_validation = allow_skip;
-    threads.push_back(new boost::thread(Validator(cross_configs[j], config, results+j)));
+    threads.push_back(new std::thread(Validator(cross_configs[j], config, results+j)));
   }
   stat::Average werror, toprated, toprated_strict;
   size_t total_node_count = 0, siblings = 0;
@@ -592,7 +591,7 @@ boost::tuple<double,double,double> run_cross_validation(int cross_start, int cro
   std::cerr << "positions " << werror.numElements()
 	    << " siblings " << siblings
 	    << " node count " << total_node_count << "\n";
-  return boost::make_tuple(werror.getAverage(), toprated.getAverage(), toprated_strict.getAverage());
+  return std::make_tuple(werror.average(), toprated.average(), toprated_strict.average());
 }
 
 void analyze_gradient(const std::string& output_prefix,
@@ -644,7 +643,7 @@ void analyze_loss(const std::string& output_prefix,
       throw std::runtime_error("read error "+gradient_filename);
   }
   {
-    boost::scoped_ptr<Eval> eval(EvalFactory::newEval(eval_type));
+    std::unique_ptr<Eval> eval(EvalFactory::newEval(eval_type));
     eval->saveWeight(&stable_w[0]);
   }
   
@@ -719,19 +718,19 @@ void learn_main(const std::string& output_prefix,
       for (size_t i=my_eval->lambdaStart(); i<my_eval->dimension(); ++i) {
 	if (abs(my_eval->flatValue(i)) > watch_threshold) {
 	  os << "  " << i << " " << my_eval->flatValue(i);
-	  boost::tuple<std::string, int, int> name_index_dim = my_eval->findFeature(i);
-	  os << "  " << name_index_dim.get<0>() << " " << name_index_dim.get<1>()
-	     << " / " << name_index_dim.get<2>()<< "\n";
+	  std::tuple<std::string, int, int> name_index_dim = my_eval->findFeature(i);
+	  os << "  " << std::get<0>(name_index_dim) << " " << std::get<1>(name_index_dim)
+	     << " / " << std::get<2>(name_index_dim)<< "\n";
 	  watch_list.push_back(i);
 	}
       }
     }
     os << " cross validation " << ctime(&now);
-    boost::tuple<double, double, double> error
+    std::tuple<double, double, double> error
       = run_cross_validation(cross_start, num_records, max_progress, false);
-    os << "\n  mean errors in search " << error.get<0>() 
-       << " top " << error.get<1>()*100.0
-       << "% (" << error.get<2>()*100.0 << "%)" << "\n";
+    os << "\n  mean errors in search " << std::get<0>(error) 
+       << " top " << std::get<1>(error)*100.0
+       << "% (" << std::get<2>(error)*100.0 << "%)" << "\n";
     os.flush();
 
     if (i == num_iteration && i > 0)
@@ -739,10 +738,10 @@ void learn_main(const std::string& output_prefix,
 
     now = time(0);
     os << " start search " << ctime(&now);
-    MilliSeconds timer = MilliSeconds::now();
+    time_point timer = clock::now();
     unsigned long long total_node_count = 0.0, skip_by_rating = 0, siblings = 0;
     {
-      double consumed = clock();
+      double consumed = ::clock();
       const KisenAnalyzer::OtherConfig config = 
 	{
 	  search_window_abs / my_eval->pawnValue(), sigmoid_alpha(),
@@ -750,11 +749,11 @@ void learn_main(const std::string& output_prefix,
 	  min_rating, my_eval.get()
 	};
       std::vector<std::string> csa_files;
-      boost::ptr_vector<boost::thread> threads;
+      boost::ptr_vector<std::thread> threads;
       KisenAnalyzer::distributeJob(num_cpus, &record_configs[0], kisen_start, num_records,
 				   kisen_filenames, min_rating, csa_files);
       for (size_t j=0; j<num_cpus; ++j) {
-	threads.push_back(new boost::thread(PVGenerator(pv_base, 
+	threads.push_back(new std::thread(PVGenerator(pv_base, 
 							record_configs[j], config, results+j)));
       }
       stat::Average werror, toprated, toprated_strict;
@@ -767,14 +766,14 @@ void learn_main(const std::string& output_prefix,
 	skip_by_rating += results[j].skip_by_rating;
 	siblings += results[j].siblings;
       }
-      consumed = clock() - consumed;
-      std::cerr << "\n  " << total_node_count << " nodes " << timer.elapsedSeconds() << " sec "
-		<< total_node_count / timer.elapsedSeconds() << " nodes/sec\n";
+      consumed = ::clock() - consumed;
+      std::cerr << "\n  " << total_node_count << " nodes " << elapsedSeconds(timer) << " sec "
+		<< total_node_count / elapsedSeconds(timer) << " nodes/sec\n";
       std::cerr << "  cpu time " << consumed / CLOCKS_PER_SEC 
 		<< "  skip by rating " << skip_by_rating << "\n";
-      os << "\n  mean errors in search (training data) " << werror.getAverage()
-	 << " top " << toprated.getAverage()*100.0
-	 << "% (" << toprated_strict.getAverage()*100.0 << "%)"
+      os << "\n  mean errors in search (training data) " << werror.average()
+	 << " top " << toprated.average()*100.0
+	 << "% (" << toprated_strict.average()*100.0 << "%)"
 	 << " positions " << werror.numElements()
 	 << " siblings " << siblings
 	 << "\n";
@@ -790,15 +789,15 @@ void learn_main(const std::string& output_prefix,
       os << " watch list\n";
       for (size_t i=0; i<watch_list.size(); ++i) {
 	const size_t index = watch_list[i];
-	os << "  " << index << " " << my_eval->findFeature(index).get<0>() 
+	os << "  " << index << " " << std::get<0>(my_eval->findFeature(index)) 
 	   << " count " << count[index] << " record " << count_by_record[0][index] << "\n";
       }
     }
     now = time(0);
     os << " start rand012 " << ctime(&now);
-    double consumed = clock();
+    double consumed = ::clock();
     learn(w);
-    consumed = clock() - consumed;
+    consumed = ::clock() - consumed;
     std::cerr << "  cpu time " << consumed / CLOCKS_PER_SEC << "\n";
 
     my_eval->setWeightScale(&w[0], 1.0);
@@ -815,7 +814,7 @@ void learn_main(const std::string& output_prefix,
       for (size_t i=0; i<watch_list.size(); ++i) {
 	const size_t index = watch_list[i];
 	const bool warn = abs(scaled_w[index]) > abs(old_w[index]);
-	os << " !"[warn] << " " << index << " " << my_eval->findFeature(index).get<0>() 
+	os << " !"[warn] << " " << index << " " << std::get<0>(my_eval->findFeature(index)) 
 	   << " " << old_w[index] << " => " << scaled_w[index] << "\n";
       }
     }
