@@ -1,12 +1,11 @@
 #include "pvFile.h"
 #include "pvVector.h"
-#include "osl/state/numEffectState.h"
-#include "osl/search/shouldPromoteCut.h"
+#include "osl/numEffectState.h"
+#include "osl/move_classifier/shouldPromoteCut.h"
 #include "osl/record/kisen.h"
 #include "osl/eval/pieceEval.h"
 
 #include <boost/program_options.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <iostream>
 
 namespace po = boost::program_options;
@@ -18,8 +17,8 @@ class StatePredicate
 public:
   StatePredicate() { }
   virtual ~StatePredicate() { }
-  virtual bool match(const osl::state::NumEffectState &state,
-		     const osl::state::NumEffectState &original_state,
+  virtual bool match(const osl::NumEffectState &state,
+		     const osl::NumEffectState &original_state,
 		     const PVVector&) const
   {
     return false;
@@ -30,7 +29,7 @@ public:
 class KingUpPredicate : public StatePredicate
 {
 private:
-  bool match(const osl::state::NumEffectState &state,
+  bool match(const osl::NumEffectState &state,
 	     osl::Player player) const
   {
     const osl::Square king = state.kingSquare(player);
@@ -48,8 +47,8 @@ private:
   }
 public:
       KingUpPredicate() : StatePredicate() { }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector&) const
   {
     return match(state, osl::BLACK) || match(state, osl::WHITE);
@@ -60,8 +59,8 @@ class AnyPredicate : public StatePredicate
 {
 public:
   AnyPredicate() : StatePredicate() { }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector&) const
   {
     return true;
@@ -73,8 +72,8 @@ class LengthPredicate : public StatePredicate
   size_t length;
 public:
   LengthPredicate(size_t l) : length(l) { }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector& moves) const
   {
     return moves.size() >= length;
@@ -84,8 +83,8 @@ public:
 class InCheckPredicate : public StatePredicate
 {
 public:
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector&) const
   {
     return state.inCheck();
@@ -95,12 +94,12 @@ public:
 class NoPromotePredicate : public StatePredicate
 {
 public:
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector& moves) const
   {
     for (size_t i=0; i<moves.size(); ++i)
-      if (osl::search::ShouldPromoteCut::canIgnoreAndNotDrop(moves[i]))
+      if (osl::ShouldPromoteCut::canIgnoreAndNotDrop(moves[i]))
 	return true;
     return false;
   }
@@ -110,8 +109,8 @@ class PawnPtype3Predicate : public StatePredicate
 {
 public:
   PawnPtype3Predicate() : StatePredicate() { }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector&) const
   {
     for (int x = 1; x <= 9; ++x)
@@ -142,8 +141,8 @@ class PawnPtype7Predicate : public StatePredicate
 {
 public:
   PawnPtype7Predicate() : StatePredicate() { }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector&) const
   {
     for (int x = 1; x <= 9; ++x)
@@ -172,8 +171,8 @@ public:
 class RookEffectPredicateP37 : public StatePredicate
 {
 public:
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector &) const
   {
     for (int i = PtypeTraits<ROOK>::indexMin;
@@ -219,8 +218,8 @@ private:
     return false;
   }
 public:
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector &) const
   {
     for (int i = PtypeTraits<BISHOP>::indexMin;
@@ -244,8 +243,8 @@ public:
 class NoRecapturePredicate : public StatePredicate
 {
 public:
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector &v) const
   {
     if (v.empty())
@@ -270,8 +269,8 @@ public:
   KingSquarePredicate(int x, int y) : king_position(x, y)
   {
   }
-  bool match(const osl::state::NumEffectState &state,
-	     const osl::state::NumEffectState &original_state,
+  bool match(const osl::NumEffectState &state,
+	     const osl::NumEffectState &original_state,
 	     const PVVector &v) const
   {
     const Player P = state.turn();
@@ -339,7 +338,7 @@ int main(int argc, char **argv)
   osl::record::KisenFile kisen(kisen_filename);
 
 
-  boost::scoped_ptr<StatePredicate> predicate;
+  std::unique_ptr<StatePredicate> predicate;
   if (pv_length > 0) 
   {
     predicate.reset(new LengthPredicate(pv_length));
@@ -391,7 +390,7 @@ int main(int argc, char **argv)
   }
 
   std::vector<osl::Move> moves;
-  osl::state::NumEffectState state(kisen.getInitialState());
+  osl::NumEffectState state(kisen.initialState());
   size_t matched = 0, num_positions=0, num_pv=0;
   for (size_t i = 0; i < pv_filenames.size(); ++i)
   {
@@ -405,9 +404,9 @@ int main(int argc, char **argv)
       if (record != cur_record)
       {
 	cur_record = record;
-	moves = kisen.getMoves(cur_record);
+	moves = kisen.moves(cur_record);
 	cur_position = 0;
-	state = NumEffectState(kisen.getInitialState());
+	state = NumEffectState(kisen.initialState());
       }
       assert(position > cur_position || cur_position == 0);
       while (position > cur_position)
