@@ -10,21 +10,19 @@
 #include "rotateRecord.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/kisen.h"
-#include "osl/state/numEffectState.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/numEffectState.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress.h"
 #include "osl/misc/milliSeconds.h"
-#include "osl/misc/ncores.h"
-#include "osl/misc/binaryIO.h"
+#include "osl/bits/binaryIO.h"
 #include "osl/stat/histogram.h"
 
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <boost/program_options.hpp>
-#include <boost/thread/thread.hpp>
-#include <boost/tuple/tuple.hpp>
-#include <boost/foreach.hpp>
-#include <ext/algorithm>
+#include <thread>
+#include <future>
+#include <tuple>
+#include <algorithm>
 #include <vector>
 #include <algorithm>
 #include <valarray>
@@ -46,7 +44,7 @@ void analyze(const std::string& output_prefix,
 	     int max_progress,
 	     bool high_rating_only);
 
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
+std::unique_ptr<gpsshogi::Eval> my_eval;
 std::string eval_type, loss_function;
 size_t num_iteration, num_iteration_internal;
 double lambda;
@@ -57,14 +55,15 @@ std::vector<std::string> csa_filenames;
 double scaling_factor, eta_increment, sigmoid_asymmetry;
 size_t num_cpus;
 std::string pv_base;
-bool smd, fix_step_size, weight_midgame, weight_winner;
+bool smd, fix_step_size, weight_midgame, weight_winner, weight_by_branches;
 bool accelerate_minor_features, clear_infrequent, clear_infrequent_by_record;
+bool parent_child_smoothing;
 int second_cross_start;
 int watch_threshold, watch_threshold_seed;
-double endgame_margin, decay_sibling_weight;
+double endgame_margin, decay_sibling_weight, aggressive_penalty_coef, high_king_weight;
 bool rotate_record_mode;
 
-boost::scoped_ptr<RotateRecord> rotate_record;
+std::unique_ptr<RotateRecord> rotate_record;
 
 /** 進行度が後半まで分布するよう重みを加える */
 double force_progress;
@@ -192,12 +191,21 @@ int main(int argc, char **argv)
     ("weight-midgame",
      po::value<bool>(&weight_midgame)->default_value(true),
      "give more importance to instances in midgame than those in opening or endgame")
+    ("weight-by-branches",
+     po::value<bool>(&weight_by_branches)->default_value(false),
+     "give a weight proportional to the number of pairs")
     ("weight-winner",
      po::value<bool>(&weight_winner)->default_value(false),
      "give more importance to winner's move")
     ("endgame-margin",
      po::value<double>(&endgame_margin)->default_value(0.0),
      "endgame margin (relative to pawn) especially for hinge-loss")
+    ("aggressive-penalty",
+     po::value<double>(&aggressive_penalty_coef)->default_value(1.0),
+     "give more penalty to aggressive moves (when > 1.0)")
+    ("high-king-coef",
+     po::value<double>(&high_king_weight)->default_value(1.0),
+     "give more weight in positions with king outside his area (when > 1.0)")
     ("decay-sibling-weight",
      po::value<double>(&decay_sibling_weight)->default_value(1.0),
      "decrease learning weight for siblings based on the difference of evaluation (need --limit-sibling=n for sort siblings")
@@ -207,6 +215,9 @@ int main(int argc, char **argv)
     ("force-progress",
      po::value<double>(&force_progress)->default_value(0.0),
      "experimental feature only for effectprogress")
+    ("parent-child-smoothing",
+     po::value<bool>(&parent_child_smoothing)->default_value(false),
+     "add penality for overestimation")
     ("help", "produce help message")
     ;
 
@@ -233,13 +244,14 @@ int main(int argc, char **argv)
     std::cerr << options << std::endl;
     return 0;
   }
-  if (num_cpus == 0 || (int)num_cpus > osl::misc::ncores()) {
+  if (num_cpus == 0 || (int)num_cpus > std::thread::hardware_concurrency()) {
     std::cerr << "do you really have so many cpus? " << num_cpus << "\n";
     return 1;
   }    
   if (! high_rating_only)
     min_rating = 0;
 
+  OslConfig::setUp();
   if (!osl::eval::ml::OpenMidEndingEval::setUp()) {
     std::cerr << "OpenMidEndingEval set up failed";
     // fall through as this might not be fatal depending on eval type used
@@ -268,7 +280,7 @@ int main(int argc, char **argv)
       std::cerr << "open failed " << priority_record_text << "\n";
       return 1;
     }
-    vector<int> priority;
+    std::vector<int> priority;
     int value;
     while (is >> value)
       priority.push_back(value);
@@ -289,19 +301,20 @@ static int position_randomness = 1;
 
 valarray_t gradient[MaxThreads], Hv[MaxThreads], v_for_Hv;
 stat::Average errors[MaxThreads];
-boost::scoped_ptr<Histogram> progress_count[MaxThreads];
-boost::scoped_ptr<Histogram> progress_count_prev;
-vector<int> progress_count_sum;
+std::unique_ptr<Histogram> progress_count[MaxThreads];
+std::unique_ptr<Histogram> progress_count_prev;
+std::vector<int> progress_count_sum;
 /** feature の出現率 */
 valarray_t frequency[MaxThreads];
 /** feature の出現回数 */
-vector<size_t> count;
+std::vector<size_t> count;
 /** feature の出現棋譜数. [0] を合計に代用 */
 valarray_t count_by_record[MaxThreads];
 valarray_t variance, reduce_scale;
 long long total[MaxThreads];
+long long aggressive_penalty_moves[MaxThreads];
 /** 監視対象の重み */
-vector<int> watch_list;
+std::vector<int> watch_list;
 
 void init_progress_count()
 {
@@ -326,7 +339,7 @@ void write_progress_count(const std::string& text_name)
   progress_count_prev->show(os);
 }
 
-struct ProcessPVBase
+struct ProcessPVBase : public misc::Align16New
 {
   int thread_id, min_count;
   ProcessPVBase(int tid, int count) 
@@ -334,7 +347,7 @@ struct ProcessPVBase
   {
   }
   virtual ~ProcessPVBase() {}
-  void operator()() const;
+  void operator()();
   virtual void beginPosition(double turn_coef, MoveData& selected) const {}
   virtual void beginPositionProgress(double turn_coef, MoveData& selected) const {}
   virtual void processInstance(double turn_coef, MoveData& selected, MoveData& sibling,
@@ -343,9 +356,17 @@ struct ProcessPVBase
 				       double weight, double progress) const {}
   virtual void endPosition() const {}
   virtual void finishRecord() const {}
+  int curPosition() const { return cur_position; }
+  const std::vector<Move>& curMoves() const { return moves; }
+  Move curMove() const { return moves[cur_position]; }
+  Player turn() const { return state.turn(); }
+private:
+  int cur_record=-1, cur_position=-1;
+  NumEffectState state;
+  std::vector<Move> moves;
 };
 
-void ProcessPVBase::operator()() const
+void ProcessPVBase::operator()()
 {
   std::string filename = PVGenerator::pv_file(pv_base, thread_id);
 
@@ -357,9 +378,8 @@ void ProcessPVBase::operator()() const
   int record, position;
   PVVector pv_best, pv;
 
-  int cur_record=-1, cur_position=-1;
-  NumEffectState state(kisen_file.getInitialState());
-  vector<Move> moves;
+  cur_record = cur_position = -1;
+  state = kisen_file.initialState();
 
   while (pr.newPosition(record, position)) {
     ++num_position;
@@ -367,14 +387,14 @@ void ProcessPVBase::operator()() const
       cur_record = record;
       if (record >= 0)
       {
-        moves = kisen_file.getMoves(cur_record);
-        state = NumEffectState(kisen_file.getInitialState());
+        moves = kisen_file.moves(cur_record);
+        state = NumEffectState(kisen_file.initialState());
       }
       else
       {
         CsaFile csa(record_configs[thread_id].csa_filenames[-record - 1]);
-        state = csa.getInitialState();
-        moves = csa.getRecord().getMoves();
+        state = csa.initialState();
+        moves = csa.moves();
       }
       cur_position = 0;
       finishRecord();
@@ -396,14 +416,32 @@ void ProcessPVBase::operator()() const
       Analyzer::makeLeaf(leaf_state, pv);
       my_eval->features(leaf_state, selected);
       if (force_progress)
-	my_eval->featuresProgress(leaf_state, progress_selected);	
+	my_eval->featuresProgress(leaf_state, progress_selected);
     }
     const int turn_coef = (state.turn() == BLACK) ? 1 : -1;
     beginPosition(turn_coef, selected);
     if (force_progress)
       beginPositionProgress(turn_coef, progress_selected);
     int num_sibling = 0;
+    std::vector<PVVector> pvs;
     while (pr.readPv(pv)) {
+      pvs.push_back(pv);
+    }
+    const double progress_move_number = 1.0*cur_position/moves.size(); // [0,1]
+    double weight = 1.0;
+    if (weight_midgame)
+      weight = 1.0 - abs(0.5-progress_move_number);
+    if (weight_winner && moves.size() < 256 
+	&& (((int)moves.size() % 2) == (cur_position % 2))) // moves[size] corresponds to toryo
+      weight = std::min(0.5, weight);
+    if (weight_by_branches)
+      weight /= std::max(20, (int)pvs.size());
+    if (record < 0) {
+      weight *= 5;
+    }
+    if (state.kingSquare(BLACK).y() < 7 || state.kingSquare(WHITE).y() > 3)
+      weight *= high_king_weight;
+    for (const auto& pv: pvs) {
       ++num_pv; ++num_sibling;
       // analyze_leaf
       {
@@ -411,21 +449,12 @@ void ProcessPVBase::operator()() const
 	Analyzer::makeLeaf(leaf_state, pv);
 	my_eval->features(leaf_state, sibling);
 	if (force_progress)
-	  my_eval->featuresProgress(leaf_state, progress_sibling);	
+	  my_eval->featuresProgress(leaf_state, progress_sibling);
       }
-      double progress = 1.0*cur_position/moves.size(); // [0,1]
-      double weight = weight_midgame ? (1.0 - abs(0.5-progress)) : 1.0;
-      if (weight_winner && moves.size() < 256 
-	  && (((int)moves.size() % 2) == (cur_position % 2))) // moves[size] corresponds to toryo
-	weight = std::min(0.5, weight);
-      if (record < 0)
-      {
-        weight *= 5;
-      }
-      processInstance(turn_coef, selected, sibling, weight, progress);
+      processInstance(turn_coef, selected, sibling, weight, progress_move_number);
       if (force_progress)
 	processInstanceProgress(turn_coef, progress_selected,
-				progress_sibling, weight, progress);
+				progress_sibling, weight, progress_move_number);
     }
     endPosition();
   }
@@ -435,7 +464,7 @@ void ProcessPVBase::operator()() const
 struct ProcessPVCount : public ProcessPVBase
 {
   mutable InstanceData instance;
-  mutable vector<size_t> count_work;
+  mutable std::vector<size_t> count_work;
   explicit ProcessPVCount(int tid) : ProcessPVBase(tid, 0), count_work(my_eval->dimension())
   {
   }
@@ -453,7 +482,7 @@ struct ProcessPVCount : public ProcessPVBase
 void ProcessPVCount::processInstance(double turn_coef, MoveData& selected, MoveData& sibling, double, double) const
 {
   progress_count[thread_id]->add(sibling.progress);
-  assert(__gnu_cxx::is_sorted(selected.diffs.begin(), selected.diffs.end()));
+  assert(std::is_sorted(selected.diffs.begin(), selected.diffs.end()));
   std::sort(sibling.diffs.begin(), sibling.diffs.end());
   instance.clear();
   Analyzer::makeInstanceSorted(turn_coef, selected.diffs, sibling.diffs,
@@ -492,7 +521,7 @@ struct ProcessPV : public ProcessPVBase
   mutable MoveData instance;
 #endif
   mutable double sibling_weight;
-  mutable int instance_count;
+  mutable int instance_count, prev_position=-100;
   ProcessPV(int tid, const valarray_t& iw, bool hv) 
     : ProcessPVBase(tid, min_frequency), w(iw), make_hv(hv),
       sibling_weight(1.0), instance_count(0)
@@ -510,7 +539,21 @@ void ProcessPV::beginPosition(double turn_coef, MoveData& selected) const {
   sibling_weight = 1.0;
   instance_count = 0;
 #ifdef L1BALL_NO_SORT
+  if (parent_child_smoothing && prev_position +1 == curPosition()) {
+    // parent-child smoothing
+    agsum = 0;
+    const MoveData& parent = this->selected, &child = selected;
+    // parent < child: ng (an overestimation in the parent move)
+    // parent > child: ok (maybe a blunder)
+    if (parent.value*turn_coef < child.value*turn_coef) {
+      double loss = LogLoss::addGradientSep
+	(w, adot, parent.diffs, child.diffs, turn_coef, count, min_count,
+	 gradient[thread_id], agsum);
+      LogLoss::addGradientSep(parent.diffs, count, min_count, agsum, gradient[thread_id]);
+    }
+  }
   agsum = 0; 
+  prev_position = curPosition();
   this->selected = selected;
   adot = ValarrayUtil::dot(this->selected.diffs, w, count, min_count);
 #endif
@@ -518,7 +561,6 @@ void ProcessPV::beginPosition(double turn_coef, MoveData& selected) const {
 
 void ProcessPV::beginPositionProgress(double turn_coef, MoveData& selected) const { 
   if (force_progress) {
-    // progress_count[thread_id]->add(selected.progress);
     sparse_vector_t empty_a;
     double agsum_dummy;
     double progress = ValarrayUtil::dot(selected.diffs, w, count, min_count);
@@ -544,15 +586,20 @@ void ProcessPV::endPosition() const
 #endif
 }
 
-void ProcessPV::processInstance(double turn_coef, MoveData& selected, MoveData& sibling, double instance_weight, double progress) const
+void ProcessPV::processInstance(double turn_coef, MoveData& selected, MoveData& sibling, double instance_weight, double progress_move_number) const
 {
   double loss = 0;
-  const double weight = instance_weight*sibling_weight;
+  double weight = instance_weight*sibling_weight;
   ++instance_count;
+  const bool better_than_selected = turn_coef*(sibling.value-this->selected.value) > 0;
 #ifdef L1BALL_NO_SORT
+  if (better_than_selected && sibling.progress > 128+this->selected.progress) {
+    weight *= aggressive_penalty_coef;
+    aggressive_penalty_moves[thread_id]++;
+  }
   double margin = 0.0;
   if (endgame_margin) 
-    margin = progress*endgame_margin*my_eval->pawnValue()/scaling_factor;
+    margin = progress_move_number*endgame_margin*my_eval->pawnValue()/scaling_factor;
   if (loss_function == "sigmoid")
     loss = SigmoidLoss::addGradientSep(w, adot, this->selected.diffs, sibling.diffs, turn_coef, count, min_count,
 				       gradient[thread_id], agsum, weight,
@@ -569,10 +616,7 @@ void ProcessPV::processInstance(double turn_coef, MoveData& selected, MoveData&
     loss = LogLoss::addGradientSep(w, adot, this->selected.diffs, sibling.diffs, turn_coef, count, min_count,
 				   gradient[thread_id], agsum, weight,
 				   margin);
-  if ((loss_function == "hinge" && loss > 0.0)
-      || (loss_function == "sigmoid" && loss > 0.5)
-      || (loss_function == "halfsigmoid" && loss > 0.5)
-      || (loss_function == "log" && loss > log(2.0)))
+  if (better_than_selected)
     instance_weight *= decay_sibling_weight;
 #else
   instance.clear();
@@ -609,10 +653,9 @@ void ProcessPV::processInstance(double turn_coef, MoveData& selected, MoveData&
   errors[thread_id].add(loss);
 }
 
-void ProcessPV::processInstanceProgress(double turn_coef, MoveData& selected, MoveData& sibling, double instance_weight, double progress) const
+void ProcessPV::processInstanceProgress(double turn_coef, MoveData& selected, MoveData& sibling, double instance_weight, double progress_move_number) const
 {
   if (force_progress) {
-    // progress_count[thread_id]->add(sibling.progress);
     sparse_vector_t empty_a;
     double agsum_dummy;
     double progress = ValarrayUtil::dot(sibling.diffs, w, count, min_count);
@@ -650,21 +693,24 @@ void GradientDescentUtil::makeGradient(const valarray_t& w, valarray_t& out, dou
       Hv[i] = 0.0;
     }
     errors[i].clear();
+    aggressive_penalty_moves[i] = 0;
   }
-  boost::ptr_vector<boost::thread> threads;
+  std::vector<std::future<void>> threads;
   for (size_t i=0; i<num_cpus; ++i)
-    threads.push_back(new boost::thread(ProcessPV(i, w, make_hv)));
+    threads.push_back(std::async(std::launch::async, ProcessPV(i, w, make_hv)));
   for (size_t i=0; i<num_cpus; ++i)
-    threads[i].join();
+    threads[i].get();
 
   out.resize(w.size());
   out = 0.0;
   for (size_t i=0; i<num_cpus; ++i) {
     out += gradient[i];
-    if (i)
+    if (i) {
       errors[0].merge(errors[i]);
+      aggressive_penalty_moves[0] += aggressive_penalty_moves[i];
+    }
   }
-  error = errors[0].getAverage();
+  error = errors[0].average();
 }
 
 void GradientDescentUtil::iterationHead(int i, const valarray_t& w, double error)
@@ -756,12 +802,12 @@ void count_all()
     count_by_record[i] = 0.0;
   }
   init_progress_count();
-  boost::ptr_vector<boost::thread> threads;
+  std::vector<std::future<void>> threads;
   for (size_t i=0; i<num_cpus; ++i) {
-    threads.push_back(new boost::thread(ProcessPVCount(i)));
+    threads.push_back(std::async(std::launch::async, ProcessPVCount(i)));
   }
   for (size_t i=0; i<num_cpus; ++i) {
-    threads[i].join();
+    threads[i].get();
     if (i == 0)
       continue;
     frequency[0] += frequency[i];
@@ -802,7 +848,7 @@ static double eta = 1e-9;
 void learn(valarray_t& w)
 {
   valarray_t old_w = w;
-  boost::scoped_ptr<L1BallBase> solver;
+  std::unique_ptr<L1BallBase> solver;
   if (smd)
     solver.reset(new GradientDescentSMD);
   else {
@@ -848,7 +894,7 @@ double sigmoid_alpha()
   return 3.0/my_eval->pawnValue();
 }
 
-boost::tuple<double,double,double> run_cross_validation(int cross_start, int cross_num, int max_progress, bool allow_skip)
+std::tuple<double,double,double> run_cross_validation(int cross_start, int cross_num, int max_progress, bool allow_skip)
 {
   const KisenAnalyzer::OtherConfig config = 
     {
@@ -856,7 +902,7 @@ boost::tuple<double,double,double> run_cross_validation(int cross_start, int cro
       max_progress, position_randomness,
       min_rating, my_eval.get()
     };
-  boost::ptr_vector<boost::thread> threads;
+  std::vector<std::future<void>> threads;
       
   KisenAnalyzer::RecordConfig cross_configs[MaxThreads];
   KisenAnalyzer::distributeJob(num_cpus, &cross_configs[0], cross_start, cross_num,
@@ -864,16 +910,16 @@ boost::tuple<double,double,double> run_cross_validation(int cross_start, int cro
                                csa_filenames);
   for (size_t j=0; j<num_cpus; ++j) {
     cross_configs[j].allow_skip_in_cross_validation = allow_skip;
-    threads.push_back(new boost::thread(Validator(cross_configs[j], config, results+j)));
+    threads.push_back(std::async(std::launch::async, Validator(cross_configs[j], config, results+j)));
   }
   stat::Average werror, toprated, toprated_strict;
   for (size_t j=0; j<num_cpus; ++j) {
-    threads[j].join();
+    threads[j].get();
     werror.merge(results[j].werrors);
     toprated.merge(results[j].toprated);
     toprated_strict.merge(results[j].toprated_strict);
   }
-  return boost::make_tuple(werror.getAverage(), toprated.getAverage(), toprated_strict.getAverage());
+  return std::make_tuple(werror.average(), toprated.average(), toprated_strict.average());
 }
 
 void analyze(const std::string& output_prefix, 
@@ -949,33 +995,33 @@ void analyze(const std::string& output_prefix,
       for (size_t i=my_eval->lambdaStart(); i<my_eval->dimension(); ++i) {
 	if (abs(my_eval->flatValue(i)) > watch_threshold) {
 	  os << " " << std::setw(6) << i << " " << std::setw(3) << my_eval->flatValue(i);
-	  boost::tuple<std::string, int, int> name_index_dim = my_eval->findFeature(i);
-	  os << " " << std::setw(14) <<name_index_dim.get<0>()
-	     << " "  << std::setw(6) << name_index_dim.get<1>()
-	     << " / " << std::setw(6) << name_index_dim.get<2>() << "  ";
-	  os << my_eval->describe(name_index_dim.get<0>(), name_index_dim.get<1>())
+	  std::tuple<std::string, int, int> name_index_dim = my_eval->findFeature(i);
+	  os << " " << std::setw(14) << std::get<0>(name_index_dim)
+	     << " "  << std::setw(6) << std::get<1>(name_index_dim)
+	     << " / " << std::setw(6) << std::get<2>(name_index_dim) << "  ";
+	  os << my_eval->describe(std::get<0>(name_index_dim), std::get<1>(name_index_dim))
 	     << "\n";
 	  watch_list.push_back(i);
 	}
       }
     }
     os << " cross validation " << ctime(&now);
-    boost::tuple<double, double, double> error
+    std::tuple<double, double, double> error
       = run_cross_validation(cross_start, num_records, max_progress, i == 0 || ! rotate_record);
-    os << "\n  mean errors in search " << error.get<0>() 
-       << " top " << error.get<1>()*100.0
-       << "% (" << error.get<2>()*100.0 << "%)" << "\n";
+    os << "\n  mean errors in search " << std::get<0>(error) 
+       << " top " << std::get<1>(error)*100.0
+       << "% (" << std::get<2>(error)*100.0 << "%)" << "\n";
     os.flush();
 
     if (second_cross_start >= 0) {
       assert(! rotate_record);
       time_t now = time(0);
       os << " cross validation (2) " << ctime(&now);
-      boost::tuple<double, double, double> error
+      std::tuple<double, double, double> error
 	= run_cross_validation(second_cross_start, num_records, max_progress, true);
-      os << "\n  mean errors in search " << error.get<0>() 
-	 << " top " << error.get<1>()*100.0
-	 << "% (" << error.get<2>()*100.0 << "%)" << "\n";
+      os << "\n  mean errors in search " << std::get<0>(error) 
+	 << " top " << std::get<1>(error)*100.0
+	 << "% (" << std::get<2>(error)*100.0 << "%)" << "\n";
       os.flush();
     }
 
@@ -985,48 +1031,49 @@ void analyze(const std::string& output_prefix,
     if (i && rotate_record) {
       now = time(0);
       os << " rotate record " << ctime(&now);
-      osl::vector<boost::tuple<int,double> > all;
+      std::vector<std::tuple<int,double> > all;
       for (size_t j=0; j<num_cpus; ++j)
 	all.insert(all.end(), results[j].all_errors.begin(), results[j].all_errors.end());
-      rotate_record->rotate(all, error.get<0>());
+      rotate_record->rotate(all, std::get<0>(error));
     }
 
     now = time(0);
     os << " start search " << ctime(&now);
-    MilliSeconds timer = MilliSeconds::now();
+    time_point timer = clock::now();
     double total_node_count = 0.0, skip_by_rating = 0;
     {
-      double consumed = clock();
+      double consumed = ::clock();
       const KisenAnalyzer::OtherConfig config = 
 	{
 	  search_window, sigmoid_alpha(),
 	  max_progress, (int)(position_randomness+osl::time_seeded_random()),
 	  min_rating, my_eval.get()
 	};
-      boost::ptr_vector<boost::thread> threads;
+      std::vector<std::future<void>> threads;
       KisenAnalyzer::distributeJob(num_cpus, &record_configs[0], kisen_start, num_records,
 				   kisen_filenames, min_rating, csa_filenames);
       for (size_t j=0; j<num_cpus; ++j) {
-	threads.push_back(new boost::thread(PVGenerator(pv_base, 
-							record_configs[j], config, results+j)));
+	threads.push_back(std::async(std::launch::async,
+				     PVGenerator(pv_base, 
+						 record_configs[j], config, results+j)));
       }
       stat::Average werror, toprated, toprated_strict;
       for (size_t j=0; j<num_cpus; ++j) {
-	threads[j].join();
+	threads[j].get();
 	werror.merge(results[j].werrors);
 	toprated.merge(results[j].toprated);
 	toprated_strict.merge(results[j].toprated_strict);
 	total_node_count += results[j].node_count;
 	skip_by_rating += results[j].skip_by_rating;
       }
-      consumed = clock() - consumed;
-      std::cerr << "\n  " << total_node_count << " nodes " << timer.elapsedSeconds() << " sec "
-		<< total_node_count / timer.elapsedSeconds() << " nodes/sec\n";
+      consumed = ::clock() - consumed;
+      std::cerr << "\n  " << total_node_count << " nodes " << elapsedSeconds(timer) << " sec "
+		<< total_node_count / elapsedSeconds(timer) << " nodes/sec\n";
       std::cerr << "  cpu time " << consumed / CLOCKS_PER_SEC 
 		<< "  skip by rating " << skip_by_rating << "\n";
-      os << "\n  mean errors in search (training data) " << werror.getAverage()
-	 << " top " << toprated.getAverage()*100.0
-	 << "% (" << toprated_strict.getAverage()*100.0 << "%)" << "\n";
+      os << "\n  mean errors in search (training data) " << werror.average()
+	 << " top " << toprated.average()*100.0
+	 << "% (" << toprated_strict.average()*100.0 << "%)" << "\n";
       os.flush();
     }
     
@@ -1044,7 +1091,7 @@ void analyze(const std::string& output_prefix,
       for (size_t i=0; i<watch_list.size(); ++i) {
 	const size_t index = watch_list[i];
 	os << "  " << index << " "
-	   << std::setw(14) << my_eval->findFeature(index).get<0>() 
+	   << std::setw(14) << std::get<0>(my_eval->findFeature(index)) 
 	   << " count " << std::setw(5) << count[index]
 	   << " record " << std::setw(5) << count_by_record[0][index] << "\n";
       }
@@ -1071,9 +1118,9 @@ void analyze(const std::string& output_prefix,
     }
     now = time(0);
     os << " start update " << ctime(&now);
-    double consumed = clock();
+    double consumed = ::clock();
     learn(w);
-    consumed = clock() - consumed;
+    consumed = ::clock() - consumed;
     std::cerr << "  cpu time " << consumed / CLOCKS_PER_SEC << "\n";
 
     my_eval->setWeight(&w[0]);
@@ -1091,8 +1138,8 @@ void analyze(const std::string& output_prefix,
 	std::ostringstream ss;
 	ss << output_prefix << eval_type + "-learn-" << i << ".bin";
 	std::ofstream os(ss.str().c_str());
-	osl::vector<int> data(my_eval->dimension());
-	BOOST_FOREACH(int& d, data)
+	std::vector<int> data(my_eval->dimension());
+	for (int& d: data)
 	  fscanf(fp, "%d", &d);
 	fclose(fp);
 	osl::misc::BinaryWriter::write(os, data);
@@ -1104,7 +1151,7 @@ void analyze(const std::string& output_prefix,
       for (size_t i=0; i<watch_list.size(); ++i) {
 	const size_t index = watch_list[i];
 	const bool warn = abs(scaled_w[index]) > abs(old_w[index]);
-	os << " !"[warn] << " " << index << " " << my_eval->findFeature(index).get<0>() 
+	os << " !"[warn] << " " << index << " " << std::get<0>(my_eval->findFeature(index)) 
 	   << " " << old_w[index] << " => " << scaled_w[index] << "\n";
       }
     }
@@ -1113,7 +1160,8 @@ void analyze(const std::string& output_prefix,
     os << "weight change: max " << old_w.max() << " ave. " << old_w.sum()/old_w.size()
        << "\n";
     old_w = scaled_w;
-
+    os << "aggressive moves " << aggressive_penalty_moves[0] << "\n";
+    
     size_t target = PAWN;
     while (target < scaled_w.size() && (scaled_w[target] == 0 || w[target] == 0))
       ++target;
