@@ -12,16 +12,15 @@
 #include "osl/rating/group/captureGroup.h"
 #include "osl/rating/group.h"
 #include "osl/record/kisen.h"
-#include "osl/state/numEffectState.h"
-#include "osl/move_generator/legalMoves.h"
+#include "osl/numEffectState.h"
 #include "osl/misc/milliSeconds.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress/effect5x3.h"
 
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <boost/program_options.hpp>
-#include <boost/thread/thread.hpp>
+#include <memory>
+#include <thread>
 #include <vector>
 #include <algorithm>
 #include <valarray>
@@ -44,7 +43,7 @@ void analyze(const std::string& output_prefix,
 	     int max_progress,
 	     bool high_rating_only);
 
-boost::scoped_ptr<osl::rating::FeatureSet> features;
+std::unique_ptr<osl::rating::FeatureSet> features;
 std::string eval_type, loss_function;
 size_t num_iteration, num_iteration_internal;
 double lambda;
@@ -201,7 +200,7 @@ struct MakeGradient
   MakeGradient(int tid, const valarray_t& iw, bool hv) : thread_id(tid), w(iw), make_hv(hv)
   {
   }
-  static void match(const NumEffectState& state, const RatingEnv& env, Move m, vector<int>& out) 
+  static void match(const NumEffectState& state, const RatingEnv& env, Move m, std::vector<int>& out) 
   {
     out.clear();
     for (size_t g=0; g<features->groupSize(); ++g) {
@@ -214,12 +213,12 @@ struct MakeGradient
   }
   void operator()() const;
   static void
-  makeInstance(const vector<int>& selected, const vector<int>& other, InstanceData& instance)
+  makeInstance(const std::vector<int>& selected, const std::vector<int>& other, InstanceData& instance)
   {
     instance.clear();
     instance.y = -1.0;
-    vector<int>::const_iterator p = other.begin();
-    vector<int>::const_iterator q = selected.begin();
+    auto p = other.begin();
+    auto q = selected.begin();
 
     while (p != other.end() && q != selected.end()) {
       const int index = std::min(*p, *q);
@@ -270,23 +269,23 @@ void MakeGradient::operator()() const
   const size_t last = (thread_id+1 == (int)num_cpus) ? num_records : width*(thread_id+1);
   for (size_t i=width*thread_id; i<last; ++i) {
 
-    if (ipx.getRating(i, BLACK) < min_rating 
-	|| ipx.getRating(i, WHITE) < min_rating) {
+    if (ipx.rating(i, BLACK) < min_rating 
+	|| ipx.rating(i, WHITE) < min_rating) {
       ++skip[thread_id];
       continue;
     }
 
-    NumEffectState state(kisen_file.getInitialState());
-    vector<Move> moves = kisen_file.getMoves(i);
+    NumEffectState state(kisen_file.initialState());
+    std::vector<Move> moves = kisen_file.moves(i);
     rating::RatingEnv env;
     env.make(state);
 
     InstanceData instance;
-    vector<int> best_match, match;
+    std::vector<int> best_match, match;
     for (size_t j=0; j+1<moves.size(); ++j) {
       const Move best_move = moves[j];
       MoveVector all_moves;
-      LegalMoves::generate(state, all_moves);
+      state.generateLegal(all_moves);
       if (! all_moves.isMember(best_move))
 	continue;
       this->match(state, env, best_move, best_match);
@@ -361,9 +360,9 @@ void L1BallLogregUtil::makeGradient(const valarray_t& w, valarray_t& out, double
     errors[i].clear();
   }
 
-  boost::ptr_vector<boost::thread> threads;
+  boost::ptr_vector<std::thread> threads;
   for (size_t i=0; i<num_cpus; ++i)
-    threads.push_back(new boost::thread(MakeGradient(i, w, make_hv)));
+    threads.push_back(new std::thread(MakeGradient(i, w, make_hv)));
   for (size_t i=0; i<num_cpus; ++i)
     threads[i].join();
 
@@ -374,7 +373,7 @@ void L1BallLogregUtil::makeGradient(const valarray_t& w, valarray_t& out, double
     if (i)
       errors[0].merge(errors[i]);
   }
-  error = errors[0].getAverage();
+  error = errors[0].average();
 }
 
 void L1BallLogregUtil::iterationHead(int i, const valarray_t& w, double error)
@@ -444,7 +443,7 @@ void setWeightToFeatures(const valarray_t& w)
 static double eta = 1e-6;
 void learn(valarray_t& w)
 {
-  boost::scoped_ptr<L1BallBase> solver;
+  std::unique_ptr<L1BallBase> solver;
   if (smd)
     solver.reset(new L1BallSMDLogreg);
   else {
@@ -501,14 +500,14 @@ struct Validation
     const int first = cross_start+width*thread_id;
     const size_t last = (thread_id+1 == (int)num_cpus) ? cross_start+num_records : first+width;
     for (size_t i=first; i<last; ++i) {
-      if (ipx.getRating(i, BLACK) < min_rating 
-	  || ipx.getRating(i, WHITE) < min_rating) {
+      if (ipx.rating(i, BLACK) < min_rating 
+	  || ipx.rating(i, WHITE) < min_rating) {
 	++skip[thread_id];
 	continue;
       }
 
-      NumEffectState state(kisen_file.getInitialState());
-      vector<Move> moves = kisen_file.getMoves(i);
+      NumEffectState state(kisen_file.initialState());
+      std::vector<Move> moves = kisen_file.moves(i);
       rating::RatingEnv env;
       env.make(state);
       progress::Effect5x3 progress(state);
@@ -566,11 +565,11 @@ void analyze(const std::string& output_prefix,
     time_t now = time(0);
     os << " cross validation " << ctime(&now);
     {
-      boost::ptr_vector<boost::thread> threads;
+      boost::ptr_vector<std::thread> threads;
       for (size_t i=0; i<num_cpus; ++i) {
 	for (int j=0; j<16; ++j)
 	  top_rated[j][i].clear();
-	threads.push_back(new boost::thread(Validation(i)));
+	threads.push_back(new std::thread(Validation(i)));
       }
       size_t total_skip = 0;
       for (size_t i=0; i<num_cpus; ++i) {
@@ -583,24 +582,24 @@ void analyze(const std::string& output_prefix,
       os << "  skip by rating " << total_skip << "\n";
       os << "progress " << std::setprecision(5);
       for (int j=0; j<16; ++j)
-	os << j << " " << 100.0*top_rated[j][0].getAverage() << "   ";
+	os << j << " " << 100.0*top_rated[j][0].average() << "   ";
       os << "\n";
       for (int j=1; j<16; ++j)
 	top_rated[0][0].merge(top_rated[j][0]);
-      os << "all " << 100.0*top_rated[0][0].getAverage() << "\n";
+      os << "all " << 100.0*top_rated[0][0].average() << "\n";
       os.flush();
     }
     if (i == num_iteration)
       break;
     now = time(0);
     os << " start search " << ctime(&now);
-    MilliSeconds timer = MilliSeconds::now();
+    time_point timer = clock::now();
     
     now = time(0);
     os << " start l1ball " << ctime(&now);
-    double consumed = clock();
+    double consumed = ::clock();
     learn(w);
-    consumed = clock() - consumed;
+    consumed = ::clock() - consumed;
     std::cerr << "  cpu time " << consumed / CLOCKS_PER_SEC << "\n";
     size_t total_skip = 0;
     {
