@@ -12,6 +12,7 @@ using namespace std;
 int main(int argc, char **argv) {
   if (argc <= 1)
     return 1;
+  osl::OslConfig::setUp();
   std::string filename = osl::OslConfig::home()+"/data/progresseval.txt";
   osl::eval::ProgressEval::setUp(filename.c_str());
   gpsshogi::StableProgressEval eval;
@@ -21,11 +22,11 @@ int main(int argc, char **argv) {
   }
   osl::KisenFile kisen_file(argv[1]);
   for (size_t i=0; i<kisen_file.size(); ++i) {
-    osl::NumEffectState state(kisen_file.getInitialState());
-    osl::vector<osl::Move> moves = kisen_file.getMoves(i);
+    osl::NumEffectState state(kisen_file.initialState());
+    std::vector<osl::Move> moves = kisen_file.moves(i);
 
     gpsshogi::MoveData data;
-    BOOST_FOREACH(osl::Move move, moves) {
+    for (osl::Move move: moves) {
       data.clear();
       eval.features(state, data, 0);      
       std::cerr << data.value << ' ' << data.value-data.diffs.back().second
