@@ -5,22 +5,20 @@
 #include "eval/eval.h"
 #include "eval/evalFactory.h"
 #include "osl/record/kisen.h"
-#include "osl/state/numEffectState.h"
-#include "osl/move_generator/legalMoves.h"
+#include "osl/numEffectState.h"
 #include "osl/record/csaRecord.h"
 #include "osl/misc/perfmon.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress.h"
 #include "osl/rating/featureSet.h"
 #include <boost/program_options.hpp>
-#include <boost/scoped_ptr.hpp>
-#include <boost/foreach.hpp>
+#include <memory>
 #include <iostream>
 
 namespace po = boost::program_options;
 using namespace osl;
 using namespace gpsshogi;
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
+std::unique_ptr<gpsshogi::Eval> my_eval;
 std::string eval_type, kisen_filename, csa_filename, eval_data;
 size_t record_id, position_id, move_id, full_width_depth, quiesce_depth, quiesce_window;
 bool all_move, quiet;
@@ -84,6 +82,7 @@ int main(int argc, char **argv)
     return 0;
   }
 
+  OslConfig::setUp();
   if (!osl::eval::ml::OpenMidEndingEval::setUp()) {
     std::cerr << "OpenMidEndingEval set up failed";
     // fall through as this might not be fatal depending on eval type used
@@ -107,8 +106,8 @@ int main(int argc, char **argv)
 
   if (csa_filename != "") {
     CsaFile file(csa_filename);
-    const vector<osl::Move> moves = file.getRecord().getMoves();
-    NumEffectState state(file.getInitialState());
+    const auto moves = file.moves();
+    NumEffectState state(file.initialState());
     PVVector pv;
     std::cerr << state << "\n";
     int value;
@@ -128,8 +127,8 @@ int main(int argc, char **argv)
   }
 
   KisenFile kisen_file(kisen_filename.c_str());
-  NumEffectState state(kisen_file.getInitialState());
-  const vector<Move> moves=kisen_file.getMoves(record_id);
+  NumEffectState state(kisen_file.initialState());
+  const std::vector<Move> moves=kisen_file.moves(record_id);
   if (position_id >= moves.size()) {
     std::cerr << "position_id too large " << position_id << " " << moves.size() << "\n";
     return 1;
@@ -153,7 +152,7 @@ void run(const NumEffectState& state, Move best_move)
   size_t consumed = 0;
   PVVector pv;
   MoveVector moves;
-  LegalMoves::generate(state, moves);
+  state.generateLegal(moves);
 
   std::cerr << state << best_move << "\n";
   int best_value;
@@ -166,8 +165,8 @@ void run(const NumEffectState& state, Move best_move)
   }
   if (! quiet) {
     std::cerr << "best value " << best_value;
-    BOOST_FOREACH(Move move, pv)
-      std::cerr << " " << record::csa::show(move);
+    for (Move move: pv)
+      std::cerr << " " << csa::show(move);
     std::cerr << "\n";
   }
 
@@ -190,8 +189,8 @@ void run(const NumEffectState& state, Move best_move)
     consumed += clock.stop();
     if (! quiet) {
       std::cerr << value;
-      BOOST_FOREACH(Move move, pv)
-	std::cerr << " " << record::csa::show(move);
+      for (Move move: pv)
+	std::cerr << " " << csa::show(move);
       std::cerr << "\n";
     }
   }
