@@ -9,14 +9,14 @@
 #include "pvFile.h"
 #include "pvGenerator.h"
 #include "osl/record/kisen.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/misc/milliSeconds.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress.h"
 
-#include <boost/thread/thread.hpp>
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <boost/program_options.hpp>
+#include <thread>
 #include <iostream>
 #include <algorithm>
 #include <utility>
@@ -29,9 +29,9 @@ typedef std::valarray<double> valarray_t;
 const int MaxThreads = 64;
 std::string output_file;
 std::string kisen_filename;
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
-vector<int> feature_count[MaxThreads];
-vector<std::pair<double,vector<double> > > record_rate;
+std::unique_ptr<gpsshogi::Eval> my_eval;
+std::vector<int> feature_count[MaxThreads];
+std::vector<std::pair<double,std::vector<double> > > record_rate;
 size_t num_cpus;
 int max_record;
 int Q;
@@ -51,7 +51,7 @@ public:
 
 class PVCount : public PVRun
 {
-  vector<char> found;
+  std::vector<char> found;
 public:
   PVCount(int tid) : PVRun(tid), found(my_eval->dimension())
   {
@@ -76,13 +76,13 @@ public:
 
 class PVRate : public PVRun
 {
-  vector<int> found;
+  std::vector<int> found;
 public:
   PVRate(int tid) : PVRun(tid), found(my_eval->dimension())
   {
     std::fill(found.begin(), found.end(), 0);
   }
-  static double maxRate(vector<int>& found)
+  static double maxRate(std::vector<int>& found)
   {
     double rate = 0.0;
     for (size_t i=0; i<found.size(); ++i) {
@@ -92,7 +92,7 @@ public:
     }
     return rate;
   }
-  static std::pair<double,vector<double> > quantile(vector<int>& found)
+  static std::pair<double,std::vector<double> > quantile(std::vector<int>& found)
   {
     int count = 0;
     for (size_t i=0; i<found.size(); ++i)
@@ -103,9 +103,9 @@ public:
       }
     assert(count);
     std::sort(found.begin(), found.end(), std::greater<int>());
-    vector<int>::iterator p = std::lower_bound(found.begin(), found.end(), 0, std::greater<int>());
+    auto p = std::lower_bound(found.begin(), found.end(), 0, std::greater<int>());
     const size_t s = p - found.begin();
-    vector<double> array(Q);
+    std::vector<double> array(Q);
     if (s == 0)
       return std::make_pair(0.0, array);
     for (int i=0; i<std::min(Q/2,8); ++i)
@@ -136,23 +136,23 @@ void run(const char *filename, PVRun *run)
   int num_records = 0;
 
   KisenFile kisen_file(kisen_filename);
-  NumEffectState state(kisen_file.getInitialState());
-  vector<Move> moves;
+  NumEffectState state(kisen_file.initialState());
+  std::vector<Move> moves;
 
   while (pr.newPosition(record, position)) {
     if (record != cur_record) {
       if (cur_record >= 0)
 	run->finishRecord(cur_record);
       cur_record = record;
-      moves = kisen_file.getMoves(cur_record);
+      moves = kisen_file.moves(cur_record);
       max_record = std::max(max_record, record);
       if ((++num_records) % 50 == 0)
 	std::cerr << '.';
-      state = NumEffectState(kisen_file.getInitialState());
+      state = NumEffectState(kisen_file.initialState());
     }
     if (position == 0) {
       cur_position = 0;
-      state = NumEffectState(kisen_file.getInitialState());
+      state = NumEffectState(kisen_file.initialState());
     } else {
       assert(position > cur_position);
       while (position > cur_position) {
@@ -258,6 +258,8 @@ int main(int argc, char **argv)
     std::cerr << options << std::endl;
     return 0;
   }
+
+  OslConfig::setUp();
   if (!osl::eval::ml::OpenMidEndingEval::setUp()) {
     std::cerr << "OpenMidEndingEval set up failed";
     // fall through as this might not be fatal depending on eval type used
@@ -273,10 +275,10 @@ int main(int argc, char **argv)
   {
     size_t counted = 0;
     while (counted < filenames.size()) {
-      boost::ptr_vector<boost::thread> threads;
+      boost::ptr_vector<std::thread> threads;
       const size_t split = std::min(num_cpus, filenames.size()-counted);
       for (size_t i=0; i<split; ++i)
-	threads.push_back(new boost::thread(CountRun(i, filenames[counted+i].c_str())));
+	threads.push_back(new std::thread(CountRun(i, filenames[counted+i].c_str())));
       counted += split;
       for (size_t i=0; i<split; ++i)
 	threads[i].join();
@@ -291,18 +293,18 @@ int main(int argc, char **argv)
   {
     size_t rated = 0;
     while (rated < filenames.size()) {
-      boost::ptr_vector<boost::thread> threads;
+      boost::ptr_vector<std::thread> threads;
       const size_t split = std::min(num_cpus, filenames.size()-rated);
       for (size_t i=0; i<split; ++i)
-	threads.push_back(new boost::thread(RateRun(i, filenames[rated+i].c_str())));
+	threads.push_back(new std::thread(RateRun(i, filenames[rated+i].c_str())));
       rated += split;
       for (size_t i=0; i<split; ++i)
 	threads[i].join();
     }
   }
   std::cerr << "\nrecord\n";
-  typedef std::pair<std::pair<double,vector<double> >, int> rate_id_t;
-  vector<rate_id_t> rate_id(record_rate.size());
+  typedef std::pair<std::pair<double,std::vector<double> >, int> rate_id_t;
+  std::vector<rate_id_t> rate_id(record_rate.size());
   for (size_t i=0; i<record_rate.size(); ++i)
     rate_id[i] = std::make_pair(record_rate[i], i);
   std::sort(rate_id.begin(), rate_id.end(), std::greater<rate_id_t>());
@@ -321,14 +323,14 @@ int main(int argc, char **argv)
   }
 
   std::ofstream os(output_file.c_str());
-  record::OKisenStream okisen(os);
+  KisenWriter okisen(os);
 
   KisenFile kisen_file(kisen_filename);
-  NumEffectState state(kisen_file.getInitialState());
+  NumEffectState state(kisen_file.initialState());
   for (size_t i=0; i<rate_id.size(); ++i) {
     const int index = rate_id[i].second;
-    vector<Move> moves = kisen_file.getMoves(index);
-    okisen.save(state, moves);
+    std::vector<Move> moves = kisen_file.moves(index);
+    okisen.save(RecordMinimal{state, moves});
   }
 }
 
