@@ -5,16 +5,17 @@
 #include "eval/progress.h"
 #include "osl/record/csaRecord.h"
 #include "osl/eval/progressEval.h"
-#include "osl/progress/ml/newProgress.h"
-#include <boost/scoped_ptr.hpp>
+#include "osl/progress.h"
+#include "osl/oslConfig.h"
 #include <boost/program_options.hpp>
+#include <memory>
 #include <iostream>
 
 namespace po = boost::program_options;
 using namespace osl;
 using namespace gpsshogi;
 
-boost::scoped_ptr<gpsshogi::Eval> my_eval;
+std::unique_ptr<gpsshogi::Eval> my_eval;
 std::string eval_type, filename, csa_filename;
 
 int main(int argc, char *argv[])
@@ -52,6 +53,7 @@ int main(int argc, char *argv[])
     return 0;
   }
 
+  OslConfig::setUp();
   osl::progress::ml::NewProgress::setUp();
   my_eval.reset(gpsshogi::EvalFactory::newEval(eval_type));
   if (my_eval == NULL) {
@@ -67,10 +69,10 @@ int main(int argc, char *argv[])
   {
     osl::eval::ProgressEval::setUp();
 
-    CsaFile file(csa_filename);
-    NumEffectState state(file.getInitialState());
-    Record r = file.getRecord();
-    const osl::vector<osl::Move> moves=r.getMoves();
+    CsaFileMinimal file(csa_filename);
+    NumEffectState state(file.initialState());
+    auto r = file.load();
+    const auto moves=r.moves;
     for (size_t i=0; i<moves.size(); ++i) {
       std::cerr << state;
       osl::eval::ProgressEval peval(state);
