@@ -6,12 +6,10 @@
 #include "eval/ptypeAttacked.h"
 #include "osl/eval/pieceEval.h"
 #include "osl/eval/progressEval.h"
-#include "osl/misc/fixedCapacityVector.h"
-#include "osl/stl/stack.h"
-#include <boost/lexical_cast.hpp>
 #include <fstream>
 #include <iostream>
 #include <iomanip>
+#include <stack>
 
 gpsshogi::
 EvalValueStack::~EvalValueStack()
@@ -84,10 +82,10 @@ Eval::describeAll(const std::string& feature) const
   return "Eval::describeAll not implemented";
 }
 
-boost::tuple<std::string, int, int> 
+std::tuple<std::string, int, int> 
 gpsshogi::Eval::findFeature(size_t /*index*/) const
 {
-  return boost::make_tuple("not_imlemented", 0, 0);
+  return std::make_tuple("not_imlemented", 0, 0);
 }
 
 void gpsshogi::Eval::features(const NumEffectState& state, MoveData& out) const
@@ -118,7 +116,7 @@ PieceEval::~PieceEval()
 
 struct IntValueStack : public gpsshogi::EvalValueStack
 {
-  osl::stack<int> values;
+  std::stack<int> values;
   void pop() { assert(! values.empty()); values.pop(); }
   int value() const { assert(! values.empty()); return values.top(); }
 };
@@ -176,7 +174,7 @@ PieceEval::load(const char *filename)
   std::ifstream is(filename);
   for (size_t i=0; i<dimension(); ++i)
     is >> values[i];
-  return is;
+  return static_cast<bool>(is);
 }
 
 void gpsshogi::
@@ -263,7 +261,7 @@ EvalComponent::evalWithUpdate(const NumEffectState& state, Move, int) const
 
 void gpsshogi::
 EvalComponent::features(const NumEffectState& state, double& value,
-			vector<std::pair<int, double> >& out, int offset) const
+			std::vector<std::pair<int, double> >& out, int offset) const
 {
   index_list_t values;
   featuresNonUniq(state, values, offset);
@@ -275,7 +273,7 @@ EvalComponent::features(const NumEffectState& state, double& value,
 
 void gpsshogi::
 EvalComponent::convert(const index_list_t& values, double& value,
-		       vector<std::pair<int, double> >& out, int offset) const
+		       std::vector<std::pair<int, double> >& out, int offset) const
 {
   value = 0;
   for (size_t i=0; i<values.size(); ++i) {
@@ -287,7 +285,7 @@ EvalComponent::convert(const index_list_t& values, double& value,
 void gpsshogi::
 EvalComponent::showSummary(std::ostream& os) const
 {
-  size_t count = 0, sum = 0;
+  size_t count = value(0)>0, sum = std::abs(value(0));
   int minw=value(0), maxw=value(0);
   for (size_t i=1; i<dimension(); ++i)
   {
@@ -474,7 +472,7 @@ class gpsshogi::RichEval::Stack : public EvalValueStack
     CArray<int,OthersLimit> others;
     Entry() : sum(0) {}
   };
-  osl::stack<Entry> values;
+  std::stack<Entry> values;
 public:  
   Stack(RichEval *ev, const NumEffectState& state) : eval(ev) { 
     assert((int)eval->others.size() <= OthersLimit);
@@ -533,7 +531,7 @@ RichEval::load(const char *filename)
   for (size_t i=0; i<dimension(); ++i)
     is >> values[i];
   setWeight(&values[0]);
-  return is;
+  return static_cast<bool>(is);
 }
 
 void gpsshogi::
@@ -727,7 +725,7 @@ const std::string gpsshogi::
 EvalComponentStages::describe(size_t local_index) const
 {
   return delegate->describe(local_index % one_dim) + " stage "
-    + boost::lexical_cast<std::string>(local_index/one_dim);
+    + std::to_string(local_index/one_dim);
 }
 
 
