@@ -5,15 +5,14 @@
 
 #include "moveData.h"
 #include "eval/indexCache.h"
-#include "osl/state/numEffectState.h"
-#include "osl/eval/ml/weights.h"
-#include "osl/progress/progress16.h"
-#include "osl/misc/random.h"
-#include "osl/stl/vector.h"
+#include "osl/numEffectState.h"
+#include "osl/eval/weights.h"
+#include "osl/progress.h"
+#include "osl/random.h"
 #include <boost/scoped_array.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/tuple/tuple.hpp>
+#include <tuple>
+#include <memory>
 #include <utility>
 #include <iosfwd>
 
@@ -63,7 +62,7 @@ namespace gpsshogi
     virtual int flatValue(size_t index) const=0;
     virtual const std::string describe(const std::string& feature, size_t local_index) const;
     virtual const std::string describeAll(const std::string& feature) const;
-    virtual boost::tuple<std::string, int, int> findFeature(size_t index) const;
+    virtual std::tuple<std::string, int, int> findFeature(size_t index) const;
     virtual size_t dimension() const=0;
     virtual size_t maxActive() const;
 
@@ -135,10 +134,10 @@ namespace gpsshogi
     virtual int evalWithUpdate(const NumEffectState& state, Move moved, int last_value) const;
     virtual const std::string name() const=0;
     void features(const NumEffectState&, double& value,
-			  vector<std::pair<int, double> >&, int offset) const;
+		  std::vector<std::pair<int, double> >&, int offset) const;
     virtual void featuresNonUniq(const NumEffectState& state, index_list_t&, int offset) const = 0;
     void convert(const index_list_t&, double& value,
-		 vector<std::pair<int, double> >&, int offset) const;
+		 std::vector<std::pair<int, double> >&, int offset) const;
     void showSummary(std::ostream&) const;
     virtual const std::string describe(size_t local_index) const;
   };
@@ -197,7 +196,7 @@ namespace gpsshogi
   class EvalComponentStages
   {
   protected:
-    boost::scoped_ptr<FeaturesOneNonUniq> delegate;
+    std::unique_ptr<FeaturesOneNonUniq> delegate;
     MultiWeights weight;
     size_t one_dim;
   public:
@@ -278,7 +277,7 @@ namespace gpsshogi
   public:
     void featuresMulti(const NumEffectState &state,
 		       MultiInt& value,
-		       vector<std::pair<int, double> > &diffs,
+		       std::vector<std::pair<int, double> > &diffs,
 		       int offset,
 		       int progress, int progress_max) const
     {
