@@ -5,7 +5,7 @@
 #include "eval/progressFeature.h"
 #include "eval/openMidEnding.h"
 #include "eval/progressEval.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 
 gpsshogi::Eval *
 gpsshogi::EvalFactory::newEval(const std::string &name)
