@@ -3,8 +3,8 @@
 #ifndef GPSSHOGI_INDEXCACHE_H
 #define GPSSHOGI_INDEXCACHE_H
 
-#include "osl/stl/vector.h"
-#include "osl/misc/fixedCapacityVector.h"
+#include "osl/container.h"
+#include <vector>
 #include <algorithm>
 
 #define L1BALL_NO_SORT
@@ -19,7 +19,7 @@ namespace gpsshogi
     {
       indices.push_back(std::make_pair(index, coef));
     }
-    void output(osl::vector<std::pair<int, double> >& out,
+    void output(std::vector<std::pair<int, double> >& out,
 		size_t offset);
   };    
 
@@ -44,7 +44,7 @@ namespace gpsshogi
 
 template <size_t Capacity>
 void gpsshogi::
-IndexCache<Capacity>::output(osl::vector<std::pair<int, double> >& out,
+IndexCache<Capacity>::output(std::vector<std::pair<int, double> >& out,
 			     size_t offset)
 {
   for (size_t i=0; i < indices.size(); ++i)
