@@ -82,13 +82,13 @@ namespace gpsshogi
   public:
     PieceKingRelativeBase(int dim, bool attack=true)
       : EvalComponent(dim), is_attack(attack) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    int evalWithUpdate(const osl::state::NumEffectState &state,
+    int eval(const osl::NumEffectState &state) const;
+    int evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, int last_value) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
-    int pieceValue(const osl::state::NumEffectState &state,
+    int pieceValue(const osl::NumEffectState &state,
 		   const osl::Piece piece) const;
     int pieceValue(const osl::Square king,const osl::Piece piece) const;
     size_t maxActive() const { return 38; }
@@ -129,10 +129,10 @@ namespace gpsshogi
   public:
     PieceKingRelativeAbsBase(bool attack=true)
       :  EvalComponent(DIM), is_attack(attack) {}
-    int eval(const osl::state::NumEffectState &state) const;
-    int evalWithUpdate(const osl::state::NumEffectState &state,
+    int eval(const osl::NumEffectState &state) const;
+    int evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, int last_value) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     virtual const std::string name() const { return "PieceKingRelativeAbsBase"; }
@@ -182,10 +182,10 @@ namespace gpsshogi
   public:
     PieceKingRelativeAbs(bool attack=true)
       :  EvalComponent(DIM), is_attack(attack) {}
-    int eval(const osl::state::NumEffectState &state) const;
-    int evalWithUpdate(const osl::state::NumEffectState &state,
+    int eval(const osl::NumEffectState &state) const;
+    int evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, int last_value) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     virtual const std::string name() const {
@@ -203,17 +203,17 @@ namespace gpsshogi
 	      const osl::Ptype ptype) const;
     int index(const osl::Ptype ptype,
 	      int distanceIndex) const;
-    int pieceValue(const osl::state::NumEffectState &state,
+    int pieceValue(const osl::NumEffectState &state,
 		   const osl::Piece piece) const;
     bool is_attack;
   public:
     SimpleAttackKing(bool attack=true) : EvalComponent(
       (osl::PTYPE_MAX - osl::PTYPE_PIECE_MIN + 1) * (8 - 1 + 1)),
 					 is_attack(attack) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    int evalWithUpdate(const osl::state::NumEffectState &state,
+    int eval(const osl::NumEffectState &state) const;
+    int evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, int last_value) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os) const;
@@ -233,8 +233,8 @@ namespace gpsshogi
       MORE_EFFECT_KING_ONLY
     };
     King8EffectBase(int dim) : EvalComponent(dim) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     virtual void showSummary(std::ostream &os) const = 0;
@@ -401,12 +401,12 @@ namespace gpsshogi
   struct King25EffectCommon
   {
     static void countEffectAndPieces(bool is_attack,
-				     const osl::state::NumEffectState &state,
+				     const osl::NumEffectState &state,
 				     const osl::Player attack,
 				     int &effect,
 				     int &piece);
     static int index(int effect, int piece_count);
-    static void featuresNonUniq(bool is_attack, const osl::state::NumEffectState &state, 
+    static void featuresNonUniq(bool is_attack, const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset);
   };
@@ -414,8 +414,8 @@ namespace gpsshogi
   {
   public:
     King25EffectAttack() : EvalComponent(17 * 128) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     size_t maxActive() const { return 2; }
@@ -428,9 +428,9 @@ namespace gpsshogi
   {
   public:
     King25EffectDefense() : EvalComponentMulti(17 * 128) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     size_t maxActiveOne() const { return 2; }
@@ -441,13 +441,13 @@ namespace gpsshogi
   struct King25EffectYCommon
   {
     static void countEffectAndPieces(bool is_attack,
-				     const osl::state::NumEffectState &state,
+				     const osl::NumEffectState &state,
 				     const osl::Player attack,
 				     int &effect,
 				     int &piece,
 				     int & king_y);
     static int index(int king_y, int effect, int piece_count);
-    static void featuresNonUniq(bool is_attack, const osl::state::NumEffectState &state, 
+    static void featuresNonUniq(bool is_attack, const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset);
   };
@@ -455,8 +455,8 @@ namespace gpsshogi
   {
   public:
     King25EffectYAttack() : EvalComponent(17 * 128 * 9) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     size_t maxActive() const { return 2; }
@@ -467,9 +467,9 @@ namespace gpsshogi
   {
   public:
     King25EffectYDefense() : EvalComponentMulti(17 * 128 * 9) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     size_t maxActiveOne() const { return 2; }
@@ -482,7 +482,7 @@ namespace gpsshogi
   class King25EffectXY : public EvalComponent
   {
   private:
-    void countEffectAndPieces(const osl::state::NumEffectState &state,
+    void countEffectAndPieces(const osl::NumEffectState &state,
 			      const osl::Player attack,
 			      int &effect,
 			      int &piece,
@@ -499,8 +499,8 @@ namespace gpsshogi
   public:
     King25EffectXY(bool attack=true) : EvalComponent(DIM_X + DIM_Y),
 				       is_attack(attack) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     size_t maxActive() const { return 4; }
@@ -525,7 +525,7 @@ namespace gpsshogi
 			    IndexCacheI<MaxActiveWithDuplication> &) const;
     const std::string name() const { return "King25Effect2"; };
     static void countEffectAndPieces(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       const osl::Player attack,
       int &effect,
       int &piece,
@@ -586,7 +586,7 @@ namespace gpsshogi
 			    IndexCacheI<MaxActiveWithDuplication> &) const;
     const std::string name() const { return "King25EffectSupported"; };
     static void countEffectAndPieces(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       const osl::Player attack,
       int &piece,
       int &supported,
@@ -646,8 +646,8 @@ namespace gpsshogi
 			  const Player defense) const;
   public:
     King25Empty() : EvalComponent(DIM) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os) const;
@@ -673,17 +673,17 @@ namespace gpsshogi
 	      Square target,
 	      Player player) const;
     template <Player Defense>
-    int evalOne(const osl::state::NumEffectState &state) const;
+    int evalOne(const osl::NumEffectState &state) const;
     template <Player Defense>
-    void oneFeature(const osl::state::NumEffectState &state,
+    void oneFeature(const osl::NumEffectState &state,
 		   CArray<int, DIM> &features) const;
   public:
     King25EmptyAbs() : EvalComponent(DIM) { }
     int evalWithUpdate(
       const NumEffectState &state, osl::Move moved,
       int last_value) const;
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     const std::string name() const { return "King25EmptyAbs"; }
@@ -710,9 +710,9 @@ namespace gpsshogi
     static int index(const NumEffectState &state, Square target,
 	      Player defense);
     template <osl::Player Defense, typename Integer, class Weights>
-    static Integer evalOne(const osl::state::NumEffectState &state, Integer initial, const Weights&);
+    static Integer evalOne(const osl::NumEffectState &state, Integer initial, const Weights&);
     template <osl::Player Defense>
-    void featureOne(const osl::state::NumEffectState &state,
+    void featureOne(const osl::NumEffectState &state,
 		    CArray<int, DIM> &feature_count) const;
   public:
     King25EffectEach() : EvalComponentMulti(DIM) { }
@@ -720,7 +720,7 @@ namespace gpsshogi
       CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState& state, Move moved, MultiInt last_value, const MultiWeights& w,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     static EffectState effectState(const NumEffectState &state,
@@ -759,7 +759,7 @@ namespace gpsshogi
       return val;
     }
     template <osl::Player Defense>
-    static void featureOne(const osl::state::NumEffectState &state,
+    static void featureOne(const osl::NumEffectState &state,
 			   IndexCacheI<MaxActiveWithDuplication> &features);
   public:
     King25EffectEachYFeatures() : FeaturesOneNonUniq(DIM) { }
@@ -827,7 +827,7 @@ namespace gpsshogi
       return val;
     }
     template <osl::Player Defense>
-    static void featureOne(const osl::state::NumEffectState &state,
+    static void featureOne(const osl::NumEffectState &state,
 			   IndexCacheI<MaxActiveWithDuplication> &features);
   public:
     King25EffectEachXFeatures() : FeaturesOneNonUniq(DIM) { }
@@ -898,7 +898,7 @@ namespace gpsshogi
     size_t maxActive() const { return 5*5*2; }
     const std::string name() const { return "King25EffectEachXY"; }
     template <osl::Player Defense>
-    static void featureOne(const osl::state::NumEffectState &state,
+    static void featureOne(const osl::NumEffectState &state,
 			   IndexCacheI<MaxActiveWithDuplication> &features);
   };
 
@@ -925,9 +925,9 @@ namespace gpsshogi
 			  int diff);
   public:
     KingXBlocked(int dim=10) : EvalComponentMulti(dim) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     const std::string name() const { return "KingXBlocked"; }
@@ -1032,9 +1032,9 @@ namespace gpsshogi
 		    CArray<int, DIM> &features) const;
   public:
     AnagumaEmpty() : EvalComponentMulti(DIM) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -1384,7 +1384,7 @@ namespace gpsshogi
       {
 	const int y = king.y() + y_diff;
 	if (x < 1 || x > 9 || y < 1 || y > 9 ||
-	    state.hasEffectAt<PlayerTraits<Defense>::opponent>(Square(x, y)))
+	    state.hasEffectAt<alt(Defense)>(Square(x, y)))
 	{
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1447,7 +1447,7 @@ namespace gpsshogi
       {
 	const int y = king.y() + y_diff;
 	if (x < 1 || x > 9 || y < 1 || y > 9 ||
-	    state.hasEffectAt<PlayerTraits<Defense>::opponent>(Square(x, y)))
+	    state.hasEffectAt<alt(Defense)>(Square(x, y)))
 	{
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1523,7 +1523,7 @@ namespace gpsshogi
       {
 	const int y = king.y() + y_diff;
 	if (x < 1 || x > 9 || y < 1 || y > 9 ||
-	    state.hasEffectAt<PlayerTraits<Defense>::opponent>(Square(x, y)))
+	    state.hasEffectAt<alt(Defense)>(Square(x, y)))
 	{
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1625,7 +1625,7 @@ namespace gpsshogi
 	{
 	  const Square pos(x, y);
 	  const Piece piece = state.pieceAt(pos);
-	  if (!state.hasEffectAt<PlayerTraits<Defense>::opponent>(pos) &&
+	  if (!state.hasEffectAt<alt(Defense)>(pos) &&
 	      (piece.isEmpty() || piece.owner() != Defense))
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1690,7 +1690,7 @@ namespace gpsshogi
 	{
 	  const Square pos(x, y);
 	  const Piece piece = state.pieceAt(pos);
-	  if (!state.hasEffectAt<PlayerTraits<Defense>::opponent>(pos) &&
+	  if (!state.hasEffectAt<alt(Defense)>(pos) &&
 	      (piece.isEmpty() || piece.owner() != Defense))
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1763,7 +1763,7 @@ namespace gpsshogi
 	{
 	  const Square pos(x, y);
 	  const Piece piece = state.pieceAt(pos);
-	  if (!state.hasEffectAt<PlayerTraits<Defense>::opponent>(pos) &&
+	  if (!state.hasEffectAt<alt(Defense)>(pos) &&
 	      (piece.isEmpty() || piece.owner() != Defense))
 	  result |= (1 << (Defense == BLACK ? y_diff + 2 : -y_diff + 2));
 	}
@@ -1815,14 +1815,14 @@ namespace gpsshogi
     const std::string name() const { return "King25Effect3"; };
     template <Player Attack>
     static void countPieces(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       int &piece_count,
       bool &with_knight,
       int &stand_count,
       bool &stand_with_knight,
       int &attacked_count)
     {
-      const Player Defense = PlayerTraits<Attack>::opponent;
+      const Player Defense = alt(Attack);
       const Square king = state.kingSquare<Defense>();
       const int min_x = std::max(1, king.x() - 2);
       const int max_x = std::min(9, king.x() + 2);
@@ -1890,14 +1890,14 @@ namespace gpsshogi
     const std::string name() const { return "King25Effect3Y"; };
     template <Player Attack>
     static void countPieces(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       int &piece_count,
       bool &with_knight,
       int &stand_count,
       bool &stand_with_knight,
       int &attacked_count)
     {
-      const Player Defense = PlayerTraits<Attack>::opponent;
+      const Player Defense = alt(Attack);
       const Square king = state.kingSquare<Defense>();
       const int min_x = std::max(1, king.x() - 2);
       const int max_x = std::min(9, king.x() + 2);
@@ -1959,11 +1959,11 @@ namespace gpsshogi
     const std::string name() const { return "King25EffectCountCombination"; };
     template <Player Attack>
     static void countPieces(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       int &attack_count,
       int &defense_count)
     {
-      const Player Defense = PlayerTraits<Attack>::opponent;
+      const Player Defense = alt(Attack);
       const Square king = state.kingSquare<Defense>();
       const int min_x = std::max(1, king.x() - 2);
       const int max_x = std::min(9, king.x() + 2);
