@@ -1,8 +1,7 @@
 #include "eval/majorPiece.h"
 #include "eval/indexCache.h"
 #include "osl/mobility/rookMobility.h"
-#include "osl/record/csa.h"
-#include <boost/foreach.hpp>
+#include "osl/csa.h"
 #include <algorithm>
 
 template <osl::Ptype MajorPiece>
@@ -28,7 +27,7 @@ int gpsshogi::MajorPieceYBase<MajorPiece>::eval(const NumEffectState &state) con
 
 template <osl::Ptype MajorPiece>
 void gpsshogi::
-MajorPieceYBase<MajorPiece>::featuresNonUniq(const osl::state::NumEffectState &state, 
+MajorPieceYBase<MajorPiece>::featuresNonUniq(const osl::NumEffectState &state, 
 		    index_list_t &diffs,
 		    int offset) const
 {
@@ -90,7 +89,7 @@ int gpsshogi::RookPawn::eval(const NumEffectState &state) const
 }
 
 void gpsshogi::RookPawn::featuresNonUniq(
-  const osl::state::NumEffectState &state,
+  const osl::NumEffectState &state,
   index_list_t &diffs,
   int offset) const
 {
@@ -251,7 +250,7 @@ osl::MultiInt gpsshogi::AllMajor::eval(const NumEffectState &state, const MultiW
 }
 
 void gpsshogi::AllMajor::featuresNonUniq(
-  const osl::state::NumEffectState &state,
+  const osl::NumEffectState &state,
   index_list_t &diffs,
   int offset) const
 {
@@ -322,7 +321,7 @@ osl::MultiInt gpsshogi::RookEffect::evalOne(const NumEffectState &state,
 
 osl::MultiInt gpsshogi::RookEffect::
 evalOnePiece(int piece_number, 
-	     const osl::state::NumEffectState &state, const MultiWeights& weights) const
+	     const osl::NumEffectState &state, const MultiWeights& weights) const
 {
   MultiInt value;
   const Piece p = state.pieceOf(piece_number);
@@ -706,7 +705,7 @@ const std::string gpsshogi::
 MajorEffectPieceFeatures<MajorPiece>::describe(size_t local_index) const
 {
   PtypeO ptypeO = static_cast<PtypeO>(local_index+PTYPEO_MIN);
-  return record::csa::show(getOwner(ptypeO))+record::csa::show(getPtype(ptypeO));
+  return csa::show(getOwner(ptypeO))+csa::show(getPtype(ptypeO));
 }
 
 template <osl::Ptype MajorPiece>
@@ -1598,11 +1597,11 @@ MajorCheckWithCapture::addOne(
     if (state.hasLongEffectAt<ROOK>(alt(owner), sq)
 	&& state.hasEffectIf(newPtypeO(BLACK,ROOK), sq, king))
       features.add(index(p.ptype(), true, sq.canPromote(alt(owner))),
-		   playerToMul(owner));
+		   sign(owner));
     if (state.hasLongEffectAt<BISHOP>(alt(owner), sq)
 	&& state.hasEffectIf(newPtypeO(BLACK,BISHOP), sq, king))
       features.add(index(p.ptype(), false, sq.canPromote(alt(owner))),
-		   playerToMul(owner));
+		   sign(owner));
   }
 }
 
@@ -1790,7 +1789,7 @@ AttackMajorsInBase::featuresOneNonUniq(
 	}};
     const bool has_gold = state.hasPieceOnStand(alt(P), GOLD);
     const bool rook_support = state.hasEffectAt(P, sq);
-    BOOST_FOREACH(pair_t pair, bishop_attack) {
+    for (pair_t pair: bishop_attack) {
       const Square attack_square = pair.second;
       if (! state[attack_square].isEmpty()
 	  || state.countEffect(P, attack_square) > 1)
@@ -1807,8 +1806,8 @@ AttackMajorsInBase::featuresOneNonUniq(
 			 state.findCheapAttack(alt(P), attack_square).ptype(),
 			 has_gold, rook_support,
 			 state.hasEffectNotBy(P, rook, bishop_square)),
-		   playerToMul(P));
-      features.add(0, playerToMul(P));
+		   sign(P));
+      features.add(0, sign(P));
     }
   }
 }
