@@ -16,8 +16,8 @@ namespace gpsshogi
     virtual bool isTarget(Piece piece) const = 0;
   public:
     MajorPieceYBase() : EvalComponent(9) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showAll(std::ostream &os) const;
@@ -62,8 +62,8 @@ namespace gpsshogi
     // different value for rook and prook?
     // how about pawn under rook?
     RookPawn() : EvalComponent(1) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os) const;
@@ -103,9 +103,9 @@ namespace gpsshogi
   {
   public:
     AllMajor() : EvalComponentMulti(1) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights&,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights&,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -129,12 +129,12 @@ namespace gpsshogi
   public:
     RookEffect(bool attack=true)
       : EvalComponentMulti(612), is_attack(attack) { } // 2 * 2 * 9 * 17
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& w,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& w,
 		  CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState &state, Move,
 			    MultiInt last_value, const MultiWeights& w,
 			    CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showAll(std::ostream &os, const MultiWeights&) const;
@@ -142,7 +142,7 @@ namespace gpsshogi
       return is_attack ? "RookEffect" : "RookEffectDefense"; };
   private:
     MultiInt evalOnePiece(int piece_number, 
-			  const osl::state::NumEffectState &state, const MultiWeights& w) const;
+			  const osl::NumEffectState &state, const MultiWeights& w) const;
   };
 
   class BishopEffect : public EvalComponentMulti
@@ -161,19 +161,19 @@ namespace gpsshogi
   public:
     explicit BishopEffect(bool attack=true)
       : EvalComponentMulti(612), is_attack(attack) { } // 2 * 2 * 9 * 17
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& w,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& w,
 		  CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState &state, Move,
 			    MultiInt last_value, const MultiWeights& w,
 			    CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showAll(std::ostream &os, const MultiWeights& w) const;
     const std::string name() const {
       return is_attack ? "BishopEffect" : "BishopEffectDefense"; };
   private:
-    MultiInt evalOnePiece(int piece_number, const osl::state::NumEffectState &state, 
+    MultiInt evalOnePiece(int piece_number, const osl::NumEffectState &state, 
 			  const MultiWeights& w) const;
   };
 
