@@ -1,11 +1,10 @@
 #include "eval/minorPiece.h"
-#include "osl/container/pieceVector.h"
-#include "osl/effect_util/additionalEffect.h"
-#include "osl/record/csa.h"
-#include <boost/lexical_cast.hpp>
+#include "osl/container.h"
+#include "osl/additionalEffect.h"
+#include "osl/csa.h"
 
 bool gpsshogi::
-SilverRetreat::canRetreat(const osl::state::NumEffectState &state,
+SilverRetreat::canRetreat(const osl::NumEffectState &state,
 			  const osl::Piece silver) const
 {
   if (!silver.isOnBoard() || silver.isPromoted())
@@ -32,7 +31,7 @@ SilverRetreat::canRetreat(const osl::state::NumEffectState &state,
 }
 
 osl::MultiInt gpsshogi::
-SilverRetreat::eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+SilverRetreat::eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		    CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -52,7 +51,7 @@ SilverRetreat::eval(const osl::state::NumEffectState &state, const MultiWeights&
 }
 
 void gpsshogi::
-SilverRetreat::featuresNonUniq(const osl::state::NumEffectState &state, 
+SilverRetreat::featuresNonUniq(const osl::NumEffectState &state, 
 			index_list_t&diffs,
 			int offset) const
 {
@@ -95,7 +94,7 @@ SilverRetreat::showSummary(std::ostream &os, const MultiWeights& weights) const
 
 
 bool gpsshogi::
-GoldRetreat::canRetreat(const osl::state::NumEffectState &state,
+GoldRetreat::canRetreat(const osl::NumEffectState &state,
 			const osl::Piece gold) const
 {
   if (!gold.isOnBoard())
@@ -116,7 +115,7 @@ GoldRetreat::canRetreat(const osl::state::NumEffectState &state,
 }
 
 osl::MultiInt gpsshogi::
-GoldRetreat::eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+GoldRetreat::eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -136,7 +135,7 @@ GoldRetreat::eval(const osl::state::NumEffectState &state, const MultiWeights& w
 }
 
 void gpsshogi::
-GoldRetreat::featuresNonUniq(const osl::state::NumEffectState &state, 
+GoldRetreat::featuresNonUniq(const osl::NumEffectState &state, 
 		      index_list_t&diffs,
 		      int offset) const
 {
@@ -180,7 +179,7 @@ GoldRetreat::showSummary(std::ostream &os, const MultiWeights& weights) const
 
 
 bool gpsshogi::
-GoldSideMove::canMove(const osl::state::NumEffectState &state,
+GoldSideMove::canMove(const osl::NumEffectState &state,
 		      const osl::Piece gold) const
 {
   if (!gold.isOnBoard())
@@ -244,9 +243,9 @@ SilverFork::matchRook(const NumEffectState& state, Piece rook,
     if (! p.isOnBoardByOwner(owner)) 
       continue;
     if (p.ptype() == ROOK)
-      return std::make_pair(playerToMul(owner), 0);
+      return std::make_pair(sign(owner), 0);
     if (p.ptype() == GOLD)
-      return std::make_pair(playerToMul(owner), state.hasEffectAt(owner, next2) ? 1 : 2);
+      return std::make_pair(sign(owner), state.hasEffectAt(owner, next2) ? 1 : 2);
   }
   return std::make_pair(0,0);
 }
@@ -280,7 +279,7 @@ SilverFork::matchGold(const NumEffectState& state, Piece gold,
       const bool recaputure = guarded
 	|| (p.ptype() == GOLD && state.hasEffectAt(owner, next2))
 	|| (np.canMoveOn(owner) && ! state.hasEffectAt(alt(owner), next));
-      return std::make_pair(playerToMul(owner), 3 + recaputure);
+      return std::make_pair(sign(owner), 3 + recaputure);
     }
   }
   return std::make_pair(0,0);
@@ -456,13 +455,13 @@ BishopRookFork::featuresOneNonUniq
 	    && isBishopForkSquare(state, defense, pi.square(), pj.square()))
 	{
 	  const int index = bishopIndex(pi.ptype(), pj.ptype())*2 + (defense == turn);
-	  features.add(index, playerToMul(defense));
+	  features.add(index, sign(defense));
 	}
 	if (has_rook[alt(defense)] 
 	    && isRookForkSquare(state, defense, pi.square(), pj.square()))
 	{
 	  const int index = rookIndex(pi.ptype(), pj.ptype())*2 + (defense == turn);
-	  features.add(index, playerToMul(defense));
+	  features.add(index, sign(defense));
 	}
       }
     }
@@ -548,14 +547,14 @@ KnightFork::featuresOneNonUniq
 	  const Piece pj = pieces[z][y][j];
 	  assert(pj.isOnBoardByOwner(defense));
 	  assert(pj.square().y() == y);
-	  if (! isForkSquare(state, defense, y - playerToMul(defense)*2,
+	  if (! isForkSquare(state, defense, y - sign(defense)*2,
 			       pi.square().x(), pj.square().x()))
 	    continue;
 	  int found = index(pi.ptype(), pj.ptype());
 	  if (! has_knight[alt(defense)])
 	    found += DROP_DIM;
 	  found = found*2 + (defense == turn);
-	  features.add(found, playerToMul(defense));
+	  features.add(found, sign(defense));
 	}
       }
     }
@@ -594,7 +593,7 @@ osl::MultiInt gpsshogi::PawnAdvance::eval(const NumEffectState &state, const Mul
 }
 
 osl::MultiInt gpsshogi::
-PawnAdvance::evalWithUpdate(const osl::state::NumEffectState &state,
+PawnAdvance::evalWithUpdate(const osl::NumEffectState &state,
 			    osl::Move moved, MultiInt last_value, const MultiWeights& weights,
 			    CArray<MultiInt,2>& /*saved_state*/) const
 {
@@ -653,7 +652,7 @@ PawnAdvance::evalWithUpdate(const osl::state::NumEffectState &state,
 }
 
 void gpsshogi::
-PawnAdvance::featuresNonUniq(const osl::state::NumEffectState &state, 
+PawnAdvance::featuresNonUniq(const osl::NumEffectState &state, 
 		      index_list_t&diffs,
 		      int offset) const
 {
@@ -734,7 +733,7 @@ osl::MultiInt gpsshogi::KnightAdvance::eval(const NumEffectState &state, const M
 }
 
 void gpsshogi::
-KnightAdvance::featuresNonUniq(const osl::state::NumEffectState &state, 
+KnightAdvance::featuresNonUniq(const osl::NumEffectState &state, 
 			index_list_t&diffs,
 			int offset) const
 {
@@ -893,7 +892,7 @@ osl::MultiInt gpsshogi::PawnDrop::eval(const NumEffectState &state, const MultiW
 }
 
 void gpsshogi::PawnDrop::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
@@ -990,7 +989,7 @@ osl::MultiInt gpsshogi::PawnDropY::eval(const NumEffectState &state, const Multi
 }
 
 void gpsshogi::PawnDropY::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
@@ -1214,7 +1213,7 @@ osl::MultiInt gpsshogi::NoPawnOnStand::eval(const NumEffectState &state, const M
 }
 
 void gpsshogi::NoPawnOnStand::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
@@ -1524,7 +1523,7 @@ osl::MultiInt gpsshogi::AllGold::eval(const NumEffectState &state, const MultiWe
 }
 
 void gpsshogi::AllGold::featuresNonUniq(
-  const osl::state::NumEffectState &state,
+  const osl::NumEffectState &state,
   index_list_t&diffs,
   int offset) const
 {
@@ -1564,8 +1563,8 @@ int gpsshogi::PtypeY::index(const Player player,
 const std::string gpsshogi::PtypeY::
 describe(size_t local_index) const
 {
-  return osl::record::csa::show(static_cast<Ptype>(local_index/9))
-    + " y=" + boost::lexical_cast<std::string>((local_index%9)+1);
+  return osl::csa::show(static_cast<Ptype>(local_index/9))
+    + " y=" + std::to_string((local_index%9)+1);
 }
 
 osl::MultiInt gpsshogi::PtypeY::eval(const NumEffectState &state, const MultiWeights& weights,
@@ -1587,7 +1586,7 @@ osl::MultiInt gpsshogi::PtypeY::eval(const NumEffectState &state, const MultiWei
 }
 
 
-osl::MultiInt gpsshogi::PtypeY::evalWithUpdate(const osl::state::NumEffectState &,
+osl::MultiInt gpsshogi::PtypeY::evalWithUpdate(const osl::NumEffectState &,
 					       osl::Move moved, MultiInt last_value, const MultiWeights& weights,
 					       CArray<MultiInt,2>& /*saved_state*/) const
 {
@@ -1627,7 +1626,7 @@ osl::MultiInt gpsshogi::PtypeY::evalWithUpdate(const osl::state::NumEffectState
 }
 
 void gpsshogi::PtypeY::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t &diffs,
   int offset) const
 {
@@ -1701,7 +1700,7 @@ osl::MultiInt gpsshogi::PtypeX::eval(const NumEffectState &state, const MultiWei
 
 
 osl::MultiInt gpsshogi::PtypeX::evalWithUpdate(
-    const osl::state::NumEffectState &,
+    const osl::NumEffectState &,
     osl::Move moved, MultiInt last_value, const MultiWeights& weights,
     CArray<MultiInt,2>& /*saved_state*/) const
 {
@@ -1741,7 +1740,7 @@ osl::MultiInt gpsshogi::PtypeX::evalWithUpdate(
 }
 
 void gpsshogi::PtypeX::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t &diffs,
   int offset) const
 {
@@ -1795,7 +1794,7 @@ PromotedMinorPieces::featuresX(
   IndexCacheI<MaxActiveWithDuplication> &features) const
 {
   PieceMask attack = promoted & state.piecesOnBoard(P);
-  const Square king = state.kingSquare<PlayerTraits<P>::opponent>();
+  const Square king = state.kingSquare<alt(P)>();
   int min_left = -10;
   int min_right = 10;
   while (attack.any())
@@ -1857,7 +1856,7 @@ PromotedMinorPiecesY::featuresX(
   IndexCacheI<MaxActiveWithDuplication> &features) const
 {
   PieceMask attack = promoted & state.piecesOnBoard(P);
-  const Square king = state.kingSquare<PlayerTraits<P>::opponent>();
+  const Square king = state.kingSquare<alt(P)>();
   const Square self_king = state.kingSquare<P>();
   int min_left = -10;
   int min_right = 10;
@@ -2044,8 +2043,8 @@ SilverHeadPawnKingRelative::featuresOneNonUniq(
 	continue;
       const Piece up_piece = state.pieceAt(up);
       if (up_piece.isEmpty() &&
-	  (state.hasEffectByPtype<PAWN>(alt(p.owner()), up) ||
-	   !state.isPawnMaskSet(alt(p.owner()), p.square().x())))
+	  (state.hasEffectByPtypeStrict<PAWN>(alt(p.owner()), up)
+	   || !state.isPawnMaskSet(alt(p.owner()), p.square().x())))
       {
 	const Square king = state.kingSquare(p.owner());
 	const int x_diff = std::abs(king.x() - p.square().x());
@@ -2174,7 +2173,7 @@ Promotion37::featuresOneNonUniq
     const int d = state.countEffect(WHITE, target);
     if (a > 0 && a == d)
       a += AdditionalEffect::hasEffect(state, target, BLACK);
-    if (a < d)
+    if (a <= d)
       continue;
     const Ptype ptype = state.findCheapAttack(BLACK, target).ptype();
     if (isPiece(ptype) && ! isPromoted(ptype))
@@ -2196,7 +2195,7 @@ Promotion37::featuresOneNonUniq
     const int d = state.countEffect(BLACK, target);
     if (a > 0 && a == d)
       a += AdditionalEffect::hasEffect(state, target, WHITE);
-    if (a < d)
+    if (a <= d)
       continue;
     const Ptype ptype = state.findCheapAttack(WHITE, target).ptype();
     if (isPiece(ptype) && ! isPromoted(ptype))
