@@ -10,7 +10,7 @@ namespace gpsshogi
   class SilverRetreat : public EvalComponentMulti
   {
   private:
-    bool canRetreat(const osl::state::NumEffectState &state,
+    bool canRetreat(const osl::NumEffectState &state,
 		    const osl::Piece silver) const;
     int index(Player P, Square pos) const
     {
@@ -19,9 +19,9 @@ namespace gpsshogi
     enum { DIM = 9 };
   public:
     SilverRetreat() : EvalComponentMulti(DIM) { }
-    osl::MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights&,
+    osl::MultiInt eval(const osl::NumEffectState &state, const MultiWeights&,
 		       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -31,7 +31,7 @@ namespace gpsshogi
   class GoldRetreat : public EvalComponentMulti
   {
   private:
-    bool canRetreat(const osl::state::NumEffectState &state,
+    bool canRetreat(const osl::NumEffectState &state,
 		    const osl::Piece gold) const;
     int index(Player P, Square pos) const
     {
@@ -40,9 +40,9 @@ namespace gpsshogi
     enum { DIM = 9 };
   public:
     GoldRetreat() : EvalComponentMulti(DIM) { }
-    osl::MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights&,
+    osl::MultiInt eval(const osl::NumEffectState &state, const MultiWeights&,
 		       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -52,7 +52,7 @@ namespace gpsshogi
   class GoldSideMove : public FeaturesOneNonUniq
   {
   private:
-    bool canMove(const osl::state::NumEffectState &state,
+    bool canMove(const osl::NumEffectState &state,
 		 const osl::Piece gold) const;
     int indexX(Square pos) const
     {
@@ -65,7 +65,7 @@ namespace gpsshogi
     enum { DIM = 14 };
   public:
     GoldSideMove() : FeaturesOneNonUniq(DIM) { }
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     const std::string name() const { return "GoldSideMove"; };
@@ -150,12 +150,12 @@ namespace gpsshogi
     enum { DIM = 9 };
   public:
     PawnAdvance() : EvalComponentMulti(DIM) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    MultiInt evalWithUpdate(const osl::state::NumEffectState &state,
+    MultiInt evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, MultiInt last_value, const MultiWeights& weights,
 			    CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -173,9 +173,9 @@ namespace gpsshogi
     enum { DIM = 9 };
   public:
     KnightAdvance() : EvalComponentMulti(DIM) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights&,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights&,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -186,9 +186,9 @@ namespace gpsshogi
   {
   public:
     KnightCheck() : EvalComponentMulti(1) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -215,7 +215,7 @@ namespace gpsshogi
     PawnDrop(bool defense=true) : EvalComponentMulti(9), is_defense(defense) { }
     MultiInt eval(const NumEffectState& state, const MultiWeights& w,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -255,9 +255,9 @@ namespace gpsshogi
     }
   public:
     PawnDropY(bool defense=true) : EvalComponentMulti(81), is_defense(defense) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showAll(std::ostream &os, const MultiWeights& weights) const;
@@ -350,7 +350,7 @@ namespace gpsshogi
     NoPawnOnStand() : EvalComponentMulti(1) { }
     MultiInt eval(const NumEffectState& state, const MultiWeights& w,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -361,8 +361,8 @@ namespace gpsshogi
   {
   public:
     PawnAndEmptyAndPieceBase(int dim) : EvalComponent(dim) { }
-    int eval(const osl::state::NumEffectState &state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    int eval(const osl::NumEffectState &state) const;
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     const std::string name() const { return "PawnAndEmptyAndPieceBase"; }
@@ -465,9 +465,9 @@ namespace gpsshogi
   {
   public:
     AllGold() : EvalComponentMulti(1) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -484,11 +484,11 @@ namespace gpsshogi
     int index(const Player, const Ptype ptype, const Square pos) const;
   public:
     PtypeY() : EvalComponentMulti(9 * PTYPE_SIZE) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState& state, Move moved, MultiInt last_value, const MultiWeights& w,
 			    CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -506,11 +506,11 @@ namespace gpsshogi
     int index(const Player, const Ptype ptype, const Square pos) const;
   public:
     PtypeX() : EvalComponentMulti(5 * PTYPE_SIZE) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState& state, Move moved, MultiInt last_value, const MultiWeights& w,
 			    CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
