@@ -4,7 +4,7 @@
 #include "osl/mobility/lanceMobility.h"
 
 int gpsshogi::RookMobility::index(
-  const osl::state::NumEffectState &state,
+  const osl::NumEffectState &state,
   const osl::Piece &rook, bool vertical) const
 {
   int result = (vertical ? osl::mobility::RookMobility::countVerticalAll(
@@ -20,7 +20,7 @@ int gpsshogi::RookMobility::index(
   return result;
 }
 
-osl::MultiInt gpsshogi::RookMobility::eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+osl::MultiInt gpsshogi::RookMobility::eval(const osl::NumEffectState &state, const MultiWeights& weights,
 					   CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -43,11 +43,11 @@ osl::MultiInt gpsshogi::RookMobility::eval(const osl::state::NumEffectState &sta
 }
 
 void gpsshogi::RookMobility::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t &diffs,
   int offset) const
 {
-  osl::misc::CArray<int, 18 * 2> mobility;
+  osl::CArray<int, 18 * 2> mobility;
   mobility.fill(0);
 
   for (int i = osl::PtypeTraits<osl::ROOK>::indexMin;
@@ -214,7 +214,7 @@ void gpsshogi::RookMobilitySumKingX::featuresOneNonUniq(
 
 
 int gpsshogi::BishopMobility::index(
-  const osl::state::NumEffectState &state,
+  const osl::NumEffectState &state,
   const osl::Piece &bishop) const
 {
   int result = osl::mobility::BishopMobility::countAll(bishop.owner(),
@@ -224,7 +224,7 @@ int gpsshogi::BishopMobility::index(
   return result;
 }
 
-osl::MultiInt gpsshogi::BishopMobility::eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+osl::MultiInt gpsshogi::BishopMobility::eval(const osl::NumEffectState &state, const MultiWeights& weights,
 					     CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -244,11 +244,11 @@ osl::MultiInt gpsshogi::BishopMobility::eval(const osl::state::NumEffectState &s
 }
 
 void gpsshogi::BishopMobility::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t &diffs,
   int offset) const
 {
-  osl::misc::CArray<int, 18 * 2> mobility;
+  osl::CArray<int, 18 * 2> mobility;
   mobility.fill(0);
 
   for (int i = osl::PtypeTraits<osl::BISHOP>::indexMin;
@@ -315,7 +315,7 @@ void gpsshogi::BishopMobilityEach::featuresOneNonUniq(
 
 
 
-osl::MultiInt gpsshogi::LanceMobility::eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+osl::MultiInt gpsshogi::LanceMobility::eval(const osl::NumEffectState &state, const MultiWeights& weights,
 					    CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -335,11 +335,11 @@ osl::MultiInt gpsshogi::LanceMobility::eval(const osl::state::NumEffectState &st
 }
 
 void gpsshogi::LanceMobility::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t &diffs,
   int offset) const
 {
-  osl::misc::CArray<int, 9> mobility;
+  osl::CArray<int, 9> mobility;
   mobility.fill(0);
 
   for (int i = osl::PtypeTraits<osl::LANCE>::indexMin;
