@@ -9,14 +9,14 @@ namespace gpsshogi
   class RookMobility : public EvalComponentMulti
   {
   private:
-    int index(const osl::state::NumEffectState &state,
+    int index(const osl::NumEffectState &state,
 	      const osl::Piece &rook, bool vertical) const;
   public:
     // vectical and horizontal, unpromoted and promoted
     RookMobility() : EvalComponentMulti(18 * 2) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -109,14 +109,14 @@ namespace gpsshogi
   class BishopMobility : public EvalComponentMulti
   {
   private:
-    int index(const osl::state::NumEffectState &state,
+    int index(const osl::NumEffectState &state,
 	      const osl::Piece &bishop) const;
   public:
     // unpromoted and promoted
     BishopMobility() : EvalComponentMulti(18 * 2) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
@@ -139,9 +139,9 @@ namespace gpsshogi
   {
   public:
     LanceMobility() : EvalComponentMulti(9) { }
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
