@@ -15,14 +15,12 @@
 #include "eval/pieceEvalComponent.h"
 #include "eval/ptypeEval.h"
 #include "eval/piecePairKing.h"
-#include "osl/progress/ml/newProgress.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/stl/stack.h"
-#include "osl/misc/binaryIO.h"
+#include "osl/progress.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/bits/binaryIO.h"
 #include "osl/oslConfig.h"
 
 #include <boost/filesystem.hpp>
-#include <boost/lexical_cast.hpp>
 #include <iomanip>
 #include <fstream>
 #include <iostream>
@@ -89,28 +87,28 @@ OpenMidEndingBase::maxActive() const
   return max_active;
 }
 
-boost::tuple<std::string, int, int> gpsshogi::
+std::tuple<std::string, int, int> gpsshogi::
 OpenMidEndingBase::findFeature(size_t index) const
 {
   for (size_t i=0; i<flat.size(); ++i) {
     if (index < flat[i].dimension())
-      return boost::make_tuple(flat[i].name(), index, flat[i].dimension());
+      return std::make_tuple(flat[i].name(), index, flat[i].dimension());
     index -= flat[i].dimension();
   }
   for (size_t s=0; s<MultiInt::size(); ++s) {
     for (size_t i=0; i<legacy.size(); ++i) {
       if (index < legacy[i].dimensionOne())
-	return boost::make_tuple(legacy[i].name(), index + legacy[i].dimensionOne()*s, legacy[i].dimensionOne());
+	return std::make_tuple(legacy[i].name(), index + legacy[i].dimensionOne()*s, legacy[i].dimensionOne());
       index -= legacy[i].dimensionOne();
     }
   }
   for (size_t i=0; i<triple.size(); ++i) {
     if (index < triple[i].dimension())
-      return boost::make_tuple(triple[i].name(), index, triple[i].dimensionOne());
+      return std::make_tuple(triple[i].name(), index, triple[i].dimensionOne());
     index -= triple[i].dimension();
   }
   assert(0);
-  return boost::make_tuple("not found", 0, 0);
+  return std::make_tuple("not found", 0, 0);
 }
 
 namespace gpsshogi
@@ -131,7 +129,7 @@ namespace gpsshogi
       CArray<CArray<MultiInt,2> ,OthersLimit> triple_state;
       Entry() : sum(0), progress(NumEffectState()) {}
     };
-    osl::stack<Entry> values;
+    std::stack<Entry> values;
     OMDStackBase(Eval *ev, const NumEffectState& state) : eval(ev) { 
       assert((int)eval->flat.size() <= OthersLimit);
       assert((int)eval->legacy.size() <= OthersLimit);
@@ -345,7 +343,7 @@ OpenMidEndingBase::load(const char *filename)
   for (size_t i=0; i<dimension(); ++i)
     is >> values[i];
   setWeight(&values[0]);
-  return is;
+  return static_cast<bool>(is);
 }
 
 void gpsshogi::
@@ -459,7 +457,7 @@ void gpsshogi::
 OpenMidEndingBase::features(const NumEffectState& state, 
 			    MoveData& data, int offset) const
 {
-  osl::vector<std::pair<int,double> >& out = data.diffs;
+  std::vector<std::pair<int,double> >& out = data.diffs;
   const int progress_max = maxProgress();
   const osl::progress::ml::NewProgress raw_progress(state);
   const int progress = this->progress(raw_progress.progress());
@@ -660,7 +658,7 @@ OpenMidEndingBase::describe(const std::string& feature, size_t local_index) cons
       if (local_index >= flat[i].dimension())
 	return "index error";
       return flat[i].describe(local_index)
-	+ " value " + boost::lexical_cast<std::string>(flat[i].value(local_index));
+	+ " value " + std::to_string(flat[i].value(local_index));
     }
   }
   for (size_t i=0; i<legacy.size(); ++i) {
@@ -671,8 +669,8 @@ OpenMidEndingBase::describe(const std::string& feature, size_t local_index) cons
       const int value = legacy_weights[i].value(local_index%dim)
 	[local_index/dim];	  
       return legacy[i].describe(local_index)
-	+ " stage " + boost::lexical_cast<std::string>(local_index/dim)
-	+ " value " + boost::lexical_cast<std::string>(value);
+	+ " stage " + std::to_string(local_index/dim)
+	+ " value " + std::to_string(value);
     }
   }
   for (size_t i=0; i<triple.size(); ++i) {
@@ -680,7 +678,7 @@ OpenMidEndingBase::describe(const std::string& feature, size_t local_index) cons
       if (local_index >= triple[i].dimension())
 	return "index error";
       return triple[i].describe(local_index)
-	+ " value " + boost::lexical_cast<std::string>(triple[i].value(local_index));
+	+ " value " + std::to_string(triple[i].value(local_index));
     }
   }
   return "not found";
@@ -1052,7 +1050,7 @@ OslOpenMidEnding::OslOpenMidEnding()
   if (boost::filesystem::exists(filename.c_str())) {
     std::cerr << "loading " << filename << "\n";
     std::ifstream is(filename.c_str());
-    vector<double> w(dimension());
+    std::vector<double> w(dimension());
     typedef osl::misc::BinaryElementReader<int> reader_t;
     reader_t reader(is);
     for (size_t i=0; i<dimension(); ++i) {
@@ -1065,7 +1063,7 @@ OslOpenMidEnding::OslOpenMidEnding()
     stable_eval->setWeightScale(&w[0], 1.0);
 
     for (size_t i=0; i<dimension(); ++i) {
-      if (findFeature(i).get<0>() == "PiecePair")
+      if (std::get<0>(findFeature(i)) == "PiecePair")
 	values[i] = stable_eval->flatValue(i);
       assert(values[i] == stable_eval->flatValue(i));
     }
@@ -1107,7 +1105,7 @@ class gpsshogi::OslOpenMidEnding::Stack : public EvalValueStack
     osl::eval::ml::OpenMidEndingEval osl_eval;
     Entry() : osl_eval(NumEffectState()) {}
   };
-  osl::stack<Entry> values;
+  std::stack<Entry> values;
 public:  
   Stack(OslOpenMidEnding *ev, const NumEffectState& state) { 
     reset(state);
@@ -1211,7 +1209,7 @@ OslOpenMidEnding::load(const char *filename)
   for (size_t i=0; i<dimension(); ++i)
     is >> values[i];
   setWeight(&values[0]);
-  return is;
+  return static_cast<bool>(is);
 }
 
 void gpsshogi::
@@ -1279,7 +1277,7 @@ OslOpenMidEnding::hasPieceValue() const
   return false;
 }
 
-boost::tuple<std::string, int, int> gpsshogi::
+std::tuple<std::string, int, int> gpsshogi::
 OslOpenMidEnding::findFeature(size_t index) const
 {
   return stable_eval->findFeature(index);
