@@ -63,7 +63,7 @@ namespace gpsshogi
     const std::string name() const { return "PieceEvalComponent"; };
     void setZero()
     {
-      vector<double> zero(osl::PTYPE_SIZE);
+      std::vector<double> zero(osl::PTYPE_SIZE);
       setWeightScale(&zero[0], 1.0);
     }
   };
