@@ -2,12 +2,13 @@
  */
 #include "eval/piecePair.h"
 #include "eval/indexCache.h"
-#include "osl/centering5x3.h"
+#include "osl/bits/centering5x3.h"
 #include "osl/stat/average.h"
-#include "osl/record/csa.h"
+#include "osl/csa.h"
 #include <iostream>
-#include <boost/lexical_cast.hpp>
 #include <iomanip>
+#include <cmath>
+#include <cstdlib>
 
 
 gpsshogi::
@@ -54,11 +55,15 @@ PiecePair::showSummary(std::ostream& os) const
     a.add(values[i]);
     a_abs.add(abs(values[i]));
   }
-  
+#ifndef __APPLE__
+  int avsum = std::abs(values).sum();
+#else
+  int avsum = 0;
+#endif
   os << "PiecePair min. " << values.min() 
-     << " abs(ave.) " << abs(values).sum()/(double)dimension()
+     << " abs(ave.) " << avsum/(double)dimension()
      << " ave. " << values.sum()/(double)dimension() << " max. " << values.max() << "\n";
-  os << "  ave. (nonzero) " << a.getAverage() << " abs(ave., nonzero) " << a_abs.getAverage()
+  os << "  ave. (nonzero) " << a.average() << " abs(ave., nonzero) " << a_abs.average()
      << " #nonzero " << a.numElements() << "\n";
 }
 
@@ -92,7 +97,7 @@ std::string csaOwnerOrEmpty(osl::PtypeO ptypeo)
 {
   if (! osl::isPiece(ptypeo))
     return "?";
-  return osl::record::csa::show(osl::getOwner(ptypeo));
+  return osl::csa::show(osl::getOwner(ptypeo));
 }
 
 const std::string gpsshogi::
@@ -113,10 +118,10 @@ PiecePair::describe(size_t local_index) const
 	    const int index = PiecePairFeature::plain_table[i][ptypeOIndex(p0)][ptypeOIndex(p1)];
 	    if (index < 0)
 	      continue;
-	    dictionary[index] = '(' + boost::lexical_cast<std::string>(o.dx())
-	      + ',' + boost::lexical_cast<std::string>(o.dy())
-	      + ") " + csaOwnerOrEmpty(p0) + record::csa::show(getPtype(p0))
-	      +':' + csaOwnerOrEmpty(p1) + record::csa::show(getPtype(p1));
+	    dictionary[index] = '(' + std::to_string(o.dx())
+	      + ',' + std::to_string(o.dy())
+	      + ") " + csaOwnerOrEmpty(p0) + csa::show(getPtype(p0))
+	      +':' + csaOwnerOrEmpty(p1) + csa::show(getPtype(p1));
 	  }
 	}
       }
@@ -137,4 +142,5 @@ PiecePair::describe(size_t local_index) const
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
+// ;;; coding:utf-8
 // ;;; End:
