@@ -5,7 +5,7 @@
 
 #include "eval/eval.h"
 #include "eval/pieceFeature.h"
-#include "osl/eval/ml/piecePair.h"
+#include "osl/eval/piecePair.h"
 namespace gpsshogi
 {
   using namespace osl;
