@@ -1,10 +1,10 @@
 #include "eval/pieceStand.h"
 #include "eval/indexCache.h"
 #include "eval/minorPiece.h"
-#include "osl/checkmate/king8Info.h"
+#include "osl/bits/king8Info.h"
 
 osl::MultiInt gpsshogi::PieceStand::evalWithUpdate(
-  const osl::state::NumEffectState &state, osl::Move moved,
+  const osl::NumEffectState &state, osl::Move moved,
   MultiInt last_value, const MultiWeights& weights,
   CArray<MultiInt,2>& /*saved_state*/) const
 {
@@ -33,7 +33,7 @@ osl::MultiInt gpsshogi::PieceStand::evalWithUpdate(
 }
 
 osl::MultiInt gpsshogi::PieceStand::eval(
-  const osl::state::NumEffectState &state, const MultiWeights& weights,
+  const osl::NumEffectState &state, const MultiWeights& weights,
   CArray<MultiInt,2>& /*saved_state*/) const
 {
   MultiInt result;
@@ -57,7 +57,7 @@ osl::MultiInt gpsshogi::PieceStand::eval(
 }
 
 void gpsshogi::PieceStand::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
@@ -110,7 +110,7 @@ void gpsshogi::PieceStand::showSummary(std::ostream &os, const MultiWeights& wei
 
 
 osl::MultiInt gpsshogi::NonPawnPieceStand::eval(
-  const osl::state::NumEffectState &state, const MultiWeights& weights,
+  const osl::NumEffectState &state, const MultiWeights& weights,
   CArray<MultiInt,2>& /*saved_state*/) const
 {
   int black_total = 0;
@@ -129,7 +129,7 @@ osl::MultiInt gpsshogi::NonPawnPieceStand::eval(
 }
 
 void gpsshogi::NonPawnPieceStand::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
@@ -294,7 +294,7 @@ CanCheckNonPawnPieceStandCombinationEach::featuresPlayer(
   const NumEffectState &state,
   IndexCacheI<MaxActiveWithDuplication>&diffs) const
 {
-  const Player defense = PlayerTraits<P>::opponent;
+  const Player defense = alt(P);
   const King8Info king = state.king8Info(defense);
   if (!KnightCheck::canCheck(state, state.kingPiece<defense>()) &&
       king.dropCandidate() == 0 && king.hasMoveCandidate<P>(state) == 0)
