@@ -2,7 +2,6 @@
 #define GPSSHOGI_SAMPLE_EVAL_LIB_PIECESTAND_H
 
 #include "eval/pieceFeature.h"
-#include "osl/pieceStand.h"
 
 namespace gpsshogi
 {
@@ -15,7 +14,7 @@ namespace gpsshogi
       CArray<MultiInt,2>& saved_state) const;
     MultiInt evalWithUpdate(const NumEffectState& state, Move moved, MultiInt last_value, const MultiWeights& w,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
@@ -26,9 +25,9 @@ namespace gpsshogi
   {
   public:
     NonPawnPieceStand() : EvalComponentMulti(21) { }  // 0 to 20 (40 - 18 - 2).
-    MultiInt eval(const osl::state::NumEffectState &state, const MultiWeights& weights,
+    MultiInt eval(const osl::NumEffectState &state, const MultiWeights& weights,
       CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights& weights) const;
