@@ -17,7 +17,7 @@ namespace gpsshogi
     PinBase() : EvalComponentMulti(DIM) { }
     MultiInt eval(const NumEffectState& state, const MultiWeights& w,
 		  CArray<MultiInt,2>& saved_state) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 		  index_list_t &diffs,
 		  int offset) const;
     void showSummary(std::ostream &os, const MultiWeights&) const;
