@@ -2,19 +2,15 @@
  */
 #include "eval/progressFeature.h"
 #include "eval/openMidEnding.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/progress/effect5x3.h"
-#include "osl/effect_util/additionalEffect.h"
-#include "osl/stl/stack.h"
-#include "osl/container/pieceVector.h"
-#include "osl/pieceStand.h"
-#include "osl/record/csa.h"
-#include <boost/lexical_cast.hpp>
-#include <boost/foreach.hpp>
+#include "osl/additionalEffect.h"
+#include "osl/csa.h"
 #include <functional>
 #include <numeric>
 #include <fstream>
 #include <iostream>
+#include <stack>
 #include <cmath>
 
 typedef osl::eval::ml::OpenMidEndingEval ome_eval_t;
@@ -70,7 +66,7 @@ class gpsshogi::ProgressFeatureBase::Stack : public EvalValueStack
     {
     }
   };
-  osl::stack<Entry> values;
+  std::stack<Entry> values;
 public:  
   Stack(ProgressFeatureBase *ev, const NumEffectState& state) : eval(ev) { 
     assert((int)eval->all.size() <= OthersLimit);
@@ -158,7 +154,7 @@ ProgressFeatureBase::load(const char *filename)
   for (size_t i=0; i<dimension(); ++i)
     is >> values[i];
   setWeight(&values[0]);
-  return is;
+  return static_cast<bool>(is);
 }
 
 void gpsshogi::
@@ -203,7 +199,7 @@ ProgressFeatureBase::setWeightScale(const double *w, double scale)
 void gpsshogi::
 ProgressFeatureBase::setWeight(const double *w)
 {
-  if (! w[dimension()-1] > 0)
+  if (! (w[dimension()-1] > 0))
     std::cerr << "error ProgressFeatureBase::setWeight max_progress is not positive.\n" << " " << w[dimension()-1] << "\n";
   assert(w[dimension()-1] > 0);
   setWeightScale(w, maxProgressConstraint()/w[dimension()-1]);
@@ -234,7 +230,7 @@ int gpsshogi::
 ProgressFeatureBase::featuresCommon(const NumEffectState& state, 
 				    MoveData& data, int offset) const
 {
-  osl::vector<std::pair<int,double> >& out = data.diffs;
+  std::vector<std::pair<int,double> >& out = data.diffs;
   int dim = 0, progress = 0;
   for (size_t i=0; i<all.size(); ++i) {
     double his_value = 0.0;
@@ -265,7 +261,7 @@ void gpsshogi::
 ProgressFeatureBase::features(const NumEffectState& state, 
 			      MoveData& data, int offset) const
 {
-  osl::vector<std::pair<int,double> >& out = data.diffs;
+  std::vector<std::pair<int,double> >& out = data.diffs;
   const ome_eval_t eval(state);
   const int progress = featuresCommon(state, data, 0);
   const int progress_max = maxProgress();
@@ -319,15 +315,15 @@ ProgressFeatureBase::setRandom()
       all[i].setValue(j, osl::random()%4);
 }
 
-boost::tuple<std::string, int, int> 
+std::tuple<std::string, int, int> 
 gpsshogi::ProgressFeatureBase::findFeature(size_t index) const
 {
   for (size_t i=0; i<all.size(); ++i) {
     if (index < all[i].dimension())
-      return boost::make_tuple(all[i].name(), index, all[i].dimension());
+      return std::make_tuple(all[i].name(), index, all[i].dimension());
     index -= all[i].dimension();
   }
-  return boost::make_tuple("max_progress", index, 1);
+  return std::make_tuple("max_progress", index, 1);
 }
 
 const std::string gpsshogi::
@@ -355,7 +351,7 @@ ProgressFeatureBase::describeAll(const std::string& feature) const
 	int value = all[i].value(j);
 	if (value != 0)
 	  out += all[i].describe(j)
-	    + " value " + boost::lexical_cast<std::string>(value) + "\n";
+	    + " value " + std::to_string(value) + "\n";
       }
       return out;
     }
@@ -391,11 +387,11 @@ struct gpsshogi::HandProgressFeatureEval::HandProgress : public EvalComponent
     for (int i=0; i<16; ++i)
       values[i] = i; // 1;
   }
-  int eval(const osl::state::NumEffectState& state) const
+  int eval(const osl::NumEffectState& state) const
   {
     return values[progress::Effect5x3(state).progress16().value()];
   }
-  void featuresNonUniq(const osl::state::NumEffectState& state, index_list_t& out, int offset) const
+  void featuresNonUniq(const osl::NumEffectState& state, index_list_t& out, int offset) const
   {
     const int progress = progress::Effect5x3(state).progress16().value();
     out.add(progress+offset, 1);
@@ -441,10 +437,10 @@ namespace gpsshogi
       for (size_t i = 0; i < dimension(); ++i)
 	values[i] = 1;
     }
-    int eval(const osl::state::NumEffectState &state) const;
-    int evalWithUpdate(const osl::state::NumEffectState &state,
+    int eval(const osl::NumEffectState &state) const;
+    int evalWithUpdate(const osl::NumEffectState &state,
 		       osl::Move moved, int last_value) const;
-    void featuresNonUniq(const osl::state::NumEffectState &state, 
+    void featuresNonUniq(const osl::NumEffectState &state, 
 			 index_list_t&diffs, int offset) const;
     void showSummary(std::ostream &os) const;
     const std::string name() const { return "ProgressPieceStand"; };
@@ -522,7 +518,7 @@ namespace gpsshogi
     void countOne(const NumEffectState &state,
 		  int &pawn, int &non_pawn) const
     {
-      PieceMask mask = (state.effectedMask(PlayerTraits<Attacked>::opponent) &
+      PieceMask mask = (state.effectedMask(alt(Attacked)) &
 			state.piecesOnBoard(Attacked));
       mask.reset(state.kingPiece<Attacked>().number());
       mask_t black_ppawn = (state.promotedPieces().getMask<PAWN>() &
@@ -649,7 +645,7 @@ namespace gpsshogi
       index /= PTYPE_SIZE;
       const Ptype ptype = static_cast<Ptype>(index%PTYPE_SIZE);
       const bool has_support = index > PTYPE_SIZE;
-      return record::csa::show(attack) + "=>" + record::csa::show(ptype)
+      return csa::show(attack) + "=>" + csa::show(ptype)
 	+ (has_support ? "#" : ".");
     }
   };
@@ -724,7 +720,7 @@ namespace gpsshogi
 	const int d = state.countEffect(alt(attack), target);
 	if (a > 0 && a == d)
 	  a += AdditionalEffect::hasEffect(state, target, attack);
-	if (a < d)
+	if (a <= d)
 	  continue;
 	const Ptype ptype = state.findCheapAttack(attack, target).ptype();
 	if (isPiece(ptype) && ! isPromoted(ptype))
@@ -783,7 +779,7 @@ namespace gpsshogi
     {
       CArray<int,7> stand = {{ 0 }};
       int filled = 0;
-      BOOST_FOREACH(Ptype ptype, PieceStand::order)
+      for (Ptype ptype: PieceStand::order)
 	if (state.hasPieceOnStand(attack, ptype))
 	  stand[filled++] = ptype-PTYPE_BASIC_MIN;
       for (int i=0; i<std::min(7,filled+1); ++i) {
@@ -817,8 +813,8 @@ namespace gpsshogi
     {
       os << "ProgressPieceStand7\n";
       for (int i=0; i<7; ++i) {
-	BOOST_FOREACH(Ptype ptype, PieceStand::order)
-	  os << "  " << record::csa::show(ptype) << ' '
+	for (Ptype ptype: PieceStand::order)
+	  os << "  " << csa::show(ptype) << ' '
 	     << this->value(ptype-PTYPE_BASIC_MIN + StandRank*i);
 	os << "\n";
       }
@@ -828,14 +824,14 @@ namespace gpsshogi
       Ptype ptype = static_cast<Ptype>((index%StandRank)+PTYPE_PIECE_MIN);
       if (ptype == KING)
 	ptype = PTYPE_EMPTY;
-      return record::csa::show(ptype)
+      return csa::show(ptype)
 	+ "(" + static_cast<char>('0'+(index/StandRank)) + ")";
     }
   };
 }
 
 int gpsshogi::ProgressPieceStand::evalWithUpdate(
-  const osl::state::NumEffectState &state, osl::Move moved,
+  const osl::NumEffectState &state, osl::Move moved,
   int last_value) const
 {
   if (moved.isPass())
@@ -859,7 +855,7 @@ int gpsshogi::ProgressPieceStand::evalWithUpdate(
 }
 
 int gpsshogi::ProgressPieceStand::eval(
-  const osl::state::NumEffectState &state) const
+  const osl::NumEffectState &state) const
 {
   int result = 0;
   for (size_t i = 0; i < osl::PieceStand::order.size(); ++i)
@@ -890,13 +886,13 @@ ProgressPieceStand::describe(size_t local_index) const
     if (local_index >= Ptype_Table.getIndexMin(ptype)
 	&& local_index < Ptype_Table.getIndexLimit(ptype))
       return Ptype_Table.getCsaName(ptype)
-	+ boost::lexical_cast<std::string>(local_index - Ptype_Table.getIndexMin(ptype));
+	+ std::to_string(local_index - Ptype_Table.getIndexMin(ptype));
   }
   return "ProgressPieceStand error";
 }
 
 void gpsshogi::ProgressPieceStand::featuresNonUniq(
-  const osl::state::NumEffectState &state, 
+  const osl::NumEffectState &state, 
   index_list_t&diffs,
   int offset) const
 {
