@@ -4,8 +4,8 @@
 #define _PROGRESSFEATURE_H
 
 #include "eval/eval.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/misc/loki.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/bits/centering5x3.h"
 #include <algorithm>
 namespace gpsshogi
 {
@@ -56,7 +56,7 @@ namespace gpsshogi
     int pawnValue() const;
 
     int maxProgress() const { return max_progress; }
-    boost::tuple<std::string, int, int> findFeature(size_t index) const;
+    std::tuple<std::string, int, int> findFeature(size_t index) const;
 
     class Stack;
     friend class Stack;
@@ -149,7 +149,7 @@ namespace gpsshogi
     }
 
     template <osl::Player Defense, typename Features>
-    static void effect5x3(const osl::state::NumEffectState &state,
+    static void effect5x3(const osl::NumEffectState &state,
 			  int offset,
 			  IndexCacheI<MaxActiveWithDuplication> &out)
     {
@@ -165,7 +165,7 @@ namespace gpsshogi
 	  const Square target(min_x+dx,min_y+dy);
 	  const NumBitmapEffect effect = state.effectSetAt(target);
 	  const int attack_count =
-	    effect.countEffect(PlayerTraits<Defense>::opponent);
+	    effect.countEffect(alt(Defense));
 	  const int defense_count = effect.countEffect(Defense);
 	  featuresEach(Features(), Player2Type<Defense>(), king, target,
 		       attack_count, defense_count,
@@ -176,7 +176,7 @@ namespace gpsshogi
 
     template <typename Features>
     static void featuresAll(
-      const osl::state::NumEffectState &state,
+      const osl::NumEffectState &state,
       IndexCacheI<MaxActiveWithDuplication> &out)
     {
       effect5x3<BLACK, Features>(state, 0, out);
@@ -422,7 +422,7 @@ namespace gpsshogi
   public:
     Effect5x3Features() :
       EvalComponent(FeatureDimension<Effect5x3List>::value) { } 
-    int eval(const osl::state::NumEffectState& state) const
+    int eval(const osl::NumEffectState& state) const
     {
       IndexCacheI<MaxActiveWithDuplication> values;
       Effect5x3Util::featuresAll<Effect5x3List>(state, values);
@@ -433,7 +433,7 @@ namespace gpsshogi
       }
       return result;
     }
-    void featuresNonUniq(const osl::state::NumEffectState& state,
+    void featuresNonUniq(const osl::NumEffectState& state,
 			 index_list_t& out,
 			 int offset) const
     {
@@ -517,12 +517,12 @@ namespace gpsshogi
     }
 
     template <osl::Player Attack, typename Features>
-    static void effect5x5(const osl::state::NumEffectState &state,
+    static void effect5x5(const osl::NumEffectState &state,
 			  int offset,
 			  IndexCacheI<MaxActiveWithDuplication> &out)
     {
       const Square king =
-	state.kingSquare<PlayerTraits<Attack>::opponent>();
+	state.kingSquare<alt(Attack)>();
       const int min_x = std::max(1, king.x() - 2);
       const int max_x = std::min(9, king.x() + 2);
       const int min_y = std::max(1, king.y() - 2);
@@ -538,7 +538,7 @@ namespace gpsshogi
 	  mask = mask | effect;
 	  const int attack_count = effect.countEffect(Attack);
 	  const int defense_count =
-	    effect.countEffect(PlayerTraits<Attack>::opponent);
+	    effect.countEffect(alt(Attack));
 	  featuresEach(Features(), Player2Type<Attack>(), king, target,
 		       attack_count, defense_count,
 		       offset, out);
@@ -551,7 +551,7 @@ namespace gpsshogi
 
     template <typename Features>
     static void featuresAll(
-      const osl::state::NumEffectState &state, int offset,
+      const osl::NumEffectState &state, int offset,
       IndexCacheI<MaxActiveWithDuplication> &out)
     {
       effect5x5<BLACK, Features>(state, offset, out);
@@ -720,7 +720,7 @@ namespace gpsshogi
     Effect5x5Features() :
       EvalComponent(FeatureDimension<Effect5x5List>::value) {
     } 
-    int eval(const osl::state::NumEffectState& state) const
+    int eval(const osl::NumEffectState& state) const
     {
       IndexCacheI<MaxActiveWithDuplication> values;
       Effect5x5Util::featuresAll<Effect5x5List>(state, 0, values);
@@ -731,7 +731,7 @@ namespace gpsshogi
       }
       return result;
     }
-    void featuresNonUniq(const osl::state::NumEffectState& state,
+    void featuresNonUniq(const osl::NumEffectState& state,
 			 index_list_t& out,
 			 int offset) const
     {
