@@ -47,6 +47,15 @@ namespace gpsshogi
     void featuresOneNonUniq(const NumEffectState &state,
 			    IndexCacheI<MaxActiveWithDuplication> &) const;
     const std::string name() const { return "NonPawnAttacked"; }
+    const std::string describe(size_t local_index) const
+    {
+      const Ptype ptype = static_cast<Ptype>(local_index % PTYPE_SIZE);
+      local_index /= PTYPE_SIZE;
+      const bool same_turn = local_index % 2;
+      const bool has_support = local_index / 2;
+      return std::string(Ptype_Table.getCsaName(ptype)) 
+	+ (has_support ? " support" : "") + (same_turn ? " turn" : "");
+    }
   };
 
   class NonPawnAttackedKingRelatve : public FeaturesOneNonUniq
