@@ -21,7 +21,7 @@ featuresOneNonUniq(const NumEffectState &state,
   board_count.fill(0);
   for (int i = 0; i < Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     if (piece.ptype() == KING)
     {
       continue;
@@ -89,7 +89,7 @@ evalWithUpdateMulti(const NumEffectState& state, Move moved,
 {
   if (moved.isPass())
     return last_values;
-  if (moved.capturePtype() == PTYPE_EMPTY && !moved.isPromote()
+  if (moved.capturePtype() == PTYPE_EMPTY && !moved.isPromotion()
       && !moved.isDrop())
     return last_values;
 
@@ -100,7 +100,7 @@ evalWithUpdateMulti(const NumEffectState& state, Move moved,
   for (int j = Ptype_Table.getIndexMin(uptype);
        j < Ptype_Table.getIndexLimit(uptype); ++j)
   {
-    const Piece p = state.getPieceOf(j);
+    const Piece p = state.pieceOf(j);
     if (p.isOnBoardByOwner(player))
       ++ptype_board_count[p.ptype() != uptype]; // 0 unpromote, 1 promote
   }
@@ -116,7 +116,7 @@ evalWithUpdateMulti(const NumEffectState& state, Move moved,
     }
     return last_values + ((player == BLACK) ? diff : -diff);
   }
-  if (moved.isPromote()) 
+  if (moved.isPromotion()) 
   {
     // promoted
     assert(ptype_board_count[1] > 0);
@@ -151,7 +151,7 @@ evalWithUpdateMulti(const NumEffectState& state, Move moved,
   for (int j = Ptype_Table.getIndexMin(ucptype);
        j < Ptype_Table.getIndexLimit(ucptype); ++j)
   {
-    const Piece p = state.getPieceOf(j);
+    const Piece p = state.pieceOf(j);
     if (p.isOnBoard())
       ++ctype_board_count[p.owner()][p.ptype() != ucptype]; // 0 unpromote, 1 promote
   }
@@ -231,7 +231,7 @@ featuresOneNonUniq(const NumEffectState &state,
   board_count.fill(0);
   for (int i = 0; i < Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     if (piece.ptype() == KING)
     {
       continue;
@@ -242,10 +242,10 @@ featuresOneNonUniq(const NumEffectState &state,
       ++board_count[piece.owner()][piece.ptype()];
     }
   }
-  CArray<int, 2> kings_x = {{ state.getKingPosition<BLACK>().x(),
-			      state.getKingPosition<WHITE>().x() }};
-  CArray<int, 2> kings_y = {{ state.getKingPosition<BLACK>().y(),
-			      10 - state.getKingPosition<WHITE>().y() }};
+  CArray<int, 2> kings_x = {{ state.kingSquare<BLACK>().x(),
+			      state.kingSquare<WHITE>().x() }};
+  CArray<int, 2> kings_y = {{ state.kingSquare<BLACK>().y(),
+			      10 - state.kingSquare<WHITE>().y() }};
   if (kings_x[0] > 5)
     kings_x[0] = 10 - kings_x[0];
   if (kings_x[1] > 5)
@@ -285,14 +285,14 @@ evalWithUpdateMulti(
 {
   assert(moved.isNormal());
   assert(moved.ptype() != KING);
-  if (moved.capturePtype() == PTYPE_EMPTY && !moved.isPromote()
+  if (moved.capturePtype() == PTYPE_EMPTY && !moved.isPromotion()
       && !moved.isDrop())
     return last_values;
 
-  CArray<int, 2> kings_x = {{ state.getKingPosition<BLACK>().x(),
-			      state.getKingPosition<WHITE>().x() }};
-  CArray<int, 2> kings_y = {{ state.getKingPosition<BLACK>().y(),
-			      10 - state.getKingPosition<WHITE>().y() }};
+  CArray<int, 2> kings_x = {{ state.kingSquare<BLACK>().x(),
+			      state.kingSquare<WHITE>().x() }};
+  CArray<int, 2> kings_y = {{ state.kingSquare<BLACK>().y(),
+			      10 - state.kingSquare<WHITE>().y() }};
   if (kings_x[0] > 5)
     kings_x[0] = 10 - kings_x[0];
   if (kings_x[1] > 5)
@@ -305,7 +305,7 @@ evalWithUpdateMulti(
   for (int j = Ptype_Table.getIndexMin(uptype);
        j < Ptype_Table.getIndexLimit(uptype); ++j)
   {
-    const Piece p = state.getPieceOf(j);
+    const Piece p = state.pieceOf(j);
     if (p.isOnBoardByOwner(player))
       ++ptype_board_count[p.ptype() != uptype]; // 0 unpromote, 1 promote
   }
@@ -329,7 +329,7 @@ evalWithUpdateMulti(
     return last_values + ((player == BLACK) ? diff : -diff);
   }
 
-  if (moved.isPromote()) 
+  if (moved.isPromotion()) 
   {
     // promoted
     assert(ptype_board_count[1] > 0);
@@ -369,7 +369,7 @@ evalWithUpdateMulti(
   for (int j = Ptype_Table.getIndexMin(ucptype);
        j < Ptype_Table.getIndexLimit(ucptype); ++j)
   {
-    const Piece p = state.getPieceOf(j);
+    const Piece p = state.pieceOf(j);
     if (p.isOnBoard())
       ++ctype_board_count[p.owner()][p.ptype() != ucptype]; // 0 unpromote, 1 promote
   }
@@ -481,22 +481,22 @@ featuresOneNonUniq(const NumEffectState &state,
        i < PtypeTraits<PAWN>::indexLimit;
        ++i)
   {
-    const Piece pawn = state.getPieceOf(i);
+    const Piece pawn = state.pieceOf(i);
     if (!pawn.isOnBoard() || pawn.isPromoted())
       continue;
-    pawn_y[pawn.owner()][pawn.position().x() - 1] = pawn.position().y();
+    pawn_y[pawn.owner()][pawn.square().x() - 1] = pawn.square().y();
   }
 
   for (int i = 0; i < Piece::SIZE; ++i)
   {
-    const Piece piece = state.getPieceOf(i);
+    const Piece piece = state.pieceOf(i);
     // only skip pawn, not ppawns
     if (piece.ptype() == PAWN)
       continue;
     if (!piece.isOnBoard())
       continue;
-    diffs.add(index(piece.owner(), piece.ptype(), piece.position().y(),
-		    pawn_y[piece.owner()][piece.position().x() - 1]),
+    diffs.add(index(piece.owner(), piece.ptype(), piece.square().y(),
+		    pawn_y[piece.owner()][piece.square().x() - 1]),
 	      piece.owner() == BLACK ? 1 : -1);
   }
 }
@@ -519,7 +519,7 @@ evalWithUpdateMulti(const NumEffectState& state,
       int pawn_y=9;
       for (; pawn_y >= 1; --pawn_y)
       {
-	const Piece p = state.getPieceAt(Position(moved.to().x(), pawn_y));
+	const Piece p = state.pieceAt(Square(moved.to().x(), pawn_y));
 	if (p.isOnBoardByOwner(player) && p.ptype() == PAWN)
 	  break;
       }
@@ -533,7 +533,7 @@ evalWithUpdateMulti(const NumEffectState& state,
     {
       if (y == moved.to().y())
 	continue;
-      const Piece p = state.getPieceAt(Position(moved.to().x(), y));
+      const Piece p = state.pieceAt(Square(moved.to().x(), y));
       if (! p.isOnBoardByOwner(player))
 	continue;
       const int index
@@ -553,7 +553,7 @@ evalWithUpdateMulti(const NumEffectState& state,
     const int new_y = 0;
     for (int y=1; y<=9; ++y)
     {
-      const Piece p = state.getPieceAt(Position(x, y));
+      const Piece p = state.pieceAt(Square(x, y));
       if (! p.isOnBoardByOwner(alt(player)))
 	continue;
       const int index
@@ -568,13 +568,13 @@ evalWithUpdateMulti(const NumEffectState& state,
   if (moved.oldPtype() == PAWN)
   {
     const int x = moved.from().x(), old_y = moved.from().y();
-    const int new_y = moved.isPromote() ? 0 : moved.to().y();    
+    const int new_y = moved.isPromotion() ? 0 : moved.to().y();    
     Piece op_pawn;
     for (int y=1; y<=9; ++y)
     {
       if (y == new_y)
 	continue;
-      const Piece p = state.getPieceAt(Position(x, y));
+      const Piece p = state.pieceAt(Square(x, y));
       if (! p.isPiece())
 	continue;
       if (p.owner() != player) 
@@ -598,7 +598,7 @@ evalWithUpdateMulti(const NumEffectState& state,
     {
       const int old_index
 	= PtypeYPawnYFeature::index(alt(player), moved.capturePtype(), moved.to().y(), 
-				    op_pawn.isPiece() ? op_pawn.position().y() : 0);
+				    op_pawn.isPiece() ? op_pawn.square().y() : 0);
       diff -= -weight.value(old_index);
     }
     return last_values + ((player == BLACK) ? diff : -diff);
@@ -609,10 +609,10 @@ evalWithUpdateMulti(const NumEffectState& state,
        i < PtypeTraits<PAWN>::indexLimit;
        ++i)
   {
-    const Piece pawn = state.getPieceOf(i);
+    const Piece pawn = state.pieceOf(i);
     if (!pawn.isOnBoard() || pawn.isPromoted())
       continue;
-    pawn_y[pawn.owner()][pawn.position().x() - 1] = pawn.position().y();
+    pawn_y[pawn.owner()][pawn.square().x() - 1] = pawn.square().y();
   }
   assert(! moved.from().isPieceStand());
   {
@@ -655,6 +655,21 @@ featuresOneNonUniq(const NumEffectState &state,
   diffs.add(ptypes[1], -1);
 }
 
+const std::string gpsshogi::PtypeCombination::
+describe(size_t local_index) const
+{
+  static const CArray<const char *, 13> pieces = {{
+      "G", "PR", "PB", "PS", "PN", "PL", "PP",
+      "R", "B", "S", "K", "L", "P"
+    }};
+  std::string ret;
+  for (size_t i=0; i<pieces.size(); ++i)
+    if ((1<<i)&local_index)
+      ret += pieces[i];
+  return ret;
+}
+
+
 void gpsshogi::PtypeCombinationY::
 featuresOneNonUniq(const NumEffectState &state,
 		   IndexCacheI<MaxActiveWithDuplication>&diffs) const
@@ -669,9 +684,9 @@ featuresOneNonUniq(const NumEffectState &state,
   updatePtype<ROOK, 7>(state, ptypes);
   updatePtype<GOLD, 0>(state, ptypes);
 
-  diffs.add((state.getKingPosition<BLACK>().y() - 1) * (1 << 13) + ptypes[0],
+  diffs.add((state.kingSquare<BLACK>().y() - 1) * (1 << 13) + ptypes[0],
 	    1);
-  diffs.add((9 - state.getKingPosition<WHITE>().y()) * (1 << 13) + ptypes[1],
+  diffs.add((9 - state.kingSquare<WHITE>().y()) * (1 << 13) + ptypes[1],
 	    -1);
 }
 
@@ -710,9 +725,9 @@ featuresOneNonUniq(const NumEffectState &state,
   updatePtype<ROOK, 7>(state, ptypes);
   updatePtype<GOLD, 0>(state, ptypes);
 
-  diffs.add((state.getKingPosition<BLACK>().y() - 1) * (1 << 13) + ptypes[0],
+  diffs.add((state.kingSquare<BLACK>().y() - 1) * (1 << 13) + ptypes[0],
 	    1);
-  diffs.add((9 - state.getKingPosition<WHITE>().y()) * (1 << 13) + ptypes[1],
+  diffs.add((9 - state.kingSquare<WHITE>().y()) * (1 << 13) + ptypes[1],
 	    -1);
 }
 
