@@ -2,14 +2,14 @@
  */
 #ifndef GPSSHOGI_INSTANCEDATA_H
 #define GPSSHOGI_INSTANCEDATA_H
-#include "osl/stl/vector.h"
+#include <vector>
 
 namespace gpsshogi
 {
   struct InstanceData
   {
-    osl::vector<unsigned int> index;
-    osl::vector<double> value;
+    std::vector<unsigned int> index;
+    std::vector<double> value;
     double y;
 
     size_t size() const { return index.size(); }
