@@ -3,7 +3,7 @@
 #ifndef GPSSHOGI_L1BALL_H
 #define GPSSHOGI_L1BALL_H
 
-#include "osl/stl/vector.h"
+#include <vector>
 #include <valarray>
 
 namespace gpsshogi
