@@ -24,7 +24,7 @@ double gpsshogi::ValarrayUtil::dot(const InstanceData& x, const valarray_t& w)
 }
 
 double gpsshogi::ValarrayUtil::
-dot(const sparse_vector_t& l, const valarray_t& r, const osl::vector<size_t>& frequency, int min_frequency)
+dot(const sparse_vector_t& l, const valarray_t& r, const std::vector<size_t>& frequency, int min_frequency)
 {
   double sum = 0.0;
   for (size_t i=0; i<l.size(); ++i) {
@@ -104,7 +104,7 @@ void gpsshogi::LogLoss::addGradientSep(const InstanceData& a, double agsum, vala
 
 double gpsshogi::LogLoss::addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 					 const sparse_vector_t& b, double turn_coef,
-					 const osl::vector<size_t>& frequency, int min_frequency,
+					 const std::vector<size_t>& frequency, int min_frequency,
 					 valarray_t& gradient, double& agsum, 
 					 double instance_weight, double margin)
 {
@@ -132,7 +132,7 @@ double gpsshogi::LogLoss::addGradientSep(const valarray_t& w, double adot, const
   return err;
 }
 void gpsshogi::LogLoss::addGradientSep(const sparse_vector_t& a, 
-				       const osl::vector<size_t>& frequency, int min_frequency,
+				       const std::vector<size_t>& frequency, int min_frequency,
 				       double agsum, valarray_t& gradient)
 {
   // x = b-a
@@ -239,7 +239,7 @@ double gpsshogi::SigmoidLoss::addGradient(const valarray_t& w, const InstanceDat
 double gpsshogi::SigmoidLoss::
 addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 	       const sparse_vector_t& b, double turn_coef,
-	       const osl::vector<size_t>& frequency, int min_frequency,
+	       const std::vector<size_t>& frequency, int min_frequency,
 	       valarray_t& gradient, double& agsum,
 	       double instance_weight, double margin)
 {
@@ -264,7 +264,7 @@ addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 
 void gpsshogi::SigmoidLoss::
 addGradientSep(const sparse_vector_t& a, 
-		    const osl::vector<size_t>& frequency, int min_frequency,
+		    const std::vector<size_t>& frequency, int min_frequency,
 		    double agsum, valarray_t& gradient)
 {
   LogLoss::addGradientSep(a, frequency, min_frequency, agsum, gradient);
@@ -312,7 +312,7 @@ double gpsshogi::HingeLoss::addGradient(const valarray_t& w, const InstanceData&
 
 void gpsshogi::HingeLoss::
 addGradientSep(const sparse_vector_t& a, 
-	       const osl::vector<size_t>& frequency, int min_frequency,
+	       const std::vector<size_t>& frequency, int min_frequency,
 	       double agsum, valarray_t& gradient)
 {
   LogLoss::addGradientSep(a, frequency, min_frequency, agsum, gradient);
@@ -321,7 +321,7 @@ addGradientSep(const sparse_vector_t& a,
 double gpsshogi::HingeLoss::
 addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 	       const sparse_vector_t& b, double turn_coef,
-	       const osl::vector<size_t>& frequency, int min_frequency,
+	       const std::vector<size_t>& frequency, int min_frequency,
 	       valarray_t& gradient, double& agsum,
 	       double instance_weight, double margin)
 {
@@ -357,7 +357,7 @@ double gpsshogi::HingeLoss::addGradient(const valarray_t& w, const InstanceData&
 double gpsshogi::HalfSigmoidLoss::
 addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 	       const sparse_vector_t& b, double turn_coef,
-	       const osl::vector<size_t>& frequency, int min_frequency,
+	       const std::vector<size_t>& frequency, int min_frequency,
 	       valarray_t& gradient, double& agsum,
 	       double instance_weight, double margin)
 {
@@ -386,7 +386,7 @@ addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 
 void gpsshogi::HalfSigmoidLoss::
 addGradientSep(const sparse_vector_t& a, 
-		    const osl::vector<size_t>& frequency, int min_frequency,
+		    const std::vector<size_t>& frequency, int min_frequency,
 		    double agsum, valarray_t& gradient)
 {
   LogLoss::addGradientSep(a, frequency, min_frequency, agsum, gradient);
