@@ -3,20 +3,20 @@
 #ifndef GPSSHOGI_LOSS_H
 #define GPSSHOGI_LOSS_H
 
-#include "osl/stl/vector.h"
+#include <vector>
 #include <valarray>
 #include <utility>
 
 namespace gpsshogi
 {
   class InstanceData;
-  typedef osl::vector<std::pair<int,double> > sparse_vector_t;
+  typedef std::vector<std::pair<int,double> > sparse_vector_t;
   struct ValarrayUtil
   {
     typedef std::valarray<double> valarray_t;
     static double dot(const valarray_t& l, const valarray_t& r);
     static double dot(const InstanceData& l, const valarray_t& r);
-    static double dot(const sparse_vector_t& l, const valarray_t& r, const osl::vector<size_t>& frequency, int min_frequency);
+    static double dot(const sparse_vector_t& l, const valarray_t& r, const std::vector<size_t>& frequency, int min_frequency);
   };
 
   struct LogLoss : public ValarrayUtil
@@ -35,12 +35,12 @@ namespace gpsshogi
 				 const InstanceData& b, valarray_t& gradient, double& agsum);
     static double addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 				 const sparse_vector_t& b, double turn_coef,
-				 const osl::vector<size_t>& frequency, int min_frequency,
+				 const std::vector<size_t>& frequency, int min_frequency,
 				 valarray_t& gradient, double& agsum,
 				 double instance_weight=1.0, double margin=0.0);
     static void addGradientSep(const InstanceData& a, double agsum, valarray_t& gradient);
     static void addGradientSep(const sparse_vector_t& a, 
-			       const osl::vector<size_t>& frequency, int min_frequency,
+			       const std::vector<size_t>& frequency, int min_frequency,
 			       double agsum, valarray_t& gradient);
   };
 
@@ -53,11 +53,11 @@ namespace gpsshogi
 
     static double addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 				 const sparse_vector_t& b, double turn_coef,
-				 const osl::vector<size_t>& frequency, int min_frequency,
+				 const std::vector<size_t>& frequency, int min_frequency,
 				 valarray_t& gradient, double& agsum,
 				 double instance_weight=1.0, double margin=0.0);
     static void addGradientSep(const sparse_vector_t& a, 
-			       const osl::vector<size_t>& frequency, int min_frequency,
+			       const std::vector<size_t>& frequency, int min_frequency,
 			       double agsum, valarray_t& gradient);
   };
 
@@ -76,22 +76,22 @@ namespace gpsshogi
     // x = b-a
     static double addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 				 const sparse_vector_t& b, double turn_coef,
-				 const osl::vector<size_t>& frequency, int min_frequency,
+				 const std::vector<size_t>& frequency, int min_frequency,
 				 valarray_t& gradient, double& agsum,
 				 double instance_weight=1.0, double margin=0.0);
     static void addGradientSep(const sparse_vector_t& a, 
-			       const osl::vector<size_t>& frequency, int min_frequency,
+			       const std::vector<size_t>& frequency, int min_frequency,
 			       double agsum, valarray_t& gradient);
   };
   struct HalfSigmoidLoss : public ValarrayUtil
   {
     static double addGradientSep(const valarray_t& w, double adot, const sparse_vector_t& a,
 				 const sparse_vector_t& b, double turn_coef,
-				 const osl::vector<size_t>& frequency, int min_frequency,
+				 const std::vector<size_t>& frequency, int min_frequency,
 				 valarray_t& gradient, double& agsum,
 				 double instance_weight=1.0, double margin=0.0);
     static void addGradientSep(const sparse_vector_t& a, 
-			       const osl::vector<size_t>& frequency, int min_frequency,
+			       const std::vector<size_t>& frequency, int min_frequency,
 			       double agsum, valarray_t& gradient);
   };
 }
