@@ -2,7 +2,7 @@
  */
 #ifndef GPSSHOGI_MOVEDATA_H
 #define GPSSHOGI_MOVEDATA_H
-#include "osl/stl/vector.h"
+#include <vector>
 #include <iosfwd>
 
 namespace gpsshogi
@@ -10,7 +10,7 @@ namespace gpsshogi
   struct MoveData
   {
     int value, progress;
-    osl::vector<std::pair<int,double> > diffs;
+    std::vector<std::pair<int,double> > diffs;
     explicit MoveData() : value(0), progress(0)
     {
     }
