@@ -4,7 +4,7 @@
 #define GPSSHOGI_PVFILE_H
 
 #include "pvVector.h"
-#include "osl/container/moveVector.h"
+#include "osl/container.h"
 #include <zlib.h>
 
 namespace gpsshogi
