@@ -6,18 +6,15 @@
 #include "analyzer.h"
 
 #include "osl/record/kisen.h"
-#include "osl/record/csaIOError.h"
 #include "osl/record/csaRecord.h"
 #include "osl/rating/featureSet.h"
 #include "osl/rating/ratingEnv.h"
-#include "osl/search/shouldPromoteCut.h"
+#include "osl/move_classifier/shouldPromoteCut.h"
 #include "osl/progress/effect5x3.h"
-#include "osl/progress/ml/newProgress.h"
-#include "osl/move_generator/legalMoves.h"
+#include "osl/progress.h"
 #include "osl/move_probability/featureSet.h"
-#include "osl/stl/hash_set.h"
 
-#include <boost/foreach.hpp>
+#include <unordered_set>
 #include <algorithm>
 #include <numeric>
 #include <sstream>
@@ -30,7 +27,7 @@ bool gpsshogi::KisenAnalyzer::compare_pass = false;
 bool gpsshogi::KisenAnalyzer::bonanza_compatible_search = false;
 int gpsshogi::KisenAnalyzer::window_asymmetry = 1;
 int gpsshogi::PVGenerator::limit_sibling = 0;
-osl::vector<int> gpsshogi::KisenAnalyzer::priority_record;
+std::vector<int> gpsshogi::KisenAnalyzer::priority_record;
 
 gpsshogi::KisenAnalyzer::
 RecordConfig::RecordConfig(size_t tid, size_t f, size_t l, const std::string& kisen, bool a)
@@ -74,12 +71,12 @@ void gpsshogi::KisenAnalyzer::operator()()
 
   init();
   KisenFile kisen_file(record.kisen_filename.c_str());
-  boost::scoped_ptr<KisenIpxFile> ipx;
+  std::unique_ptr<KisenIpxFile> ipx;
   if (config.min_rating)
     ipx.reset(new KisenIpxFile(KisenFile::ipxFileName(record.kisen_filename)));
 
   assert(record.last >= record.first);
-  vector<size_t> orders(record.last - record.first);
+  std::vector<size_t> orders(record.last - record.first);
   for (size_t i=0; i<orders.size(); ++i)
     orders[i] = i + record.first;
   if (use_percent < 100) {
@@ -104,8 +101,8 @@ void gpsshogi::KisenAnalyzer::operator()()
     }
     orders.resize(limit);
   }
-  hash_set<HashKey,osl::stl::hash<HashKey> > visited;
-  BOOST_FOREACH(size_t i, orders) {
+  std::unordered_set<HashKey, std::hash<HashKey>> visited;
+  for (size_t i: orders) {
     if (record.allow_skip_in_cross_validation && isCrossValidation()) {
       if (i % 4)
 	continue;
@@ -118,8 +115,8 @@ void gpsshogi::KisenAnalyzer::operator()()
 	std::cerr << ".";
     }
     if (config.min_rating
-	&& (ipx->getRating(i, BLACK) < config.min_rating 
-	    || ipx->getRating(i, WHITE) < config.min_rating)) {
+	&& (ipx->rating(i, BLACK) < config.min_rating 
+	    || ipx->rating(i, WHITE) < config.min_rating)) {
       ++(result->skip_by_rating);
       continue;
     }
@@ -128,8 +125,8 @@ void gpsshogi::KisenAnalyzer::operator()()
 #endif
     ++result->record_processed;
 
-    NumEffectState state(kisen_file.getInitialState());
-    const vector<Move> moves=kisen_file.getMoves(i);
+    NumEffectState state(kisen_file.initialState());
+    const std::vector<Move> moves=kisen_file.moves(i);
     Quiesce quiesce(config.my_eval, normal_depth, quiesce_depth);
     osl::progress::ml::NewProgress progress(state);
     stat::Average record_errors;
@@ -165,8 +162,8 @@ void gpsshogi::KisenAnalyzer::operator()()
     }
 
     if (isCrossValidation())
-      result->all_errors.push_back(boost::make_tuple
-				   (i, record_errors.getAverage()));    
+      result->all_errors.push_back(std::make_tuple
+				   (i, record_errors.average()));    
   }
 
   if (!isCrossValidation())
@@ -174,8 +171,8 @@ void gpsshogi::KisenAnalyzer::operator()()
     for (size_t i = 0; i < record.csa_filenames.size(); ++i)
     {
       CsaFile csa(record.csa_filenames[i]);
-      NumEffectState state = csa.getInitialState();
-      const vector<Move> moves = csa.getRecord().getMoves();
+      NumEffectState state = csa.initialState();
+      const std::vector<Move> moves = csa.moves();
       if (!moves.empty())
       {
         Quiesce quiesce(config.my_eval, normal_depth, quiesce_depth);
@@ -215,13 +212,13 @@ KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t
   if (num_assignment == 0 || first == last)
     return;
   KisenFile kisen_file(file);
-  vector<int> moves(last-first+1);
+  std::vector<int> moves(last-first+1);
   for (size_t i=first; i<last; ++i)
     moves[i-first+1] = 
-      kisen_file.getMoves(i).size()
-      + std::max((int)kisen_file.getMoves(i).size()-60, 0)
-      + std::max((int)kisen_file.getMoves(i).size()-120, 0)
-      + std::max((int)kisen_file.getMoves(i).size()-180, 0)
+      kisen_file.moves(i).size()
+      + std::max((int)kisen_file.moves(i).size()-60, 0)
+      + std::max((int)kisen_file.moves(i).size()-120, 0)
+      + std::max((int)kisen_file.moves(i).size()-180, 0)
       + moves[i-first];
   const int average_moves = moves.back()/num_assignment;
   size_t cur = first;
@@ -263,7 +260,7 @@ KisenAnalyzer::distributeJob(size_t split, RecordConfig *out, size_t kisen_start
                              const std::vector<std::string>& csa_files)
 {
   size_t total = 0;
-  vector<size_t> totals(files.size()+1), sizes(files.size());
+  std::vector<size_t> totals(files.size()+1), sizes(files.size());
   for (size_t i=0; i<files.size(); ++i) {
     totals[i] = total;
     try {
@@ -300,8 +297,8 @@ KisenAnalyzer::distributeJob(size_t split, RecordConfig *out, size_t kisen_start
   // first, try to assgin at least one cpu for each file
   int cpu_left = split;
   const int offset = kisen_start - totals[start_file];
-  vector<int> assignment(files.size()); 
-  vector<double> amount(files.size());
+  std::vector<int> assignment(files.size()); 
+  std::vector<double> amount(files.size());
   for (size_t i=0; i<std::min(split, end_file-start_file); ++i) {
     const int file = start_file+i;
     assignment[file] = 1;
@@ -388,14 +385,14 @@ Validator::forEachPosition(int /*record_id*/, int /*position_id*/, size_t,
     return;
 
   MoveVector moves;
-  LegalMoves::generate(state, moves);
+  state.generateLegal(moves);
   if (moves.size() < 2 || ! moves.isMember(best_move))
     return;
   if (! bonanza_compatible_search && compare_pass && ! state.inCheck())
     moves.push_back(Move::PASS(state.turn()));
 
   size_t move_id = 0;
-  vector<int> values; values.reserve(moves.size());
+  std::vector<int> values; values.reserve(moves.size());
   values.push_back(best_value*turn_sign);
   for (MoveVector::const_iterator p=moves.begin(); p!=moves.end(); ++p, ++move_id) {
     if (*p == best_move)
@@ -534,7 +531,7 @@ PVGenerator::searchSiblings(Quiesce& quiesce, int width,
     if (*p == best_move)
       continue;
     if (! p->isPass()
-	&& osl::search::ShouldPromoteCut::canIgnoreAndNotDrop(*p)
+	&& osl::ShouldPromoteCut::canIgnoreAndNotDrop(*p)
 	&& state.hasEffectAt(alt(p->player()), p->to()))
       continue;
     pv.clear();
@@ -622,7 +619,7 @@ PVGenerator::forEachPosition(int record_id, int position_id, size_t position_siz
   }
 
   double cur_errors = 0.0;
-  BOOST_FOREACH(const value_and_pv_t& p, values) {
+  for (const value_and_pv_t& p: values) {
     cur_errors += SigmoidUtil::alphax(p.first - best_value,
 				      config.sigmoid_alpha);
   }
