@@ -1,16 +1,15 @@
 #include "pvVector.h"
-#include "osl/state/numEffectState.h"
-#include "osl/eval/pieceEval.h"
-#include <boost/foreach.hpp>
+#include "osl/numEffectState.h"
+#include "osl/eval/ptypeEval.h"
 #include <iostream>
 
 int gpsshogi::PVVector::pieceValue() const
 {
   static const osl::NumEffectState dummy;
   int sum = 0;
-  BOOST_FOREACH(osl::Move move, *this)
+  for (osl::Move move: *this)
     if (move.isNormal())
-      sum += osl::PieceEval::diffWithMove(dummy, move);
+      sum += osl::eval::Ptype_Eval_Table.diffWithMove(dummy, move);
   return sum;
 }
 
@@ -18,13 +17,13 @@ int gpsshogi::PVVector::pieceValueOfTurn() const
 {
   if (empty())
     return 0;
-  return pieceValue() * playerToMul(front().player());
+  return pieceValue() * sign(front().player());
 }
 
 std::ostream& gpsshogi::operator<<(std::ostream& os, const PVVector& moves)
 {
   os<< "PVVector" << std::endl;
-  BOOST_FOREACH(osl::Move m, moves) {
+  for (osl::Move m: moves) {
     os << m << std::endl;
   }
   return os<<std::endl;
