@@ -3,8 +3,8 @@
 #ifndef GPSSHOGI_PVVECTOR_H
 #define GPSSHOGI_PVVECTOR_H
 
-#include "osl/move.h"
-#include "osl/misc/fixedCapacityVector.h"
+#include "osl/container.h"
+
 namespace gpsshogi
 {
   enum { PvMaxDepth = 48 };
