@@ -2,29 +2,27 @@
  */
 #include "quiesce.h"
 #include "osl/search/sortCaptureMoves.h"
-#include "osl/search/shouldPromoteCut.h"
+#include "osl/move_classifier/shouldPromoteCut.h"
 #include "osl/search/quiescenceGenerator.h"
 #include "osl/move_probability/featureSet.h"
 #include "osl/rating/featureSet.h"
 #include "osl/rating/ratingEnv.h"
-#include "osl/record/opening/bookInMemory.h"
+#include "osl/book/bookInMemory.h"
 #include "osl/move_order/captureSort.h"
 #include "osl/checkmate/immediateCheckmate.h"
 #include "osl/eval/evalTraits.h"
 #include "osl/eval/pieceEval.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/move_generator/legalMoves.h"
 #include "osl/move_generator/capture_.h"
 #include "osl/move_generator/promote_.h"
 #include "osl/move_generator/escape_.h"
 #include "osl/move_generator/capture_.h"
 #include "osl/move_generator/allMoves.h"
-#include "osl/move_action/store.h"
+#include "osl/move_generator/move_action.h"
 #include "osl/move_classifier/check_.h"
 #include "osl/eval/see.h"
 #include "osl/rating/ratedMoveVector.h"
-#include "osl/record/csa.h"
-#include <boost/foreach.hpp>
+#include "osl/csa.h"
 #include <iostream>
 
 const size_t NoDebug = (size_t)-1;
@@ -218,7 +216,7 @@ Quiesce::generateAllMoves(MoveVector& moves, int depth_left) const
 {
   if (bonanzaCompatible()) {
     MoveVector all;
-    LegalMoves::generate(*state(), all);
+    state()->generateLegal(all);
     selectSeePlus(*state(), all, moves, -40000);
     return;
   }
@@ -336,8 +334,8 @@ Quiesce::search(int alpha, int beta, int depth_left)
 	      << ' ' << eval_value->value() << ' '
 	      << (bonanzaCompatible() ? "B" : "")
 	      << (consider_standpat ? "S" : "");
-    BOOST_FOREACH(Move move, history)
-      std::cerr << ' ' << record::csa::show(move);
+    for (Move move: history)
+      std::cerr << ' ' << csa::show(move);
     std::cerr << "\n";
     return state()->inCheck() ? infty(alt(turn)) : infty(turn);
   }
@@ -529,7 +527,7 @@ Quiesce::search(int alpha, int beta, int depth_left)
       && history[history.size()-2].isDrop();
     MoveVector all;
     GenerateEscapeKing::generateCheap(*state(), all);
-    BOOST_FOREACH(Move move, all) {
+    for (Move move: all) {
       if (need_selection && move.isDrop()
 	  && ! state()->hasEffectAt(state()->turn(), move.to()))
 	continue;		// successive sacrifice
@@ -564,7 +562,7 @@ Quiesce::search(int alpha, int beta, int depth_left)
   for (MoveVector::const_iterator p=moves.begin(); p!=moves.end(); ++p) {
     if (first_moves.isMember(*p))
       continue;
-    if (osl::search::ShouldPromoteCut::canIgnoreAndNotDrop(*p))
+    if (osl::ShouldPromoteCut::canIgnoreAndNotDrop(*p))
       continue;
     const bool extension = full_search_depth_left > 0
       && reduction > 0 && ! history.empty()
