@@ -5,13 +5,11 @@
 
 #include "eval/eval.h"
 #include "pvVector.h"
-#include "osl/hash/hashKey.h"
+#include "osl/hashKey.h"
 #include "osl/state/historyState.h"
-#include "osl/container/moveVector.h"
-#include "osl/stl/hash_map.h"
-#include "osl/stl/vector.h"
-#include "osl/misc/cstdint.h"
-#include <boost/scoped_ptr.hpp>
+#include "osl/container.h"
+#include <unordered_map>
+#include <memory>
 
 namespace gpsshogi
 {
@@ -50,7 +48,7 @@ namespace gpsshogi
   };
   class Table
   {
-    typedef hash_map<HashKey, Record> map_t;
+    typedef std::unordered_map<HashKey, Record, std::hash<HashKey>> map_t;
     map_t table;
   public:
     Table();
@@ -61,7 +59,7 @@ namespace gpsshogi
   };
   class BigramTable
   {
-    typedef hash_map<int, Move> map_t;
+    typedef std::unordered_map<int, Move> map_t;
     map_t table;
   public:
     BigramTable();
@@ -95,9 +93,9 @@ namespace gpsshogi
     PVVector history;
     CArray<Move, PvMaxDepth> killers;
     size_t time;
-    vector<PVVector> pv;
+    std::vector<PVVector> pv;
     uint64_t node_count;
-    boost::scoped_ptr<EvalValueStack> eval_value;
+    std::unique_ptr<EvalValueStack> eval_value;
   public:
     explicit Quiesce(Eval *, int all_moves_depth=0, int quiesce_depth=3);
     ~Quiesce();
