@@ -3,10 +3,10 @@
 #ifndef _ROTATERECORD_H
 #define _ROTATERECORD_H
 
-#include "osl/stl/vector.h"
-#include <boost/tuple/tuple.hpp>
 #include <boost/noncopyable.hpp>
 #include <string>
+#include <vector>
+
 namespace gpsshogi
 {
   class RotateRecord : boost::noncopyable
@@ -17,7 +17,7 @@ namespace gpsshogi
     RotateRecord(const std::string& src, int window, const std::string& work, int start=0);
     ~RotateRecord();
 
-    void rotate(const osl::vector<boost::tuple<int,double> >& all, double average);
+    void rotate(const std::vector<std::tuple<int,double> >& all, double average);
   };
 }
 
