@@ -6,99 +6,88 @@
 #include "eval/progressEval.h"
 #include "analyzer.h"
 #include "osl/eval/pieceEval.h"
-#include "osl/record/csaString.h"
-#include "osl/record/csaRecord.h"
+#include "osl/csa.h"
 #include "osl/oslConfig.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/eval/progressEval.h"
-#include "osl/progress/ml/newProgress.h"
-#include <ext/algorithm>
+#include "osl/progress.h"
+#include <algorithm>
 #include <fstream>
 #include <iostream>
 #include <valarray>
 
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 
 using namespace osl;
 using namespace osl::eval;
-extern bool isShortTest;
+extern bool long_test;
 
-class EvalTest : public testing::Test
+static  int Gold() { return gpsshogi::PieceEval().value(GOLD); }
+static  int Rook() { return gpsshogi::PieceEval().value(ROOK); }
+static  int total(const gpsshogi::Eval& eval,
+		  const std::vector<std::pair<int, double> >& diff) 
 {
-protected:
-  void SetUp()
-  {
-    osl::eval::ml::OpenMidEndingEval::setUp();
-    osl::progress::ml::NewProgress::setUp();
-    osl::eval::ProgressEval::setUp();
+  int sum = 0;
+  for (size_t i=0; i<diff.size(); ++i) {
+    sum += (int)(eval.flatValue(diff[i].first)*diff[i].second);
   }
-  int Gold() { return gpsshogi::PieceEval().value(GOLD); }
-  int Rook() { return gpsshogi::PieceEval().value(ROOK); }
-  int total(const gpsshogi::Eval& eval,
-	    const osl::vector<std::pair<int, double> >& diff) 
-  {
-    int sum = 0;
-    for (size_t i=0; i<diff.size(); ++i) {
-      sum += (int)(eval.flatValue(diff[i].first)*diff[i].second);
-    }
-    return sum;
+  return sum;
+}
+static  void testConsistentBase(boost::ptr_vector<gpsshogi::Eval> &evals,
+				double error)
+{
+  for (size_t j=0; j<evals.size(); ++j) {
+    evals[j].setRandom();
   }
-  void testConsistentBase(boost::ptr_vector<gpsshogi::Eval> &evals,
-			  double error)
-  {
-    for (size_t j=0; j<evals.size(); ++j) {
-      evals[j].setRandom();
-    }
   
-    std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-    ASSERT_TRUE(ifs);
-    std::string file_name;
-    for (int i=0;i<900 && (ifs >> file_name) ; i++)
-    {
-      if ((i % 100) == 0)
-	std::cerr << '.';
-      if (file_name == "") 
-	break;
-      file_name = OslConfig::testCsaFile(file_name);
+  std::ifstream ifs(OslConfig::testCsaFile("FILES"));
+  BOOST_REQUIRE(ifs);
+  std::string file_name;
+  for (int i=0;i<900 && (ifs >> file_name) ; i++)
+  {
+    if ((i % 100) == 0)
+      std::cerr << '.';
+    if (file_name == "") 
+      break;
+    file_name = OslConfig::testCsaFile(file_name);
 
-      const Record record=CsaFile(file_name).getRecord();
-      const vector<osl::Move> moves=record.getMoves();
+    const auto record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
 
-      NumEffectState state(record.getInitialState());
+    NumEffectState state(record.initialState());
     
-      for (unsigned int i=0; i<moves.size(); i++) {
-	const Move m = moves[i];
-	state.makeMove(m);
+    for (unsigned int i=0; i<moves.size(); i++) {
+      const Move m = moves[i];
+      state.makeMove(m);
 
-	for (size_t j=0; j<evals.size(); ++j) {
-	  const int value = evals[j].eval(state);
+      for (size_t j=0; j<evals.size(); ++j) {
+	const int value = evals[j].eval(state);
 	
-	  gpsshogi::MoveData data;
-	  const int& features_value = data.value;
-	  const vector<std::pair<int, double> >& diffs = data.diffs;
-	  evals[j].features(state, data, 0);
+	gpsshogi::MoveData data;
+	const int& features_value = data.value;
+	const auto& diffs = data.diffs;
+	evals[j].features(state, data, 0);
 #ifndef L1BALL_NO_SORT
-          ASSERT_TRUE(__gnu_cxx::is_sorted(diffs.begin(), diffs.end()));
+	BOOST_REQUIRE(__gnu_cxx::is_sorted(diffs.begin(), diffs.end()));
 #endif
-	  if (abs(value - total(evals[j], diffs)) > evals[j].roundUp()) {
-	    std::cerr << "eval " << j << "\n" << state << m << " " << features_value << "\n";
-	    for (size_t k=0; k<diffs.size(); ++k)
-	      std::cerr << diffs[k].first << " "
-			<< evals[j].findFeature(diffs[k].first).get<0>()
-			<< " " << diffs[k].second
-			<< "  " << evals[j].flatValue(diffs[k].first) << "\n";
-	    std::cerr << "inequality " << value << " " << total(evals[j], diffs)
-		      << ' ' << features_value << "\n";
-	  }
-	  ASSERT_NEAR(value, total(evals[j], diffs), evals[j].roundUp());
-	  ASSERT_NEAR(value, features_value, error);
+	if (abs(value - total(evals[j], diffs)) > evals[j].roundUp()) {
+	  std::cerr << "eval " << j << "\n" << state << m << " " << features_value << "\n";
+	  for (size_t k=0; k<diffs.size(); ++k)
+	    std::cerr << diffs[k].first << " "
+		      << std::get<0>(evals[j].findFeature(diffs[k].first))
+		      << " " << diffs[k].second
+		      << "  " << evals[j].flatValue(diffs[k].first) << "\n";
+	  std::cerr << "inequality " << value << " " << total(evals[j], diffs)
+		    << ' ' << features_value << "\n";
 	}
+	BOOST_CHECK_SMALL(value - total(evals[j], diffs), std::max(2,evals[j].roundUp()));
+	BOOST_CHECK_SMALL((double)(value - features_value), error);
       }
     }
   }
-};
+}
 
-TEST_F(EvalTest, testStableOpenMidEndingEval)
+BOOST_AUTO_TEST_CASE(EvalTestStableOpenMidEndingEval)
 {  
   gpsshogi::StableOpenMidEnding eval;
   {
@@ -107,21 +96,21 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
   }
   using namespace osl;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-  ASSERT_TRUE(ifs);
+  BOOST_REQUIRE(ifs);
   std::string file_name;
 
   osl::eval::ml::OpenMidEndingEval::setUp();
   osl::progress::ml::NewProgress::setUp();
 
-  ASSERT_EQ(osl::progress::ml::NewProgress::maxProgress(), eval.maxProgress());
-  for (int i=0;i<(isShortTest ? 10 : 200) && (ifs >> file_name) ; i++)
+  BOOST_REQUIRE_EQUAL(osl::progress::ml::NewProgress::maxProgress(), eval.maxProgress());
+  for (int i=0;i<(!long_test ? 10 : 200) && (ifs >> file_name) ; i++)
   {
     if (file_name == "")
       break;
     file_name = OslConfig::testCsaFile(file_name);
-    const Record rec=CsaFile(file_name).getRecord();
-    const vector<osl::Move> moves=rec.getMoves();
-    NumEffectState state(rec.getInitialState());
+    const RecordMinimal record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
+    NumEffectState state(record.initialState());
     osl::eval::ml::OpenMidEndingEval test_eval(state, false);
     for (unsigned int i=0; i<moves.size(); i++){
       const Move m = moves[i];
@@ -134,14 +123,21 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 	std::cerr << "gpsshogi\n";
 	eval.debug(state);
       }
-      ASSERT_EQ(test_eval.openingValue(), eval.openingValue(state)) << state << m << " progress " << eval.progress(state)
-								    << " progress max " << eval.maxProgress();
-      ASSERT_EQ(test_eval.midgameValue(), eval.midgameValue(state)) << state << m;
-#ifdef EVAL_QUAD
-      ASSERT_EQ(test_eval.midgame2Value(), eval.midgame2Value(state)) << state << m;
+      BOOST_REQUIRE_EQUAL(test_eval.openingValue(), eval.openingValue(state));
+#if 0
+      << state << m << " progress " << eval.progress(state)
+      << " progress max " << eval.maxProgress();
 #endif
-      ASSERT_EQ(test_eval.endgameValue(), eval.endgameValue(state)) << state << m;
-      ASSERT_EQ(test_eval.progressIndependentValue(), eval.progressIndependentValue(state)) << state << m;
+      BOOST_REQUIRE_EQUAL(test_eval.midgameValue(), eval.midgameValue(state));
+      // << state << m;
+#ifdef EVAL_QUAD
+      BOOST_REQUIRE_EQUAL(test_eval.midgame2Value(), eval.midgame2Value(state));
+      // << state << m;
+#endif
+      BOOST_REQUIRE_EQUAL(test_eval.endgameValue(), eval.endgameValue(state));
+      // << state << m;
+      BOOST_REQUIRE_EQUAL(test_eval.progressIndependentValue(), eval.progressIndependentValue(state));
+      // << state << m;
       if (abs(test_eval.value() - eval.eval(state)) > 2.0) {
 	const int progress = eval.progress(state);
 	MultiInt stage_value;
@@ -151,12 +147,14 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 	stage_value[3] = eval.endgameValue(state);
 	int flat = test_eval.progressIndependentValueAdjusted
 	  (eval.progressIndependentValue(state),progress,eval.maxProgress());
-	ASSERT_NEAR(test_eval.value(),
-		    eval.compose(flat, stage_value, progress),
-		    2.0) << state << m;
+	BOOST_CHECK_SMALL(test_eval.value()
+			  - eval.compose(flat, stage_value, progress),
+			  2);
+	//<< state << m;
       }
       else
-	ASSERT_NEAR(test_eval.value(), eval.eval(state), 2.0) << state << m;
+	BOOST_CHECK_SMALL(test_eval.value() - eval.eval(state), 2);
+      // << state << m;
     }
   }
   // additional positions
@@ -171,9 +169,10 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 				 "P7+FU+FU+GI+KI+KA+FU+GI * +KY\n"
 				 "P8 * +OU+KI *  *  *  *  * +HI\n"
 				 "P9+KY+KE *  *  *  *  * +KE * \n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     osl::eval::ml::OpenMidEndingEval test_eval(state, false);
-    ASSERT_NEAR(test_eval.value(), eval.eval(state), 2.0) << state;
+    BOOST_CHECK_SMALL(test_eval.value() - eval.eval(state), 2);
+    // << state;
   }
   {
     const NumEffectState state(CsaString(
@@ -188,9 +187,9 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 				 "P9+KY+KE *  *  *  *  * +HI+KY\n"
 				 "P+00KI00GI00KE00FU00FU\n"
 				 "P-00FU00FU\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     osl::eval::ml::OpenMidEndingEval test_eval(state, false);
-    ASSERT_NEAR(test_eval.value(), eval.eval(state), 2.0) << state;
+    BOOST_CHECK_SMALL(test_eval.value()- eval.eval(state), 2);
   }
   {
     const NumEffectState state(CsaString(
@@ -205,13 +204,13 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 				 "P9 *  *  *  *  * +KI * +KE+KY\n"
 				 "P+00HI00HI00KI00KI00GI\n"
 				 "P-00KI00GI00KE00KY00FU00FU00FU00FU00FU00FU00FU\n"
-				 "-\n").getInitialState());
+				 "-\n").initialState());
     osl::eval::ml::OpenMidEndingEval test_eval(state, false);
-    ASSERT_NEAR(test_eval.value(), eval.eval(state), 2.0) << state;
+    BOOST_CHECK_SMALL(test_eval.value()- eval.eval(state), 2);
   }
 }
 
-TEST_F(EvalTest, testAllDifferential)
+BOOST_AUTO_TEST_CASE(EvalTestAllDifferential)
 {
   gpsshogi::PieceEval eval;
   {
@@ -225,7 +224,7 @@ TEST_F(EvalTest, testAllDifferential)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI * +OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::MoveData md;
     eval.features(state, md, 0);
   }
@@ -241,22 +240,22 @@ TEST_F(EvalTest, testAllDifferential)
 				 "P8 *  *  *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
 				 "P+00FU\n"
-				 "-\n").getInitialState());
+				 "-\n").initialState());
     gpsshogi::MoveData md;
     eval.features(state, md, 0);
   }
 }
 
-TEST_F(EvalTest, testConstruct)
+BOOST_AUTO_TEST_CASE(EvalTestConstruct)
 {
-  ASSERT_TRUE(osl::eval::ml::OpenMidEndingEval::setUp());
-  ASSERT_TRUE(osl::progress::ml::NewProgress::setUp());
+  BOOST_REQUIRE(osl::eval::ml::OpenMidEndingEval::setUp());
+  BOOST_REQUIRE(osl::progress::ml::NewProgress::setUp());
   gpsshogi::PieceEval eval;
   gpsshogi::RichEval reval(0);
   {
     const NumEffectState state((SimpleState(HIRATE)));
-    EXPECT_EQ(0, eval.eval(state));
-    EXPECT_EQ(0, reval.eval(state));
+    BOOST_CHECK_EQUAL(0, eval.eval(state));
+    BOOST_CHECK_EQUAL(0, reval.eval(state));
   }
   
   {
@@ -270,13 +269,13 @@ TEST_F(EvalTest, testConstruct)
 			      "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 			      "P8 * +KA *  *  *  *  * +HI * \n"
 			      "P9+KY+KE+GI * +OU+KI+GI+KE+KY\n"
-			      "+\n").getInitialState());
-    EXPECT_EQ(-Gold()*2, eval.eval(state));
-    EXPECT_EQ(-Gold()*2, reval.eval(state));
+			      "+\n").initialState());
+    BOOST_CHECK_EQUAL(-Gold()*2, eval.eval(state));
+    BOOST_CHECK_EQUAL(-Gold()*2, reval.eval(state));
 
     gpsshogi::MoveData data;
     reval.features(state, data, 0);
-    EXPECT_EQ(-Gold()*2, static_cast<int>(data.value));
+    BOOST_CHECK_EQUAL(-Gold()*2, static_cast<int>(data.value));
   }
 
   {
@@ -291,13 +290,13 @@ TEST_F(EvalTest, testConstruct)
 			      "P8 * +KA *  *  *  *  * +HI * \n"
 			      "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
 			      "P+00HI\n"
-			      "+\n").getInitialState());
-    EXPECT_EQ(Rook()*2, eval.eval(state));
-    EXPECT_EQ(Rook()*2, reval.eval(state));
+			      "+\n").initialState());
+    BOOST_CHECK_EQUAL(Rook()*2, eval.eval(state));
+    BOOST_CHECK_EQUAL(Rook()*2, reval.eval(state));
   }
 }
 
-TEST_F(EvalTest, testConsistent)
+BOOST_AUTO_TEST_CASE(EvalTestConsistent)
 {
   boost::ptr_vector<gpsshogi::Eval> evals;
   evals.push_back(new gpsshogi::PieceEval);
@@ -305,7 +304,7 @@ TEST_F(EvalTest, testConsistent)
   testConsistentBase(evals, 0.1);
 }
 
-TEST_F(EvalTest, testConsistentProgress)
+BOOST_AUTO_TEST_CASE(EvalTestConsistentProgress)
 {
   boost::ptr_vector<gpsshogi::Eval> evals;
 #ifdef LEARN_TEST_PROGRESS
@@ -320,7 +319,7 @@ TEST_F(EvalTest, testConsistentProgress)
   testConsistentBase(evals, 0.1 * 16);
 }
 
-TEST_F(EvalTest, testConsistentUpdate)
+BOOST_AUTO_TEST_CASE(EvalTestConsistentUpdate)
 {
   boost::ptr_vector<gpsshogi::Eval> evals;
   evals.push_back(new gpsshogi::PieceEval);
@@ -333,13 +332,13 @@ TEST_F(EvalTest, testConsistentUpdate)
   evals.push_back(new gpsshogi::KOpenMidEnding());
   evals.push_back(new gpsshogi::KProgressEval());
 
-  osl::vector<int> values(evals.size());
+  std::vector<int> values(evals.size());
   for (size_t j=0; j<evals.size(); ++j) {
     evals[j].setRandom();
   }
   
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-  ASSERT_TRUE(ifs);
+  BOOST_REQUIRE(ifs);
   std::string file_name;
   for (int i=0;i<900 && (ifs >> file_name) ; i++)
   {
@@ -349,10 +348,10 @@ TEST_F(EvalTest, testConsistentUpdate)
       break;
     file_name = OslConfig::testCsaFile(file_name);
 
-    const Record record=CsaFile(file_name).getRecord();
-    const vector<osl::Move> moves=record.getMoves();
+    const auto record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
 
-    NumEffectState state(record.getInitialState());
+    NumEffectState state(record.initialState());
     
     boost::ptr_vector<gpsshogi::EvalValueStack> eval_values;
     for (size_t j=0; j<evals.size(); ++j) {
@@ -367,16 +366,16 @@ TEST_F(EvalTest, testConsistentUpdate)
 	const int value = evals[j].eval(state);
 
 	eval_values[j].push(state, m);
-	EXPECT_EQ(value, eval_values[j].value())
-	  << "eval " << j << "\n" << state << m << "\n";
+	BOOST_CHECK_EQUAL(value, eval_values[j].value());
+	// << "eval " << j << "\n" << state << m << "\n";
       }
       if (! state.inCheck()) {
 	state.changeTurn();
 	for (size_t j=0; j<evals.size(); ++j) {
 	  eval_values[j].push(state, Move::PASS(alt(state.turn())));
 	  const int value = evals[j].eval(state);
-	  EXPECT_EQ(value, eval_values[j].value())
-	    << " eval(pass) " << j << "\n" << state << m << "\n";
+	  BOOST_CHECK_EQUAL(value, eval_values[j].value());
+	  // << " eval(pass) " << j << "\n" << state << m << "\n";
 	  eval_values[j].pop();
 	}
 	state.changeTurn();
@@ -385,7 +384,7 @@ TEST_F(EvalTest, testConsistentUpdate)
   }
 }
 
-TEST_F(EvalTest, testSaveWeight)
+BOOST_AUTO_TEST_CASE(EvalTestSaveWeight)
 {
   boost::ptr_vector<gpsshogi::Eval> evals;
   evals.push_back(new gpsshogi::PieceEval);
@@ -398,17 +397,17 @@ TEST_F(EvalTest, testSaveWeight)
   evals.push_back(new gpsshogi::KOpenMidEnding());
   evals.push_back(new gpsshogi::KProgressEval());
 
-  osl::vector<int> values(evals.size());
+  std::vector<int> values(evals.size());
   for (size_t j=0; j<evals.size(); ++j) {
     evals[j].setRandom();
     std::valarray<double> weight(evals[j].dimension());
     evals[j].saveWeight(&weight[0]);
     for (size_t i=0; i<evals[j].dimension(); ++i)
-      ASSERT_EQ(evals[j].flatValue(i), weight[i]);
+      BOOST_REQUIRE_EQUAL(evals[j].flatValue(i), weight[i]);
   }  
 }
 
-TEST_F(EvalTest, testSymmetry)
+BOOST_AUTO_TEST_CASE(EvalTestSymmetry)
 {  
   boost::ptr_vector<gpsshogi::Eval> evals;
   evals.push_back(new gpsshogi::PieceEval);
@@ -427,16 +426,16 @@ TEST_F(EvalTest, testSymmetry)
 
   using namespace osl;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-  ASSERT_TRUE(ifs);
+  BOOST_REQUIRE(ifs);
   std::string file_name;
-  for (int i=0;i<(isShortTest ? 10 : 200) && (ifs >> file_name) ; i++)
+  for (int i=0;i<(!long_test ? 10 : 200) && (ifs >> file_name) ; i++)
   {
     if (file_name == "")
       break;
     file_name = OslConfig::testCsaFile(file_name);
-    const Record rec=CsaFile(file_name).getRecord();
-    const vector<osl::Move> moves=rec.getMoves();
-    NumEffectState state(rec.getInitialState());
+    const RecordMinimal record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
+    NumEffectState state(record.initialState());
     for (unsigned int i=0; i<moves.size(); i++){
       const Move m = moves[i];
       state.makeMove(m);
@@ -450,15 +449,15 @@ TEST_F(EvalTest, testSymmetry)
 	  std::cerr << "\n";
 	  evals[j].showEvalSummary(state_r);
 	}
-	ASSERT_NEAR(evals[j].eval(state), -evals[j].eval(state_r),
-		    evals[j].roundUp()*2);
+	BOOST_CHECK_SMALL(evals[j].eval(state) - (-evals[j].eval(state_r)),
+			  std::max(1,evals[j].roundUp()*2));
       }
     }
   } 
 }
 
 #ifdef LEARN_TEST_PROGRESS
-TEST_F(EvalTest, testStableProgress)
+BOOST_AUTO_TEST_CASE(EvalTestStableProgress)
 {  
   gpsshogi::StableEffectProgressFeatureEval progress;
   {
@@ -468,31 +467,30 @@ TEST_F(EvalTest, testStableProgress)
   }
   using namespace osl;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-  ASSERT_TRUE(ifs);
+  BOOST_REQUIRE(ifs);
   std::string file_name;
 
   const int osl_progress_scale = osl::progress::ml::NewProgress::ProgressScale;
 
   osl::progress::ml::NewProgress::setUp();
-  ASSERT_EQ(osl::progress::ml::NewProgress::maxProgress(),
-	    progress.maxProgress() / osl_progress_scale) << progress.maxProgress();
-  for (int i=0;i<(isShortTest ? 10 : 200) && (ifs >> file_name) ; i++)
+  BOOST_REQUIRE_EQUAL(osl::progress::ml::NewProgress::maxProgress(),
+		      progress.maxProgress() / osl_progress_scale); 
+  for (int i=0;i<(!long_test ? 10 : 200) && (ifs >> file_name) ; i++)
   {
     if (file_name == "")
       break;
     file_name = OslConfig::testCsaFile(file_name);
-    const Record rec=CsaFile(file_name).getRecord();
-    const vector<osl::Move> moves=rec.getMoves();
-    NumEffectState state(rec.getInitialState());
+    const RecordMinimal record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
+    NumEffectState state(record.initialState());
     osl::progress::ml::NewProgress test_progress(state);
     for (unsigned int i=0; i<moves.size(); i++){
       const Move m = moves[i];
       state.makeMove(m);
       test_progress.update(state, m);
-      ASSERT_EQ(test_progress.progress(),
+      BOOST_REQUIRE_EQUAL(test_progress.progress(),
 		std::max(std::min(progress.progress(state),
-				  progress.maxProgress() - osl_progress_scale), 0) / osl_progress_scale)
-	<< state << m;
+				  progress.maxProgress() - osl_progress_scale), 0) / osl_progress_scale);
     }
   } 
 
@@ -501,12 +499,12 @@ TEST_F(EvalTest, testStableProgress)
     const char *filename = "../stable-eval.txt";
     eval.load(filename);
   }
-  ASSERT_NEAR(progress.pawnValue() / osl_progress_scale, eval.pawnValue(),
-    eval.pawnValue() / 10);
+  BOOST_CHECK_SMALL(progress.pawnValue() / osl_progress_scale - eval.pawnValue(),
+		    eval.pawnValue()/10);
 }
 #endif
 
-TEST_F(EvalTest, testStableProgressEval)
+BOOST_AUTO_TEST_CASE(EvalTestStableProgressEval)
 {  
   osl::eval::ProgressEval::setUp();
   gpsshogi::StableProgressEval eval;
@@ -516,26 +514,28 @@ TEST_F(EvalTest, testStableProgressEval)
   }
   using namespace osl;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
-  ASSERT_TRUE(ifs);
+  BOOST_REQUIRE(ifs);
   std::string file_name;
 
-  for (int i=0;i<(isShortTest ? 10 : 200) && (ifs >> file_name) ; i++)
+  for (int i=0;i<(!long_test ? 10 : 200) && (ifs >> file_name) ; i++)
   {
     if (file_name == "")
       break;
     file_name = OslConfig::testCsaFile(file_name);
-    const Record rec=CsaFile(file_name).getRecord();
-    const vector<osl::Move> moves=rec.getMoves();
-    NumEffectState state(rec.getInitialState());
+    const auto record=CsaFileMinimal(file_name).load();
+    const auto moves=record.moves;
+    NumEffectState state(record.initialState());
     osl::eval::ProgressEval osl_eval(state);
     for (unsigned int i=0; i<moves.size(); i++){
       const Move m = moves[i];
       state.makeMove(m);
       osl_eval.update(state, m);
-      ASSERT_EQ(osl_eval.openingValue(), eval.openingValue(state)) << state << m << " progress " << eval.progress(state)
-								    << " progress max " << eval.maxProgress();
-      ASSERT_EQ(osl_eval.endgameValue(), eval.endgameValue(state)) << state << m;
-      ASSERT_NEAR(osl_eval.value(), eval.eval(state), 2.0) << state << m;
+      BOOST_REQUIRE_EQUAL(osl_eval.openingValue(), eval.openingValue(state));
+      // << state << m << " progress " << eval.progress(state)
+      // << " progress max " << eval.maxProgress();
+      BOOST_REQUIRE_EQUAL(osl_eval.endgameValue(), eval.endgameValue(state));
+      // << state << m;
+      BOOST_CHECK_SMALL(osl_eval.value() - eval.eval(state), 2);
     }
   }
   // additional positions
@@ -550,9 +550,9 @@ TEST_F(EvalTest, testStableProgressEval)
 				 "P7+FU+FU+GI+KI+KA+FU+GI * +KY\n"
 				 "P8 * +OU+KI *  *  *  *  * +HI\n"
 				 "P9+KY+KE *  *  *  *  * +KE * \n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     osl::eval::ProgressEval osl_eval(state);
-    ASSERT_NEAR(osl_eval.value(), eval.eval(state), 2.0) << state;
+    BOOST_CHECK_SMALL(osl_eval.value()-eval.eval(state), 2);
   }
   {
     const NumEffectState state(CsaString(
@@ -567,9 +567,9 @@ TEST_F(EvalTest, testStableProgressEval)
 				 "P9+KY+KE *  *  *  *  * +HI+KY\n"
 				 "P+00KI00GI00KE00FU00FU\n"
 				 "P-00FU00FU\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     osl::eval::ProgressEval osl_eval(state);
-    ASSERT_NEAR(osl_eval.value(), eval.eval(state), 2.0) << state;
+    BOOST_CHECK_SMALL(osl_eval.value() - eval.eval(state), 2);
   }
 }
 
