@@ -1,11 +1,10 @@
 #include "l1Ball.h"
 #include "loss.h"
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 #include <iostream>
 #include <fstream>
 
-extern bool isShortTest;
-
+extern bool long_test;
 using namespace gpsshogi;
 
 /* ------------------------------------------------------------------------- */
@@ -35,7 +34,7 @@ void L1BallLogreg::makeGradient(const valarray_t& w, valarray_t& gradient, doubl
 
 void L1BallLogreg::iterationHead(int i, const valarray_t& w, double prev_error)
 {
-    if (! isShortTest)
+    if (long_test)
 	std::cerr << "iter " << i << " " << prev_error << "\n";
 }
 /* ------------------------------------------------------------------------- */
@@ -64,18 +63,18 @@ void L1BallSMDLogreg::makeGradient(const valarray_t& w, valarray_t& gradient, do
 
 void L1BallSMDLogreg::iterationHead(int i, const valarray_t& w, double prev_error)
 {
-    if (! isShortTest)
+    if (long_test)
 	std::cerr << "iter " << i << " " << prev_error << "\n";
 }
 
 /* ------------------------------------------------------------------------- */
 
-TEST(L1BallTest, testConstruct)
+BOOST_AUTO_TEST_CASE(L1BallTestConstruct)
 {
     L1BallLogreg solver;
 }
 
-TEST(L1BallTest, testSolve)
+BOOST_AUTO_TEST_CASE(L1BallTestSolve)
 {
     L1BallLogreg solver;
     x = std::vector<valarray_t>(num_e, valarray_t(num_f));
@@ -96,11 +95,11 @@ TEST(L1BallTest, testSolve)
     w = 0.0;
     // solver.setFixWidth(true);
     solver.solve(w);
-    EXPECT_GT(solver.lastIteration(), 0);
-    EXPECT_LT(solver.lastError(), 0.1);
+    BOOST_CHECK(solver.lastIteration() > 0);
+    BOOST_CHECK(solver.lastError() < 0.1);
 }
 
-TEST(L1BallTest, testSolveSMD)
+BOOST_AUTO_TEST_CASE(L1BallTestSolveSMD)
 {
     L1BallSMDLogreg solver;
     x = std::vector<valarray_t>(num_e, valarray_t(num_f));
@@ -120,8 +119,8 @@ TEST(L1BallTest, testSolveSMD)
     valarray_t w(num_f);
     w = 0.0;
     solver.solve(w);
-    EXPECT_GT(solver.lastIteration(), 0);
-    EXPECT_LT(solver.lastError(), 0.1);
+    BOOST_CHECK(solver.lastIteration() > 0);
+    BOOST_CHECK(solver.lastError() < 0.1);
 }
 
 /* ------------------------------------------------------------------------- */
