@@ -1,14 +1,11 @@
 #include "eval/majorPiece.h"
-#include "osl/record/csaString.h"
 #include "osl/record/csaRecord.h"
 
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 
 using namespace osl;
-using namespace osl::state;
-using namespace osl::record;
 
-TEST(NumPiecesBetweenBishopAndKingTest, countBetween)
+BOOST_AUTO_TEST_CASE(NumPiecesBetweenBishopAndKingTestCountBetween)
 {
   {
     const NumEffectState state(CsaString(
@@ -21,33 +18,33 @@ TEST(NumPiecesBetweenBishopAndKingTest, countBetween)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
-    ASSERT_EQ(1,
+				 "+\n").initialState());
+    BOOST_REQUIRE_EQUAL(1,
 	      gpsshogi::NumPiecesBetweenBishopAndKingAll::countBetween(
 		state,
 		state.kingSquare<BLACK>(),
 		state.pieceAt(Square(9, 5))));
-    ASSERT_EQ(0,
+    BOOST_REQUIRE_EQUAL(0,
 	      gpsshogi::NumPiecesBetweenBishopAndKingSelf::countBetween(
 		state,
 		state.kingSquare<BLACK>(),
 		state.pieceAt(Square(9, 5))));
-    ASSERT_EQ(1,
+    BOOST_REQUIRE_EQUAL(1,
 	      gpsshogi::NumPiecesBetweenBishopAndKingOpp::countBetween(
 		state,
 		state.kingSquare<BLACK>(),
 		state.pieceAt(Square(9, 5))));
-    ASSERT_EQ(3,
+    BOOST_REQUIRE_EQUAL(3,
 	      gpsshogi::NumPiecesBetweenBishopAndKingAll::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
 		state.pieceAt(Square(8, 8))));
-    ASSERT_EQ(1,
+    BOOST_REQUIRE_EQUAL(1,
 	      gpsshogi::NumPiecesBetweenBishopAndKingSelf::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
 		state.pieceAt(Square(8, 8))));
-    ASSERT_EQ(2,
+    BOOST_REQUIRE_EQUAL(2,
 	      gpsshogi::NumPiecesBetweenBishopAndKingOpp::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
@@ -64,18 +61,18 @@ TEST(NumPiecesBetweenBishopAndKingTest, countBetween)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 *  *  *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
-    ASSERT_EQ(8,
+				 "+\n").initialState());
+    BOOST_REQUIRE_EQUAL(8,
 	      gpsshogi::NumPiecesBetweenBishopAndKingAll::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
 		state.pieceAt(Square(8, 6))));
-    ASSERT_EQ(8,
+    BOOST_REQUIRE_EQUAL(8,
 	      gpsshogi::NumPiecesBetweenBishopAndKingSelf::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
 		state.pieceAt(Square(8, 6))));
-    ASSERT_EQ(8,
+    BOOST_REQUIRE_EQUAL(8,
 	      gpsshogi::NumPiecesBetweenBishopAndKingOpp::countBetween(
 		state,
 		state.kingSquare<WHITE>(),
@@ -83,7 +80,7 @@ TEST(NumPiecesBetweenBishopAndKingTest, countBetween)
   }
 }
 
-TEST(BishopBishopPieceTest, feature)
+BOOST_AUTO_TEST_CASE(BishopBishopPieceTestFeature)
 {
   {
     const NumEffectState state(CsaString(
@@ -96,12 +93,12 @@ TEST(BishopBishopPieceTest, feature)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::BishopBishopPiece bbp;
     gpsshogi::IndexCacheI<gpsshogi::MaxActiveWithDuplication> features;
     bbp.featuresOneNonUniq(state, features);
-    ASSERT_EQ(1, features.size());
-    ASSERT_EQ(bbp.index(osl::newPtypeO(BLACK, PAWN), true, true),
+    BOOST_REQUIRE_EQUAL(1, features.size());
+    BOOST_REQUIRE_EQUAL(bbp.index(osl::newPtypeO(BLACK, PAWN), true, true),
 	      features[0].first);
   }
   {
@@ -115,12 +112,12 @@ TEST(BishopBishopPieceTest, feature)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 * +KA+GI *  *  *  * +HI * \n"
 				 "P9+KY+KE * +KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::BishopBishopPiece bbp;
     gpsshogi::IndexCacheI<gpsshogi::MaxActiveWithDuplication> features;
     bbp.featuresOneNonUniq(state, features);
-    ASSERT_EQ(1, features.size());
-    ASSERT_EQ(features[0].first,
+    BOOST_REQUIRE_EQUAL(1, features.size());
+    BOOST_REQUIRE_EQUAL(features[0].first,
 	      bbp.index(osl::newPtypeO(BLACK, PAWN), false, true));
   }
 
@@ -135,15 +132,15 @@ TEST(BishopBishopPieceTest, feature)
 				 "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE * +KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::BishopBishopPiece bbp;
     gpsshogi::IndexCacheI<gpsshogi::MaxActiveWithDuplication> features;
     bbp.featuresOneNonUniq(state, features);
-    ASSERT_EQ(0, features.size());
+    BOOST_REQUIRE_EQUAL(0, features.size());
   }
 }
 
-TEST(AttackMajorsInBaseTest, feature)
+BOOST_AUTO_TEST_CASE(AttackMajorsInBaseTestFeature)
 {
   {
     const NumEffectState state(CsaString(
@@ -158,15 +155,15 @@ TEST(AttackMajorsInBaseTest, feature)
 				 "P9+KY+KE * +OU *  *  * +KE+KY\n"
 				 "P+00KI00FU00FU\n"
 				 "P-00GI00FU00FU00FU\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::AttackMajorsInBase amib;
     gpsshogi::IndexCacheI<gpsshogi::MaxActiveWithDuplication> features;
     amib.featuresOneNonUniq(state, features);
-    ASSERT_EQ(2, features.size());
-    ASSERT_EQ(amib.index(ROOK, BISHOP, true, false, false), features[0].first);
-    ASSERT_EQ(-1, features[0].second);
-    ASSERT_EQ( 0, features[1].first);
-    ASSERT_EQ(-1, features[1].second);
+    BOOST_REQUIRE_EQUAL(2, features.size());
+    BOOST_REQUIRE_EQUAL(amib.index(ROOK, BISHOP, true, false, false), features[0].first);
+    BOOST_REQUIRE_EQUAL(-1, features[0].second);
+    BOOST_REQUIRE_EQUAL( 0, features[1].first);
+    BOOST_REQUIRE_EQUAL(-1, features[1].second);
   }
 
   {
@@ -182,15 +179,15 @@ TEST(AttackMajorsInBaseTest, feature)
 				 "P9+KY+KE * +OU *  *  * +KE+KY\n"
 				 "P+00FU00FU\n"
 				 "P-00GI00FU00FU00FU\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::AttackMajorsInBase amib;
     gpsshogi::IndexCacheI<gpsshogi::MaxActiveWithDuplication> features;
     amib.featuresOneNonUniq(state, features);
-    ASSERT_EQ(2, features.size());
-    ASSERT_EQ(amib.index(PTYPE_EMPTY, BISHOP, false, false, false), features[0].first);
-    ASSERT_EQ(-1, features[0].second);
-    ASSERT_EQ( 0, features[1].first);
-    ASSERT_EQ(-1, features[1].second);
+    BOOST_REQUIRE_EQUAL(2, features.size());
+    BOOST_REQUIRE_EQUAL(amib.index(PTYPE_EMPTY, BISHOP, false, false, false), features[0].first);
+    BOOST_REQUIRE_EQUAL(-1, features[0].second);
+    BOOST_REQUIRE_EQUAL( 0, features[1].first);
+    BOOST_REQUIRE_EQUAL(-1, features[1].second);
   }
 }
 // ;;; Local Variables:
