@@ -1,11 +1,10 @@
 #include "eval/minorPiece.h"
-#include "osl/record/csaString.h"
 #include "osl/record/csaRecord.h"
 
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 
 using namespace osl;
-using namespace osl::state;
+using namespace osl;
 using namespace osl::record;
 
 typedef osl::FixedCapacityVector<std::pair<int,int>,gpsshogi::MaxActiveWithDuplication> features_t;
@@ -15,14 +14,14 @@ public:
   PromotedMinorPiecesTest() : gpsshogi::EvalComponentStages(new gpsshogi::PromotedMinorPieces)
   {
   }
-  void getFeatures(const osl::state::NumEffectState &state,
+  void getFeatures(const osl::NumEffectState &state,
 		   gpsshogi::index_list_t &features) const
   {
     featuresOneNonUniq(state, features);
   }
 };
 
-TEST(PromotedMinorPiecesTest, features)
+BOOST_AUTO_TEST_CASE(PromotedMinorPiecesTestFeatures)
 {
   {
     const NumEffectState state(CsaString(
@@ -35,11 +34,11 @@ TEST(PromotedMinorPiecesTest, features)
 				 "P7+FU-TO+FU+FU+FU+FU+FU-TO+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::index_list_t features;
     PromotedMinorPiecesTest test;
     test.getFeatures(state, features);
-    ASSERT_EQ(0, features.size());
+    BOOST_REQUIRE_EQUAL(0, features.size());
   }
 
   {
@@ -53,13 +52,13 @@ TEST(PromotedMinorPiecesTest, features)
 				 "P7+FU-TO+FU+FU+FU+FU+FU-TO+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE * \n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::index_list_t features;
     PromotedMinorPiecesTest test;
     test.getFeatures(state, features);
-    ASSERT_EQ(1, features.size());
-    EXPECT_EQ(4, features[0].first);
-    EXPECT_EQ(1, features[0].second);
+    BOOST_REQUIRE_EQUAL(1, features.size());
+    BOOST_CHECK_EQUAL(4, features[0].first);
+    BOOST_CHECK_EQUAL(1, features[0].second);
   }
 
   {
@@ -73,15 +72,15 @@ TEST(PromotedMinorPiecesTest, features)
 				 "P7+FU-TO+FU+FU+FU+FU+FU-TO+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::index_list_t features;
     PromotedMinorPiecesTest test;
     test.getFeatures(state, features);
-    ASSERT_EQ(2, features.size());
-    EXPECT_EQ(3, features[0].first);
-    EXPECT_EQ(1, features[0].second);
-    EXPECT_EQ(4, features[1].first);
-    EXPECT_EQ(1, features[1].second);
+    BOOST_REQUIRE_EQUAL(2, features.size());
+    BOOST_CHECK_EQUAL(3, features[0].first);
+    BOOST_CHECK_EQUAL(1, features[0].second);
+    BOOST_CHECK_EQUAL(4, features[1].first);
+    BOOST_CHECK_EQUAL(1, features[1].second);
   }
 
   {
@@ -95,17 +94,17 @@ TEST(PromotedMinorPiecesTest, features)
 				 "P7+FU-TO+FU+FU+FU+FU+FU-TO+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::index_list_t features;
     PromotedMinorPiecesTest test;
     test.getFeatures(state, features);
-    ASSERT_EQ(2, features.size());
+    BOOST_REQUIRE_EQUAL(2, features.size());
 #ifdef L1BALL_NO_SORT
-    EXPECT_EQ(0, features[1].first);
-    EXPECT_EQ(1, features[1].second);
+    BOOST_CHECK_EQUAL(0, features[1].first);
+    BOOST_CHECK_EQUAL(1, features[1].second);
 #else
-    EXPECT_EQ(0, features[0].first);
-    EXPECT_EQ(1, features[0].second);
+    BOOST_CHECK_EQUAL(0, features[0].first);
+    BOOST_CHECK_EQUAL(1, features[0].second);
 #endif
   }
 
@@ -120,13 +119,13 @@ TEST(PromotedMinorPiecesTest, features)
 				 "P7+FU-TO+FU+FU+FU+FU+FU-TO+FU\n"
 				 "P8 * +KA *  *  *  *  * +HI * \n"
 				 "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
-				 "+\n").getInitialState());
+				 "+\n").initialState());
     gpsshogi::index_list_t features;
     PromotedMinorPiecesTest test;
     test.getFeatures(state, features);
-    ASSERT_EQ(1, features.size());
-    EXPECT_EQ(3, features[0].first);
-    EXPECT_EQ(-1, features[0].second);
+    BOOST_REQUIRE_EQUAL(1, features.size());
+    BOOST_CHECK_EQUAL(3, features[0].first);
+    BOOST_CHECK_EQUAL(-1, features[0].second);
   }
 }
 
