@@ -2,12 +2,12 @@
  */
 #include "pvFile.h"
 
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 
 using namespace gpsshogi;
 using namespace osl;
 
-TEST(PvFileTest, testConstruct)
+BOOST_AUTO_TEST_CASE(PvFileTestConstruct)
 {
   {
     gpsshogi::PVFileWriter pw("pvFile-test.gz");
@@ -17,7 +17,7 @@ TEST(PvFileTest, testConstruct)
   }
 }
 
-TEST(PvFileTest, testRW)
+BOOST_AUTO_TEST_CASE(PvFileTestRW)
 {
   PVVector pv;
   pv.push_back(Move(Square(7,7),Square(7,6),PAWN,PTYPE_EMPTY,false,BLACK));
@@ -27,7 +27,7 @@ TEST(PvFileTest, testRW)
   }
   {
     int c = gpsshogi::PVFileReader::countPosition("pvFile-test.gz");
-    EXPECT_EQ(0, c);
+    BOOST_CHECK_EQUAL(0, c);
   }
   {
     gpsshogi::PVFileWriter pw("pvFile-test.gz");
@@ -38,17 +38,17 @@ TEST(PvFileTest, testRW)
     gpsshogi::PVFileReader pr("pvFile-test.gz");
     int r, p;
     pr.newPosition(r, p);
-    EXPECT_EQ(3, r);
-    EXPECT_EQ(4, p);
+    BOOST_CHECK_EQUAL(3, r);
+    BOOST_CHECK_EQUAL(4, p);
 
     PVVector pv2;
     pr.readPv(pv2);
-    EXPECT_EQ(pv.size(), pv2.size());
-    EXPECT_TRUE(std::equal(pv.begin(), pv.end(), pv2.begin()));
+    BOOST_CHECK_EQUAL(pv.size(), pv2.size());
+    BOOST_CHECK(std::equal(pv.begin(), pv.end(), pv2.begin()));
   }
   {
     int c = gpsshogi::PVFileReader::countPosition("pvFile-test.gz");
-    EXPECT_EQ(1, c);
+    BOOST_CHECK_EQUAL(1, c);
   }
 }
 
