@@ -1,9 +1,7 @@
 #ifndef BOARD_H
 #define BOARD_H
 
-#include "osl/move.h"
-#include "osl/stl/vector.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/record/kanjiPrint.h"
 #include "osl/record/searchInfo.h"
 
@@ -12,10 +10,10 @@
      class Board
      {
        osl::NumEffectState initial;
-       osl::vector<osl::Move> moves;
-       osl::vector<int> time;
-       osl::vector<osl::record::SearchInfo> search_info;
-       osl::vector<std::string> comments;
+       std::vector<osl::Move> moves;
+       std::vector<int> time;
+       std::vector<osl::record::SearchInfo> search_info;
+       std::vector<std::string> comments;
        /** N-th move, not index of the moves array */
        size_t current_move;
      public:
@@ -36,13 +34,13 @@
          else
            return moves.at(current_move-1);
        }
-       osl::vector<osl::Move> getMovesToCurrent() const
+       std::vector<osl::Move> getMovesToCurrent() const
        {
-         osl::vector<osl::Move>::const_iterator it = moves.begin();
+         std::vector<osl::Move>::const_iterator it = moves.begin();
          it += std::min(moves.size(), current_move);
 
-         osl::vector<osl::Move>::const_iterator begin = moves.begin();
-         osl::vector<osl::Move> ret(begin, it); // copy
+         std::vector<osl::Move>::const_iterator begin = moves.begin();
+         std::vector<osl::Move> ret(begin, it); // copy
          return ret;
        } 
        void showState() const;
@@ -50,7 +48,7 @@
        void showUsiHistory() const;
        void showEval(const std::string& name) const;
        void setMoves(const osl::SimpleState& state,
-		     const osl::vector<osl::Move>& _moves, const size_t _current_move = 0)
+		     const std::vector<osl::Move>& _moves, const size_t _current_move = 0)
        {
 	 initial = osl::NumEffectState(state);
          moves = _moves;
@@ -58,15 +56,15 @@
 	 time.clear();
 	 search_info.clear();
        }
-       void setTime(const osl::vector<int>& t)
+       void setTime(const std::vector<int>& t)
        {
 	 time = t;
        }
-       void setComments(const osl::vector<std::string>& c)
+       void setComments(const std::vector<std::string>& c)
        {
 	 comments = c;
        }
-       void setSearchInfo(const osl::vector<osl::record::SearchInfo>& info) 
+       void setSearchInfo(const std::vector<osl::record::SearchInfo>& info) 
        {
 	 search_info = info;
        }
