@@ -1,36 +1,30 @@
 #include "book.h"
 #include "osl/record/kanjiPrint.h"
-#include "osl/record/csa.h"
+#include "osl/csa.h"
 #ifndef MINIMAL_GPSSHELL
 #  include <gsl_cdf.h>
 #endif
-#include <boost/shared_ptr.hpp>
-#include <boost/foreach.hpp>
 #include <boost/format.hpp>
-#include <boost/lambda/lambda.hpp>
-#include <boost/lambda/bind.hpp>
 #include <cmath>
 #include <iostream>
 
-using namespace boost::lambda;
-
 int gpsshell::
 Book::getStateIndex(const osl::SimpleState& state, 
-                    const osl::vector<osl::Move>& moves) const
+                    const std::vector<osl::Move>& moves) const
 {
-  int state_index = the_book->getStateIndex(moves);
+  int state_index = the_book->stateIndex(moves);
   if (state_index < 0)
-    state_index = the_book->getStateIndex(state); // it could take a long time
+    state_index = the_book->stateIndex(state); // it could take a long time
   return state_index;
 }
 
 void gpsshell::
 Book::showState(const osl::SimpleState& state, 
-                const osl::vector<osl::Move>& moves,
+                const std::vector<osl::Move>& moves,
                 int max_count) const
 {
   osl::record::KanjiPrint printer(std::cerr, 
-                                  boost::shared_ptr<osl::record::Characters>(
+                                  std::shared_ptr<osl::record::Characters>(
                                             new osl::record::KIFCharacters())
                                   );
 
@@ -42,8 +36,8 @@ Book::showState(const osl::SimpleState& state,
   }
 
   const osl::Player turn   = state.turn();
-  const int black_win = the_book->getBlackWinCount(state_index);
-  const int white_win = the_book->getWhiteWinCount(state_index);
+  const int black_win = the_book->blackWinCount(state_index);
+  const int white_win = the_book->whiteWinCount(state_index);
   const int trial     = black_win + white_win;
   const int nwins     = (turn == osl::BLACK ? black_win : white_win); 
   double win_rate     = 0.0;
@@ -75,13 +69,13 @@ Book::showState(const osl::SimpleState& state,
   gpsshell::WMoveStatsContainer wstats = getWMoveStats(state, moves);
   std::cout << boost::format("found %d moves\n") % wstats.size();
 
-  BOOST_FOREACH(const gpsshell::WMoveStats& st, wstats)
+  for (const gpsshell::WMoveStats& st: wstats)
   {
     if (--max_count < 0) break;
 
     std::cout << boost::format("[% 6d] %s  win:% 7d loss:% 7d  rate:% 7.4f - % 7.4f = % 7.4f\n") 
-                                % st.getWmove().getWeight() 
-                                % osl::record::csa::show(st.getWmove().getMove())
+                                % st.getWmove().weight 
+                                % osl::csa::show(st.getWmove().move)
                                 % st.nwins()
                                 % st.nlosses()
                                 % st.winRate()
@@ -92,7 +86,7 @@ Book::showState(const osl::SimpleState& state,
 
 gpsshell::WMoveContainer gpsshell::
 Book::getMoves(const osl::SimpleState& state, 
-               const osl::vector<osl::Move>& moves) const
+               const std::vector<osl::Move>& moves) const
 {
   const gpsshell::WMoveStatsContainer wstats
     = getWMoveStats(state, moves);
@@ -102,7 +96,7 @@ Book::getMoves(const osl::SimpleState& state,
   if (wstats.empty())
     return wmoves; // empty
   
-  BOOST_FOREACH(const gpsshell::WMoveStats& ws, wstats)
+  for (const gpsshell::WMoveStats& ws: wstats)
   {
     wmoves.push_back(ws.getWmove());
   }
@@ -112,7 +106,7 @@ Book::getMoves(const osl::SimpleState& state,
 
 gpsshell::WMoveStatsContainer gpsshell::
 Book::getWMoveStats(const osl::SimpleState& state, 
-                    const osl::vector<osl::Move>& moves) const
+                    const std::vector<osl::Move>& moves) const
 {
   const int state_index = getStateIndex(state, moves);
   gpsshell::WMoveStatsContainer wstats;
@@ -121,13 +115,13 @@ Book::getWMoveStats(const osl::SimpleState& state,
     return wstats; // empty
 
   {
-    WMoveContainer wmoves = the_book->getMoves(state_index);
+    WMoveContainer wmoves = the_book->moves(state_index);
     wstats.reserve(wmoves.size());
-    BOOST_FOREACH(const osl::record::opening::WMove& wmove, wmoves)
+    for (const auto& wmove: wmoves)
     {
-      const int next_state_index = wmove.getStateIndex();
-      const int black_win        = the_book->getBlackWinCount(next_state_index);
-      const int white_win        = the_book->getWhiteWinCount(next_state_index);
+      const int next_state_index = wmove.stateIndex();
+      const int black_win        = the_book->blackWinCount(next_state_index);
+      const int white_win        = the_book->whiteWinCount(next_state_index);
       gpsshell::WMoveStats st(wmove, black_win, white_win);
       wstats.push_back(st);
     }
@@ -142,7 +136,7 @@ Book::getWMoveStats(const osl::SimpleState& state,
   gpsshell::WMoveStatsContainer::iterator it = wstats.begin();
   for (/* none */; it != wstats.end(); ++it)
   {
-    if (it->getWmove().getWeight() < 1)
+    if (it->getWmove().weight < 1)
       break;
   }
   std::sort(it, wstats.end(), gpsshell::WMoveStatsSortByWins());
@@ -156,9 +150,9 @@ Book::getWMoveStats(const osl::SimpleState& state,
 int gpsshell::getMaxWeight(const gpsshell::WMoveContainer& moves)
 {
   int max_weight = 0;
-  BOOST_FOREACH(const osl::record::opening::WMove& wmove, moves) {
-    if (max_weight < wmove.getWeight()) {
-      max_weight = wmove.getWeight();
+  for (const osl::book::WMove& wmove: moves) {
+    if (max_weight < wmove.weight) {
+      max_weight = wmove.weight;
     }
   }
   return max_weight;
@@ -167,8 +161,8 @@ int gpsshell::getMaxWeight(const gpsshell::WMoveContainer& moves)
 int gpsshell::getSumOfWeights(const gpsshell::WMoveContainer& moves)
 {
   int sum = 0;
-  BOOST_FOREACH(const osl::record::opening::WMove& wmove, moves) {
-    sum += wmove.getWeight();
+  for (const osl::book::WMove& wmove: moves) {
+    sum += wmove.weight;
   }
   return sum;
 }
@@ -181,9 +175,9 @@ struct WeightLessThan
     : criteria(criteria)
   {}
 
-  bool operator()(const osl::record::opening::WMove& wmove) const
+  bool operator()(const osl::book::WMove& wmove) const
   {
-    return (wmove.getWeight() < criteria ? true : false);
+    return (wmove.weight < criteria ? true : false);
   }
 };
 
