@@ -14,27 +14,25 @@
 #endif
 #include "osl/eval/pieceEval.h"
 #include "osl/eval/progressEval.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/state/numEffectState.h"
-#include "osl/record/csa.h"
-#include "osl/record/compactBoard.h"
-#include "osl/record/usi.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/numEffectState.h"
+#include "osl/book/compactBoard.h"
+#include "osl/record/usiRecord.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaIOError.h"
-#include "osl/record/csaString.h"
 #include "osl/record/kisen.h"
 #include "osl/record/ki2.h"
 #include "osl/record/kakinoki.h"
 #include "osl/record/myshogi.h"
-#include "osl/record/opening/openingBook.h"
-#include "osl/record/opening/bookInMemory.h"
+#include "osl/book/openingBook.h"
+#include "osl/book/bookInMemory.h"
 #include "osl/game_playing/alphaBetaPlayer.h"
 #include "osl/game_playing/gameState.h"
 #include "osl/search/alphaBeta3.h"
 #include "osl/search/alphaBeta4.h"
+#include "osl/search/usiProxy.h"
 #include "osl/search/searchRecorder.h"
 #include "osl/misc/filePath.h"
-#include "osl/misc/random.h"
+#include "osl/random.h"
 #include "osl/misc/sjis2euc.h"
 #include "osl/search/moveGenerator.h"
 #include "osl/search/searchState2.h"
@@ -45,7 +43,6 @@
 #include "osl/rating/featureSet.h"
 #include "osl/rating/ratingEnv.h"
 #include "osl/move_probability/featureSet.h"
-#include "osl/move_generator/legalMoves.h"
 #include "osl/misc/eucToLang.h"
 #include "osl/c/facade.h"
 #include "osl/oslConfig.h"
@@ -53,17 +50,16 @@
 #include <boost/algorithm/string.hpp>
 #include <boost/date_time/gregorian/gregorian.hpp> // with I/O
 #include <boost/format.hpp>
-#include <boost/foreach.hpp>
 #include <boost/lexical_cast.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 #include <deque>
 #include <iostream>
 
 /*========== Global variables ==========*/
 
 extern boost::filesystem::path cache_dir;
-extern boost::scoped_ptr<gpsshell::Board> board;
-extern boost::scoped_ptr<gpsshell::Book> the_book;
+extern std::unique_ptr<gpsshell::Board> board;
+extern std::unique_ptr<gpsshell::Book> the_book;
 extern std::string redis_server_host;
 extern int redis_server_port;
 extern std::string redis_password;
@@ -81,7 +77,7 @@ namespace { // anonymous
     for (size_t i=0; i<result.size(); ++i)
       result[i] = toupper(result[i]);
     if (result[0] != '+' && result[0] != '-')
-      result.insert(0, osl::record::csa::show(state.turn()));
+      result.insert(0, osl::csa::show(state.turn()));
     if (result.size() == 5) {
       const int from = (result[1]-'0')*10 + (result[2]-'0');
       if (from >= 11 && from <= 99 && (from % 10)) {
@@ -115,6 +111,7 @@ void setCommandsMain(gpsshell::MySession* s)
   s->addCommand("search",                &gpsshell::MySession::search );
   s->addCommand("qsearch",               &gpsshell::MySession::qsearch );
   s->addCommand("search4",               &gpsshell::MySession::search4 );
+  s->addCommand("search_usi",            &gpsshell::MySession::search_usi );
   s->addCommand("checkmate_attack",      &gpsshell::MySession::checkmate_attack );
   s->addCommand("checkmate_escape",      &gpsshell::MySession::checkmate_escape );
   s->addCommand("threatmate",            &gpsshell::MySession::threatmate );
@@ -327,13 +324,13 @@ MySession::open(const std::vector<std::string>& params)
   if (boost::algorithm::iequals(".csa", ext))
   {
     const osl::CsaFile file(osl::misc::file_string(path));
-    const osl::record::Record record = file.getRecord();
-    osl::vector<osl::Move> moves;
-    osl::vector<int> time;
-    osl::vector<std::string> comments;
-    osl::vector<osl::record::SearchInfo> search_info;
-    record.getMoves(moves, time, comments, search_info);
-    board->setMoves(file.getInitialState(), moves);
+    const osl::Record record = file.load();
+    std::vector<osl::Move> moves;
+    std::vector<int> time;
+    std::vector<std::string> comments;
+    std::vector<osl::SearchInfo> search_info;
+    record.load(moves, time, comments, search_info);
+    board->setMoves(file.initialState(), moves);
     board->setTime(time);
     board->setComments(comments);
     board->setSearchInfo(search_info);
@@ -343,26 +340,26 @@ MySession::open(const std::vector<std::string>& params)
   else if (boost::algorithm::iequals(".usi", ext))
   {
     const osl::UsiFile file(osl::misc::file_string(path));
-    const osl::vector<osl::Move> moves = file.getRecord().getMoves();
-    board->setMoves(file.getInitialState(), moves);
+    const auto moves = file.load().moves();
+    board->setMoves(file.initialState(), moves);
   }
   else if (boost::algorithm::iequals(".ki2", ext))
   {
     const osl::Ki2File file(osl::misc::file_string(path));
-    const osl::vector<osl::Move> moves = file.getRecord().getMoves();
-    board->setMoves(file.getInitialState(), moves);
+    const auto moves = file.load().moves();
+    board->setMoves(file.initialState(), moves);
   }
   else if (boost::algorithm::iequals(".kif", ext) 
 	   && osl::KakinokiFile::isKakinokiFile(osl::misc::file_string(path)))
   {
     const osl::KakinokiFile file(osl::misc::file_string(path));
-    const osl::record::Record record = file.getRecord();
-    osl::vector<osl::Move> moves;
-    osl::vector<int> time;
-    osl::vector<std::string> comments;
-    osl::vector<osl::record::SearchInfo> search_info;
-    record.getMoves(moves, time, comments, search_info);
-    board->setMoves(file.getInitialState(), moves);
+    const osl::Record record = file.load();
+    std::vector<osl::Move> moves;
+    std::vector<int> time;
+    std::vector<std::string> comments;
+    std::vector<osl::SearchInfo> search_info;
+    record.load(moves, time, comments, search_info);
+    board->setMoves(file.initialState(), moves);
     board->setComments(comments);
   }
   else if (boost::algorithm::iequals(".kif", ext))
@@ -378,17 +375,17 @@ MySession::open(const std::vector<std::string>& params)
       return;
     }
       std::cout << "Opened " << index << "/" << file.size()-1 << "\n"
-                << "  StartDate: " << ipx.getStartDate(index) << "\n";
+                << "  StartDate: " << ipx.startDate(index) << "\n";
     const osl::Player both[] = {osl::BLACK, osl::WHITE};
-    BOOST_FOREACH(const osl::Player p, both) {
+    for (const osl::Player p: both) {
       std::cout << "  " << p << ": "
-                << osl::misc::sjis2euc(ipx.getPlayer(index, p))
-                << "@" << ipx.getRating(index, p)
-                << " [" << osl::misc::sjis2euc(ipx.getTitle(index, p))  << "]\n";
+                << osl::misc::sjis2euc(ipx.player(index, p))
+                << "@" << ipx.rating(index, p)
+                << " [" << osl::misc::sjis2euc(ipx.title(index, p))  << "]\n";
     }
 
-    const osl::vector<osl::Move> moves = file.getMoves(index);
-    board->setMoves(file.getInitialState(), moves);
+    const std::vector<osl::Move> moves = file.moves(index);
+    board->setMoves(file.initialState(), moves);
   }
   board->showState();
 }
@@ -400,9 +397,9 @@ MySession::usiposition(const std::vector<std::string>& params)
   for (size_t i=1; i<params.size(); ++i)
     all += " " + params[i];
   osl::NumEffectState initial_state;
-  osl::vector<osl::Move> moves;
+  std::vector<osl::Move> moves;
   try {
-    osl::record::usi::parse(all.substr(8), initial_state, moves);
+    osl::usi::parse(all.substr(8), initial_state, moves);
   }
   catch (std::exception& e) {
     std::cerr << "usi parse error " << e.what() << "\n";
@@ -421,14 +418,15 @@ MySession::openstdin()
       break;
     lines += line + "\n";
   }
-  const osl::CsaString file(lines.c_str());
-  const osl::record::Record record = file.getRecord();
-  osl::vector<osl::Move> moves;
-  osl::vector<int> time;
-  osl::vector<std::string> comments;
-  osl::vector<osl::record::SearchInfo> search_info;
-  record.getMoves(moves, time, comments, search_info);
-  board->setMoves(file.getInitialState(), moves);
+  std::istringstream is(lines);
+  const osl::CsaFile file(is);
+  const osl::Record record = file.load();
+  std::vector<osl::Move> moves;
+  std::vector<int> time;
+  std::vector<std::string> comments;
+  std::vector<osl::SearchInfo> search_info;
+  record.load(moves, time, comments, search_info);
+  board->setMoves(file.initialState(), moves);
   board->setTime(time);
   board->setComments(comments);
   board->setSearchInfo(search_info);
@@ -516,7 +514,7 @@ MySession::move(const std::vector<std::string>& params)
     const std::string move_string = adjust_move_string(params[i], board->getState());
     osl::Move move;
     try {
-      move = osl::record::csa::strToMove(move_string, board->getState());
+      move = osl::csa::strToMove(move_string, board->getState());
     }
     catch (std::runtime_error& e) {
       std::cerr << "parse error " << e.what() << "\n";
@@ -629,24 +627,58 @@ MySession::search4(const std::vector<std::string>& params)
   table.setVerbose(true);    
   osl::NumEffectState state(board->getState());
   osl::search4::AlphaBeta4 search(state,solver,&table,recorder);
-  osl::search::TimeAssigned assign(osl::MilliSeconds::Interval(time*1000),
-				   osl::MilliSeconds::Interval(time*1000));
+  osl::search::TimeAssigned assign(osl::milliseconds(time*1000),
+				   osl::milliseconds(time*1000));
+  osl::Move best_move = search.computeBestMoveIteratively(2000,100,0,0,assign);
+  std::cout << best_move << std::endl;
+}
+
+void gpsshell::
+MySession::search_usi(const std::vector<std::string>& params)
+{
+  static const size_t time_default = 30;
+  static size_t time = time_default;
+  if (params.size() >= 2) 
+  {
+    try 
+    {
+      time = boost::lexical_cast<size_t>(params[1]);
+    } 
+    catch (boost::bad_lexical_cast& blc) 
+    {
+      std::cerr << blc.what() << std::endl;
+      std::cerr << "USAGE: search_usi <time_in_sec>" << std::endl
+                << "time is now " << time << " "
+                << "(default: " << time_default << ")"
+                << std::endl;
+      return;
+    }
+  }
+
+  osl::search::SearchState2::checkmate_t solver;
+  osl::search::CountRecorder recorder;
+  osl::SimpleHashTable table;
+  table.setVerbose(true);    
+  osl::NumEffectState state(board->getState());
+  osl::search::UsiProxy search(state,solver,&table,recorder);
+  osl::search::TimeAssigned assign(osl::milliseconds(time*1000),
+				   osl::milliseconds(time*1000));
   osl::Move best_move = search.computeBestMoveIteratively(2000,100,0,0,assign);
   std::cout << best_move << std::endl;
 }
 
 void show(const osl::search::QuiescenceRecord& qrecord)
 {
-  std::cerr << "best move " << osl::record::csa::show(qrecord.bestMove()) << "\n";
+  std::cerr << "best move " << osl::csa::show(qrecord.bestMove()) << "\n";
   std::cerr << "upper bound " << qrecord.upperBound() 
 	    << " (" << qrecord.upperDepth() << ")\n";
   std::cerr << "lower bound " << qrecord.lowerBound() 
 	    << " (" << qrecord.lowerDepth() << ")\n";
   std::cerr << "static value " << qrecord.staticValue() 
 	    << " " << qrecord.staticThreat(0).value
-	    << " " << osl::record::csa::show(qrecord.staticThreat(0).move)
+	    << " " << osl::csa::show(qrecord.staticThreat(0).move)
 	    << " " << qrecord.staticThreat(1).value
-	    << " " << osl::record::csa::show(qrecord.staticThreat(1).move)
+	    << " " << osl::csa::show(qrecord.staticThreat(1).move)
 	    << "\n";
 }
 
@@ -832,7 +864,7 @@ MySession::generateMoves(const std::vector<std::string>& params)
 
   std::cout << "limit " << limit << "\n";
   for (size_t i=0; i<moves.size(); ++i) {
-    std::cout << osl::record::csa::show(moves[i].move()) 
+    std::cout << osl::csa::show(moves[i].move()) 
 	      << "  " << moves[i].logProb();
     const osl::RatedMove *r = rated_moves.find(moves[i].move());
     if (r) {
@@ -847,27 +879,27 @@ MySession::generateLegalMoves(const std::vector<std::string>& params)
 {
   const osl::NumEffectState state = board->getState();
   osl::MoveVector moves;
-  osl::LegalMoves::generate(state, moves);
-  BOOST_FOREACH(osl::Move m, moves)
-    std::cout << osl::record::csa::show(m) << "\n";
+  state.generateLegal(moves);
+  for (osl::Move m: moves)
+    std::cout << osl::csa::show(m) << "\n";
 }
 
 void gpsshell::
 MySession::generateNotLosingMoves(const std::vector<std::string>& params)
 {
   osl::game_playing::GameState state(board->getInitialState());
-  osl::vector<osl::Move> moves(board->getMovesToCurrent());
-  BOOST_FOREACH(osl::Move move, moves)
+  std::vector<osl::Move> moves(board->getMovesToCurrent());
+  for (osl::Move move: moves)
     state.pushMove(move);
   osl::MoveVector normal, loss;
   state.generateNotLosingMoves(normal, loss);
   std::cout << "normal moves\n";
-  BOOST_FOREACH(osl::Move m, normal)
-    std::cout << osl::record::csa::show(m) << "\n";
+  for (osl::Move m: normal)
+    std::cout << osl::csa::show(m) << "\n";
   if (! loss.empty()) {
     std::cout << "losing moves\n";
-    BOOST_FOREACH(osl::Move m, loss)
-      std::cout << osl::record::csa::show(m) << "\n";
+    for (osl::Move m: loss)
+      std::cout << osl::csa::show(m) << "\n";
   }
 }
 
@@ -888,7 +920,7 @@ MySession::rating(const std::vector<std::string>& params)
   for (size_t i=0; i<moves.size(); ++i) {
     if (moves[i].rating() < min_rate)
       break;
-    std::cout << osl::record::csa::show(moves[i].move()) 
+    std::cout << osl::csa::show(moves[i].move()) 
 	      << "  " << moves[i].rating() 
 	      << "  " << moves[i].optimisticRating() 
 	      << "\n";
@@ -904,7 +936,7 @@ MySession::rating2(const std::vector<std::string>& params)
   if (params.size() > 1) {
     std::string option_string = params[1];
     try {
-      single_move = osl::record::csa::strToMove(option_string, state);
+      single_move = osl::csa::strToMove(option_string, state);
     }
     catch (...) {
       std::istringstream is(option_string);
@@ -922,7 +954,7 @@ MySession::rating2(const std::vector<std::string>& params)
 					history, threatmate);
   if (info.threatmate_move.isNormal())
     std::cout << "note: threatmate "
-	      << osl::record::csa::show(info.threatmate_move) 
+	      << osl::csa::show(info.threatmate_move) 
 	      << "\n";
   if (single_move.isNormal()) {
     double p = fs.matchExp(info, single_move);
@@ -932,7 +964,7 @@ MySession::rating2(const std::vector<std::string>& params)
   fs.generateLogProb2(info, moves);
   for (size_t i=0; i<moves.size(); ++i) {
     std::cout << std::setw(3) << i 
-	      << std::setw(8) << osl::record::csa::show(moves[i].move()) 
+	      << std::setw(8) << osl::csa::show(moves[i].move()) 
 	      << " " << std::setw(4) << moves[i].logProb();
     std::cout << ((i % 4 == 3) ? "\n" : "   ");
   }
@@ -954,8 +986,8 @@ MySession::quiescemoves(const std::vector<std::string>& params)
     QuiescenceGenerator<WHITE>::promote(state, state.pin(alt(state.turn())),
 					moves);
   std::cout << "promote";
-  BOOST_FOREACH(Move move, moves)
-    std::cout << " " << osl::record::csa::show(move);
+  for (Move move: moves)
+    std::cout << " " << osl::csa::show(move);
   std::cout << "\n";
 }
 
@@ -971,7 +1003,7 @@ MySession::annotate(const std::vector<std::string>& params)
   const std::string move_string = adjust_move_string(params[1], board->getState());
   osl::Move move;
   try {
-    move = osl::record::csa::strToMove(move_string, board->getState());
+    move = osl::csa::strToMove(move_string, board->getState());
   }
   catch (std::runtime_error& e) {
     std::cerr << "parse error " << e.what() << "\n";
@@ -1018,13 +1050,13 @@ MySession::usiShow(const std::vector<std::string>& params)
 {
   if (params.size() == 1) {
     std::cout << "position " 
-	      << osl::record::usi::show(board->getState())
+	      << osl::usi::show(board->getState())
 	      << std::endl;
     return;
   }
   std::ofstream os(params[1].c_str());
   os << "position " 
-     << osl::record::usi::show(board->getState())
+     << osl::usi::show(board->getState())
      << std::endl;
 }
 void gpsshell::
@@ -1155,14 +1187,14 @@ MySession::openingNext(const std::vector<std::string>& params)
     std::cout << "There is no next move." << std::endl;
     return;
   }
-  if (wmoves.at(0).getWeight() == 0 && params.size() == 1)
+  if (wmoves.at(0).weight == 0 && params.size() == 1)
   {
     // do not visit a zero-weighted move automatically.
     std::cout << "There is no weighted move. Specify an index (starting with zero) you want to visit.\n";
     return;
   }
-  const osl::record::opening::WMove wmove = wmoves.at(std::min(nth, wmoves.size()-1));
-  const std::string move_str = osl::record::csa::show(wmove.getMove());
+  const osl::book::WMove wmove = wmoves.at(std::min(nth, wmoves.size()-1));
+  const std::string move_str = osl::csa::show(wmove.move);
   std::vector<std::string> command;
   command.push_back(params[0]);
   command.push_back(move_str);
@@ -1190,8 +1222,8 @@ MySession::openingNextRandomLevel(const std::vector<std::string>& params)
   const size_t index = osl::misc::time_seeded_random() % wmoves.size();
   std::cout << boost::format("selected %2d of %2d move(s) [1,2,...]\n")
                % (index+1) % wmoves.size();
-  const osl::record::opening::WMove wmove = wmoves.at(index);
-  const std::string move_str = osl::record::csa::show(wmove.getMove());
+  const osl::book::WMove wmove = wmoves.at(index);
+  const std::string move_str = osl::csa::show(wmove.move);
   std::vector<std::string> command;
   command.push_back(params[0]);
   command.push_back(move_str);
@@ -1233,15 +1265,15 @@ MySession::openingNextRandomWeight(const std::vector<std::string>& params)
   const int target_weight = osl::misc::time_seeded_random() % sum;
   ::gpsshell::WMoveContainer::iterator it = wmoves.begin();
   for (int total = 0; it != wmoves.end(); ++it) {
-    total += it->getWeight();
+    total += it->weight;
     if (target_weight < total)
       break;
   }
 
   std::cout << boost::format("selected %2d of %2d move(s) [1,2,...]\n")
                % (std::distance(wmoves.begin(), it) + 1) % wmoves.size();
-  const osl::record::opening::WMove wmove = *it;
-  const std::string move_str = osl::record::csa::show(wmove.getMove());
+  const osl::book::WMove wmove = *it;
+  const std::string move_str = osl::csa::show(wmove.move);
   std::vector<std::string> command;
   command.push_back(params[0]);
   command.push_back(move_str);
@@ -1288,8 +1320,8 @@ MySession::openingInclude(const std::vector<std::string>& params)
   try
   {
     const osl::CsaFile file(osl::misc::file_string(path));
-    const osl::record::Record record = file.getRecord();
-    const osl::vector<osl::Move> moves = record.getMoves();
+    const osl::Record record = file.load();
+    const std::vector<osl::Move> moves = record.moves();
 
     if (nth_move > moves.size())
     {
@@ -1300,15 +1332,15 @@ MySession::openingInclude(const std::vector<std::string>& params)
     }
 
     osl::NumEffectState state;
-    BOOST_FOREACH(const osl::Move& move, moves)
+    for (const osl::Move& move: moves)
     {
       state.makeMove(move);
     }
 
     osl::Player self = nth_move % 2 == 1 ? osl::BLACK : osl::WHITE;
-    const boost::shared_ptr<osl::record::opening::WeightedBook> book = 
+    const std::shared_ptr<osl::book::WeightedBook> book = 
       the_book->getWeightedBook();
-    const int rc =  book->getStateIndex(state, false, self);
+    const int rc =  book->stateIndex(state, false, self);
     if (rc == -1)
     {
       std::cout << "The state is not found in the book\n";
@@ -1318,7 +1350,7 @@ MySession::openingInclude(const std::vector<std::string>& params)
       std::cout << "The state is included in the book\n";
     }
   }
-  catch (osl::record::csa::CsaIOError& e)
+  catch (osl::csa::CsaIOError& e)
   {
     std::cerr << boost::format("Failed to open the csa file: %s\n") % osl::misc::file_string(path);
     std::cerr << USAGE;
@@ -1346,11 +1378,11 @@ MySession::openingShowShortestLines(const std::vector<std::string>& params)
   if (params.size() == 2)
     TOPN = boost::lexical_cast<int>(params[1]);
 
-  boost::shared_ptr<osl::record::opening::WeightedBook> book = the_book->getWeightedBook();
+  std::shared_ptr<osl::book::WeightedBook> book = the_book->getWeightedBook();
 
-  std::vector<gpsshell::VisitFlag> history(book->getTotalState(), gpsshell::UNVISITED);
+  std::vector<gpsshell::VisitFlag> history(book->totalState(), gpsshell::UNVISITED);
   std::deque<gpsshell::VisitState> fronts;
-  fronts.push_back(gpsshell::VisitState(book->getStartState()));
+  fronts.push_back(gpsshell::VisitState(book->startState()));
   
   int temp_top = TOPN; 
   while (!fronts.empty()) {
@@ -1358,29 +1390,29 @@ MySession::openingShowShortestLines(const std::vector<std::string>& params)
     fronts.pop_front();
     history[vs.state_index] = gpsshell::VISITED;
 
-    const osl::record::opening::WeightedBook::WMoveContainer wmoves = book->getMoves(vs.state_index, false);
+    const auto wmoves = book->moves(vs.state_index, false);
     if (wmoves.empty()) {
       // found a leaf node!
       std::cout << "\n";
-      BOOST_FOREACH(const osl::Move& m, vs.moves) {
-        std::cout << osl::record::csa::show(m);
+      for (const osl::Move& m: vs.moves) {
+        std::cout << osl::csa::show(m);
       }
       std::cout << "\n";
-      the_book->showState(book->getBoard(vs.state_index), vs.moves, 3);
+      the_book->showState(book->board(vs.state_index), vs.moves, 3);
       if (--temp_top < 1) 
         break; // exit the whole loop
       else
         continue;
     }
 
-    BOOST_FOREACH(const osl::record::opening::WMove& wmove, wmoves) {
-      const int next_index = wmove.getStateIndex();
-      if (! history[next_index] == gpsshell::UNVISITED)
+    for (const osl::book::WMove& wmove: wmoves) {
+      const int next_index = wmove.stateIndex();
+      if (history[next_index] != gpsshell::UNVISITED)
         continue;
 
       gpsshell::VisitState next(next_index);
       next.moves = vs.moves; // copy
-      next.moves.push_back(wmove.getMove());
+      next.moves.push_back(wmove.move);
       fronts.push_back(next);
       history[next_index] = ENTERED;
     } // for wmoves
@@ -1408,9 +1440,9 @@ MySession::ignoreListShow(const std::vector<std::string>& params)
   const gpsshell::IgnoreList::index_t index = the_ignorelist.getCurrentIndex();
   std::vector<std::string> args;
   args.push_back("open");
-  args.push_back(osl::misc::file_string(index.get<0>()));
-  args.push_back(boost::lexical_cast<std::string>(index.get<1>()));
-  const std::string& comment = index.get<2>();
+  args.push_back(osl::misc::file_string(std::get<0>(index)));
+  args.push_back(std::to_string(std::get<1>(index)));
+  const std::string& comment = std::get<2>(index);
   if (!comment.empty())
   std::cout << boost::format("%s\n") % comment;
 
@@ -1503,8 +1535,8 @@ MySession::showBookInMemory(const std::vector<std::string>& params)
   osl::HashKey key(board->getState());
   osl::MoveVector moves;
   book.find(key, moves);
-  BOOST_FOREACH(osl::Move move, moves)
-    std::cout << osl::record::csa::show(move) << std::endl;
+  for (osl::Move move: moves)
+    std::cout << osl::csa::show(move) << std::endl;
   std::cout << "BookInMemory has " << moves.size() << std::endl;  
 }
 
