@@ -1,4 +1,4 @@
-;;; Copyright (C) 2011 Team GPS.
+;;; Copyright (C) 2011-2014 Team GPS.
 ;;; 
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
             [twitter_clj.engine :as engine]
             [twitter_clj.subprocess :as sub]
             [clojure.string :as str]
-            [clojure.contrib.logging :as log]))
+            [clojure.tools.logging :as log]))
 
 ;; ==================================================
 ;; Global variables
@@ -46,7 +46,6 @@
     (reset! stdin  new-stdin)
     (reset! stdout new-stdout)
     (reset! stderr new-stderr)))
-    
 
 (defn stop-ki2-engine
   "Stop a ki2 engine."
@@ -59,76 +58,77 @@
   (reset! stdout nil)
   (reset! stderr nil))
 
-
 (defn is-valid-position
   "Validates a position. If it is valid, return true; false otherwise."
   [position]
   {:pre [(not (nil? @proc))]}
-  (log/debug (format "Validate a position: %s" position))
+  (log/debugf "Validate a position: %s" position)
   (sub/write @stdout (format "isvalidposition %s" position))
-  (let [ret (.readLine @stdin)]
+  (let [ret (.readLine ^java.io.BufferedReader @stdin)]
     (= "valid" ret)))
 
-
 (defn set-position
   "Set a usi position to the engine."
   [position]
   {:pre [(not (nil? @proc))]}
-  (log/debug (format "Set ki2 engine: %s" position))
+  (log/debugf "Set ki2 engine: %s" position)
   (sub/write @stdout position))
 
+(defn filter-threatmate
+  [moves]
+  (loop [moves moves
+         ret   []]
+    (let [i (.indexOf ^String moves "(")]
+      (if (neg? i)
+        [moves ret] ;; base
+        (let [before (subs moves 0 i)
+              c      (dec (count (str/split before #" ")))
+              after  (subs moves (inc (.indexOf ^String moves ")")))]
+          (assert (= \^ (nth moves (inc i))))
+          (recur (str before after) (conj ret c)))))))
+
+(def TSUMERO "(詰めろ)")
+
+(defn add-threatmate
+  [moves i]
+  {:pre [(not-empty moves) (<= 0 i)]}
+  (loop [p 0
+         i (inc i)]
+    (assert (<= 0 p (dec (count moves))) ) 
+    (if (= p (dec (count moves)))
+      (do
+        (assert (zero? i))
+        (str moves TSUMERO))
+      (if (some #(= % (nth moves p)) [\▲ \△])
+        (if (zero? i)
+          (str (subs moves 0 p) TSUMERO (subs moves p)) ;; base
+          (recur (inc p) (dec i)))
+        (recur (inc p) i)))))
 
 (defn show
   "Convert usi moves to Kanji moves by using the ki2 engine."
   [usi-moves]
   {:post [(not-empty %)]}
-  (letfn [(filter-threatmate [moves]
-            (loop [moves moves
-                   ret   []]
-              (let [i (.indexOf moves "(")]
-                (if (neg? i)
-                  [moves ret] ;; base
-                  (let [before (subs moves 0 i)
-                        c (dec (count (str/split before #" ")))
-                        after (subs moves (inc (.indexOf moves ")")))]
-                    (assert (= \^ (nth moves (inc i))))
-                    (recur (str before after) (conj ret c)))))))
-           (add-threatmate [moves i]
-             {:pre [(not-empty moves) (<= 0 i)]}
-             (let [TSUMERO "(詰めろ)"]
-               (loop [p     0
-                      i     (inc i)]
-                 (assert (<= 0 p (dec (count moves))) ) 
-                 (if (= p (dec (count moves)))
-                   (do
-                     (assert (zero? i))
-                     (str moves TSUMERO))
-                   (if (some #(= % (nth moves p)) [\▲ \△])
-                     (if (zero? i)
-                       (str (subs moves 0 p) TSUMERO (subs moves p)) ;; base
-                       (recur (inc p) (dec i)))
-                     (recur (inc p) i))))))]
-    (log/debug (format "Converting usi moves to Kanji: %s" usi-moves))
+    (log/debugf "Converting usi moves to Kanji: %s" usi-moves)
     (let [[moves indexes] (filter-threatmate usi-moves)] 
       (sub/write @stdout (format "ki2moves %s" moves))
-      (let [line (.readLine @stdin)
-            m (re-find #"^ki2moves (.*)$" line)
-            _ (assert m)
+      (let [line      (.readLine ^java.io.BufferedReader @stdin)
+            m         (re-find #"^ki2moves (.*)$" line)
+            _         (assert m)
             ki2-moves (nth m 1)]
-        (loop [moves ki2-moves
+        (loop [moves   ki2-moves
                indexes indexes]
           (if (seq indexes)
             (recur (add-threatmate moves (first indexes)) (rest indexes))
-            moves))))))
-
+            moves)))))
 
 (defn current-info
   "Retrieve the latest move etc. from the engine."
   []
   (sub/write @stdout "ki2currentinfo")
-  (let [line (.readLine @stdin)
+  (let [line (.readLine ^java.io.BufferedReader @stdin)
         m (re-find #"^ki2currentinfo (\d+) (.*)$" line)]
     (if m
-      [(Integer. (nth m 1)) (nth m 2)]
+      [(Integer. ^String (nth m 1)) (nth m 2)]
       [0 ""])))
 
