@@ -1,4 +1,4 @@
-;;; Copyright (C) 2011 Team GPS.
+;;; Copyright (C) 2011-2014 Team GPS.
 ;;; 
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -15,17 +15,31 @@
 ;;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 (ns twitter_clj.usi_converter
-  (:import (java.util.concurrent LinkedBlockingQueue))
   (:require [clojure.string :as str]
             [clojure.java.io :as io]
-            [clojure.contrib.command-line :as cmd]
-            [clojure.contrib.logging :as log]))
+            [clojure.tools.cli :refer [parse-opts]]
+            [clojure.tools.logging :as log]))
 
 ;; ==================================================
 ;; Global variables
 ;; ==================================================
 
-(def options (atom {}))
+(def cli-options
+  [[nil "--end END" "Ending moves"
+   :default 350
+   :parse-fn #(Integer/parseInt %)]
+   ["-f" "--file FILE" "kifu file"
+    :default "target.kif"]
+   [nil "--start START" "Starting moves"
+    :default 1
+    :parse-fn #(Integer/parseInt %)]
+   ["-h" "--help"]])
+
+;; Interval to read a file in seconds
+(def READ_FILE_WAIT_SECONDS 3)
+
+;; Holds commandline options
+(def opts (atom {}))
 
 (def row-positions
   {"1" "a", "2" "b", "3" "c", "4" "d", "5" "e", "6" "f", "7" "g", "8" "h", "9" "i",
@@ -41,21 +55,20 @@
  {"歩" "p", "香" "l", "桂" "n", "銀" "s", "金" "g", 
   "角" "b", "馬" "+b", "飛" "r", "龍" "+r", "竜" "+r"})
 
-(def moves-queue
-  (LinkedBlockingQueue.))
-
-
 ;; ==================================================
 ;; Functions
 ;; ==================================================
 
-(defn put-queue
-  [str]
-  (log/info (format "Pushing the queue: %s" str))
-  (.put moves-queue str))
-
+(defn check-file []
+  "Checks exisntance of a file. If a file is not found, throws an error"
+  (let [file (:file @opts)]
+    (when-not (.exists (io/as-file file))
+      (log/fatal (str "Kifu file not found: " file))
+      (throw (java.io.FileNotFoundException. file)))
+    file))
 
 (defn parse-line
+  "Converts a normal move in the Kifu format to the USI format."
   [move-str from last-move]
   {:pre [(pos? (count move-str))]
    :post [(<= 4 (count %))]}
@@ -70,15 +83,15 @@
                       (get column-positions (str (subs move-str 0 1)))
                       (get row-positions    (str (subs move-str 1 2)))))]
    (cond
-     (.contains move-str "不成")
+     (.contains ^String move-str "不成")
        move
      (re-find #"成$" move-str)
        (str move "+")
      :else
        move)))
 
-
 (defn parse-line-drop
+  "Converts a drop move in the Kifu format to the USI format."
   [move-str]
   {:pre [(.contains move-str "打")]}
   (str (str/upper-case (get pieces (subs move-str 2 3)))
@@ -86,12 +99,11 @@
        (get column-positions (str (subs move-str 0 1)))
        (get row-positions    (str (subs move-str 1 2)))))
 
-
 (defn parse-moves
   [lines]
   (loop [current-move 1
-         lines lines
-         ret []]
+         lines        lines
+         ret          []]
     (if-not (seq lines)
       ret ;; base
       (let [line (str/trim (first lines))]
@@ -111,53 +123,66 @@
         :else
           (recur current-move (rest lines) ret))))))
 
+(defn accumulate-moves
+  "Accumelates moves and returns a sequnece of lines.
+   For example, for [m1 m2 m3] it will return [\"m1\" \"m1 m2\" \"m1 m2 m3\"]"
+  [moves]
+  (reduce (fn [v m]
+            (if (empty? v)
+              (conj v m)
+              (conj v (str (last v) " " m))))
+          []
+          (filter #(not= "resign" %) moves)))
 
-(defn start-main-loop
+(defn main-loop
   [nstart nend]
-  (letfn [(main-loop [nstart nend]
-            (let [contents (slurp (:file @options) :encoding "Shift_JIS")
-                  moves (parse-moves (str/split-lines contents))]
-              (log/debug (format "Read %d/%d moves..." (count moves) nstart))
-              (cond
-                (<= nend (count moves))
-                  nil ;; base
-                (< (count moves) nstart)
-                  (let [sec 10]
-                    (log/trace (format "Sleeping for %d seconds..." sec))
-                    (Thread/sleep (* sec 1000))
-                    (recur nstart nend))
-                :else
-                  (let [lines (for [i (range 0 (count (filter #(not= "resign" %) moves)))]
-                                (format "position startpos moves %s"
-                                        (str/join " " (take (inc i) moves))))]
-                    (dorun (map put-queue (drop (dec nstart) lines)))
-                    (if-not (= "resign" (last moves))
-                      (recur (inc (count moves)) nend)
-                      (put-queue "resign"))))))] ;; base
-    (if-not (.exists (io/as-file (:file @options)))
-      (do
-        (log/fatal "Kifu file not found")
-        (throw (java.io.FileNotFoundException. (:file @options))))
-      (let [thread (Thread. #(main-loop nstart nend))]
-        (.start thread)
-        thread))))
-       
+  (let [contents (slurp (check-file) :encoding "Shift_JIS")
+        moves    (parse-moves (str/split-lines contents))]
+    (log/debugf "Read %d/%d moves..." (count moves) nstart)
+    (cond
+      (<= nend (count moves))
+        nil ;; base
+      (< (count moves) nstart)
+        (do
+          (log/tracef "Too eary to start. Sleeping for %d seconds..." READ_FILE_WAIT_SECONDS)
+          (Thread/sleep (* 5 READ_FILE_WAIT_SECONDS 1000))
+          (recur nstart nend))
+      :else
+        (do
+          (dorun (map #(println (str "position startpos moves " %))
+                      (drop (dec nstart) (accumulate-moves moves))))
+          (if (= "resign" (last moves))
+            (do
+              (log/trace "A player resigned. Finishing...")
+              (println "resign")) ;; base
+            (do
+              (Thread/sleep (* READ_FILE_WAIT_SECONDS 1000))
+              (recur (inc (count moves)) nend)))))))
 
-(defn -main [& args]
-  (cmd/with-command-line args
-    "Convert a kifu file to usi moves"
-    [[end    "ending moves" 350]
-     [file f "kifu file" ""]
-     [start  "starting moves" 35]
-     remaining]
-    (swap! options assoc :end   (Integer. end))
-    (swap! options assoc :file  file)
-    (swap! options assoc :start (Integer. start))
-    (let [thread (start-main-loop (:start @options) (:end @options))]
-      (loop []
-        (let [s (.take moves-queue)]
-          (println s)
-          (if (= "resign" s)
-            (.join thread) ;; base
-            (recur)))))))
+(defn usage
+  [options-summary]
+  (->> ["USAGE: lein usi_convert [options]"
+        ""
+        "Options:"
+        options-summary]
+    (str/join \newline)))
+
+(defn error-msg
+  [errors]
+  (str "The following errors occurred while parsing your command:\n\n"
+    (str/join \newline errors)))
+
+(defn exit
+  [status msg]
+  (println msg)
+  (System/exit status))
+
+(defn -main
+  [& args]
+  (let [{:keys [options arguments errors summary]} (parse-opts args cli-options)]
+    (reset! opts options)
+    (cond
+      (:help @opts) (exit 0 (usage summary))
+      errors        (exit 1 (error-msg errors)))
+    (main-loop (:start @opts) (:end @opts))))
 
