@@ -10,7 +10,7 @@
 #include <boost/shared_ptr.hpp>
 #include <string>
 
-typedef boost::shared_ptr<Magick::Image> ImagePtr;
+typedef std::shared_ptr<Magick::Image> ImagePtr;
 
 /**
  * PieceImage represents an image of a piece.
@@ -65,7 +65,7 @@ private:
   double board_hegiht;
   double cell_width;
   double cell_height;
-  boost::scoped_ptr<Magick::Image> image;
+  std::unique_ptr<Magick::Image> image;
 
   /**
    * Return a piece string in Black's stand
@@ -176,7 +176,7 @@ private:
    *        ex. sfen.lnsgkgsnl_1r5b1_ppppppppp_9_9_9_PPPPPPPPP_1B5R1_LNSGKGSNL.b.-.png
    * @return an instance of BoardImage. If a line is invalid, return a null pointer.
    */
-  boost::shared_ptr<BoardImage> generate_image(const std::string& line,
+  std::shared_ptr<BoardImage> generate_image(const std::string& line,
                                                std::string& file_name) const;
   bool checkmateEscape(const osl::SimpleState& state) const;
 };
