@@ -6,10 +6,8 @@
 #include "indexList.h"
 #include "moveInfo.h"
 #include "stateInfo.h"
-#include "osl/effect_util/additionalEffect.h"
-#include "osl/neighboring8.h"
+#include "osl/additionalEffect.h"
 #include "osl/effect_util/neighboring8Direct.h"
-#include <boost/foreach.hpp>
 #include <string>
 
 namespace gpsshogi
@@ -56,7 +54,7 @@ namespace gpsshogi
 		    Player player)
     {
       const Square king = state.kingSquare(alt(player));
-      int ry = (move.to().y() - king.y())*playerToMul(player);
+      int ry = (move.to().y() - king.y())*osl::sign(player);
       if (ry == 0) return 0;
       return ry > 0 ? 1 : -1;
     }
@@ -138,7 +136,7 @@ namespace gpsshogi
       const Ptype captured = move.move.capturePtype();
       const Player player = move.player;
       int index = (move.move.ptype())*PTYPE_SIZE + captured;
-      BOOST_STATIC_ASSERT(PTYPE_EDGE == 1);
+      static_assert(PTYPE_EDGE == 1, "");
       if (captured != PTYPE_EMPTY
 	  && captured == state.threatened[alt(player)].ptype())
 	++index;
@@ -610,7 +608,7 @@ namespace gpsshogi
     void match(const StateInfo& state, const MoveInfo& info, int offset, index_list_t& out) const
     {
       const Move move = info.move;
-      BOOST_FOREACH(Piece piece, state.pin_by_opposing_sliders) {
+      for (Piece piece: state.pin_by_opposing_sliders) {
 	if (! state.state.hasEffectIf(move.ptypeO(), move.to(),
 					  piece.square())) 
 	  continue;
@@ -720,7 +718,7 @@ namespace gpsshogi
 	= Board_Table.getLongDirection<BLACK>(piece.square(), to);
       const StateInfo::long_attack_t&
 	cache = state.long_attack_cache[piece.number()][longToShort(d)];
-      BOOST_FOREACH(int index, cache) {
+      for (int index: cache) {
 	assert(index < LongAttackSize);
 	out.add(index+offset, 1);
       }      
@@ -1011,7 +1009,7 @@ namespace gpsshogi
     static bool isOpeningKingRoad(Move move, Square king) 
     {
       return ! move.isDrop()
-	&& Neighboring8::isNeighboring8(move.from(), king);
+	&& move.from().isNeighboring8(king);
     }
     static bool isDefendingThreatmate(Move move, Move threatmate,
 				      const NumEffectState& state) 
@@ -1145,7 +1143,7 @@ namespace gpsshogi
       const int value = 1;
       const Offset up = Board_Table.getOffset(state.turn(), U);
       const int basic_a = move.ptype() * PTYPE_SIZE*PTYPE_SIZE;
-      BOOST_FOREACH(PinnedGeneral defense, pinned_list) {
+      for (PinnedGeneral defense: pinned_list) {
 	if (to != defense.attack) 
 	  continue;
 	assert(defense.general.owner() != move.player());
@@ -1173,7 +1171,7 @@ namespace gpsshogi
 	  out.add(offset + a + PTYPE_EDGE, value);
 	  out.add(offset + b + PTYPE_EDGE, value);
 	}
-	if (Neighboring8::isNeighboring8(defense.covered.square(), king)) {
+	if (defense.covered.square().isNeighboring8(king)) {
 	  out.add(offset + a + KING, value);
 	  out.add(offset + b + KING, value);
 	}
@@ -1234,7 +1232,7 @@ namespace gpsshogi
     void match(const StateInfo& state, const MoveInfo& info, int offset, index_list_t& out) const
     {
       const Move move = info.move;
-      BOOST_FOREACH(Piece piece, state.king8_long_pieces) {
+      for (Piece piece: state.king8_long_pieces) {
 	if (! state.state.hasEffectIf(move.ptypeO(), move.to(),
 					  piece.square())) 
 	  continue;
@@ -1441,7 +1439,7 @@ namespace gpsshogi
 			 const CArray<Direction,3>& directions)
     {
       int liberty = 0;
-      BOOST_FOREACH(Direction d, directions) {
+      for (Direction d: directions) {
 	if ((ki.liberty() & (1<<d)) == 0)
 	  continue;
 	++liberty;
