@@ -3,7 +3,7 @@
 #ifndef GPSSHOGI_MOVE_PROBABILITY_INDEXLIST_H
 #define GPSSHOGI_MOVE_PROBABILITY_INDEXLIST_H
 
-#include "osl/misc/fixedCapacityVector.h"
+#include "osl/container.h"
 namespace gpsshogi
 {
   typedef double weight_t;
