@@ -1,29 +1,21 @@
 #include "feature.h"
-#include "osl/record/csaString.h"
-#include "osl/record/csa.h"
+#include "osl/csa.h"
 #include "osl/oslConfig.h"
-#include "gtest/gtest.h"
+#include <boost/test/unit_test.hpp>
 
 using namespace osl;
-struct FeatureTest : public testing::Test
-{
-  void SetUp()
-  {
-    OslConfig::setUp();
-  }
-};
 
 using gpsshogi::StateInfo;
 using gpsshogi::PinnedGeneral;
-TEST_F(FeatureTest, patternCommon)
+BOOST_AUTO_TEST_CASE(FeatureTestPatternCommon)
 {
-  ASSERT_EQ(48, gpsshogi::PatternCommon::PromotionBase);
-  ASSERT_EQ(64, gpsshogi::PatternCommon::SquareDim);
+  BOOST_CHECK_EQUAL(48, gpsshogi::PatternCommon::PromotionBase);
+  BOOST_CHECK_EQUAL(64, gpsshogi::PatternCommon::SquareDim);
 }
 
-TEST_F(FeatureTest, supportAttack)
+BOOST_AUTO_TEST_CASE(FeatureTestSupportAttack)
 {  
-  vector<Move> moves;
+  std::vector<Move> moves;
   {
     NumEffectState state(CsaString(
 			   "P1-OU-KE-GI *  *  *  * -KE-KY\n"
@@ -37,28 +29,28 @@ TEST_F(FeatureTest, supportAttack)
 			   "P9+KY+KE * +KI *  *  * +KE+KY\n"
 			   "P+00KA00FU\n"
 			   "P-00KA00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     Move m36fu(Square(3,6),PAWN,BLACK);
     size_t index = gpsshogi::ToEffect::supportAttack
       (StateInfo(state,moves,-1), Square(3,5), m36fu);
-    ASSERT_EQ(PTYPE_EMPTY*PTYPE_SIZE + ROOK, index);
+    BOOST_CHECK_EQUAL(PTYPE_EMPTY*PTYPE_SIZE + ROOK, index);
   }
 }
 
-TEST_F(FeatureTest, blockLong)
+BOOST_AUTO_TEST_CASE(FeatureTestBlockLong)
 {
   using gpsshogi::BlockLong;
-  ASSERT_EQ(0, BlockLong::longAttackIndex(newPtypeO(BLACK, LANCE)));
-  ASSERT_EQ(1, BlockLong::longAttackIndex(newPtypeO(BLACK, BISHOP)));
-  ASSERT_EQ(2, BlockLong::longAttackIndex(newPtypeO(BLACK, ROOK)));
-  ASSERT_EQ(3, BlockLong::longAttackIndex(newPtypeO(BLACK, PROOK)));
-  ASSERT_EQ(3, BlockLong::longAttackIndex(newPtypeO(BLACK, PBISHOP)));
-  ASSERT_EQ(4, BlockLong::longAttackIndex(newPtypeO(WHITE, LANCE)));
-  ASSERT_EQ(5, BlockLong::longAttackIndex(newPtypeO(WHITE, BISHOP)));
-  ASSERT_EQ(6, BlockLong::longAttackIndex(newPtypeO(WHITE, ROOK)));
-  ASSERT_EQ(7, BlockLong::longAttackIndex(newPtypeO(WHITE, PROOK)));
-  ASSERT_EQ(7, BlockLong::longAttackIndex(newPtypeO(WHITE, PBISHOP)));
-  vector<Move> moves;
+  BOOST_CHECK_EQUAL(0, BlockLong::longAttackIndex(newPtypeO(BLACK, LANCE)));
+  BOOST_CHECK_EQUAL(1, BlockLong::longAttackIndex(newPtypeO(BLACK, BISHOP)));
+  BOOST_CHECK_EQUAL(2, BlockLong::longAttackIndex(newPtypeO(BLACK, ROOK)));
+  BOOST_CHECK_EQUAL(3, BlockLong::longAttackIndex(newPtypeO(BLACK, PROOK)));
+  BOOST_CHECK_EQUAL(3, BlockLong::longAttackIndex(newPtypeO(BLACK, PBISHOP)));
+  BOOST_CHECK_EQUAL(4, BlockLong::longAttackIndex(newPtypeO(WHITE, LANCE)));
+  BOOST_CHECK_EQUAL(5, BlockLong::longAttackIndex(newPtypeO(WHITE, BISHOP)));
+  BOOST_CHECK_EQUAL(6, BlockLong::longAttackIndex(newPtypeO(WHITE, ROOK)));
+  BOOST_CHECK_EQUAL(7, BlockLong::longAttackIndex(newPtypeO(WHITE, PROOK)));
+  BOOST_CHECK_EQUAL(7, BlockLong::longAttackIndex(newPtypeO(WHITE, PBISHOP)));
+  std::vector<Move> moves;
   {
     NumEffectState state(CsaString(
 			   "P1-OU-KE-GI *  *  *  * -KE-KY\n"
@@ -72,20 +64,20 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  *  * +KE+KY\n"
 			   "P+00KA\n"
 			   "P-00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, BLACK);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, true);
     int add = (BlockLong::longAttackIndex(newPtypeO(WHITE,BISHOP))*PTYPEO_SIZE
 		+ ptypeOIndex(newPtypeO(BLACK,ROOK)))*8;
-    ASSERT_EQ(6, index.size());
-    ASSERT_EQ(base+add, index[0].first);
-    ASSERT_EQ(base+add+2, index[1].first);
-    ASSERT_EQ(base+add+3, index[2].first);
-    ASSERT_EQ(base+add+4, index[3].first);
-    ASSERT_EQ(base+add+5, index[4].first);
-    ASSERT_EQ(base+add+6, index[5].first);
+    BOOST_CHECK_EQUAL(6, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(base+add+2, index[1].first);
+    BOOST_CHECK_EQUAL(base+add+3, index[2].first);
+    BOOST_CHECK_EQUAL(base+add+4, index[3].first);
+    BOOST_CHECK_EQUAL(base+add+5, index[4].first);
+    BOOST_CHECK_EQUAL(base+add+6, index[5].first);
   } 
   {
     NumEffectState state(CsaString(
@@ -100,19 +92,19 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  *  * +KY+KE\n" // KY
 			   "P+00KA\n"
 			   "P-00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, BLACK);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, true);
     int add = (BlockLong::longAttackIndex(newPtypeO(WHITE,BISHOP))*PTYPEO_SIZE
 		+ ptypeOIndex(newPtypeO(BLACK,ROOK)))*8;
-    ASSERT_EQ(5, index.size());
-    ASSERT_EQ(base+add, index[0].first);
-    ASSERT_EQ(base+add+3, index[1].first);
-    ASSERT_EQ(base+add+4, index[2].first);
-    ASSERT_EQ(base+add+5, index[3].first);
-    ASSERT_EQ(base+add+6, index[4].first);
+    BOOST_CHECK_EQUAL(5, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(base+add+3, index[1].first);
+    BOOST_CHECK_EQUAL(base+add+4, index[2].first);
+    BOOST_CHECK_EQUAL(base+add+5, index[3].first);
+    BOOST_CHECK_EQUAL(base+add+6, index[4].first);
   } 
   {
     NumEffectState state(CsaString(
@@ -127,20 +119,20 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  *  * +KE+KY\n"
 			   "P+00KA\n"
 			   "P-00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, BLACK);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, true);
     int add = (BlockLong::longAttackIndex(newPtypeO(WHITE,BISHOP))*PTYPEO_SIZE
 		+ ptypeOIndex(newPtypeO(WHITE,ROOK)))*8;
-    ASSERT_EQ(6, index.size());
-    ASSERT_EQ(base+add, index[0].first);
-    ASSERT_EQ(base+add+2, index[1].first);
-    ASSERT_EQ(base+add+3, index[2].first);
-    ASSERT_EQ(base+add+4, index[3].first);
-    ASSERT_EQ(base+add+5, index[4].first);
-    ASSERT_EQ(base+add+6, index[5].first);
+    BOOST_CHECK_EQUAL(6, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(base+add+2, index[1].first);
+    BOOST_CHECK_EQUAL(base+add+3, index[2].first);
+    BOOST_CHECK_EQUAL(base+add+4, index[3].first);
+    BOOST_CHECK_EQUAL(base+add+5, index[4].first);
+    BOOST_CHECK_EQUAL(base+add+6, index[5].first);
   } 
   {
     NumEffectState state(CsaString(
@@ -155,15 +147,15 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  *  * +KE+KY\n"
 			   "P+00FU\n"
 			   "P-00KA\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, WHITE);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, true);
     int add = (BlockLong::longAttackIndex(newPtypeO(BLACK,BISHOP))*PTYPEO_SIZE // turn's
 	       + ptypeOIndex(newPtypeO(WHITE,ROOK)))*8;     // opponent's
-    ASSERT_EQ(1, index.size());
-    ASSERT_EQ(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(1, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
   } 
   {
     NumEffectState state(CsaString(
@@ -178,15 +170,15 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  *  * +KE+KY\n"
 			   "P+00FU\n"
 			   "P-00KA\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, WHITE);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, false);
     int add = (BlockLong::longAttackIndex(newPtypeO(WHITE,BISHOP))*PTYPEO_SIZE // opponent's
 	       + ptypeOIndex(newPtypeO(BLACK,ROOK)))*8;     // turn's
-    ASSERT_EQ(2, index.size());
-    ASSERT_EQ(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(2, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
   } 
   {
     NumEffectState state(CsaString(
@@ -201,24 +193,24 @@ TEST_F(FeatureTest, blockLong)
 			   "P9+KY+KE * +KI *  * +KE+KY * \n" // edge
 			   "P+00KA\n"
 			   "P-00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     gpsshogi::index_list_t index;
     Move m55(Square(5,5), BISHOP, BLACK);
     BlockLong::findAll(StateInfo(state,moves,-1), m55, index);
     const int base = BlockLong::ptypeSupport(BISHOP, true);
     int add = (BlockLong::longAttackIndex(newPtypeO(WHITE,BISHOP))*PTYPEO_SIZE
 	       + ptypeOIndex(PTYPEO_EMPTY))*8;
-    ASSERT_EQ(3, index.size());
-    ASSERT_EQ(base+add, index[0].first);
-    ASSERT_EQ(base+add+2, index[1].first);
-    ASSERT_EQ(base+add+3, index[2].first);
+    BOOST_CHECK_EQUAL(3, index.size());
+    BOOST_CHECK_EQUAL(base+add, index[0].first);
+    BOOST_CHECK_EQUAL(base+add+2, index[1].first);
+    BOOST_CHECK_EQUAL(base+add+3, index[2].first);
   } 
 }
 
-TEST_F(FeatureTest, testLureDefender)
+BOOST_AUTO_TEST_CASE(FeatureTestLureDefender)
 {  
   // gold
-  vector<Move> moves;
+  std::vector<Move> moves;
   {
     NumEffectState state(CsaString(
 			   "P1 * -OU-FU * -GI * +RY  *  * \n"
@@ -231,18 +223,18 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P8 *  *  * +KI *  * +KI *  * \n"
 			   "P9 * +OU * +GI *  * +FU-TO * \n"
 			   "P-00AL\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_EQ(5, info.exchange_pins[BLACK].size());
-    ASSERT_EQ(2, info.exchange_pins[WHITE].size());
-    ASSERT_EQ(Square(5,3), info.exchange_pins[WHITE][0].attack);
-    ASSERT_EQ(state.pieceOnBoard(Square(5,1)),
+    BOOST_CHECK_EQUAL(5, info.exchange_pins[BLACK].size());
+    BOOST_CHECK_EQUAL(2, info.exchange_pins[WHITE].size());
+    BOOST_CHECK_EQUAL(Square(5,3), info.exchange_pins[WHITE][0].attack);
+    BOOST_CHECK_EQUAL(state.pieceOnBoard(Square(5,1)),
 	      info.exchange_pins[WHITE][0].covered);
 
-    ASSERT_EQ(Square(4,7), info.exchange_pins[BLACK][0].attack);
-    ASSERT_EQ(Square(3,7), info.exchange_pins[BLACK][1].attack);
-    ASSERT_EQ(Square(2,7), info.exchange_pins[BLACK][2].attack);
-    ASSERT_EQ(state.pieceOnBoard(Square(3,9)),
+    BOOST_CHECK_EQUAL(Square(4,7), info.exchange_pins[BLACK][0].attack);
+    BOOST_CHECK_EQUAL(Square(3,7), info.exchange_pins[BLACK][1].attack);
+    BOOST_CHECK_EQUAL(Square(2,7), info.exchange_pins[BLACK][2].attack);
+    BOOST_CHECK_EQUAL(state.pieceOnBoard(Square(3,9)),
 	      info.exchange_pins[BLACK][0].covered);
   }
   {
@@ -257,9 +249,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P8+FU+OU+KI+KI *  *  *  *  * \n"
 			   "P9+KY+KE * +KE *  * -HI * -NY\n"
 			   "P-00KA00GI00KE00FU00FU00FU00FU\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[BLACK].isMember
+    BOOST_CHECK(info.exchange_pins[BLACK].isMember
 		(PinnedGeneral(state[Square(6,8)],state[Square(6,9)],Square(5,8))));
   }
   {
@@ -275,9 +267,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P9 * +OU+GI-GI *  *  * +KE+KY\n"
 			   "P+00KI00GI00KE00FU00FU00FU00FU00FU00FU00FU\n"
 			   "P-00KI00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(3,2)],state[Square(4,3)],Square(2,2))));
   }
 
@@ -294,18 +286,18 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P8 *  * +GI * +GI *  *  *  * \n"
 			   "P9+OU+TO *  *  * +KI * -RY * \n"
 			   "P-00AL\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[BLACK].isMember
+    BOOST_CHECK(info.exchange_pins[BLACK].isMember
 		(PinnedGeneral(state[Square(5,8)], state[Square(4,9)], Square(5,7))));
-    ASSERT_TRUE(info.exchange_pins[BLACK].isMember
+    BOOST_CHECK(info.exchange_pins[BLACK].isMember
 		(PinnedGeneral(state[Square(5,8)], state[Square(4,9)], Square(4,7))));
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(5,2)], state[Square(4,1)], Square(6,3))));
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(5,2)], state[Square(4,1)], Square(4,3))));
-    ASSERT_EQ(2, info.exchange_pins[BLACK].size());
-    ASSERT_EQ(3, info.exchange_pins[WHITE].size());
+    BOOST_CHECK_EQUAL(2, info.exchange_pins[BLACK].size());
+    BOOST_CHECK_EQUAL(3, info.exchange_pins[WHITE].size());
   }
   {
     NumEffectState state(CsaString(
@@ -320,11 +312,11 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P9+KY *  * +OU *  *  * +KE+KY\n"
 			   "P+00GI00GI00KE00FU\n"
 			   "P-00FU00FU00FU00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(6,2)], state[Square(5,1)], Square(6,3))));
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(6,2)], state[Square(5,1)], Square(7,3))));
   }
   {
@@ -340,9 +332,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P9+KY * +GI * +OU+KI * +KE+KY\n"
 			   "P+00KY00FU00FU00FU00FU\n"
 			   "P-00KI00GI\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[BLACK].isMember
+    BOOST_CHECK(info.exchange_pins[BLACK].isMember
 		(PinnedGeneral(state[Square(7,9)], state[Square(8,8)], Square(7,8))));
   }
   {
@@ -358,9 +350,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P9+KY *  *  *  * +KI *  * +KY\n"
 			   "P+00KA00GI00FU00FU\n"
 			   "P-00KA00KI00FU00FU00FU00FU00FU00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(3,5)], state[Square(4,6)], Square(3,6))));
   }
 
@@ -379,9 +371,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P+00KE00FU00FU00FU\n"
 			   "P-00GI00FU\n"
 			   "-\n"
-			   ).getInitialState());
+			   ).initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[BLACK].isMember
+    BOOST_CHECK(info.exchange_pins[BLACK].isMember
 		(PinnedGeneral(state[Square(6,8)], state[Square(5,7)], Square(5,9))));
   }
 
@@ -399,9 +391,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P+00HI00KA00KA00GI00KE00FU00FU00FU\n"
 			   "P-00GI00FU\n"
 			   "+\n"
-			   ).getInitialState());
+			   ).initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(8,7)], state[Square(8,6)], Square(7,7))));
   }
 
@@ -419,9 +411,9 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P+00KI00FU00FU\n"
 			   "P-00KI00GI00GI00FU00FU\n"
 			   "+\n"
-			   ).getInitialState());
+			   ).initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(7,2)], state[Square(6,1)], Square(6,3))));
   }
   
@@ -439,16 +431,16 @@ TEST_F(FeatureTest, testLureDefender)
 			   "P+00KA00GI00FU00FU00FU00FU\n"
 			   "P-00KA00KE00FU00FU\n"
 			   "+\n"
-			   ).getInitialState());
+			   ).initialState());
     StateInfo info(state,moves,-1);
-    ASSERT_TRUE(info.exchange_pins[WHITE].isMember
+    BOOST_CHECK(info.exchange_pins[WHITE].isMember
 		(PinnedGeneral(state[Square(6,2)], state[Square(7,3)], Square(7,1))));
   }
 }
 
-TEST_F(FeatureTest, testLongRecapture)
+BOOST_AUTO_TEST_CASE(FeatureTestLongRecapture)
 {
-  vector<Move> moves;
+  std::vector<Move> moves;
   { 
     NumEffectState state(CsaString(
 			   "P1-KY *  *  *  *  * -OU * +UM\n"
@@ -462,19 +454,19 @@ TEST_F(FeatureTest, testLongRecapture)
 			   "P9+KY+KE+FU *  *  *  *  * -NY\n"
 			   "P+00KA00KI00KE00FU00FU00FU\n"
 			   "P-00KY00FU00FU00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
     Move m21ka(Square(2,1),BISHOP,BLACK);
     gpsshogi::LongRecapture feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m21ka), 0, out);
-    ASSERT_TRUE(! out.empty());
+    BOOST_CHECK(! out.empty());
   }
 }
 
-TEST_F(FeatureTest, testKingBlockade)
+BOOST_AUTO_TEST_CASE(FeatureTestKingBlockade)
 {
-  vector<Move> moves;
+  std::vector<Move> moves;
   { 
     NumEffectState state(CsaString(
 			   "P1-OU * +UM-GI *  *  * -KE-KY\n"
@@ -488,15 +480,15 @@ TEST_F(FeatureTest, testKingBlockade)
 			   "P9+KY+KE *  *  *  *  *  * +KY\n"
 			   "P+00KI00KE00FU00FU\n"
 			   "P-00HI00KA00KI00KI00FU00FU\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     StateInfo info(state,moves,-1);
     Move m76hi(Square(7,6),ROOK,WHITE);
     gpsshogi::KingBlockade feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m76hi), 0, out);
-    ASSERT_EQ(2, out.size());
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockSideWide, out[0].first % 5);
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockBack, out[1].first % 5);
+    BOOST_CHECK_EQUAL(2, out.size());
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockSideWide, out[0].first % 5);
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockBack, out[1].first % 5);
   }
   {
     NumEffectState state(CsaString(
@@ -511,15 +503,15 @@ TEST_F(FeatureTest, testKingBlockade)
 			   "P9+KY+KE *  *  *  *  * +KE * \n"
 			   "P+00HI00KA00KI00GI00FU00FU\n"
 			   "P-00KI00KI00GI00FU00FU00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
     Move m86ka(Square(8,6),BISHOP,BLACK);
     gpsshogi::KingBlockade feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m86ka), 0, out);
-    ASSERT_EQ(2, out.size());
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockSideWide, out[0].first % 5);
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockBack, out[1].first % 5);
+    BOOST_CHECK_EQUAL(2, out.size());
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockSideWide, out[0].first % 5);
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockBack, out[1].first % 5);
   }
   {
     NumEffectState state(CsaString(
@@ -534,23 +526,23 @@ TEST_F(FeatureTest, testKingBlockade)
 			   "P9 * -UM+GI * +KE *  *  * +KY\n"
 			   "P+00HI00GI00KE00FU00FU\n"
 			   "P-00GI00KE00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
     Move m86ke(Square(8,6),KNIGHT,BLACK);
     gpsshogi::KingBlockade feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m86ke), 0, out);
-    ASSERT_EQ(3, out.size());
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockLastOne, out[0].first % 5);
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockFront, out[1].first % 5);
-    ASSERT_EQ(gpsshogi::KingBlockade::BlockSideOther, out[2].first % 5);
+    BOOST_CHECK_EQUAL(3, out.size());
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockLastOne, out[0].first % 5);
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockFront, out[1].first % 5);
+    BOOST_CHECK_EQUAL(gpsshogi::KingBlockade::BlockSideOther, out[2].first % 5);
   }
 }
 
-TEST_F(FeatureTest, testCoverFork)
+BOOST_AUTO_TEST_CASE(FeatureTestCoverFork)
 {
   using gpsshogi::CoverFork;
-  vector<Move> moves;
+  std::vector<Move> moves;
   { 
     NumEffectState state(CsaString(
 			   "P1-KY *  *  *  * -KI-GI-KE-KY\n"
@@ -564,23 +556,23 @@ TEST_F(FeatureTest, testCoverFork)
 			   "P9 *  * +FU *  * +KI * +KE+KY\n"
 			   "P+00HI00GI00KY00FU00FU\n"
 			   "P-00KE00FU00FU\n"
-			   "+\n").getInitialState());
+			   "+\n").initialState());
     StateInfo info(state,moves,-1);
     Move m76hi(Square(7,6),ROOK,BLACK);
-    ASSERT_TRUE(CoverFork::defending(state, m76hi, Square(4,9)));
-    ASSERT_TRUE(CoverFork::defending(state, m76hi, Square(7,2)));
+    BOOST_CHECK(CoverFork::defending(state, m76hi, Square(4,9)));
+    BOOST_CHECK(CoverFork::defending(state, m76hi, Square(7,2)));
     CoverFork feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m76hi), 0, out);
-    ASSERT_EQ(1*4, out.size());
-    ASSERT_EQ(((ROOK*PTYPE_SIZE)+GOLD)*PTYPE_SIZE+PROOK, out[3].first);
+    BOOST_CHECK_EQUAL(1*4, out.size());
+    BOOST_CHECK_EQUAL(((ROOK*PTYPE_SIZE)+GOLD)*PTYPE_SIZE+PROOK, out[3].first);
   }
 }
 
-TEST_F(FeatureTest, testPromotionBySacrifice)
+BOOST_AUTO_TEST_CASE(FeatureTestPromotionBySacrifice)
 {
   using gpsshogi::CoverFork;
-  vector<Move> moves;
+  std::vector<Move> moves;
   { 
     NumEffectState state(CsaString(
 			   "P1-KY * +RY * -KI-OU *  * -KY\n"
@@ -594,13 +586,13 @@ TEST_F(FeatureTest, testPromotionBySacrifice)
 			   "P9+KY+KE * +OU * +KI+GI+KE+KY\n"
 			   "P+00FU00FU00FU\n"
 			   "P-00KA00FU\n"
-			   "-\n").getInitialState());
+			   "-\n").initialState());
     StateInfo info(state,moves,-1);
     Move m77ke(Square(8,5),Square(7,7),KNIGHT,PTYPE_EMPTY,false,WHITE);
     gpsshogi::PromotionBySacrifice feature;
     gpsshogi::index_list_t out;
     feature.match(info, gpsshogi::MoveInfo(info, m77ke), 0, out);
-    ASSERT_TRUE(out.size() > 0);
+    BOOST_CHECK(out.size() > 0);
   }
 }
 
