@@ -6,11 +6,14 @@ use IO::Handle;
 use IO::Socket;
 use IO::Select;
 use File::Path;
+use List::Util qw(max min);
 use module::CsaBoard;
 use module::StopWatch;
 
 $| = 1;
 
+my @startupusi = ();
+
 my $config = { usi_engine    => '',
 	       csa_host      => 'wdoor.c.u-tokyo.ac.jp',
 	       csa_port      => 4081,
@@ -18,6 +21,7 @@ my $config = { usi_engine    => '',
 	       csa_pw        => 'yowai_gps-1500-0',
 	       sec_limit     => 1500,
 	       sec_limit_up  => 0,
+	       sec_inc_per_move  => 0,
 	       time_response => 0.5,
 	       ponder        => 1,
 	       verbose       => '',
@@ -28,15 +32,16 @@ my $config = { usi_engine    => '',
 	       usinewgame    => 1,
 	       resign_value  => 0,
 	       logdir        => "log",
-	       startup_usi   => '',
+	       startup_usi   => \@startupusi,
 	       server_stdio  => ""
 	     };
 GetOptions($config, 'usi_engine=s', 'csa_host=s', 'csa_port=i',
 	   'csa_id=s', 'csa_pw=s', 'sec_limit=i', 'sec_limit_up=i',
+	   'sec_inc_per_move=i',
 	   'time_response=f', 'ponder!', 'verbose!', 'send_pv!',
 	   'stop_interval=f', 'pawn_value=f',
 	   'stable_ratio=f', 'usinewgame!', 'resign_value=i', 'logdir=s',
-	   'startup_usi=s',
+	   'startup_usi=s@',
 	   'server_stdio=s') || die "$!";
 
 die "usi_engine not specified" unless $config->{usi_engine};
@@ -118,13 +123,19 @@ sub init_client ($) {
       if ($line =~ /^option name UsiOutputPawnValue type spin default ([0-9]+)/);
     last if ($line =~ /^readyok/);
   }
-  write_line($client, $config->{startup_usi})
-    if ($config->{startup_usi});
+  if ($config->{startup_usi}) {
+    foreach $_ (@startupusi) {
+      write_line($client, $_);
+    }
+  }
   $status->{client} = $client;
 }
 
 sub init_server ($) {
   my ($status) = @_;
+  $status->{board} = new CsaBoard;
+  $status->{time_used} = {'+'=>0, '-'=>0};
+  $status->{time_gained} = {'+' => $config->{sec_inc_per_move}, '-'=>0};
   my $server = { type=>type_server, buf=>"" };
   $server->{log} = $status->{log};
   open ($status->{csa}, "> ".$config->{logdir}."/".$status->{gameid}.".csa") || die $!;
@@ -149,6 +160,7 @@ sub init_server ($) {
   my $in_game_summary = undef;
   while (1) {
     my $line = read_line($server, keep_alive);
+    # print STDERR $line."\n";
     if (!$line) {
       write_line($server, "")
 	if (time - $server->{last_activity} >= keep_alive);
@@ -173,9 +185,16 @@ sub init_server ($) {
       $my_color = $1;
       next;
     }
+    if ($line =~ /^([+-])(\d{4}\w{2})(,T(\d+))?/) {
+	my ($color, $move, $sec) = ($1, $2, $4);
+	$status->{time_used}->{$color} += $sec || 1;
+	print STDERR "given ".$color.$move."\n";
+	$status->{board}->make_csamove($color.$move);
+    }
   }
   $status->{server} = $server;
   $status->{my_color} = $my_color;
+  print STDERR $status->{board}->csa_show;
 }
 
 sub write_line ($$) {
@@ -232,24 +251,43 @@ sub read_line ($@) {
 
 sub assign_time ($) {
   my ($status) = @_;
-  my $turn_used = $status->{time_used}->{$status->{board}->{turn}};
-  my $left = $config->{sec_limit} - $turn_used;
-  if ($left < $config->{sec_limit_up}*2) {
-    $status->{sec_standard} = $status->{sec_hard}
-      = $config->{sec_limit_up};
+  my $turn = $status->{board}->{turn};
+  my $turn_used = $status->{time_used}->{$turn};
+  my $left = $config->{sec_limit} - $turn_used + $status->{time_gained}->{$turn};
+  my $sec_limit_up = $config->{sec_limit_up} || $config->{sec_inc_per_move};
+  my $reserve = 0;
+  if ($config->{sec_inc_per_move} && $left >= $sec_limit_up*2) {
+    $reserve = max($left*0.2, $sec_limit_up);
+    $left -= $reserve;
+  }
+  if ($status->{phase} != phase_puzzling) {
+    printf STDERR "time used %ds %ds", $status->{time_used}->{'+'},
+      $status->{time_used}->{'-'};
+    printf STDERR " gained %ds %ds", $status->{time_gained}->{'+'},
+      $status->{time_gained}->{'-'}
+      if $config->{sec_inc_per_move};
+    printf STDERR " left %ds %ds",
+      $config->{sec_limit} + $status->{time_gained}->{'+'} - $status->{time_used}->{'+'},
+      $config->{sec_limit} + $status->{time_gained}->{'-'} - $status->{time_used}->{'-'};
+    print STDERR "\n";
+  }
+  if ($left <= $sec_limit_up*2) {
+    my $standard = $sec_limit_up;
+    my $saving = 0;
+    $saving = max(1, $config->{sec_inc_per_move}/10)
+      if ($config->{sec_inc_per_move}>1 && $left+$reserve < $sec_limit_up*3);
+    $status->{sec_standard} = $standard - $saving;
+    $status->{sec_hard} = $standard + $saving + $reserve*3/4;
     return;
   }
   my $nmoves = $status->{board}->count_moves;
-  printf STDERR "time used %ds %ds\n", $status->{time_used}->{'+'},
-    $status->{time_used}->{'-'}
-      if $status->{phase} != phase_puzzling;
-  if ($config->{sec_limit_up} > 0) {
-    my $a = $config->{sec_limit_up}*2;
+  if ($sec_limit_up > 0) {
+    my $a = $sec_limit_up*2;
     my $tt = 120 + $nmoves/5;
     my $t = ($nmoves < $tt) ? ($tt - $nmoves)/2+1 : 10;
     $a = 1.0 * $left / $t if $a < 1.0 * $left / $t;
     $status->{sec_standard} = $a;
-    $status->{sec_hard} = $a*2 < $left ? $a*2 : $left;
+    $status->{sec_hard} = min($a*2, $left+$reserve/2);
     return;
   }
   if ($left < 20) {
@@ -262,15 +300,15 @@ sub assign_time ($) {
   }
   my $p = $config->{ponder} ? 2.2 : 2.0;
   my $t = ($nmoves < 104) ? ((125 - $nmoves)/$p+1) : $nmoves/8;
-  my $reduce = ($config->{sec_limit_up} < 30) ? 0.85 : 1.0;
+  my $reduce = ($sec_limit_up < 30) ? 0.85 : 1.0;
   my $a = $reduce*($left - 60) / $t + 1;
-  my $scale = ($config->{sec_limit_up} < 30) ? 2.5 : 5;
+  my $scale = ($sec_limit_up < 30) ? 2.5 : 5;
   $status->{sec_standard} = $a;
-  $status->{sec_hard} = $a*$scale < ($left-60) ? $a*$scale : ($left-60);
+  $status->{sec_hard} = min($a*$scale, $left-60);
 
   # adjustment
   ## limit
-  if ($config->{sec_limit_up} < 30) {
+  if ($sec_limit_up < 30) {
     my $maximum = 24.0 * $config->{sec_limit} / 1500;
     $a = $maximum if ($a > $maximum);
   }
@@ -283,7 +321,7 @@ sub assign_time ($) {
     my $a = $config->{sec_limit}/60.0;
     printf STDERR "increased %.1f => %.1f\n", $status->{sec_standard}, $a;
     $status->{sec_standard} = $a;
-    $status->{sec_hard} = $a*2.5 < ($left-60) ? $a*2.5 : ($left-60);
+    $status->{sec_hard} = min($a*2.5, $left-60);
   }
   ## decrease
   my $my_used = $status->{time_used}->{$status->{my_color}};
@@ -395,12 +433,10 @@ sub valid_usi ($) {
 sub start_game ($) {
   my ($status) = @_;
   printf STDERR "\nnew game %s\n\n", $status->{gameid};
-  $status->{board} = new CsaBoard;
   die unless $status->{my_color};
-  $status->{time_used} = {'+'=>0, '-'=>0};
   $status->{id} = 0;
   $status->{bestmove} = 0;
-  $status->{phase} = ($status->{my_color} eq '+')
+  $status->{phase} = ($status->{my_color} eq $status->{board}->{turn})
     ? phase_thinking : phase_puzzling;
   write_line($status->{client}, "usinewgame") if $config->{usinewgame};
   new_position($status);
@@ -443,6 +479,7 @@ sub handle_server_message ($$) {
   die unless ($line =~ /^([+-])(\d{4}\w{2})(,T(\d+))?/);
   my ($color, $move, $sec) = ($1, $2, $4);
   $status->{time_used}->{$color} += $sec || 1;
+  $status->{time_gained}->{$color} += $config->{sec_inc_per_move};
   if ($color eq $status->{my_color}) {
     print {$status->{csa}} "'** ".$status->{prev_pv}."\n"
       if $status->{prev_pv};
