@@ -14,7 +14,7 @@ int main()
     udp::socket socket(io_service, udp::endpoint
 		       (udp::v4(), gpsshogi::udp_log_port));
 
-    boost::array<char, 1024> recv_buf;
+    std::array<char, 1024> recv_buf;
     while (true) {
       udp::endpoint remote_endpoint;
       boost::system::error_code error;
