@@ -5,27 +5,23 @@
 #include "searchNode.h"
 #include "logging.h"
 #include "osl/game_playing/usiState.h"
-#include "osl/record/csa.h"
-#include "osl/record/csaString.h"
-#include "osl/record/csaIOError.h"
-#include "osl/record/usi.h"
-#include "osl/record/opening/openingBook.h"
+#include "osl/record/csaRecord.h"
+#include "osl/usi.h"
+#include "osl/book/openingBook.h"
 #include "osl/game_playing/weightTracer.h"
-#include "osl/hash/hashKey.h"
+#include "osl/hashKey.h"
 #include "osl/oslConfig.h"
 #include <boost/asio/ip/tcp.hpp>
 #include <boost/asio/streambuf.hpp>
 #include <boost/asio/write.hpp>
 #include <boost/asio/read_until.hpp>
-#include <boost/bind/bind.hpp>
-#include <boost/thread/thread.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <boost/algorithm/string/trim.hpp>
 #include <boost/algorithm/string/replace.hpp>
 #include <boost/algorithm/string/split.hpp>
 #include <boost/filesystem/operations.hpp>
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/foreach.hpp>
+#include <thread>
 #include <iostream>
 
 void gpsshogi::CsaGameCondition::
@@ -55,11 +51,11 @@ class gpsshogi::CsaServer::MultiTcpIp
   CsaConfig & config;		// overwrite limit_seconds..
   int selected;
   boost::asio::io_service& io;
-  boost::mutex& mutex;
-  boost::condition& condition;
+  std::mutex& mutex;
+  std::condition_variable& condition;
 public:
   MultiTcpIp(CsaConfig & c, boost::asio::io_service& i,
-	     boost::mutex& m, boost::condition& cond)
+	     std::mutex& m, std::condition_variable& cond)
     : config(c), selected(-1), io(i), mutex(m), condition(cond) {
   }
   bool loginWithRetry(const CsaConfig& config)
@@ -89,14 +85,14 @@ public:
       boost::system::error_code ec;      
       while (socket.back().connect(server, ec)) {
 	std::cerr << "." << std::flush;
-	boost::this_thread::sleep(boost::posix_time::seconds(15));
+	std::this_thread::sleep_for(std::chrono::seconds(15));
       }
       std::cerr << "\n" << std::flush;
       writeLine(n, "LOGIN " + account.username + ' ' + account.password);
       std::string line;
       if (! readLine(n, line)) {
 	Logging::error("^disconnected before LOGIN (retry)");
-	boost::this_thread::sleep(boost::posix_time::seconds(15));
+	std::this_thread::sleep_for(std::chrono::seconds(15));
 	socket.pop_back();
 	continue;
       }
@@ -137,12 +133,12 @@ public:
     for (size_t i=0; i<account.size(); ++i) {
       boost::asio::async_read_until
 	(socket[i], buffer_r[i], "\n",
-	 boost::bind(&MultiTcpIp::waitChallenge, this, i, _1));
+	 [=](boost::system::error_code ec, size_t){ this->waitChallenge(i, ec); });
     }
 
-    boost::mutex::scoped_lock lk(mutex);
+    std::unique_lock<std::mutex> lk(mutex);
     while (selected < 0)
-      condition.wait(mutex);
+      condition.wait(lk);
 
     Logging::notice("^selected ("+to_s(selected)
 		    +") "+account[selected].username);
@@ -165,7 +161,7 @@ public:
   void waitChallenge(size_t called, const boost::system::error_code& ec) {
     if (ec || selected >= 0)
       return;
-    boost::mutex::scoped_lock lk(mutex);
+    std::lock_guard<std::mutex> lk(mutex);
     selected = called;
     for (size_t i=0; i<account.size(); ++i) {
       if (i == selected)
@@ -179,7 +175,7 @@ public:
 
 class gpsshogi::CsaServer::TcpIp : public gpsshogi::CsaServer::Connection
 {
-  boost::scoped_ptr<std::iostream> ios;
+  std::unique_ptr<std::iostream> ios;
 public:
   bool loginWithRetry(const CsaConfig& config)
   {
@@ -190,7 +186,7 @@ public:
       if (! *ios)
 	Logging::info("^waiting csaserver ready");
       while (! *ios) {
-	boost::this_thread::sleep(boost::posix_time::seconds(15));
+	std::this_thread::sleep_for(std::chrono::seconds(15));
 	ios.reset(new boost::asio::ip::tcp::iostream
 		  (config.servername, to_s(config.portnumber)));
       }
@@ -198,7 +194,7 @@ public:
       std::string line;
       if (! readLine(line)) {
 	Logging::error("^disconnected before LOGIN (retry)");
-	boost::this_thread::sleep(boost::posix_time::seconds(15));
+	std::this_thread::sleep_for(std::chrono::seconds(15));
 	continue;
       }
       Logging::info("^"+line);
@@ -221,7 +217,7 @@ public:
 
 class gpsshogi::CsaServer::StdIO : public gpsshogi::CsaServer::Connection
 {
-  boost::scoped_ptr<boost::asio::ip::tcp::iostream> ios;
+  std::unique_ptr<boost::asio::ip::tcp::iostream> ios;
 public:
   bool loginWithRetry(const CsaConfig& config)
   {
@@ -264,11 +260,11 @@ public:
       boost::filesystem::create_directory(path()+"/in");
       boost::filesystem::create_directory(path()+"/out");
       writeLine("LOGIN " + config.username + ' ' + config.password);
-      boost::this_thread::sleep(boost::posix_time::seconds(1));
+      std::this_thread::sleep_for(std::chrono::seconds(1));
       std::string line;
       if (! readLine(line)) {
 	Logging::error("^retry LOGIN");
-	boost::this_thread::sleep(boost::posix_time::seconds(5));
+	std::this_thread::sleep_for(std::chrono::seconds(5));
 	continue;
       }
       Logging::info("^"+line);
@@ -289,7 +285,7 @@ public:
 	return true;
       }
       // todo: inotify
-      boost::this_thread::sleep(boost::posix_time::milliseconds(50));
+      std::this_thread::sleep_for(std::chrono::milliseconds(50));
       // retry if our first login message was cleared
       if (in == 0) {
 	std::ifstream is((path()+"/out/"+id(0)+".txt").c_str());
@@ -327,8 +323,8 @@ gpsshogi::CsaServer::
 void gpsshogi::CsaServer::
 start()
 {
-  // todo: use its own io_service and remove boost::condition
-  boost::thread(boost::bind(&CsaServer::playGames, this, config.games));
+  // todo: use its own io_service and remove std::condition_variable
+  std::thread(&CsaServer::playGames, this, config.games).detach();
 }
 
 bool gpsshogi::CsaServer::
@@ -397,20 +393,21 @@ waitOpponent(int gameid)
       game.csaFileFlush();
       try {
 	std::cerr << position << "\n";
-	osl::CsaString csa(position.c_str());
-	game.initial_state = csa.getInitialState();
-	osl::record::Record record = csa.getRecord();
-	osl::vector<int> times;
-	record.getMoves(game.initial_moves, times);
+	std::istringstream is(position);
+	osl::CsaFile csa(is);
+	game.initial_state = csa.initialState();
+	auto record = csa.load();
+	std::vector<int> times;
+	record.load(game.initial_moves, times);
 	for (size_t i=0; i<times.size(); ++i) {
 	  game.time_used[osl::indexToPlayer(i%2)] += times[i];
 	}
 	std::cerr << "used BLACK " << game.time_used[osl::BLACK]
 		  << " WHITE " << game.time_used[osl::WHITE] << '\n';
 	game.state = osl::HistoryState(game.initial_state);
-	BOOST_FOREACH(osl::Move move, game.initial_moves) {
+	for (osl::Move move: game.initial_moves) {
 	  if (! game.state.state().isValidMove(move))
-	    throw osl::CsaIOError("not valid move "+osl::record::csa::show(move));
+	    throw osl::CsaIOError("not valid move "+osl::csa::show(move));
 	  game.state.makeMove(move);
 	}
 	connection->writeLine("AGREE");
@@ -474,7 +471,7 @@ waitOpponent(int gameid)
 	Logging::error("^unknown color "+my_color);
 	return false;
       }
-      game.my_turn = osl::record::csa::charToPlayer(my_color[0]);
+      game.my_turn = osl::csa::charToPlayer(my_color[0]);
       continue;
     }
     if (in_position)
@@ -524,34 +521,34 @@ CsaServer::makeMoveFromServer()
     std::vector<std::string> elements;
     boost::algorithm::split(elements, line, boost::algorithm::is_any_of(","));
     try {
-      osl::Move move = osl::record::csa::strToMove(elements[0], game.state);
+      osl::Move move = osl::csa::strToMove(elements[0], game.state);
       int seconds = 0;
       if (elements.size() > 1 && elements[1][0] == 'T')
 	seconds = boost::lexical_cast<int>(elements[1].substr(1));
       if (move.isNormal()) {
 	if (my_last_move.isNormal() && move != my_last_move) {
-	  Logging::error("^unexpected response " + osl::record::csa::show(move)
-			 + " while expected " +  osl::record::csa::show(my_last_move));
+	  Logging::error("^unexpected response " + osl::csa::show(move)
+			 + " while expected " +  osl::csa::show(my_last_move));
 	  if (my_last_move.player() != move.player()) {
 	    deffered_input = line; // assume missing input
 	    move = my_last_move;
 	    seconds = 1;
 	  }
 	  game_history.push_back
-	    (boost::make_tuple(my_last_score, my_last_move, 1));
+	    (std::make_tuple(my_last_score, my_last_move, 1));
 	  my_last_score = 0;
 	}
-	game_history.push_back(boost::make_tuple
+	game_history.push_back(std::make_tuple
 			       (my_last_score, move, seconds));
 	std::ostringstream ss;
 	for (int i=0; i<std::min(8,(int)game_history.size()); ++i) {
 	  const int id = game_history.size()-i-1;
-	  const boost::tuple<int,osl::Move,int> data = game_history[id];
+	  const std::tuple<int,osl::Move,int> data = game_history[id];
 	  ss << (id+1) << "."
-	     << osl::record::csa::show(data.get<1>())
-	     << ",T" << data.get<2>();
-	  if (data.get<0>())
-	    ss << '<' << data.get<0>() << '>';
+	     << osl::csa::show(std::get<1>(data))
+	     << ",T" << std::get<2>(data);
+	  if (std::get<0>(data))
+	    ss << '<' << std::get<0>(data) << '>';
 	  ss << ' ';
 	}
 	Logging::notice(ss.str());
@@ -560,16 +557,16 @@ CsaServer::makeMoveFromServer()
 	game.state.makeMove(move);
 	game.time_used[move.player()] += seconds;
 	double margin = (game_history.size() > 30) ? 1.8 : 0.8;
-	double elapsed = last_move_time.elapsedSeconds();
+	double elapsed = osl::elapsedSeconds(last_move_time);
 	if (elapsed < margin) {
 	  Logging::notice("sleep "+to_s((int)((margin-elapsed)*1000))
-			  +"ms for "+osl::record::csa::show(move));
-	  boost::this_thread::sleep(boost::posix_time::milliseconds
-				    ((margin-elapsed)*1000));
+			  +"ms for "+osl::csa::show(move));
+	  std::this_thread::sleep_for(std::chrono::milliseconds
+				      ((int)((margin-elapsed)*1000)));
 	}
-	last_move_time = osl::MilliSeconds::now();
-	io->post(boost::bind(&Coordinator::moveRoot, coordinator,
-			     osl::record::usi::show(move)));
+	last_move_time = osl::clock::now();
+	io->post(std::bind(&Coordinator::moveRoot, coordinator,
+			     osl::usi::show(move)));
 	return true;
       }
     }
@@ -608,7 +605,7 @@ playGames(int num_games)
     else
       connection.reset(new TcpIp());
     if (! connection->loginWithRetry(config)) { // wrong password => no retry
-      io->post(boost::bind(&Coordinator::prepareQuit, coordinator));
+      io->post(std::bind(&Coordinator::prepareQuit, coordinator));
       return;
     }
     current_status = Initializing;
@@ -616,10 +613,11 @@ playGames(int num_games)
     if (! waitOpponent(i)) 
       goto cleanup;
     current_status = Idle;
+    my_last_move = osl::Move();
     
     // new game
     Logging::notice("^new game");
-    io->post(boost::bind(&Coordinator::newGameStart, coordinator));
+    io->post(std::bind(&Coordinator::newGameStart, coordinator));
     while (1) {
       osl::NumEffectState current = game.state;
       info = InterimReport();
@@ -628,7 +626,7 @@ playGames(int num_games)
 	osl::Move move = searchBestMove(); // may block
 	my_last_move = move;
 	my_last_score = info.bestValue();
-	std::string msg = osl::record::csa::show(move);
+	std::string msg = osl::csa::show(move);
 	std::string csa_info = "";
 	if (info.bestValue() || ! info.pv.empty()) {
 	  boost::algorithm::replace_all(last_pv, "+", " +"); 
@@ -658,19 +656,19 @@ playGames(int num_games)
       std::ofstream os((Logging::path()+"game.csa").c_str());
       os << game.csalines;
     }
-    io->post(boost::bind(&Coordinator::gameFinished, coordinator));
+    io->post(std::bind(&Coordinator::gameFinished, coordinator));
     logDisconnected();
     connection.reset();
     game.csafile.reset();
-    boost::this_thread::sleep(boost::posix_time::seconds(15));
+    std::this_thread::sleep_for(std::chrono::seconds(15));
   }
-  io->post(boost::bind(&Coordinator::prepareQuit, coordinator));
+  io->post(std::bind(&Coordinator::prepareQuit, coordinator));
 }
 
 osl::Move gpsshogi::CsaServer::
 searchBestMove() 
 {
-  static osl::record::opening::WeightedBook book(osl::OslConfig::openingBook());
+  static osl::book::WeightedBook book(osl::OslConfig::openingBook());
   // book
   if (osl::HashKey(game.initial_state)
       == osl::HashKey(osl::SimpleState(osl::HIRATE))
@@ -678,7 +676,7 @@ searchBestMove()
   {
     osl::game_playing::WeightTracer tracer
       (book, false, config.book_width_root, config.book_width);
-    BOOST_FOREACH(osl::Move m, game.state.history())
+    for (osl::Move m: game.state.history())
       tracer.update(m);
     if (! tracer.isOutOfBook()) {
       const osl::Move best_move = tracer.selectMove();
@@ -698,13 +696,13 @@ searchBestMove()
   seconds.opponent_used = game.time_used[alt(game.my_turn)];
   seconds.allow_ponder = config.ponder;
   seconds.my_turn = game.my_turn;
-  boost::mutex::scoped_lock lk(mutex);
+  std::unique_lock<std::mutex> lk(mutex);
   current_status = Go;
   go_positions.push_back(usi_state.usiString());
-  io->post(boost::bind(&Coordinator::handleGoInGame, coordinator,
+  io->post(std::bind(&Coordinator::handleGoInGame, coordinator,
 		       go_positions.size(), go_positions.back(), seconds));
   while (bestmove_history.size() < go_positions.size())
-    condition.wait(mutex);
+    condition.wait(lk);
   current_status = Idle;
   return bestmove_history.back();
 }
@@ -725,12 +723,12 @@ outputSearchResult(int position_id, const std::string& msg)
     boost::algorithm::split(elements, msg, boost::algorithm::is_any_of(" "));
     if (elements.size() < 2 || elements[0] != "bestmove")
       throw std::logic_error("^unkown usi bestmove "+msg);
-    move = osl::record::usi::strToMove(elements[1], game.state);
+    move = osl::usi::strToMove(elements[1], game.state);
   }
   catch (...) {
     Logging::error("^treat %TORYO for unexpected seacrh result "+msg);
   }
-  boost::mutex::scoped_lock lk(mutex);
+  std::lock_guard<std::mutex> lk(mutex);
   bestmove_history.push_back(move);
   condition.notify_all();
 }
@@ -738,12 +736,12 @@ outputSearchResult(int position_id, const std::string& msg)
 void gpsshogi::CsaServer::
 outputSearchProgress(int position_id, const std::string& msg)
 {
-  static osl::MilliSeconds last_report;
-  osl::MilliSeconds now = osl::MilliSeconds::now();
+  static osl::time_point last_report;
+  osl::time_point now = osl::clock::now();
   InterimReport report;
   report.updateByInfo(msg, -1);
   osl::HistoryState copy(game.state);
-  boost::mutex::scoped_lock lk(mutex);
+  std::lock_guard<std::mutex> lk(mutex);
   info.set(copy.state().turn(), report);
   last_pv = SearchNode::toCSA(copy, info.joinPV());
   std::ostringstream ss;
@@ -751,7 +749,7 @@ outputSearchProgress(int position_id, const std::string& msg)
      << info.bestValue()*100/usi_pawn_value
      << ' ' << last_pv << " (" << info.pv.size()
      << ' ' << info.depth_head << ")";
-  if ((now - last_report).value() >= 5000)
+  if (now - last_report >= osl::milliseconds(5000))
     Logging::notice(ss.str());
   else
     Logging::info(ss.str());
