@@ -6,15 +6,14 @@
 #include "usiStatus.h"
 #include "logging.h"
 #include "osl/eval/evalTraits.h"
-#include "osl/record/usi.h"
-#include "osl/record/csa.h"
+#include "osl/usi.h"
+#include "osl/csa.h"
 #include "osl/game_playing/usiResponse.h"
 #include "osl/game_playing/gameState.h"
 #include "osl/checkmate/fixedDepthSearcher.h"
-#include "osl/enter_king/enterKing.h"
+#include "osl/enterKing.h"
 #include "osl/eval/pieceEval.h"
-#include "osl/container/moveStack.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/progress.h"
 #include "osl/move_probability/featureSet.h"
 #include "osl/sennichite.h"
 #include "osl/enter_king/simplePredictor.h"
@@ -23,7 +22,6 @@
 #include <boost/algorithm/string/trim.hpp>
 #include <boost/algorithm/string/join.hpp>
 #include <boost/range/iterator_range.hpp>
-#include <boost/foreach.hpp>
 #include <boost/format.hpp>
 #include <iostream>
 #include <iomanip>
@@ -127,7 +125,7 @@ status() const
   std::string msg 
     = to_s(probing.size()) + "/"+to_s(split_waiting.size());
   int number = 0;
-  BOOST_FOREACH(int id, probing) {
+  for (int id: probing) {
     if (++number > 10) {
       msg += "...";
       break;
@@ -153,7 +151,7 @@ gpsshogi::SearchNode::
 ~SearchNode()
 {
   typedef successor_table_t::value_type value_type;
-  BOOST_FOREACH(value_type& c, succ)
+  for (value_type& c: succ)
     if (c.second) {
       if (c.second->parent && c.second->parent != this)
 	Logging::error("parent inconsistent "+path()+" -- "+c.first);
@@ -179,7 +177,7 @@ successor(const std::string& move)
     assert(0);
   }
   assert(! osl_move.isInvalid()); // not always isNormal e.g., %KACHI
-  boost::shared_ptr<SearchNode>& node = succ[move];
+  std::shared_ptr<SearchNode>& node = succ[move];
   if (! node) {
     if (probe.probed.count(move)) 
       node = probe.probed[move];
@@ -263,10 +261,10 @@ successorOther()
 {
   typedef successor_table_t::value_type value_type;
   std::string ignore_moves = "";
-  BOOST_FOREACH(value_type& v, succ) 
+  for (value_type& v: succ) 
     if (v.first != "other")
       ignore_moves += " "+v.first;
-  boost::shared_ptr<SearchNode>& node = succ["other"];
+  std::shared_ptr<SearchNode>& node = succ["other"];
   if (! node) 
     node.reset(new SearchNode(position, key, this, "other", ignore_moves));
   else if (node->ignore_moves != ignore_moves) {
@@ -289,13 +287,13 @@ prepareProbe(slave_set_t& stopped)
     slave_set_t worked, restart_cancelled, waited;
     stopSubTree(worked, restart_cancelled, waited);
     std::string msg = "|conflict in probe " + path();
-    BOOST_FOREACH(int id, worked)
+    for (int id: worked)
       msg += " "+to_s(id);
     Logging::error(msg+" restartcancel "+to_s(restart_cancelled.size())+" "+to_s(waited.size()));
     stopped.insert(worked.begin(), worked.end());
   }
   probe.clear();
-  probe.start = osl::MilliSeconds::now();
+  probe.start = osl::clock::now();
 
   if (moves.empty())
     generateMoves();  
@@ -304,7 +302,7 @@ prepareProbe(slave_set_t& stopped)
   else {
     std::string ignored="";
     probe.target.reserve(moves.normal.size());
-    BOOST_FOREACH(const std::string& move, moves.normal)
+    for (const std::string& move: moves.normal)
       if (! hasMove(move))
 	probe.target.push_back(move);
       else
@@ -385,7 +383,7 @@ append(const std::string& position, std::string move)
 }
 
 bool gpsshogi::SearchNode::
-update(boost::function<void(std::string)> progress)
+update(std::function<void(std::string)> progress)
 {
   if (! parent) {
     progress(report().composeInfo(key.isPlayerOfTurn(osl::WHITE)));
@@ -399,7 +397,7 @@ recalculateNodeCount() const
 {
   uint64_t sum = 0;
   typedef successor_table_t::value_type pair_t;
-  BOOST_FOREACH(const pair_t& v, succ) 
+  for (const pair_t& v: succ) 
     sum += v.second->nodeCount();;
   return sum;
 }
@@ -425,7 +423,7 @@ winValue(int mate_length) const
 
 bool gpsshogi::SearchNode::
 update(const std::string& move, const InterimReport& child,
-       boost::function<void(std::string)> progress)
+       std::function<void(std::string)> progress)
 {
   main.node_count = recalculateNodeCount();
   main.pv.elapsed = main.elapsed = std::max(main.elapsed, child.elapsed);
@@ -446,7 +444,7 @@ update(const std::string& move, const InterimReport& child,
   bool forced_win = false, solved_all = !probe.onGoing();
   typedef successor_table_t::value_type pair_t;
   uint64_t best_node_count = 0;
-  BOOST_FOREACH(const pair_t& v, succ) {
+  for (const pair_t& v: succ) {
     if (! v.second->isSolved())
       solved_all = false;
     if (v.second->pv().empty()
@@ -498,7 +496,7 @@ update(const std::string& move, const InterimReport& child,
 		  + " " + to_s(draw_value));
 
   // root
-  if (probe.start.value() > split_time.value())
+  if (probe.start > split_time)
     return false;
   const int report_threshold = usi_pawn_value/2;
   if (old_bestmove != bestMove() || abs(changed) > report_threshold || isSolved()) {
@@ -528,18 +526,18 @@ prepareSplit()
 		  + " " + to_s(sub.node_count));
   sub = main;
   main = InterimReport();
-  last_tree_change = split_time = osl::MilliSeconds::now();
+  last_tree_change = split_time = osl::clock::now();
   propagateTreeChangeTime();
 
   if (! probe.probed.empty()) {
     std::string msg = "";
     typedef successor_table_t::value_type pair_t;
-    BOOST_FOREACH(pair_t& v, probe.probed)
+    for (pair_t& v: probe.probed)
       msg += " "+v.first;
     Logging::info("|has past probe "+path()+msg);
   }
   std::string added = "";
-  BOOST_FOREACH(const std::string& move, probe.target) {
+  for (const std::string& move: probe.target) {
     if (hasMove(move)) {
       SearchNodePtr node = succ[move];
       if (node->leaf.working[0]) {
@@ -573,17 +571,17 @@ parseMove(const osl::HistoryState& state, std::string usi_move)
 {
   if (usi_move == "other")
     return osl::Move();
-  return osl::record::usi::strToMove(usi_move, state.state());
+  return osl::usi::strToMove(usi_move, state.state());
 }
 
 std::string gpsshogi::SearchNode::toCSA(const std::string& str) const
 {
   std::vector<std::string> moves;
   boost::algorithm::split(moves, str, boost::algorithm::is_any_of(" "));
-  BOOST_FOREACH(std::string& move, moves) {
+  for (std::string& move: moves) {
     const osl::Move osl_move = findMove(move);
     if (osl_move.isNormal())
-      move = osl::record::csa::show(osl_move);
+      move = osl::csa::show(osl_move);
   }
   return join(moves, "");
 }
@@ -604,7 +602,7 @@ toCSA(osl::HistoryState& state, std::string usi_moves_string,
   std::vector<osl::Move> moves;
   moves.reserve(string_moves.size());
   bool error = false;
-  BOOST_FOREACH(const std::string& usi, string_moves) {
+  for (const std::string& usi: string_moves) {
     try {
       osl::Move move = parseMove(state, usi);
       if (! move.isNormal() && ! move.isPass())
@@ -620,9 +618,9 @@ toCSA(osl::HistoryState& state, std::string usi_moves_string,
 		     +to_s(state.state()));
     }
   }
-  BOOST_FOREACH(osl::Move move, moves) 
+  for (osl::Move move: moves) 
     state.unmakeMove();
-  const std::string (*f)(osl::Move) = osl::record::csa::show;
+  const std::string (*f)(osl::Move) = osl::csa::show;
   std::transform(moves.begin(), moves.end(), string_moves.begin(), f);
   return join(string_moves, "")+(error ? "csaerror" : "");
 }
@@ -633,7 +631,7 @@ sortByProbe(std::vector<int> *evals) const
   successor_table_t new_probed;
   std::string excluded = "";
   typedef successor_table_t::value_type pair_t;
-  BOOST_FOREACH(const pair_t& v, probe.probed) {
+  for (const pair_t& v: probe.probed) {
     if (! hasMove(v.first)) {
       new_probed[v.first] = v.second;
     }
@@ -647,7 +645,7 @@ sortByProbe(std::vector<int> *evals) const
   }
   std::vector<std::string> result
     = sortByTable(new_probed, evals);
-  BOOST_FOREACH(std::string move, moves.normal) {
+  for (std::string move: moves.normal) {
     if (! hasMove(move)
 	&& std::count(result.begin(), result.end(), move) == 0) {
       result.push_back(move);
@@ -667,7 +665,7 @@ sortByTable(const successor_table_t& table, std::vector<int> *evals) const
   sorted.reserve(table.size());
   typedef successor_table_t::value_type pair_t;
   const int sign = this->sign();
-  BOOST_FOREACH(const pair_t& v, table) {
+  for (const pair_t& v: table) {
     const int neg_preference = -v.second->value()*sign;
     if (v.first == "other" && v.second->pv().empty()) {
       Logging::info("|"+path()+" skipped other of empty pv");
@@ -704,7 +702,7 @@ sortByTable(const successor_table_t& table, std::vector<int> *evals) const
 
 void gpsshogi::SearchNode::
 showStatus(std::ostream& os, osl::HistoryState& state,
-	   osl::MilliSeconds now, int indent)
+	   osl::time_point now, int indent)
 {
   assert(state.state().turn() == turn());
   const std::string spacer(indent*2, ' ');
@@ -713,7 +711,7 @@ showStatus(std::ostream& os, osl::HistoryState& state,
   if (parent_move.find("other") == 0)
     os << "others ";
   else if (parent_move != "")
-    os << osl::record::csa::show(state.history().back());
+    os << osl::csa::show(state.history().back());
   else
     os << "root";
   os << ' ' << turn() << ' '
@@ -740,14 +738,14 @@ showStatus(std::ostream& os, osl::HistoryState& state,
   else if (&data == &solved)
     os << " solved";
   // seconds searched on this node
-  if (! (split_time == osl::MilliSeconds()))
+  if (! (split_time == osl::time_point()))
     os << " "
-       << boost::format("%.1f") % (now - split_time).toSeconds()
+       << boost::format("%.1f") % osl::toSeconds(now - split_time)
        << "s";
   // stability of subtree
-  if (! (last_tree_change == osl::MilliSeconds()))
+  if (! (last_tree_change == osl::time_point()))
     os << " ("
-       << boost::format("%.1f") % (now - last_tree_change).toSeconds()
+       << boost::format("%.1f") % osl::toSeconds(now - last_tree_change)
        << "s)";
   os << "\n";
   if (&data == &main && leaf.working[0] && leaf.working[0]->id() != data.owner)
@@ -758,7 +756,7 @@ showStatus(std::ostream& os, osl::HistoryState& state,
     return;
   // show sub-pv if any
   if (isLeaf()) {
-    BOOST_FOREACH(const pv_table::value_type& v, data.alternatives) {
+    for (const pv_table::value_type& v: data.alternatives) {
       if (v.second.depth + 1 < data.depth_head)
 	continue;
       os << spacer << "    alt " << turn() << ' '
@@ -775,7 +773,7 @@ showStatus(std::ostream& os, osl::HistoryState& state,
   std::vector<key_ptr_t> sorted;
   sorted.reserve(succ.size());
   typedef successor_table_t::value_type pair_t;
-  BOOST_FOREACH(const pair_t& v, succ) {
+  for (const pair_t& v: succ) {
     if (v.second->pv().empty())
       continue;
     const int neg_preference = -v.second->value()*sign();
@@ -783,7 +781,7 @@ showStatus(std::ostream& os, osl::HistoryState& state,
     sorted.push_back(std::make_pair(key, v.second));
   }
   std::sort(sorted.begin(), sorted.end());  
-  BOOST_FOREACH(const key_ptr_t& c, sorted) {
+  for (const key_ptr_t& c: sorted) {
     try {
       std::string usi = c.second->parent_move;
       const osl::Move move = (usi == "other")
@@ -810,7 +808,7 @@ stopSubTree(slave_set_t& stopped, slave_set_t& restart_cancelled,
 	    slave_set_t& waited)
 {
   has_workers = false;
-  BOOST_FOREACH(UsiSlavePtr& slave, leaf.working) {
+  for (UsiSlavePtr& slave: leaf.working) {
     if (slave) {
       if (slave->stop(id()))	   // node id
 	stopped.insert(slave->id()); // slave id
@@ -827,7 +825,7 @@ stopSubTree(slave_set_t& stopped, slave_set_t& restart_cancelled,
   }
   // recursively stop descendants
   typedef successor_table_t::value_type value_type;
-  BOOST_FOREACH(value_type& c, succ)
+  for (value_type& c: succ)
     if (c.second)
       c.second->stopSubTree(stopped, restart_cancelled, waited);
 }
@@ -838,14 +836,14 @@ stopProbe(slave_set_t& waited)
   const std::string path=this->path();
   std::vector<std::string> ps, pp;
   if (! probe.split_waiting.empty()) {
-    BOOST_FOREACH(UsiSlavePtr slave, probe.split_waiting) {
+    for (UsiSlavePtr slave: probe.split_waiting) {
       waited.insert(slave->id());
       ps.push_back(to_s(slave->id()));
     }
     probe.split_waiting.clear();
   }
   if (! probe.probing.empty()) {
-    BOOST_FOREACH(int pid, probe.probing)
+    for (int pid: probe.probing)
       pp.push_back(to_s(pid));
     probe.probing.clear();
   }
@@ -864,7 +862,7 @@ generateMoves()
   osl::UsiState usi_state;
   usi_state.parseUsi(position);
   osl::game_playing::GameState gstate(usi_state.initial_state);
-  BOOST_FOREACH(osl::Move m, usi_state.moves) 
+  for (osl::Move m: usi_state.moves) 
     gstate.pushMove(m);
 
   osl::MoveVector normal, win, draw, loss;
@@ -884,10 +882,10 @@ generateMoves()
 					history, threatmate);
   feature_set.generateLogProb(info, rmoves);
   take_back_moves = 0;
-  BOOST_FOREACH(osl::MoveLogProb m, rmoves) {
+  for (osl::MoveLogProb m: rmoves) {
     if (prev.isNormal() && m.move().to() == prev.to())
       ++take_back_moves;
-    const std::string usi = osl::record::usi::show(m.move());
+    const std::string usi = osl::usi::show(m.move());
     moves.all.push_back(m.move());
     moves.usi.push_back(usi);
     if (std::count(win.begin(), win.end(), m.move()))
@@ -901,7 +899,7 @@ generateMoves()
       assert(state.inCheck() || ! m.move().ignoreUnpromote());
       if (!state.inCheck() && m.move().hasIgnoredUnpromote()) {
 	osl::Move nopromote = m.move().unpromote();
-	std::string nopromote_usi = osl::record::usi::show(nopromote);
+	std::string nopromote_usi = osl::usi::show(nopromote);
 	moves.all.push_back(nopromote);
 	moves.usi.push_back(nopromote_usi);
 	moves.nopromote.insert(nopromote_usi);
@@ -946,7 +944,7 @@ generateMoves()
     osl::Move checkmate_move; 
     if (solver.hasCheckmateMoveOfTurn(2, checkmate_move)
 	.isCheckmateSuccess())
-      moves.win.insert(osl::record::usi::show(checkmate_move));
+      moves.win.insert(osl::usi::show(checkmate_move));
   }
   if (! moves.win.empty() && solved.node_count == 0) {
     Logging::info("|"+path()+" winning node");
@@ -985,8 +983,8 @@ path(const std::string& sofar) const
 }
 
 void gpsshogi::SearchNode::
-searchInLeaf(boost::function<void(InterimReport)> progress,
-	     boost::function<void(InterimReport)> finish,
+searchInLeaf(std::function<void(InterimReport)> progress,
+	     std::function<void(InterimReport)> finish,
 	     int msec, UsiSlavePtr slave,
 	     slave_set_t& stopped_slave, int multi_pv)
 {
@@ -1017,13 +1015,13 @@ searchInLeaf(boost::function<void(InterimReport)> progress,
   slave->go(id(), position, ignoreMoves(), msec, progress, finish,
 	    sign()*draw_value, multi_pv);
   if (msec > probe_msec) {
-    last_tree_change = osl::MilliSeconds::now();
+    last_tree_change = osl::clock::now();
     propagateTreeChangeTime();
   }
 }
 
 void gpsshogi::SearchNode::
-runMate(boost::function<void(std::string)> finish,
+runMate(std::function<void(std::string)> finish,
 	int msec, UsiSlavePtr solver)
 {
   if (leaf.working[1]) {
@@ -1042,11 +1040,11 @@ std::string gpsshogi::SearchNode::ignoreMoves() const
     ? (parent ? &parent->moves : 0)
     : &this->moves;
   if (parent) {
-    BOOST_FOREACH(std::string move, moves->draw)
+    for (std::string move: moves->draw)
       ret += " " + move;
-    BOOST_FOREACH(std::string move, moves->loss)
+    for (std::string move: moves->loss)
       ret += " " + move;
-    BOOST_FOREACH(std::string move, moves->nopromote)
+    for (std::string move: moves->nopromote)
       ret += " " + move;
   }
   return ret == "" ? ret : ("ignore_moves" + ret);
