@@ -7,8 +7,8 @@
 #include "slaveManager.h"
 #include "interimReport.h"
 #include "logging.h"
-#include "osl/record/usi.h"
-#include "osl/record/csa.h"
+#include "osl/usi.h"
+#include "osl/csa.h"
 #include "osl/game_playing/gameState.h"
 #include "osl/game_playing/searchPlayer.h"
 #include "osl/sennichite.h"
@@ -16,11 +16,9 @@
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/join.hpp>
 #include <boost/algorithm/string/trim.hpp>
-#include <boost/lambda/lambda.hpp>
 #include <boost/range/iterator_range.hpp>
-#include <boost/bind/bind.hpp>
-#include <boost/foreach.hpp>
 #include <iostream>
+#include <iomanip>
 #include <fstream>
 #include <sstream>
 #include <limits>
@@ -28,7 +26,7 @@ using boost::algorithm::join;
 
 const int msec_max = 24*60*60*1000; // 1 day
 const int SplitWidthDefault = 2;
-static osl::MilliSeconds last_report;
+static osl::time_point last_report;
 int gpsshogi::SearchTree::human_rounding = 0; // only effective for human v.s. computer
 int gpsshogi::SearchTree::draw_value_cp = 0;
 const int rounding_msec = 300; // 1000 - rtt - margin
@@ -58,7 +56,7 @@ gpsshogi::SearchTree::
   task_queue.clear();
   if (! stopped_slave.empty()) {
     std::string msg = "*waiting some slave at gameFinished";
-    BOOST_FOREACH(int pid, stopped_slave)
+    for (int pid: stopped_slave)
       msg += " " + to_s(pid);
     Logging::error(msg);
   }
@@ -69,17 +67,17 @@ stopSubTree(SearchNode& node)
 {
   slave_set_t restart_cancelled, waited;
   node.stopSubTree(stopped_slave, restart_cancelled, waited);
-  BOOST_FOREACH(int slave, waited)
+  for (int slave: waited)
     scheduled_slave.erase(slave);
 
   std::string msg = "";
-  BOOST_FOREACH(int slave, waited)
+  for (int slave: waited)
     msg += " "+to_s(slave);
   if (msg != "")
     Logging::info("*collected waiting"+msg);
 
   msg = "";
-  BOOST_FOREACH(int slave, restart_cancelled) {
+  for (int slave: restart_cancelled) {
     msg += " "+to_s(slave);
     restart_other_waiting.erase(slave);
   }
@@ -101,7 +99,7 @@ gameFinished()
   task_queue.clear();
   if (! stopped_slave.empty()) {
     std::string msg = "*waiting some slave at gameFinished";
-    BOOST_FOREACH(int pid, stopped_slave)
+    for (int pid: stopped_slave)
       msg += " " + to_s(pid);
     Logging::warn(msg);
   }
@@ -110,10 +108,10 @@ gameFinished()
 void gpsshogi::SearchTree::
 showRootInfo()
 {
-  if (searching().info.elapsedSeconds() > probe_msec*5.0/1000) {
+  if (osl::elapsedSeconds(searching().info) > probe_msec*5.0/1000) {
     std::string info = root->report().composeInfo(root->key.isPlayerOfTurn(osl::WHITE));
     if (info != searching().info_string) {
-      searching().info = osl::MilliSeconds::now();
+      searching().info = osl::clock::now();
       progress(info);
       searching().info_string = info;
     }
@@ -135,9 +133,9 @@ nodeProgress(UsiSlavePtr slave, std::string node_id, InterimReport report)
   node->main.pv.score += node->heuristic_cost; // adjust only at leaf
   
   if (node->update(progress)) {
-    searching().info = osl::MilliSeconds::now();
-    if (searching().started.elapsedSeconds()*5000 > msec()
-	&& last_report.elapsedSeconds() > probe_msec*5.0/1000) {
+    searching().info = osl::clock::now();
+    if (osl::elapsedSeconds(searching().started)*5000 > msec()
+	&& osl::elapsedSeconds(last_report) > probe_msec*5.0/1000) {
       last_report = searching().info;
       logStatus();
     }
@@ -192,9 +190,9 @@ probeProgress(UsiSlavePtr slave, std::string node_id, InterimReport report)
   }
   node->main.set(node->turn(), report);
   if (node->update(progress)
-      && last_report.elapsedSeconds() > probe_msec*5.0/1000) {
+      && osl::elapsedSeconds(last_report) > probe_msec*5.0/1000) {
     logStatus();
-    last_report = osl::MilliSeconds::now();
+    last_report = osl::clock::now();
   }
 }
 
@@ -252,7 +250,7 @@ stopTree()
   for (size_t i=0; i<task_queue.size(); ++i) {
     if (task_queue[i] == Think) {
       task_queue.erase(task_queue.begin()+i);
-      usi_queue.post(boost::bind(finish, "bestmove resign"));
+      usi_queue.post(std::bind(finish, "bestmove resign"));
       internalFinish(searching().position_id);
       return;
     }
@@ -282,7 +280,7 @@ SearchTree::internalFinish(int id)
     searching().forced_move_or_similar = true;
   searching().value = root->value();
   finish = 0;
-  progress = boost::bind(&SearchTree::ponderProgress, this, _1);
+  progress = [=](std::string msg){ this->ponderProgress(msg); };
 }
 
 void gpsshogi::
@@ -299,7 +297,7 @@ SearchTree::ponderProgress(std::string msg)
   std::string pv = SearchNode::toCSA(copy, info.joinPV());
   static int last_value = 0;
   if (info.bestValue() != last_value
-      && last_report.elapsedSeconds() > probe_msec*5.0/1000) {
+      && osl::elapsedSeconds(last_report) > probe_msec*5.0/1000) {
     std::ostringstream ss;
     ss << "ponder " << std::setfill(' ') << std::setw(5)
        << info.bestValue()*100/usi_pawn_value
@@ -307,7 +305,7 @@ SearchTree::ponderProgress(std::string msg)
        << ' ' << info.depth_head << ")";
     Logging::notice(ss.str());
     last_value = info.bestValue();
-    last_report = osl::MilliSeconds::now();
+    last_report = osl::clock::now();
   }
 }
 
@@ -346,7 +344,7 @@ bool sufficientHandPieces(const osl::NumEffectState& state)
   if (pawns > 2)
     return true;
   int sum = 0;
-  BOOST_FOREACH(osl::Ptype ptype, osl::PieceStand::order) {
+  for (osl::Ptype ptype: osl::PieceStand::order) {
     sum += state.countPiecesOnStand(osl::BLACK, ptype)
       + state.countPiecesOnStand(osl::WHITE, ptype);
   }
@@ -427,11 +425,11 @@ assignTime(const TimeCondition& config,
   return std::pair<int,int>(standard, hard);
 }
 
-boost::function<void(void)> gpsshogi::SearchTree::
+std::function<void(void)> gpsshogi::SearchTree::
 go(int id, const std::string& position, 
    int active, const std::vector<UsiSlavePtr>& slaves,
-   boost::function<void(std::string)> p,
-   boost::function<void(std::string)> f,
+   std::function<void(std::string)> p,
+   std::function<void(std::string)> f,
    const TimeCondition& config,
    const std::vector<UsiSlavePtr>& mate_solvers)
 {
@@ -461,7 +459,7 @@ go(int id, const std::string& position,
   }
   else {
     osl::game_playing::GameState game_state(state.initial_state);
-    BOOST_FOREACH(osl::Move move, state.moves)
+    for (osl::Move move: state.moves)
       game_state.pushMove(move);
     std::pair<int,int> time = assignTime(config, game_state);
     new_status.msec_standard = std::max(1,time.first);
@@ -478,7 +476,7 @@ go(int id, const std::string& position,
   if (!root->needProbe()) {
     statistics.prepared++;
   }
-  BOOST_FOREACH(UsiSlavePtr slave, slaves) {
+  for (UsiSlavePtr slave: slaves) {
     if (all_slave.insert(slave->id()).second) {
       if (scheduled_slave.count(slave->id()) == 0 
 	  && restart_other_waiting.count(slave->id()) == 0) {
@@ -500,7 +498,7 @@ go(int id, const std::string& position,
   int draw_value = draw_value_cp*usi_pawn_value/100;
   if (config.total - config.used <= 10 && config.byoyomi_msec == 0)
     draw_value = std::max(draw_value, usi_pawn_value*10);
-  SearchNode::setDrawValue(draw_value*playerToMul(root->turn()));
+  SearchNode::setDrawValue(draw_value*sign(root->turn()));
   searching().early_win_needed
     = (config.byoyomi_msec > 0) ? false
     : osl::inaniwa::InaniwaDetection::IsInaniwa
@@ -521,7 +519,7 @@ go(int id, const std::string& position,
        << " nopromote " << root->moves.nopromote.size() << "\n";
     ss << state.currentState();
     if (! state.moves.empty())
-      ss << "last move " << osl::record::csa::show(state.moves.back());
+      ss << "last move " << osl::csa::show(state.moves.back());
     ss << " used " << config.used << ' ' << config.opponent_used
        << " time " << msec()/1000 << ' ' << msecMax()/1000
        << " other/ext/pre/all " << statistics.selected_other
@@ -529,7 +527,7 @@ go(int id, const std::string& position,
        << "/" << statistics.values.size()
        << " width " << splitWidth(/*leaf*/128)
        << " # " + to_s(all_slave.size())
-       << " draw " << draw_value*playerToMul(root->turn())
+       << " draw " << draw_value*sign(root->turn())
        << " status " << to_s(status)
        << " ina " << to_s(searching().early_win_needed)
        << uptimeString();
@@ -556,16 +554,16 @@ go(int id, const std::string& position,
     else
       status = Thinking;
     std::string msg = "*pondering => thinking ";
-    BOOST_FOREACH(Task task, task_queue)
+    for (Task task: task_queue)
       msg += " "+to_s(task);
     Logging::info(msg);
-    return boost::bind(&SearchTree::stopTree, this);
+    return std::bind(&SearchTree::stopTree, this);
   }
 
   // construct root
   if (root->isSolved() && root->isWinValue(root->value())) {
     Logging::notice("immediate response "+root->bestMove());
-    usi_queue.post(boost::bind(finish, "bestmove "+root->bestMove()));
+    usi_queue.post(std::bind(finish, "bestmove "+root->bestMove()));
     searching().forced_move_or_similar = true;
     internalFinish(id);
     return 0;      
@@ -573,7 +571,7 @@ go(int id, const std::string& position,
   if (root->moves.normal.empty()) {
     if (! root->moves.draw.empty()) {
       Logging::notice("no normal moves other than draw");
-      usi_queue.post(boost::bind(finish, "bestmove "
+      usi_queue.post(std::bind(finish, "bestmove "
 				 +*root->moves.draw.begin()));
       searching().forced_move_or_similar = true;
       internalFinish(id);
@@ -581,7 +579,7 @@ go(int id, const std::string& position,
     }
     if (root->moves.all.empty() && root->moves.nopromote.empty()) {
       Logging::notice("no not-losing moves");
-      usi_queue.post(boost::bind(finish, "bestmove resign"));
+      usi_queue.post(std::bind(finish, "bestmove resign"));
       searching().forced_move_or_similar = true;
       internalFinish(id);
       return 0;
@@ -592,10 +590,10 @@ go(int id, const std::string& position,
   }
   if (root->moves.all.size() == 1 && root->moves.draw.empty()) {
     Logging::notice("forced move");
-    usi_queue.post(boost::bind
+    usi_queue.post(std::bind
 		   (progress, "info string forced move at the root: "
 		    + root->moves.normal[0]));
-    usi_queue.post(boost::bind
+    usi_queue.post(std::bind
 		   (finish, "bestmove "+root->moves.normal[0]));
     searching().forced_move_or_similar = true;
     internalFinish(id);
@@ -610,10 +608,10 @@ go(int id, const std::string& position,
     task_queue.push_back(WaitSlave);
     task_queue.push_back(Think);
     Logging::notice("*defer startThinking() in 150ms");
-    return boost::bind(&SearchTree::stopTree, this);
+    return std::bind(&SearchTree::stopTree, this);
   }
   startThinking();
-  return boost::bind(&SearchTree::stopTree, this);
+  return std::bind(&SearchTree::stopTree, this);
 }
 
 struct NpsCompare
@@ -630,7 +628,7 @@ selectIdle(std::set<UsiSlavePtr>& idle)
 {
   std::vector<UsiSlavePtr> slaves;
   std::string reserved="", stopped="";
-  BOOST_FOREACH(UsiSlavePtr p, idle) {
+  for (UsiSlavePtr p: idle) {
     if (!p) {
       Logging::error("*slave null");
       continue;
@@ -702,9 +700,9 @@ probeAndSplit(SearchNode& node, std::vector<UsiSlavePtr> slaves)
   node.prepareProbe(stopped_slave); 
   {
     std::string msg
-      = "*probe " + path+" "+ to_s((node.probe.start - started()).value())
+      = "*probe " + path+" "+ to_s(osl::msec(node.probe.start - started()))
       + "ms #";
-    BOOST_FOREACH(UsiSlavePtr slave, slaves) {
+    for (UsiSlavePtr slave: slaves) {
       current_idle.erase(slave);
       msg += " "+to_s(slave->id());
     }
@@ -774,7 +772,7 @@ probeAndSplit(SearchNode& node, std::vector<UsiSlavePtr> slaves)
 	int width = std::min(3, splitWidth(node.depth8()));
 	for (size_t i=1; i<slaves.size(); i+=width) // reserve [0]
 	  half.push_back(slaves[i]); 
-	BOOST_FOREACH(UsiSlavePtr slave, half)
+	for (UsiSlavePtr slave: half)
 	  std::remove(slaves.begin(), slaves.end(), slave);
 	slaves.resize(slaves.size()-half.size());
       }
@@ -803,7 +801,7 @@ probeAndSplit(SearchNode& node, std::vector<UsiSlavePtr> slaves)
     // fall through
   }
   // enough time ?
-  int elapsed=(status==Thinking) ? (node.probe.start-started()).value() : 0;
+  int elapsed=(status==Thinking) ? osl::msec(node.probe.start-started()) : 0;
   if ((msec() - elapsed) < probe_msec*4) {
     Logging::info("*split by probability " + node.moves.normal[0]
 		  + " at " + path);
@@ -878,11 +876,11 @@ void gpsshogi::SearchTree::splitTree(SearchNode& node)
   std::vector<std::string> moves = node.sortByProbe(&evals);
   {
     std::string msg
-      = "*split " + path + " " + to_s((node.split_time - started()).value())
-      + "ms probe " + to_s((node.probe.start - started()).value())
+      = "*split " + path + " " + to_s(osl::msec(node.split_time - started()))
+      + "ms probe " + to_s(osl::msec(node.probe.start - started()))
       + "ms #";
     std::string slave_error="";
-    BOOST_FOREACH(UsiSlavePtr slave, node.probe.split_waiting) {
+    for (UsiSlavePtr slave: node.probe.split_waiting) {
       if (slave->usiStatus() != Idle)
 	slave_error += " "+slave->idMark()+to_s(slave->usiStatus());
       else {
@@ -905,10 +903,10 @@ void gpsshogi::SearchTree::splitTree(SearchNode& node)
     Logging::info(msg);
     if (! node.parent) {
       logStatus();
-      last_report = osl::MilliSeconds::now();
+      last_report = osl::clock::now();
     }
   }
-  assert(node.probe.start.value()); // called after probe
+  assert(node.probe.start != osl::time_point()); // called after probe
   node.probe.split_waiting.clear();
   if (node.isSolved()) {
     Logging::info("*split cancelled at solved node "+node.path());
@@ -972,9 +970,9 @@ setUpHeuristic(SearchNode& node)
     osl::NumEffectState state = usi_state.currentState();
     osl::Player turn = searching().config.my_turn;
     int count = 0;
-    BOOST_FOREACH(osl::Ptype ptype, osl::PieceStand::order)
+    for (osl::Ptype ptype: osl::PieceStand::order)
       count += state.countPiecesOnStand(turn, ptype);
-    node.heuristic_cost = count*usi_pawn_value*playerToMul(turn);
+    node.heuristic_cost = count*usi_pawn_value*sign(turn);
     if (node.heuristic_cost)
       Logging::info("*short time heuristic "+node.path()
 		    +" "+to_s(node.heuristic_cost));
@@ -990,11 +988,10 @@ goNode(const UsiSlavePtr& slave, SearchNode& node, int millisec)
       && node.parent_move == "other"
       && node.parent == root.get())
     multi_pv = 2;
+  auto path = node.pathId();
   node.searchInLeaf
-    (boost::bind(&SearchTree::nodeProgress, this, slave,
-		 node.pathId(), _1),
-     boost::bind(&SearchTree::nodeFinish, this, slave,
-		 node.pathId(), _1),
+    ([=](InterimReport r) { this->nodeProgress(slave, path, r); },
+     [=](InterimReport r) { this->nodeFinish(slave, path, r); },
      millisec, slave, stopped_slave, multi_pv);
 }
 
@@ -1006,12 +1003,11 @@ goProbe(const UsiSlavePtr& slave, SearchNode& child)
     stopped_slave.erase(slave->id());
   }
     
+  auto path = child.pathId();
   child.parent->probe.probing.insert(slave->id());
   child.searchInLeaf
-    (boost::bind(&SearchTree::probeProgress, this, slave,
-		 child.pathId(), _1),
-     boost::bind(&SearchTree::probeFinish, this, slave,
-		 child.pathId(), _1),
+    ([=](InterimReport r) { this->probeProgress(slave, path, r); },
+     [=](InterimReport r) { this->probeFinish(slave, path, r); },
      probe_msec, slave, stopped_slave, 1);
 }
 
@@ -1022,11 +1018,11 @@ showStatus(std::ostream& os)
     return;
   os << Logging::datetime()
      << " status=" << to_s(status) << " elapsed "
-     << (osl::MilliSeconds::now()-started()).value()
+     << osl::msec(osl::clock::now()-started())
      << " msec-max " << msecMax() << "\n";
   osl::HistoryState copy(state.currentState());
   assert(copy.state().turn() == root->turn());
-  root->showStatus(os, copy, osl::MilliSeconds::now());
+  root->showStatus(os, copy, osl::clock::now());
 }
 
 void gpsshogi::SearchTree::
@@ -1075,36 +1071,36 @@ periodic()
       || std::count(task_queue.begin(), task_queue.end(), Think)
       || std::count(task_queue.begin(), task_queue.end(), ExpandOther))
     return;
-  osl::misc::MilliSeconds now = osl::misc::MilliSeconds::now();
-  int elapsed=(status==Thinking) ? (now-searching().started).value() : 0;
-  static osl::misc::MilliSeconds last_assign, last_health_test;
+  osl::time_point now = osl::clock::now();
+  int elapsed=(status==Thinking) ? osl::msec(now-searching().started) : 0;
+  static osl::time_point last_assign, last_health_test;
   if ((status == Thinking || this->ponder)
-      && (now-last_assign).value() > probe_msec*2
+      && osl::msec(now-last_assign) > probe_msec*2
       && (msec() > 4000 || !root->hasWorker())
       && elapsed*2 < msec()
       && ! root->probe.onGoing()
       && current_idle.size()*4 >= all_slave.size()) {
     Logging::info("*reassign idles #"+to_s(current_idle.size()));
     growTree(status == Thinking || status == PanicTimeOther);
-    last_assign = now = osl::misc::MilliSeconds::now();
+    last_assign = now = osl::clock::now();
   }
   if (! mate_idle.empty() && task_queue.empty() && status != TreeIdle)
     assignMate();
   if (status != TreeIdle
-      && root && (now-last_health_test).value() > probe_msec) {
+      && root && osl::msec(now-last_health_test) > probe_msec) {
     Logging::info("*run health test");
-    last_health_test = now = osl::misc::MilliSeconds::now();
+    last_health_test = now = osl::misc::clock::now();
     healthTest(*root, now);
   }
 }
 
 void gpsshogi::SearchTree::healthTest(SearchNode& node,
-				      const osl::misc::MilliSeconds &now) 
+				      const osl::time_point &now) 
 {
   if (node.moves.empty() || node.isSolved())
     return;
   if (node.probe.onGoing()) {
-    int elapsed_msec = (now-node.probe.start).value();
+    int elapsed_msec = osl::msec(now-node.probe.start);
     if (elapsed_msec >= probe_msec*2) {
       std::string msg = "*delay in split "+to_s(elapsed_msec)
 	+" msec "+node.path()
@@ -1118,7 +1114,7 @@ void gpsshogi::SearchTree::healthTest(SearchNode& node,
   }
 
   typedef successor_table_t::value_type value_type;
-  BOOST_FOREACH(value_type& child, node.succ) {
+  for (value_type& child: node.succ) {
     if (child.first != "other" && child.second)
       healthTest(*child.second, now);
   }
@@ -1143,13 +1139,13 @@ bool gpsshogi::SearchTree::assignMate(SearchNode& node, UsiSlavePtr solver)
   if (node.isSolved())
     return false;
   if (! node.mate_tested && ! node.leaf.working[1]) {
-    node.runMate(boost::bind(&SearchTree::mateResult, this, solver,
-			     node.pathId(), _1),
+    auto path = node.pathId();
+    node.runMate([=](std::string msg) { this->mateResult(solver, path, msg);},
 		 std::min(msec(),probe_msec*10), solver);
     return true;
   }
   typedef successor_table_t::value_type value_type;
-  BOOST_FOREACH(value_type& child, node.succ) {
+  for (value_type& child: node.succ) {
     if (child.first != "other" && child.second
 	&& assignMate(*child.second, solver))
       return true;
@@ -1246,8 +1242,8 @@ finishIfStable()
 {
   assert(root && !searching().finished);
   // finish if stable
-  osl::MilliSeconds now = osl::MilliSeconds::now();
-  int elapsed = (now-started()).value();
+  osl::time_point now = osl::clock::now();
+  int elapsed = osl::msec(now-started());
   bool finish_search = false;
   if (searching().sufficient_ponder != ""
       && searching().sufficient_ponder == root->bestMove()) {
@@ -1255,7 +1251,7 @@ finishIfStable()
   }
   if (! finish_search
       && status == Thinking
-      && (now-root->lastTreeChangeForBestMove()).value() > msec()*3/4
+      && osl::msec(now-root->lastTreeChangeForBestMove()) > msec()*3/4
       && root->betterThan(root->value()+usi_pawn_value/2, prev().value)
       && root->nodeCountBestMove() > recentNodeCountBest()) {
     if (! root->bestMoveIsOther()) {
@@ -1278,7 +1274,7 @@ finishIfStable()
       && msec() < msecMax()
       && status == Thinking
       && root->isPrimaryTakeBack(root->bestMove())
-      && (now-root->lastTreeChangeForBestMove()).value() > msec()/2
+      && osl::msec(now-root->lastTreeChangeForBestMove()) > msec()/2
       && root->betterThan(root->value()+usi_pawn_value/2, prev().value)
       && root->nodeCountBestMove() > recentNodeCountBest()/2) {
     Logging::info("*early finish for takeback "+root->toCSA(root->bestMove())
@@ -1333,7 +1329,7 @@ finishIfStable()
 void gpsshogi::SearchTree::tryExpandOther(double elapsed)
 {
   logStatus();
-  last_report = osl::MilliSeconds::now();
+  last_report = osl::clock::now();
 
   const std::vector<std::string> best_moves = root->sortBySearchValue();
   if (! root->findMove(root->bestMove()).isNormal()
@@ -1349,7 +1345,7 @@ void gpsshogi::SearchTree::tryExpandOther(double elapsed)
   const std::string best_move2 = (best_moves.size() < 2)
     ? "" : best_moves[1]; // i.e., best move among normal children
   typedef successor_table_t::value_type value_type;
-  BOOST_FOREACH(value_type& child, root->succ)
+  for (value_type& child: root->succ)
     if (child.first != best_move2 && child.first != "other")
       stopSubTree(*child.second);
   const int nslaves = stopped_slave.size()+current_idle.size();
@@ -1435,7 +1431,7 @@ expandOther()
   assert(! root->expanded_other_pv.back().empty());
   const std::vector<std::string>& pv = root->expanded_other_pv.back();
   status = PanicTimeOther;
-  searching().restarted.push_back(osl::MilliSeconds::now());
+  searching().restarted.push_back(osl::clock::now());
   std::vector<UsiSlavePtr> slaves = idleSlaves();
   Logging::notice("*panic time extension for "
 		  +root->toCSA(root->expanded_other_pv.back()[0])
@@ -1465,7 +1461,7 @@ expandOther()
 void gpsshogi::SearchTree::
 growTree(bool in_thinking)
 {
-  double started = searching().started.elapsedSeconds();
+  double started = osl::elapsedSeconds(searching().started);
   Logging::info("*grow tree status="+to_s(status)
 		+" idle "+to_s(current_idle.size())
 		+" mateidle "+to_s(mate_idle.size())
@@ -1498,9 +1494,9 @@ growTree(bool in_thinking)
   }
 
   logStatus();
-  const osl::MilliSeconds now = osl::MilliSeconds::now();
+  const osl::time_point now = osl::clock::now();
   last_report = now;
-  double finished = searching().started.elapsedSeconds();
+  double finished = osl::elapsedSeconds(searching().started);
   Logging::info("*grow tree done "
 		+to_s(round(1000*(finished - started)))+"ms."
 		+" ( "+to_s(round(1000*started))
@@ -1520,7 +1516,7 @@ growTree(SearchNode& node, std::vector<UsiSlavePtr> slaves)
     node.generateMoves();
   {
     std::string msg = "*grow " + node.path() + " #";
-    BOOST_FOREACH(UsiSlavePtr slave, slaves)
+    for (UsiSlavePtr slave: slaves)
       msg += " "+to_s(slave->id());
     if (node.isSolved()) 
       msg += " already solved";
@@ -1545,7 +1541,7 @@ growTree(SearchNode& node, std::vector<UsiSlavePtr> slaves)
 		  +" #slaves " +to_s(slaves.size()));
     if (root->hasLeafWorker()) {
       if (root->probe.onGoing()) {
-	BOOST_FOREACH(UsiSlavePtr slave, slaves)
+	for (UsiSlavePtr slave: slaves)
 	  root->probe.split_waiting.push_back(slave);
 	return;
       }
@@ -1597,7 +1593,7 @@ growTree(SearchNode& node, std::vector<UsiSlavePtr> slaves)
 	  int width = std::min(3, splitWidth(node.depth8()));
 	  for (size_t i=0; i<slaves.size(); i+=width)
 	    half.push_back(slaves[i]); 
-	  BOOST_FOREACH(UsiSlavePtr slave, half)
+	  for (UsiSlavePtr slave: half)
 	    std::remove(slaves.begin(), slaves.end(), slave);
 	  slaves.resize(slaves.size()-half.size());
 	}
@@ -1607,7 +1603,7 @@ growTree(SearchNode& node, std::vector<UsiSlavePtr> slaves)
       }
       Logging::info(msg+" merged into split_waiting "+to_s(slaves.size())
 		    +" => "+to_s(node.probe.onGoingCount()));
-      BOOST_FOREACH(UsiSlavePtr slave, slaves) {
+      for (UsiSlavePtr slave: slaves) {
 	scheduled_slave.insert(slave->id());
 	node.probe.split_waiting.push_back(slave);
       }
@@ -1770,14 +1766,14 @@ moveRoot(const std::string& move,
   }
   if (ponder) {
     typedef successor_table_t::value_type value_type;
-    BOOST_FOREACH(value_type& child, root->succ)
+    for (value_type& child: root->succ)
       if (child.first != move)
 	stopSubTree(*child.second);
     task_queue.push_back(WaitSlave);
     task_queue.push_back(WaitSlave);
     task_queue.push_back(WaitSlave);
   }
-  BOOST_FOREACH(UsiSlavePtr slave, idles)
+  for (UsiSlavePtr slave: idles)
     current_idle.insert(slave);
 
   if (root->hasScheduledSlave()) {
@@ -1823,12 +1819,12 @@ moveRoot(const std::string& move,
   if (filename == "")
     logStatus();
 
-  const osl::MilliSeconds now = osl::MilliSeconds::now();
+  const osl::time_point now = osl::clock::now();
   bool time_management = searching().position_id >= 0
     && msec() < msecMax()
     && root->turn() == searching().config.my_turn;
   bool ponder_success = time_management
-    && (now-root->lastTreeChangeForBestMove()).value() > msec()*3/4
+    && osl::msec(now-root->lastTreeChangeForBestMove()) > msec()*3/4
     && root->betterThan(root->value()+usi_pawn_value/2, prev().value)
     && root->nodeCountBestMove() > recentNodeCountBest()
     && ! root->bestMoveIsOther();
@@ -1854,7 +1850,7 @@ moveRoot(const std::string& move,
     if (! state.moves.empty())
       ss << "last move "
 	 << to_s(state.moves.size()+1) << "th "
-	 << osl::record::csa::show(state.moves.back());
+	 << osl::csa::show(state.moves.back());
     ss << " other/extended/prepared/search " << statistics.selected_other
        << "/" << statistics.extended << "/" << statistics.prepared
        << "/" << statistics.values.size()
