@@ -2,7 +2,7 @@
  */
 #ifndef GPSSHOGI_TIMECONDITION_H
 #define GPSSHOGI_TIMECONDITION_H
-#include "osl/player.h"
+#include "osl/basic_type.h"
 namespace gpsshogi
 {
   struct TimeCondition
