@@ -5,8 +5,8 @@
 #include "usiStatus.h"
 
 #include <boost/asio/io_service.hpp>
-#include <boost/thread/mutex.hpp>
-#include <boost/thread/condition.hpp>
+#include <mutex>
+#include <condition_variable>
 namespace gpsshogi
 {
   class Coordinator;
@@ -30,8 +30,8 @@ namespace gpsshogi
       return current_status;
     }
 
-    mutable boost::mutex mutex;
-    boost::condition condition;
+    mutable std::mutex mutex;
+    std::condition_variable condition;
   };
 }
 
