@@ -8,7 +8,7 @@ my $number = $options{n} ? sprintf("%03d", $options{n}) : "000";
 
 my $extract = './util/extract-eval.pl';
 my $make_chart = './util/make-chart.pl';
-my $tweet = './tweet.pl';
+my $tweet = './tweet-oauth.pl';
 my $urlfile = 'url'.$number.'.txt';
 my $chartfile = "chart".$number.".txt";
 my $chartfile_en = "chart".$number."-en.txt";
