@@ -11,32 +11,32 @@
 #include "osl/search/fixedEval.h"
 #include "osl/search/searchState2.h"
 #include "osl/search/analyzer/recordSet_.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/game_playing/alphaBetaPlayer.h"
-#include "osl/move_generator/legalMoves.h"
-#include "osl/container/moveVector.h"
 #include "osl/effect_util/effectUtil.h"
 #include "osl/sennichite.h"
-#include "osl/record/csa.h"
+#include "osl/csa.h"
 #include "osl/record/ki2.h"
 
 #include "gpsshogi/gui/util.h"
 #include "gpsshogi/gui/board.h"
 
-#include <QtGui>
-#include <qlayout.h>
-#include <qlistview.h>
-#include <qspinbox.h>
-#include <qcombobox.h>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#else
+#  include <QtGui>
+#endif
+#include <QVBoxLayout>
+#include <QComboBox>
 #include <QProgressDialog>
-#include <qpushbutton.h>
-#include <qmessagebox.h>
-#include <qthread.h>
-#include <qapplication.h>
-#include <qtextcodec.h>
+#include <QPushButton>
+#include <QMessageBox>
+#include <QThread>
+#include <QApplication>
+#include <QString>
+#include <QTextCodec>
 #include <QTableView>
 
-#include <boost/scoped_ptr.hpp>
 #include <sstream>
 #include <unistd.h>
 #include <time.h>
@@ -45,6 +45,7 @@ using gpsshogi::gui::Util;
 
 const QString AnalysisViewer::PROGRESS_ALPHA_BETA = QString("Progress Alpha Beta2");
 const QString AnalysisViewer::TEST_ALPHA_BETA = QString("OpenMidEndingEval Alpha Beta2");
+const QString AnalysisViewer::USI_PROXY = QString("USI Engine (gpsfish)");
 
 
 static void generateMoves(const osl::SimpleHashRecord *record,
@@ -66,6 +67,7 @@ static void generateMoves(const osl::SimpleHashRecord *record,
   if (! record->inCheck())
     moves.push_back(osl::MoveLogProb(osl::Move::PASS(state.turn()), 200));
 }
+
 static bool hasChildAfterMove(const osl::SimpleState& state,
 			      const osl::search::SimpleHashTable& table,
 			      const osl::MoveStack& history,
@@ -80,8 +82,10 @@ static bool hasChildAfterMove(const osl::SimpleState& state,
   osl::MoveLogProbVector moves;
   generateMoves(child_record, child_state, new_history, moves);
   for (size_t i=0; i<moves.size(); ++i)
+  {
     if (table.find(child_key.newHashWithMove(moves[i].move())))
       return true;
+  }
   return false;
 }
 
@@ -93,8 +97,8 @@ public:
   QuiescenceDialog(const osl::hash::HashKey& key, 
 		   const osl::SimpleState& state,
 		   const osl::search::SimpleHashTable *table,
-		   QWidget *parent = 0, const char *name = 0)
-    : QDialog(parent, name) {
+		   QWidget *parent = 0)
+    : QDialog(parent) {
     QuiescenceTree *tree = new QuiescenceTree(this);
     tree->showRecord(key, state, table);
     QVBoxLayout *layout = new QVBoxLayout(this);
@@ -113,30 +117,30 @@ class SearchMoveTreeItem : public MoveTreeItem
 {
 public:
   SearchMoveTreeItem(SearchMoveTree *parent, osl::Move m, int v,
-		     bool bestMove, int winState,
-		     const osl::search::SimpleHashRecord *record)
+		     bool _bestMove, int _winState,
+		     const osl::search::SimpleHashRecord *_record)
     : MoveTreeItem(parent, m),
-      value(v), bestMove(bestMove), winState(winState), record(record),
+      value(v), bestMove(_bestMove), winState(_winState), record(_record),
       parent_item(0), tree(parent)
   {
     setupText(m, v, record);
+    setCellColor();
   }
-  SearchMoveTreeItem(SearchMoveTreeItem *parent, osl::Move m, int v, bool bestMove,
-		     int winState,
-		     const osl::search::SimpleHashRecord *record)
+  SearchMoveTreeItem(SearchMoveTreeItem *parent, osl::Move m, int v,
+                     bool _bestMove, int _winState,
+                     const osl::search::SimpleHashRecord *_record)
     : MoveTreeItem(parent, m),
-      value(v), bestMove(bestMove), winState(winState), record(record),
+      value(v), bestMove(_bestMove), winState(_winState), record(_record),
       parent_item(parent), tree(parent->tree)
   {
     setupText(m, v, record);
+    setCellColor();
   }
-  void setOpen(bool);
+  void setNextMove();
   bool isBestMove() const {
     return bestMove;
   }
-  void paintCell(QPainter *p, const QColorGroup &cg,
-		 int column, int width, int align);
-  int compare(Q3ListViewItem *i, int col, bool ascending) const;
+  bool operator<(const QTreeWidgetItem& other) const;
   MoveTreeItem *bestChild() const;
   const osl::search::SimpleHashRecord *getRecord() const {
     return record;
@@ -151,6 +155,7 @@ public:
     std::reverse(moves.begin(), moves.end());
   }
 private:
+  void setCellColor();
   void setupText(osl::Move m, int v,
 		 const osl::search::SimpleHashRecord *record) {
     setText(0, Util::moveToString(m));
@@ -178,17 +183,10 @@ private:
       setText(5, record ? QString("%1").arg(record->lowerLimit()) : "*");
       setText(6, record ? QString("%1").arg(record->nodeCount()) : "");
     }
+    for (int i=1; i<columnCount(); ++i) {
+      setTextAlignment(i, Qt::AlignRight);
+    }
   }
-  int compareInt(int a, int b) const
-  {
-    if (a == b)
-      return 0;
-    else if (a < b)
-      return -1;
-    else
-      return 1;
-  }
-
   int value;
   bool bestMove;
   int winState;
@@ -201,16 +199,11 @@ public:
   static const int NO_CHECKMATE = 2;
 };
 
-void SearchMoveTreeItem::setOpen(bool open)
+void SearchMoveTreeItem::setNextMove()
 {
-  if (open && depth() >= 32)
+  if (!childCount() && record)
   {
-    setExpandable(false);
-    return;
-  }
-  if (open && ! childCount() && record)
-  {
-    listView()->setUpdatesEnabled(false);
+    treeWidget()->setUpdatesEnabled(false);
 
     osl::MoveVector history;
     getMovesToCurrent(history);
@@ -230,6 +223,10 @@ void SearchMoveTreeItem::setOpen(bool open)
     for (size_t i=0; i<moves.size(); ++i)
     {
       const osl::Move move = moves[i].move();
+      if (!move.isNormal())
+      {
+        continue;
+      }
       const osl::HashKey child_key = key.newHashWithMove(move);
       const osl::SimpleHashRecord *child_record = tree->getTable().find(child_key);
       if (record->threatmate().maybeThreatmate(move.player()) &&
@@ -248,111 +245,107 @@ void SearchMoveTreeItem::setOpen(bool open)
 	       child_record->bestMove().isNormal())
 	winState = CHECKMATE_LOSE;
 
-      SearchMoveTreeItem *item =
-	new SearchMoveTreeItem(this,
-			       move,
-			       moves[i].logProb(),
-			       move == record->bestMove().move(),
-			       winState,
-			       child_record);
-      if (child_record)
-	item->setExpandable(hasChildAfterMove(state, tree->getTable(), move_history, 
-					      child_key, child_record, move));
+      new SearchMoveTreeItem(this,
+                             move,
+                             moves[i].logProb(),
+                             move == record->bestMove().move(),
+                             winState,
+                             child_record);
     }
 
-    listView()->setUpdatesEnabled(true);
+    treeWidget()->setUpdatesEnabled(true);
   }
-  Q3ListViewItem::setOpen(open);
 }
 
-void SearchMoveTreeItem::paintCell(QPainter *p, const QColorGroup &cg,
-				   int column, int width, int align)
+
+void SearchMoveTreeItem::setCellColor()
 {
-  if (column == 0)
+  static int column = 0;
+  QBrush brush(foreground(column));
+  if (winState == CHECKMATE_WIN)
   {
-    QColorGroup colorGroup(cg);
-    QColor bestColor(colorGroup.text());
-    if (winState == CHECKMATE_WIN)
+    brush.setColor(QColor("red"));
+  }
+  else if (winState == CHECKMATE_LOSE)
+  {
+    brush.setColor(QColor("gray"));
+  }
+  else if (record 
+           && (record->threatmate().maybeThreatmate(osl::BLACK)
+               || record->threatmate().maybeThreatmate(osl::WHITE)))
+  {
+    brush.setColor(QColor("purple"));
+  }
+  else if (bestMove)
+  {
+    brush.setColor(QColor("blue"));
+  }
+  setForeground(column, brush);
+}
+
+bool SearchMoveTreeItem::operator<(const QTreeWidgetItem& other) const
+{
+  const int col = treeWidget()->sortColumn();
+  const SearchMoveTreeItem& item = (const SearchMoveTreeItem&)other;
+
+  if (col == 0)
+  {
+    if (isBestMove())
     {
-      bestColor =  QColor("red");
+      return true;
     }
-    else if (winState == CHECKMATE_LOSE)
+    else if (item.isBestMove())
     {
-      bestColor = QColor("gray");
+      return false;
     }
-    else if (record 
-	     && (record->threatmate().maybeThreatmate(osl::BLACK)
-		 || record->threatmate().maybeThreatmate(osl::WHITE)))
+    else
     {
-      bestColor = QColor("purple");
+      return MoveTreeItem::operator<(other);
     }
-    else if (bestMove)
-    {
-      bestColor =  QColor("blue");
-    }
-    colorGroup.setColor(QColorGroup::Text, bestColor);
-    Q3ListViewItem::paintCell(p, colorGroup, column, width, align);
   }
   else
-    Q3ListViewItem::paintCell(p, cg, column, width, align);
+  {
+    bool b1 = true;
+    const int i1 = text(col).toInt(&b1); // true for integer
+    bool b2 = true;
+    const int i2 = item.text(col).toInt(&b2);
+    if (b1 && b2)
+    {
+      return i1 < i2;
+    }
+    else if (!b1 && !b2)
+    {
+      return text(col) < item.text(col);
+
+    }
+    else if (b1)
+    {
+      return true;
+    }
+    else
+    {
+      return false;
+    }
+  }
 }
 
-int SearchMoveTreeItem::compare(Q3ListViewItem *i, int col, bool ascending) const
+SearchMoveTree::SearchMoveTree(QWidget *parent)
+  : MoveTree(parent)
 {
-  if (col == 0 && isBestMove())
-    return -1;
-  else if (col == 0 && ((SearchMoveTreeItem *)i)->isBestMove())
-    return 1;
-  else if (col == 2)
-  {
-    SearchMoveTreeItem *item = (SearchMoveTreeItem *)i;
-    if (!record || !item || !item->getRecord())
-      return MoveTreeItem::compare(i, col, ascending);
-    return compareInt(record->lowerBound(), item->getRecord()->lowerBound());
-  }
-  else if (col == 3)
-  {
-    SearchMoveTreeItem *item = (SearchMoveTreeItem *)i;
-    if (!record || !item || !item->getRecord())
-      return MoveTreeItem::compare(i, col, ascending);
-    return compareInt(record->upperBound(), item->getRecord()->upperBound());
-  }
-  else if (col == 4)
-  {
-    SearchMoveTreeItem *item = (SearchMoveTreeItem *)i;
-    if (!record || !item || !item->getRecord())
-      return MoveTreeItem::compare(i, col, ascending);
-    return compareInt(record->lowerLimit(), item->getRecord()->lowerLimit());
-  }
-  else if (col == 5)
-  {
-    SearchMoveTreeItem *item = (SearchMoveTreeItem *)i;
-    if (!record || !item || !item->getRecord())
-      return MoveTreeItem::compare(i, col, ascending);
-    return compareInt(record->upperLimit(), item->getRecord()->upperLimit());
-  }
-  else
-    return MoveTreeItem::compare(i, col, ascending);
-}
-
-SearchMoveTree::SearchMoveTree(QWidget *parent, const char *name)
-  : MoveTree(parent, name)
-{
-  addColumn("Move");
-  addColumn("Probability");
-  addColumn("Lower Bound");
-  addColumn("Upper Bound");
-  addColumn("Lower Limit");
-  addColumn("Upper Limit");
-  addColumn("Node Count");
-  for (int i = 1; i < columns(); i++)
-  {
-    setColumnAlignment(i, Qt::AlignRight);
+  setColumnCount(7);
+  setHeaderLabels(QStringList() << "Move" <<
+                                   "Probability" <<
+                                   "Lower Bound" <<
+                                   "Upper Bound" <<
+                                   "Lower Limit" <<
+                                   "Upper Limit" <<
+                                   "Node Count");
+  for (int i = 1; i < columnCount(); i++) {
     setColumnWidth(i, columnWidth(i) / 2);
   }
 }
 
-void SearchMoveTree::addRecord(const osl::state::SimpleState& state,
+void SearchMoveTree::addRecord(const osl::SimpleState& state,
 			       const osl::search::SimpleHashTable *t,
 			       const osl::search::SimpleHashRecord *record,
 			       const osl::game_playing::SearchPlayer *p,
@@ -368,6 +361,8 @@ void SearchMoveTree::addRecord(const osl::state::SimpleState& state,
 void SearchMoveTree::addRootItem(const osl::search::SimpleHashRecord *root_record, 
 				 const osl::MoveStack& history)
 {
+  setSortingEnabled(false);
+
   osl::MoveLogProbVector moves;
   generateMoves(root_record, initial_state, history, moves);
   const osl::HashKey key(initial_state);
@@ -387,31 +382,36 @@ void SearchMoveTree::addRootItem(const osl::search::SimpleHashRecord *root_recor
 	     record->bestMove().isPass())
       winState = SearchMoveTreeItem::CHECKMATE_LOSE;
 
-    Q3ListViewItem *item =
-      new SearchMoveTreeItem(this,
-			     moves[i].move(),
-			     moves[i].logProb(),
-			     moves[i].move() == root_record->bestMove().move(),
-			     winState,
-			     record);
+    SearchMoveTreeItem *item = new SearchMoveTreeItem(this,
+                                  moves[i].move(),
+                                  moves[i].logProb(),
+                                  moves[i].move() == root_record->bestMove().move(),
+                                  winState,
+                                  record);
     if (record && hasChildAfterMove(initial_state, *table, history, 
 				    child_key, record, moves[i].move()))
-      item->setExpandable(true);
+    {
+      item->setNextMove();
+    }
   }
+
+  setSortingEnabled(true);
 }
 
 void SearchMoveTree::showQuiescenceRecord()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *) selectedItem();
-  if (!item)
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
     return;
 
-  osl::stl::vector<osl::Move> moves;
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
+
+  std::vector<osl::Move> moves;
   for (; item; item = (SearchMoveTreeItem *)item->parent())
   {
     moves.push_back(item->getMove());
   }
-  osl::state::NumEffectState newState(initial_state);
+  osl::NumEffectState newState(initial_state);
   for (int i = moves.size() - 1; i >= 0; i--)
   {
     if (moves[i].isInvalid())
@@ -427,7 +427,11 @@ void SearchMoveTree::showQuiescenceRecord()
 
 void SearchMoveTree::showRecord()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *) selectedItem();
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
+    return;
+
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
   if (!item || !item->getRecord())
     return;
 
@@ -441,16 +445,18 @@ void SearchMoveTree::showRecord()
 
 void SearchMoveTree::showMoves()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *) selectedItem();
-  if (!item)
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
     return;
 
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
+
   osl::MoveVector moves;
   item->getMovesToCurrent(moves);
   QString moves_text;
   for (size_t i = 0; i < moves.size(); ++i)
   {
-    moves_text.append(osl::record::csa::show(moves[i]).c_str()).append("\n");
+    moves_text.append(osl::csa::show(moves[i]).c_str()).append("\n");
   }
   
   QMessageBox::information(this, "Moves",
@@ -459,10 +465,12 @@ void SearchMoveTree::showMoves()
 
 void SearchMoveTree::showMovesInKanji()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *) selectedItem();
-  if (!item)
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
     return;
 
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
+
   osl::MoveVector moves;
   item->getMovesToCurrent(moves);
   osl::NumEffectState state(initial_state);
@@ -471,8 +479,8 @@ void SearchMoveTree::showMovesInKanji()
   for (size_t i = 0; i < moves.size(); ++i)
   {
     std::string euc_move = i 
-      ? osl::record::ki2::show(moves[i], state, moves[i-1])
-      : osl::record::ki2::show(moves[i], state);
+      ? osl::ki2::show(moves[i], state, moves[i-1])
+      : osl::ki2::show(moves[i], state);
     moves_text.append(codec->toUnicode(euc_move.c_str(), euc_move.length()))
       .append("\n");
     state.makeMove(moves[i]);
@@ -484,11 +492,13 @@ void SearchMoveTree::showMovesInKanji()
 
 void SearchMoveTree::showSubtree()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *) selectedItem();
-  if (!item)
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
     return;
 
-  osl::stl::vector<osl::Move> moves;
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
+
+  std::vector<osl::Move> moves;
   for (; item; item = (SearchMoveTreeItem *)item->parent())
   {
     moves.push_back(item->getMove());
@@ -523,32 +533,32 @@ void SearchMoveTree::showSubtree()
 void SearchMoveTree::buildContextMenu(QMenu *menu)
 {
   MoveTree::buildContextMenu(menu);
-  menu->insertSeparator();
+  menu->addSeparator();
   QAction *showQRecordAction = new QAction(tr("Show Quiescence Record"), this);
   menu->addAction(showQRecordAction);
-  connect(showQRecordAction, SIGNAL(activated()),
+  connect(showQRecordAction, SIGNAL(triggered()),
 	  this, SLOT(showQuiescenceRecord()));
 
   QAction *showTreeAction = new QAction(tr("Show This Subtree"), this);
   menu->addAction(showTreeAction);
-  connect(showTreeAction, SIGNAL(activated()),
+  connect(showTreeAction, SIGNAL(triggered()),
 	  this, SLOT(showSubtree()));
 
-  menu->insertSeparator();
+  menu->addSeparator();
   QAction *showRecordAction = new QAction(tr("Dump Record Data"), this);
   menu->addAction(showRecordAction);
-  connect(showRecordAction, SIGNAL(activated()),
+  connect(showRecordAction, SIGNAL(triggered()),
 	  this, SLOT(showRecord()));
 
   QAction *showMovesAction = new QAction(tr("Show moves to this node"), this);
   menu->addAction(showMovesAction);
-  connect(showMovesAction, SIGNAL(activated()),
+  connect(showMovesAction, SIGNAL(triggered()),
 	  this, SLOT(showMoves()));
 
   QAction *showMovesInKanjiAction =
     new QAction(tr("Show moves to this node in Kanji"), this);
   menu->addAction(showMovesInKanjiAction);
-  connect(showMovesInKanjiAction, SIGNAL(activated()),
+  connect(showMovesInKanjiAction, SIGNAL(triggered()),
 	  this, SLOT(showMovesInKanji()));
 }
 
@@ -570,8 +580,8 @@ private:
   const int time;
 };
 
-AnalysisViewer::AnalysisViewer(QWidget *parent, const char *name)
-  : BoardAndListTabChild(parent, name),
+AnalysisViewer::AnalysisViewer(QWidget *parent)
+  : BoardAndListTabChild(parent),
     record(0),
     algorithm(TEST_ALPHA_BETA),
     algorithmIndex(0),
@@ -602,8 +612,8 @@ AnalysisViewer::AnalysisViewer(QWidget *parent, const char *name)
 
   connect(pvView, SIGNAL(doubleClicked(const QModelIndex &)),
           this, SLOT(openMoves(const QModelIndex &)));
-  connect(board, SIGNAL(statusChanged()),
-	  this, SLOT(notifyState()));
+  connect(moveTree, SIGNAL(itemExpanded(QTreeWidgetItem*)),
+          this, SLOT(expandMove(QTreeWidgetItem*)));
 
   init();
 }
@@ -613,15 +623,16 @@ QSize AnalysisViewer::sizeHint() const
   return moveTree->sizeHint();
 }
 
-bool AnalysisViewer::analyze(const osl::state::SimpleState& s,
-			     const osl::stl::vector<osl::Move> &moves)
+bool AnalysisViewer::analyze(const osl::SimpleState& s,
+			     const std::vector<osl::Move> &moves)
 {
   QStringList strList;
   strList
     << TEST_ALPHA_BETA
+    << USI_PROXY
     << PROGRESS_ALPHA_BETA
     ;
-  boost::scoped_ptr<SearchDialogImpl>
+  std::unique_ptr<SearchDialogImpl>
     dialog(new SearchDialogImpl(&strList,
 				algorithmIndex,
 				depthLimit,
@@ -641,8 +652,8 @@ bool AnalysisViewer::analyze(const osl::state::SimpleState& s,
   return analyzeWithSavedValue(s, moves);
 }
 
-bool AnalysisViewer::analyzeWithSavedValue(const osl::state::SimpleState& s,
-					   const osl::stl::vector<osl::Move> &moves)
+bool AnalysisViewer::analyzeWithSavedValue(const osl::SimpleState& s,
+					   const std::vector<osl::Move> &moves)
 {
   moveTree->clear();
   initialState.copyFrom(s);
@@ -665,6 +676,11 @@ bool AnalysisViewer::analyzeWithSavedValue(const osl::state::SimpleState& s,
     player.reset(new osl::game_playing::AlphaBeta2OpenMidEndingEvalPlayer());
     dynamic_cast<osl::game_playing::AlphaBeta2OpenMidEndingEvalPlayer&>(*player).enableMultiPV(multiPVWidth);
   }
+  else if (algorithm == USI_PROXY)
+  {
+    player.reset(new osl::game_playing::UsiProxyPlayer());
+    dynamic_cast<osl::game_playing::UsiProxyPlayer&>(*player).enableMultiPV(multiPVWidth);
+  }
  else
   {
     abort(); // shouldn't happen;
@@ -693,13 +709,13 @@ bool AnalysisViewer::analyzeWithSavedValue(const osl::state::SimpleState& s,
   QProgressDialog progress(tr("Searching..........................................."),
                            tr("Abort Search"), 0, time*8,
                            this);
-  QLabel *search_info = new QLabel(tr("Searching"));
-  progress.setLabel(search_info);
-  
-  boost::shared_ptr<osl::search::SearchMonitor> monitor
-    (new ViewerSearchMonitor(search_info, gameState.state()));
+  progress.setLabelText(tr("Searching"));
+  std::shared_ptr<ViewerSearchMonitor> monitor(new ViewerSearchMonitor(gameState.state()));
   player->addMonitor(monitor);
 
+  connect(monitor.get(), SIGNAL(updated(const QString&)),
+          &progress, SLOT(setLabelText(const QString&)));
+
   SearchThread thread(*player, gameState, time);
   thread.start();
   for (int i = 0; i < time*8; i++)
@@ -742,7 +758,7 @@ bool AnalysisViewer::analyzeWithSavedValue(const osl::state::SimpleState& s,
 void AnalysisViewer::saveSearchValue(const SearchDialogImpl& dialog)
 {
   algorithm = dialog.searchPlayerComboBox->currentText();
-  algorithmIndex = dialog.searchPlayerComboBox->currentItem();
+  algorithmIndex = dialog.searchPlayerComboBox->currentIndex();
   depthLimit = dialog.depthLimitBox->value();
   initialDepthLimit = dialog.initialDepthLimitBox->value();
   deepningStep = dialog.deepningStepBox->value();
@@ -776,7 +792,11 @@ int AnalysisViewer::getRecordValue(const osl::search::SimpleHashRecord *r,
 
 const osl::search::SimpleHashRecord *AnalysisViewer::selectedRecord()
 {
-  SearchMoveTreeItem *item = (SearchMoveTreeItem *)moveTree->selectedItem();
+  QList<QTreeWidgetItem *> selected = moveTree->selectedItems();
+  if (selected.empty())
+    return 0;
+
+  SearchMoveTreeItem *item = (SearchMoveTreeItem *)selected[0];
   if (item)
   {
     return item->getRecord();
@@ -785,19 +805,18 @@ const osl::search::SimpleHashRecord *AnalysisViewer::selectedRecord()
   return 0;
 }
 
-void AnalysisViewer::openMoves(const QModelIndex &index)
+void AnalysisViewer::openMoves(const QModelIndex & index)
 {
   QVariant v = sortedPvModel->data(index, PvModel::FirstMoveRole);
   osl::Move move = osl::Move::makeDirect(v.toInt());
 
-  for (SearchMoveTreeItem *child = (SearchMoveTreeItem *)moveTree->firstChild();
-       child; child = (SearchMoveTreeItem *)child->nextSibling())
-  {
+  for (int i=0; i < moveTree->topLevelItemCount(); ++i) {
+    SearchMoveTreeItem *child = (SearchMoveTreeItem *)moveTree->topLevelItem(i);
     if (child->getMove() == move)
     {
-      moveTree->setSelected(child, true);
+      child->setSelected(true);
       moveTree->expandBest();
-      moveTree->ensureItemVisible(child);
+      moveTree->scrollToItem(child);
       return;
     }
   }
@@ -809,11 +828,11 @@ QWidget *AnalysisViewer::moveGenerateDialog()
     = (MoveGeneratorDialog *)BoardAndListTabChild::moveGenerateDialog();
 
   if (dialog)
-    connect(this, SIGNAL(statusChanged(const osl::state::SimpleState &,
-				       const osl::stl::vector<osl::Move> &,
+    connect(this, SIGNAL(statusChanged(const osl::SimpleState &,
+				       const std::vector<osl::Move> &,
 				       int, osl::Move)),
-	    dialog, SLOT(setStatus(const osl::state::SimpleState &,
-				   const osl::stl::vector<osl::Move> &,
+	    dialog, SLOT(setStatus(const osl::SimpleState &,
+				   const std::vector<osl::Move> &,
 				   int, osl::Move)));
   return dialog;
 }
@@ -830,6 +849,19 @@ int AnalysisViewer::getLimit()
     return 1000;
 }
 
+void AnalysisViewer::expandMove(QTreeWidgetItem *item)
+{
+  moveTree->setSortingEnabled(false);
+
+  for (int i=0; i<item->childCount(); ++i)
+  {
+    SearchMoveTreeItem *c = (SearchMoveTreeItem *)item->child(i);
+    c->setNextMove();
+  }
+
+  moveTree->setSortingEnabled(true);
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
