@@ -4,13 +4,12 @@
 #include "moveTree.h"
 #include "pvModel.h"
 
-#include "osl/state/simpleState.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/search/simpleHashTable.h"
 #include "osl/game_playing/gameState.h"
 #include "osl/game_playing/searchPlayer.h"
+#include "osl/container/moveStack.h"
 
-#include <boost/scoped_ptr.hpp>
 
 namespace osl
 {
@@ -30,17 +29,18 @@ class SearchMoveTree;
 class SearchMoveTreeItem;
 class SearchDialogImpl;
 class QContextMenuEvent;
+class QWidget;
 
 class AnalysisViewer : public BoardAndListTabChild
 {
 Q_OBJECT
 public:
-  AnalysisViewer(QWidget *parent = 0, const char *name = 0);
+  AnalysisViewer(QWidget *parent = 0);
   virtual QSize sizeHint() const;
-  bool analyze(const osl::state::SimpleState& s,
-	       const osl::stl::vector<osl::Move>& moves);
-  bool analyzeWithSavedValue(const osl::state::SimpleState& s,
-			     const osl::stl::vector<osl::Move>& moves);
+  bool analyze(const osl::SimpleState& s,
+	       const std::vector<osl::Move>& moves);
+  bool analyzeWithSavedValue(const osl::SimpleState& s,
+			     const std::vector<osl::Move>& moves);
   const osl::search::SimpleHashRecord *selectedRecord();
   const osl::search::SimpleHashRecord *getRecord() {
     return record;
@@ -50,6 +50,7 @@ public slots:
   QWidget *moveGenerateDialog();
 private slots:
   void openMoves(const QModelIndex &);
+  void expandMove(QTreeWidgetItem *_item);
 private:
   void bestMoves(const osl::NumEffectState&, 
 		 const osl::search::SimpleHashTable&);
@@ -58,9 +59,9 @@ private:
   void saveSearchValue(const SearchDialogImpl& dialog);
 
   QTableView *pvView;
-  boost::scoped_ptr<QAbstractItemModel> pvModel;
-  boost::scoped_ptr<QSortFilterProxyModel> sortedPvModel;
-  boost::scoped_ptr<osl::game_playing::SearchPlayer> player;
+  std::unique_ptr<QAbstractItemModel> pvModel;
+  std::unique_ptr<QSortFilterProxyModel> sortedPvModel;
+  std::unique_ptr<osl::game_playing::SearchPlayer> player;
   const osl::search::SimpleHashRecord *record;
 
   QString algorithm;
@@ -74,23 +75,22 @@ private:
   int multiPVWidth;
   int searchTime;
 
-  static const QString PROGRESS_MTDF;
-  static const QString PLAIN_MTDF;
   static const QString PROGRESS_ALPHA_BETA;
   static const QString TEST_ALPHA_BETA;
+  static const QString USI_PROXY;
 };
 
 class SearchMoveTree : public MoveTree
 {
   Q_OBJECT
 public:
-  SearchMoveTree(QWidget *parent = 0, const char *name = 0);
-  void addRecord(const osl::state::SimpleState& state,
+  SearchMoveTree(QWidget *parent = 0);
+  void addRecord(const osl::SimpleState& state,
 		 const osl::search::SimpleHashTable *table,
 		 const osl::search::SimpleHashRecord *record,
 		 const osl::game_playing::SearchPlayer *player,
-		 const osl::container::MoveStack& history);
-  const osl::state::SimpleState initialState() const { return initial_state; }
+		 const osl::MoveStack& history);
+  const osl::SimpleState initialState() const { return initial_state; }
   const osl::search::SimpleHashTable& getTable() const { return *table; }
 protected:
   void buildContextMenu(QMenu *);
@@ -102,9 +102,9 @@ private slots:
   void showMovesInKanji();
 private:
   void addRootItem(const osl::search::SimpleHashRecord *record,
-		   const osl::container::MoveStack& history);
+		   const osl::MoveStack& history);
 
-  osl::state::SimpleState initial_state;
+  osl::SimpleState initial_state;
   const osl::search::SimpleHashTable *table;
   const osl::game_playing::SearchPlayer *player;
 };
