@@ -4,25 +4,25 @@
 #define QListViewItem Q3ListViewItem
 
 class MoveTree;
-class Q3ListViewItem;
+class QTreeWidgetItem;
 
 class BoardAndListTabChild : public BoardTabChild
 {
 Q_OBJECT
 public:
-  BoardAndListTabChild(QWidget *parent = 0, const char *name = 0);
+  BoardAndListTabChild(QWidget *parent = 0);
   void forward();
   void backward();
   int moveCount() const {
     return numMoves;
   }
-  osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &moves);
+  osl::NumEffectState getStateAndMovesToCurrent(std::vector<osl::Move> &moves);
   void toLastState();
 private slots:
-  void updateBoardSlot(Q3ListViewItem *item);
+  void updateBoardSlot(QTreeWidgetItem *item);
 
 protected:
-  virtual void updateBoard(Q3ListViewItem *item);
+  virtual void updateBoard(QTreeWidgetItem *item);
   void init();
   bool tryForward();
 
