@@ -34,13 +34,13 @@ public:
   virtual const osl::NumEffectState& getState();
   virtual void toggleOrientation() {
   }
-  virtual osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &/*moves*/) {
+  virtual osl::NumEffectState getStateAndMovesToCurrent(std::vector<osl::Move> &/*moves*/) {
     return getState();
   }
   virtual QWidget *moveGenerateDialog() {
     return NULL;
   }
-  void setState(const osl::state::SimpleState &state);
+  void setState(const osl::SimpleState &state);
 private slots:
   void processText();
   void reserveToBlack();
