@@ -1,17 +1,18 @@
 #include "boardTabChild.h"
+#include "mainwindow.h"
 
 #include "gpsshogi/gui/board.h"
 #include "moveGeneratorDialog.h"
-#include "osl/record/csa.h"
-#include "osl/record/usi.h"
+#include "osl/csa.h"
+#include "osl/usi.h"
 
 #include <qclipboard.h>
 #include <qapplication.h>
 #include <qinputdialog.h>
 #include <sstream>
 
-BoardTabChild::BoardTabChild(QWidget *parent, const char *name)
- : TabChild(parent, name)
+BoardTabChild::BoardTabChild(QWidget *parent)
+ : TabChild(parent)
 {
   board = new gpsshogi::gui::Board(initialState, this);
   connect(board, SIGNAL(statusChanged()),
@@ -67,12 +68,12 @@ void BoardTabChild::copy()
 void BoardTabChild::copyBoardAndMoves()
 {
   std::ostringstream oss(std::ostringstream::out);
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = getStateAndMovesToCurrent(moves);
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = getStateAndMovesToCurrent(moves);
   oss << state;
   for (size_t i = 0; i < moves.size(); i++)
   {
-    oss << osl::record::csa::show(moves[i]) << std::endl;
+    oss << osl::csa::show(moves[i]) << std::endl;
   }
 
   const std::string &board_string = oss.str();
@@ -89,7 +90,7 @@ void BoardTabChild::copyBoardAndMoves()
 void BoardTabChild::copyUsi()
 {
   std::ostringstream oss(std::ostringstream::out);
-  oss << "position " << osl::record::usi::show(board->getState());
+  oss << "position " << osl::usi::show(board->getState());
   const std::string &board_string = oss.str();
   QString boardString (board_string.c_str());
 
@@ -104,12 +105,12 @@ void BoardTabChild::copyUsi()
 void BoardTabChild::copyBoardAndMovesUsi()
 {
   std::ostringstream oss(std::ostringstream::out);
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = getStateAndMovesToCurrent(moves);
-  oss << "position " << osl::record::usi::show(state) << " moves";
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = getStateAndMovesToCurrent(moves);
+  oss << "position " << osl::usi::show(osl::NumEffectState(state)) << " moves";
   for (size_t i = 0; i < moves.size(); i++)
   {
-    oss << " " << osl::record::usi::show(moves[i]);
+    oss << " " << osl::usi::show(moves[i]);
   }
 
   const std::string &board_string = oss.str();
@@ -149,8 +150,8 @@ void BoardTabChild::showArrowMove(bool on)
 
 QWidget *BoardTabChild::moveGenerateDialog()
 {
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = getStateAndMovesToCurrent(moves);
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = getStateAndMovesToCurrent(moves);
   MoveGeneratorDialog *dialog =
     new MoveGeneratorDialog(state, moves, getLimit(), 
 			    getNextMove(), this);
@@ -162,11 +163,26 @@ QWidget *BoardTabChild::moveGenerateDialog()
 
 void BoardTabChild::notifyState()
 {
-  osl::state::SimpleState s;
-  osl::stl::vector<osl::Move> m;
+  osl::SimpleState s;
+  std::vector<osl::Move> m;
   s = getStateAndMovesToCurrent(m);
   emit statusChanged(s, m, getLimit(), getNextMove());
 }
+
+MainWindow *BoardTabChild::getMainWindow() const
+{
+  MainWindow *ret = NULL;
+  foreach(QWidget *widget, qApp->topLevelWidgets())
+  {
+    if(widget->inherits("QMainWindow"))
+    {
+      ret = qobject_cast<MainWindow*>(widget);
+      break;
+    }
+  }
+  Q_CHECK_PTR(ret);
+  return ret;
+}
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
