@@ -2,6 +2,8 @@
 #define _BOARD_TABCHILD_H
 #include "tabchild.h"
 
+class MainWindow;
+
 namespace gpsshogi
 {
   namespace gui
@@ -14,7 +16,7 @@ class BoardTabChild : public TabChild
 {
   Q_OBJECT
 public:
-  BoardTabChild(QWidget *parent = 0, const char *name = 0);
+  BoardTabChild(QWidget *parent = 0);
   void toInitialState();
   osl::Player turn() const;
   const osl::NumEffectState& getState();
@@ -30,14 +32,15 @@ public:
   void highlightLastMove(bool on);
   void highlightBookMove(bool on);
   void showArrowMove(bool on);
-  virtual osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &moves) = 0;
+  MainWindow *getMainWindow() const;
+  virtual osl::NumEffectState getStateAndMovesToCurrent(std::vector<osl::Move> &moves) = 0;
   virtual int getLimit() { return 1000; };
 public slots:
   QWidget *moveGenerateDialog();
 signals:
   void statusChanged();
-  void statusChanged(const osl::state::SimpleState &state,
-		     const osl::stl::vector<osl::Move> &moves,
+  void statusChanged(const osl::SimpleState &state,
+		     const std::vector<osl::Move> &moves,
 		     int limit, osl::Move next);
 protected:
   virtual osl::Move getNextMove() { return osl::Move::INVALID(); }
