@@ -8,8 +8,8 @@ class ClickableLabel : public CopyRateLabel
 {
 Q_OBJECT
 public:
-  ClickableLabel(const QString &text, QWidget *parent, const char *name = 0)
-    : CopyRateLabel(text, parent, name) {
+  ClickableLabel(const QString &text, QWidget *parent)
+    : CopyRateLabel(text, parent) {
   }
 protected:
   void mousePressEvent(QMouseEvent *event);
