@@ -1,7 +1,11 @@
 #include "copyLabel.h"
 
 #include <qclipboard.h>
-#include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#else
+#  include <QtGui>
+#endif
 #include <qapplication.h>
 #include <cmath>
 
@@ -12,7 +16,7 @@ void CopyLabel::contextMenuEvent(QContextMenuEvent *e)
 
   QMenu menu(this);
   QAction *copyAction = new QAction("&Copy", this);
-  connect(copyAction, SIGNAL(activated()),
+  connect(copyAction, SIGNAL(triggered()),
           this, SLOT(copy()));
   menu.addAction(copyAction);
   menu.exec(e->globalPos());
@@ -29,8 +33,8 @@ void CopyLabel::copy()
 }
 
   
-CopyRateLabel::CopyRateLabel(const QString &text, QWidget *parent, const char *name)
-  : CopyLabel(text, parent, name) 
+CopyRateLabel::CopyRateLabel(const QString &text, QWidget *parent)
+  : CopyLabel(text, parent) 
 {
   setColor(QColor(255, 255, 0), QColor(0, 128, 255));
   setRate(0.0);
