@@ -8,8 +8,8 @@ class CopyLabel : public QLabel
 {
 Q_OBJECT
 public:
-  CopyLabel(const QString &text, QWidget *parent, const char *name = 0)
-    : QLabel(text, parent, name) {
+  CopyLabel(const QString &text, QWidget *parent)
+    : QLabel(text, parent) {
     setMinimumSize(sizeHint());
   }
   void contextMenuEvent(QContextMenuEvent *);
@@ -21,7 +21,7 @@ class CopyRateLabel : public CopyLabel
 {
 Q_OBJECT
 public:
-  CopyRateLabel(const QString &text, QWidget *parent, const char *name = 0);
+  CopyRateLabel(const QString &text, QWidget *parent);
   void setColor(QColor p, QColor n ) { positive = p; negative = n; }
   void setRate(double r);
 private:
