@@ -4,7 +4,6 @@
 #define _DUALEVALUATIONDIALOG_H
 
 #include "osl/record/searchInfo.h"
-#include "osl/stl/vector.h"
 #include <qdialog.h>
 #include <cmath>
 
@@ -13,9 +12,9 @@ class DualEvaluationDialog : public QDialog
 {
 Q_OBJECT
 public:
-  DualEvaluationDialog(QWidget *parent = 0, const char *name = 0);
-  void setInfo(const osl::vector<osl::record::SearchInfo>& info);
-  void setRawValues(const osl::vector<int>& eval, const osl::vector<double>& progress);
+  DualEvaluationDialog(QWidget *parent = 0);
+  void setInfo(const std::vector<osl::record::SearchInfo>& info);
+  void setRawValues(const std::vector<int>& eval, const std::vector<double>& progress);
   void emitSelected(int index) { // XXX
     emit selected(index);
   }
@@ -34,11 +33,11 @@ class DualEvaluationGraph : public QWidget
 {
 Q_OBJECT
 public:
-  DualEvaluationGraph(DualEvaluationDialog *parent, const char *name = 0);
-  void setInfo(const osl::vector<osl::record::SearchInfo>& info) {
+  DualEvaluationGraph(DualEvaluationDialog *parent);
+  void setInfo(const std::vector<osl::record::SearchInfo>& info) {
     this->info = info;
   }
-  void setRawValues(const osl::vector<int>& eval, const osl::vector<double>& progress)
+  void setRawValues(const std::vector<int>& eval, const std::vector<double>& progress)
   {
     this->eval = eval;
     this->progress = progress;
@@ -83,9 +82,9 @@ private:
   {
     return std::max(std::max(info.size(), eval.size()), progress.size());
   }
-  osl::vector<osl::record::SearchInfo> info;
-  osl::vector<int> eval;
-  osl::vector<double> progress;
+  std::vector<osl::record::SearchInfo> info;
+  std::vector<int> eval;
+  std::vector<double> progress;
   int cursor;
   DualEvaluationDialog *dialog;
 private slots:
