@@ -10,12 +10,12 @@
 #include <QTabBar>
 #include <QPushButton>
 #include <QSortFilterProxyModel>
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/eval/progressEval.h"
 #include "osl/eval/endgame/attackDefense.h"
 #include "osl/eval/endgame/kingPieceValues.h"
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/progress.h"
 
 using namespace osl::eval::ml;
 
@@ -167,26 +167,26 @@ int OpenMidEndingEvalUtil::progressAdjustedTotal(
 class OpenMidEndingEvalDebugModel : public QAbstractTableModel
 {
 public:
-  OpenMidEndingEvalDebugModel(const osl::state::NumEffectState &s,
+  OpenMidEndingEvalDebugModel(const osl::NumEffectState &s,
                               QObject *parent = 0);
   int rowCount(const QModelIndex &parent = QModelIndex()) const;
   int columnCount(const QModelIndex &parent = QModelIndex()) const;
   QVariant data(const QModelIndex &index, int role) const;
   QVariant headerData(int section, Qt::Orientation orientation,
 		      int role = Qt::DisplayRole) const;
-  void setStatus(const osl::state::SimpleState &state);
-  const osl::state::NumEffectState &getState() const { return state; }
+  void setStatus(const osl::SimpleState &state);
+  const osl::NumEffectState &getState() const { return state; }
 private:
   QStringList headers;
   QStringList row_headers;
   int progress_value;
   osl::eval::ml::OpenMidEndingEvalDebugInfo debug_info;
-  osl::state::NumEffectState state;
+  osl::NumEffectState state;
   double pawn_value;
 };
 
 OpenMidEndingEvalDebugModel::OpenMidEndingEvalDebugModel(
-  const osl::state::NumEffectState &s,
+  const osl::NumEffectState &s,
   QObject *parent)
   : QAbstractTableModel(parent), state(s)
 {
@@ -275,9 +275,9 @@ QVariant OpenMidEndingEvalDebugModel::headerData(int section,
   return QVariant();
 }
 
-void OpenMidEndingEvalDebugModel::setStatus(const osl::state::SimpleState &s_state)
+void OpenMidEndingEvalDebugModel::setStatus(const osl::SimpleState &s_state)
 {
-  state = osl::state::NumEffectState(s_state);
+  state = osl::NumEffectState(s_state);
   osl::eval::ml::OpenMidEndingEval eval(state);
   debug_info = eval.debugInfo(state);
   osl::progress::ml::NewProgress new_progress(state);
@@ -285,14 +285,14 @@ void OpenMidEndingEvalDebugModel::setStatus(const osl::state::SimpleState &s_sta
   emit dataChanged(createIndex(0, 0), createIndex(0, headers.size()));
 }
 
-void OpenMidEndingEvalDebug::setStatus(const osl::state::SimpleState &state)
+void OpenMidEndingEvalDebug::setStatus(const osl::SimpleState &state)
 {
   model->setStatus(state);
 }
 
-OpenMidEndingEvalDebug::OpenMidEndingEvalDebug(const osl::state::NumEffectState &s,
-			     QWidget *parent, const char *name)
-  : QWidget(parent, name)
+OpenMidEndingEvalDebug::OpenMidEndingEvalDebug(const osl::NumEffectState &s,
+			     QWidget *parent)
+  : QWidget(parent)
 {
   model = new OpenMidEndingEvalDebugModel(s, this);
   QTableView *view = new QTableView(this);
@@ -307,12 +307,12 @@ OpenMidEndingEvalDebug::OpenMidEndingEvalDebug(const osl::state::NumEffectState
 }
 
 OpenMidEndingEvalDebugDialog::OpenMidEndingEvalDebugDialog(
-  const osl::state::SimpleState &s,
-  QWidget *parent, const char *name)
-  : QDialog(parent, name)
+  const osl::SimpleState &s,
+  QWidget *parent)
+  : QDialog(parent)
 {
   QVBoxLayout *layout = new QVBoxLayout(this);
-  debug = new OpenMidEndingEvalDebug(osl::state::NumEffectState(s), this);
+  debug = new OpenMidEndingEvalDebug(osl::NumEffectState(s), this);
   layout->addWidget(debug);
 
   QPushButton *button = new QPushButton(this);
@@ -322,8 +322,8 @@ OpenMidEndingEvalDebugDialog::OpenMidEndingEvalDebugDialog(
 }
 
 void OpenMidEndingEvalDebugDialog::setStatus(
-  const osl::state::SimpleState &state,
-  const osl::stl::vector<osl::Move> &,
+  const osl::SimpleState &state,
+  const std::vector<osl::Move> &,
   int, osl::Move)
 {
   debug->setStatus(state);
@@ -333,8 +333,8 @@ void OpenMidEndingEvalDebugDialog::setStatus(
 class OpenMidEndingEvalDiffModel : public QAbstractTableModel
 {
 public:
-  OpenMidEndingEvalDiffModel(const osl::state::NumEffectState &s1,
-                             const osl::state::NumEffectState &s2,
+  OpenMidEndingEvalDiffModel(const osl::NumEffectState &s1,
+                             const osl::NumEffectState &s2,
                              QObject *parent = 0);
   int rowCount(const QModelIndex &parent = QModelIndex()) const;
   int columnCount(const QModelIndex &parent = QModelIndex()) const;
@@ -346,13 +346,13 @@ private:
   QStringList row_headers;
   int progress_value1, progress_value2;
   osl::eval::ml::OpenMidEndingEvalDebugInfo debug_info1, debug_info2;
-  osl::state::NumEffectState state1, state2;
+  osl::NumEffectState state1, state2;
   double pawn_value;
 };
 
 OpenMidEndingEvalDiffModel::OpenMidEndingEvalDiffModel(
-  const osl::state::NumEffectState &s1,
-  const osl::state::NumEffectState &s2,
+  const osl::NumEffectState &s1,
+  const osl::NumEffectState &s2,
   QObject *parent)
   : QAbstractTableModel(parent), state1(s1), state2(s2)
 {
@@ -435,8 +435,8 @@ QVariant OpenMidEndingEvalDiffModel::headerData(int section,
   return QVariant();
 }
 
-OpenMidEndingEvalDiff::OpenMidEndingEvalDiff(const osl::state::NumEffectState &s1,
-                                             const osl::state::NumEffectState &s2,
+OpenMidEndingEvalDiff::OpenMidEndingEvalDiff(const osl::NumEffectState &s1,
+                                             const osl::NumEffectState &s2,
                                              QWidget *parent)
   : QWidget(parent) {
   model = new OpenMidEndingEvalDiffModel(s1, s2, this);
@@ -452,8 +452,8 @@ OpenMidEndingEvalDiff::OpenMidEndingEvalDiff(const osl::state::NumEffectState &s
 }
 
 OpenMidEndingEvalDiffDialog::OpenMidEndingEvalDiffDialog(
-  const osl::state::NumEffectState &s1,
-  const osl::state::NumEffectState &s2,
+  const osl::NumEffectState &s1,
+  const osl::NumEffectState &s2,
   QWidget *parent) : QDialog(parent)
 {
   QVBoxLayout *layout = new QVBoxLayout(this);
@@ -461,10 +461,10 @@ OpenMidEndingEvalDiffDialog::OpenMidEndingEvalDiffDialog(
   layout->addWidget(tab);
   debug = new OpenMidEndingEvalDiff(s1, s2, this);
   layout->addWidget(debug);
-  debug1 = new OpenMidEndingEvalDebug(osl::state::NumEffectState(s1), this);
+  debug1 = new OpenMidEndingEvalDebug(osl::NumEffectState(s1), this);
   layout->addWidget(debug1);
   debug1->setVisible(false);
-  debug2 = new OpenMidEndingEvalDebug(osl::state::NumEffectState(s2), this);
+  debug2 = new OpenMidEndingEvalDebug(osl::NumEffectState(s2), this);
   layout->addWidget(debug2);
   debug2->setVisible(false);
   connect(tab, SIGNAL(currentChanged(int)), this, SLOT(selectTab(int)));
