@@ -2,15 +2,14 @@
 #define _EVAL_DEBUG_H
 
 #include "itemDelegate.h"
-#include <boost/scoped_ptr.hpp>
 #include <QWidget>
 #include <QDialog>
 #include <QModelIndex>
 #include <QStringList>
-#include "osl/eval/ml/openMidEndingEval.h"
-#include "osl/state/numEffectState.h"
-#include "osl/stl/vector.h"
+#include "osl/eval/openMidEndingEval.h"
+#include "osl/numEffectState.h"
 #include "osl/container/pieceValues.h"
+#include <vector>
 
 class OpenMidEndingEvalDebugModel;
 class OpenMidEndingEvalDiffModel;
@@ -33,34 +32,34 @@ class OpenMidEndingEvalDebug : public QWidget
   Q_OBJECT
 public:
   OpenMidEndingEvalDebug(
-    const osl::state::NumEffectState &s,
-    QWidget *parent = 0, const char *name = 0);
-  void setStatus(const osl::state::SimpleState &state);
+    const osl::NumEffectState &s,
+    QWidget *parent = 0);
+  void setStatus(const osl::SimpleState &state);
 private:
   OpenMidEndingEvalDebugModel *model;
-  boost::scoped_ptr<DoubleItemDelegate> delegate;
+  std::unique_ptr<DoubleItemDelegate> delegate;
 };
 
 class OpenMidEndingEvalDiff : public QWidget
 {
 public:
-  OpenMidEndingEvalDiff(const osl::state::NumEffectState &s1,
-                        const osl::state::NumEffectState &s2,
+  OpenMidEndingEvalDiff(const osl::NumEffectState &s1,
+                        const osl::NumEffectState &s2,
                         QWidget *parent = 0);
 private:
   OpenMidEndingEvalDiffModel *model;
-  boost::scoped_ptr<DoubleItemDelegate> delegate;
+  std::unique_ptr<DoubleItemDelegate> delegate;
 };
 
 class OpenMidEndingEvalDebugDialog : public QDialog
 {
   Q_OBJECT
 public:
-  OpenMidEndingEvalDebugDialog(const osl::state::SimpleState &s,
-		      QWidget *parent = 0, const char *name = 0);
+  OpenMidEndingEvalDebugDialog(const osl::SimpleState &s,
+		      QWidget *parent = 0);
 public slots:
-  void setStatus(const osl::state::SimpleState &state,
-		 const osl::stl::vector<osl::Move> &,
+  void setStatus(const osl::SimpleState &state,
+		 const std::vector<osl::Move> &,
 		 int, osl::Move);
 private:
   OpenMidEndingEvalDebug *debug;
@@ -71,8 +70,8 @@ class OpenMidEndingEvalDiffDialog : public QDialog
   Q_OBJECT
 public:
   OpenMidEndingEvalDiffDialog(
-    const osl::state::NumEffectState &s1,
-    const osl::state::NumEffectState &s2,
+    const osl::NumEffectState &s1,
+    const osl::NumEffectState &s2,
     QWidget *parent = 0);
   QSize sizeHint() const;
 private slots:
