@@ -1,30 +1,11 @@
-/****************************************************************************
-**
-** Copyright (C) 2004-2006 Trolltech AS. All rights reserved.
-**
-** This file is part of the example classes of the Qt Toolkit.
-**
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
-**
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-****************************************************************************/
-
-#include <QtGui>
-#include <QtNetwork>
-
 #include "httpwindow.h"
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#else
+#  include <QtGui>
+#endif
+#include <QtNetwork>
+#include <QNetworkAccessManager>
 
 QString HttpWindow::lastUrl;
 
@@ -32,6 +13,9 @@ HttpWindow::HttpWindow(QWidget *parent, bool reload)
     : QDialog(parent)
 {
     setModal(true);
+    progressDialog = new QProgressDialog(this);
+    progressDialog->setMinimumDuration(1000); // msec
+
     urlLineEdit = new QLineEdit(lastUrl);
 
     urlLabel = new QLabel(tr("&URL:"));
@@ -42,19 +26,11 @@ HttpWindow::HttpWindow(QWidget *parent, bool reload)
     downloadButton = new QPushButton(tr("Open"));
     downloadButton->setDefault(true);
 
-    progressDialog = new QProgressDialog(this);
-
-    http = new QHttp(this);
-
+    http = new QNetworkAccessManager(this);
+    connect(http, SIGNAL(finished(QNetworkReply*)),
+                  this, SLOT(httpRequestFinished(QNetworkReply*)));
     connect(urlLineEdit, SIGNAL(textChanged(const QString &)),
             this, SLOT(enableDownloadButton()));
-    connect(http, SIGNAL(requestFinished(int, bool)),
-            this, SLOT(httpRequestFinished(int, bool)));
-    connect(http, SIGNAL(dataReadProgress(int, int)),
-            this, SLOT(updateDataReadProgress(int, int)));
-    connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
-            this, SLOT(readResponseHeader(const QHttpResponseHeader &)));
-    connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelDownload()));
     connect(downloadButton, SIGNAL(clicked()), this, SLOT(downloadFile()));
     connect(quitButton, SIGNAL(clicked()), this, SLOT(reject()));
 
@@ -74,26 +50,25 @@ HttpWindow::HttpWindow(QWidget *parent, bool reload)
     setLayout(mainLayout);
 
     setWindowTitle(tr("HTTP"));
+    const QClipboard *clipboard = QApplication::clipboard();
+    const QString text = clipboard->text();
+    if (!text.isEmpty())
+    {
+      urlLineEdit->setText(text);
+    }
     urlLineEdit->setFocus();
     if (reload)
-	downloadFile();
+      downloadFile();
 }
 
 void HttpWindow::downloadFile()
 {
-    QUrl url(urlLineEdit->text());
-    lastUrl = url;
+    httpRequestAborted = false;
+    const QUrl url(urlLineEdit->text());
+    lastUrl = url.toString();
     QFileInfo fileInfo(url.path());
     fileName = fileInfo.fileName();
-#if 0
-    if (QFile::exists(fileName)) {
-        QMessageBox::information(this, tr("HTTP"),
-                                 tr("There already exists a file called %1 in "
-                                    "the current directory.")
-                                 .arg(fileName));
-        return;
-    }
-#endif
+
     file = new QFile(fileName);
     if (!file->open(QIODevice::WriteOnly)) {
         QMessageBox::information(this, tr("HTTP"),
@@ -104,30 +79,32 @@ void HttpWindow::downloadFile()
         return;
     }
 
-    http->setHost(url.host(), url.port() != -1 ? url.port() : 80);
-    if (!url.userName().isEmpty())
-        http->setUser(url.userName(), url.password());
-
-    httpRequestAborted = false;
-    httpGetId = http->get(url.path(), file);
-
     progressDialog->setWindowTitle(tr("HTTP"));
     progressDialog->setLabelText(tr("Downloading %1.").arg(fileName));
+    progressDialog->setWindowModality(Qt::WindowModal);
     downloadButton->setEnabled(false);
+
+    QNetworkRequest request(url);
+    reply = http->get(request);
+
+    connect(reply, SIGNAL(downloadProgress (qint64, qint64)),
+            this, SLOT(updateDataReadProgress(qint64, qint64)));
+    connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelDownload()));
 }
 
 void HttpWindow::cancelDownload()
 {
     statusLabel->setText(tr("Download canceled."));
     httpRequestAborted = true;
-    http->abort();
+    reply->abort();
     downloadButton->setEnabled(true);
     reject();
 }
 
-void HttpWindow::httpRequestFinished(int requestId, bool error)
+void HttpWindow::httpRequestFinished(QNetworkReply *reply)
 {
-    if (httpRequestAborted) {
+    if (httpRequestAborted || 
+        reply->error() != QNetworkReply::NoError) {
         if (file) {
             file->close();
             file->remove();
@@ -135,53 +112,32 @@ void HttpWindow::httpRequestFinished(int requestId, bool error)
             file = 0;
         }
 
-        progressDialog->hide();
-        return;
-    }
-
-    if (requestId != httpGetId)
-        return;
-
-    progressDialog->hide();
-    file->close();
-
-    if (error) {
-        file->remove();
         QMessageBox::information(this, tr("HTTP"),
                                  tr("Download failed: %1.")
-                                 .arg(http->errorString()));
+                                 .arg(reply->error()));
+        reject();
     } else {
-        QString fileName = QFileInfo(QUrl(urlLineEdit->text()).path()).fileName();
-        statusLabel->setText(tr("Downloaded %1 to current directory.").arg(fileName));
+      QTextStream out(file);
+      out << reply->readAll();
+
+      file->close();
+      delete file;
+      file = 0;
+
+      QString fileName = QFileInfo(QUrl(urlLineEdit->text()).path()).fileName();
+      statusLabel->setText(tr("Downloaded %1 to current directory.").arg(fileName));
+      downloadButton->setEnabled(true);
+
+      accept();
     }
 
-    downloadButton->setEnabled(true);
-    delete file;
-    file = 0;
-
-    if (error)
-	reject();
-    else
-	accept();
+    reply->deleteLater();
 }
 
-void HttpWindow::readResponseHeader(const QHttpResponseHeader &responseHeader)
-{
-    if (responseHeader.statusCode() != 200) {
-        QMessageBox::information(this, tr("HTTP"),
-                                 tr("Download failed: %1.")
-                                 .arg(responseHeader.reasonPhrase()));
-        httpRequestAborted = true;
-        progressDialog->hide();
-        http->abort();
-        return;
-    }
-}
-
-void HttpWindow::updateDataReadProgress(int bytesRead, int totalBytes)
+void HttpWindow::updateDataReadProgress(qint64 bytesRead, qint64 totalBytes)
 {
     if (httpRequestAborted)
-        return;
+      return;
 
     progressDialog->setMaximum(totalBytes);
     progressDialog->setValue(bytesRead);
