@@ -9,6 +9,6 @@ QString DoubleItemDelegate::displayText(const QVariant &value,
   }
   else
   {
-    QStyledItemDelegate::displayText(value, locale);
+    return QStyledItemDelegate::displayText(value, locale);
   }
 }
