@@ -1,5 +1,7 @@
 #include "kifuViewer.h"
 #include "moveList.h"
+#include "mainwindow.h"
+#include "searchMonitor.h"
 
 #include "moveGeneratorDialog.h"
 #include "kifuAnalyzer.h"
@@ -9,44 +11,39 @@
 #include "gpsshogi/gui/util.h"
 
 #include "osl/search/searchMonitor.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaString.h"
-#include "osl/record/csaIOError.h"
 #include "osl/record/kisen.h"
 #include "osl/record/ki2.h"
-#include "osl/record/usi.h"
+#include "osl/usi.h"
 
-#include <qlayout.h>
+#include <QVBoxLayout>
+#include <QApplication>
+#include <QClipboard>
 #include <QListWidget>
 #include <QTableWidget>
 #include <QThread>
-#include <Q3ListView>
-#include <QDateTime>
-#include <qtextcodec.h>
-#include <qtimer.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
-#include <qtextbrowser.h>
-#include <qmessagebox.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
+#include <QTreeWidget>
+#include <QHeaderView>
+#include <QMenu>
+#include <QWidget>
+#include <QTextCodec>
+#include <QTimer>
+#include <QFile>
+#include <QTextBrowser>
 
-#include <boost/foreach.hpp>
 #include <iostream>
 
 volatile bool KifuViewer::analyzeOnlineEnabled = false;
 volatile bool KifuViewer::stateForAnalysisChanged = false;
-boost::scoped_ptr<osl::NumEffectState> KifuViewer::stateForAnalysis;
-boost::scoped_ptr<KifuViewer::AnalysisOnlineThread> KifuViewer::thread;
+std::unique_ptr<osl::NumEffectState> KifuViewer::stateForAnalysis;
+std::unique_ptr<KifuViewer::AnalysisOnlineThread> KifuViewer::thread;
 KifuViewer::AnalysisOnlineDialog *KifuViewer::analysisOnlineDialog = 0;
-static QMutex analysisOnlineMutex;
 
 
-KifuViewer::KifuViewer(QWidget *parent, const char *name)
-  : BoardTabChild(parent, name), lastReadTime(0),
-    index(-1), manualIndex(-1), ignoreMoveSignal(false),
+KifuViewer::KifuViewer(QWidget *parent)
+  : BoardTabChild(parent), lastReadTime(0),
+    index(-1), manualIndex(-1), kifuFileMutex(QMutex::Recursive), ignoreMoveSignal(false),
     watchFileEnabled(false)
 {
   list = new MoveList(this);
@@ -57,10 +54,10 @@ KifuViewer::KifuViewer(QWidget *parent, const char *name)
   updateTime();
 
   QVBoxLayout *eastLayout = new QVBoxLayout;
-  eastLayout->addWidget(players, 2);
-  eastLayout->addWidget(timeView, 2);
-  eastLayout->addWidget(moveInfoView, 5);
-  eastLayout->addWidget(commentView, 6);
+  eastLayout->addWidget(players, 4);
+  eastLayout->addWidget(timeView, 3);
+  eastLayout->addWidget(moveInfoView, 6);
+  eastLayout->addWidget(commentView, 2);
   QHBoxLayout *mainLayout = new QHBoxLayout(this);
   mainLayout->addWidget(list, 1);
   mainLayout->addWidget(board, 4);
@@ -80,15 +77,16 @@ KifuViewer::KifuViewer(QWidget *parent, const char *name)
 	  this, SLOT(reloadFile()));
   connect(timer, SIGNAL(timeout()),
 	  this, SLOT(updateStatusForAnalysis()));
-  connect(this, SIGNAL(statusChanged(const osl::state::SimpleState &,
-				     const osl::stl::vector<osl::Move> &,
+  connect(this, SIGNAL(statusChanged(const osl::SimpleState &,
+				     const std::vector<osl::Move> &,
 				     int, osl::Move)),
-	  this, SLOT(prepareUpdateForAnalysis(const osl::state::SimpleState &,
-					      const osl::stl::vector<osl::Move> &,
+	  this, SLOT(prepareUpdateForAnalysis(const osl::SimpleState &,
+					      const std::vector<osl::Move> &,
 					      int, osl::Move)));
   connect(this, SIGNAL(analyzeOnlineDisabled()), this, SLOT(stopAnalysisOnline()));
 
-  timer->start(1000, false);
+  timer->setSingleShot(false);
+  timer->start(1000);
 }
 
 KifuViewer::~KifuViewer()
@@ -175,7 +173,10 @@ void KifuViewer::updateState()
   if (manualIndex >= 0 && manualIndex < (int)manualMoves.size())
     board->setState(state, manualMoves[manualIndex]);
   else
-    board->setState(state);
+  {
+    const osl::Move move = index >= 0 ? list->getMove(index) : osl::Move();
+    board->setState(state, move);
+  }
   if (index == -1)
   {
     list->setCurrentItem(list->item(0));
@@ -220,6 +221,14 @@ void KifuViewer::updateTime()
   timeView->setItem(0, 0, black_time);
   timeView->setItem(1, 0, white_time);
 
+  timeView->resizeColumnsToContents();
+  timeView->resizeRowsToContents();
+#if QT_VERSION >= 0x050000
+  timeView->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
+#else
+  timeView->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+#endif
+
   moveInfoView->clear();
   commentView->clear();
   if (0 <= index && manualIndex == -1)
@@ -294,268 +303,194 @@ void KifuViewer::reloadFile()
   }
 }
 
-class OnlineViewItem : public Q3ListViewItem
+class OnlineViewItem : public QTreeWidgetItem
 {
   int depth;
   int relative_value;
+  size_t node_count;
 public:
-  OnlineViewItem(Q3ListView *pvList, int depth, double elapsed, size_t node_count, 
+  OnlineViewItem(QTreeWidget *pvList, int _depth, double elapsed, size_t _node_count,
 		 int value, QString pv, osl::Player turn)
-    : Q3ListViewItem(pvList, QString("%1").arg(depth, 2),
-		     QString("%1").arg(elapsed, 0, 'f', 1),
-		     QString("%1").arg(node_count, 6),
-		     QString("%1").arg(value*osl::playerToMul(turn), 5), 
-		     pv),
-      depth(depth), relative_value(value)
+    : QTreeWidgetItem(pvList,
+                      QStringList() << QString("%1").arg(_depth, 2) <<
+		                       QString("%1").arg(elapsed, 0, 'f', 1) <<
+		                       QString("%1").arg(QLocale(QLocale::English).toString(static_cast<qulonglong>(_node_count))) <<
+		                       QString("%1").arg(value, 5) <<
+		                       pv),
+      depth(_depth), relative_value(value*osl::sign(turn)), node_count(_node_count)
   {
   }
-  int compare(Q3ListViewItem *i, int col, bool ascending) const
+  bool operator<(const QTreeWidgetItem& other_item) const
   {
-    if (col == 0) {
-      const double me = depth*1e6 + relative_value;
-      const double other = ((OnlineViewItem*)i)->depth*1e6+((OnlineViewItem*)i)->relative_value;
-      if (me < other)
-	return 1;
-      if (me == other)
-	return 0;
-      return -1;
+    const OnlineViewItem& item = (const OnlineViewItem&)other_item;
+    
+    if (depth != item.depth)
+    {
+      return depth > item.depth;
+    }
+    else
+    {
+      return node_count > item.node_count;
     }
-    return Q3ListViewItem::compare(i, col, ascending);
   }
 };
 
-class KifuViewer::AnalysisOnlineDialog
-  : public QDialog, public osl::misc::Align16New
+
+
+KifuViewer::AnalysisOnlineDialog::AnalysisOnlineDialog(const osl::NumEffectState& state, 
+			      QWidget *parent)
+  : QDialog(parent), pvList(0),
+    codec(QTextCodec::codecForName("EUC-JP")), 
+    root(state), root_key(state), 
+    node_count(0), elapsed(0), closed(false)
 {
-  QLabel *status;
-  Q3ListView *pvList;
-  QTextCodec *codec;
-  osl::NumEffectState root;
-  osl::HashKey root_key;
-  osl::Move cur_move;
-  size_t node_count;
-  double elapsed, memory;
-  static QRect lastGeometry;
-public:
-  volatile bool closed;
-  explicit AnalysisOnlineDialog(const osl::NumEffectState& state, 
-				QWidget *parent = 0, const char *name = 0)
-    : QDialog(parent, name), status(0), pvList(0),
-      codec(QTextCodec::codecForName("EUC-JP")), 
-      root(state), root_key(state), 
-      node_count(0), elapsed(0), memory(0), closed(false)
-  {
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    status = new QLabel("Searching");
-    layout->addWidget(status);
+  QVBoxLayout *layout = new QVBoxLayout(this);
 
-    pvList = new Q3ListView(this);
-    pvList->addColumn("Depth");
-    pvList->addColumn("Elapsed");
-    pvList->addColumn("Node");
-    pvList->addColumn("Value");
-    pvList->addColumn("Principal Variation");
-    pvList->setColumnAlignment(0, Qt::AlignRight);
-    pvList->setColumnAlignment(1, Qt::AlignRight);
-    pvList->setColumnAlignment(2, Qt::AlignRight);
-    pvList->setColumnAlignment(3, Qt::AlignRight);
-    pvList->setAllColumnsShowFocus(true) ;
-    layout->addWidget(pvList);
+  pvList = new QTreeWidget(this);
+  pvList->setColumnCount(5);
+  pvList->setHeaderLabels(QStringList() << "Depth" <<
+			  "Elapsed" <<
+			  "Node" <<
+			  "Value" <<
+			  "Principal Variation");
+  pvList->setAllColumnsShowFocus(true) ;
+  layout->addWidget(pvList);
+}
 
-    QPushButton *button = new QPushButton(this);
-    button->setText("&Finish");
-    layout->addWidget(button);
-    connect(button, SIGNAL(clicked()), this, SLOT(accept()));
-  }
-  void updateStatus()
+void KifuViewer::AnalysisOnlineDialog::updateStatus(const QString& status)
+{
+  if (! cur_move.isNormal() || closed)
+    return;
+
+  setWindowTitle(status);
+}
+
+void KifuViewer::AnalysisOnlineDialog::showPVInt(unsigned long key,
+      int depth, size_t node_count, double elapsed, int value, const std::vector<int>& pv_int)
+{
+  std::vector<osl::Move> pv;
+  pv.reserve(pv_int.size());
+  for (const int m : pv_int)
   {
-    if (! cur_move.isNormal() || closed)
-      return;
-    QMutexLocker lk(&analysisOnlineMutex);
-    std::string euc_move = osl::record::ki2::show(cur_move, root);
-    status->setText(QString::fromUtf8("探索中 %1 %2秒 NPS %3 Memory %4%")
-		    .arg(codec->toUnicode(euc_move.c_str(), euc_move.length()))
-		    .arg(elapsed, 0, 'g', 3).arg((int)(node_count/elapsed))
-		    .arg((int)memory)
-		    );
+    pv.push_back(osl::Move::makeDirect(m));
   }
-  void setState(const osl::NumEffectState& state)
+  showPV(key, depth, node_count, elapsed, value, pv, "", nullptr);
+}
+
+void KifuViewer::AnalysisOnlineDialog::
+showPV(unsigned long key,
+       int depth, size_t node_count, double elapsed, int value,
+       const std::vector<osl::Move>& pv, const char *additional_message,
+       const std::vector<char> *pv_threatmate)
+{
+  if (closed || key != root_key.signature())
+    return;
+  std::string euc_pv = pv_threatmate
+    ? osl::ki2::show(&*pv.begin(), &*pv.end(),
+		     &*pv_threatmate->begin(), &*pv_threatmate->end(),
+		     root)
+    : osl::ki2::show(&*pv.begin(), &*pv.end(), root);
   {
-    root = state;
-    root_key = osl::HashKey(state), 
-    node_count = 0;
-    elapsed = memory = 0;
     pvList->setUpdatesEnabled(false);
-    pvList->clear();
+    pvList->setSortingEnabled(false);
+
+    QTreeWidgetItem *item =
+      new OnlineViewItem(pvList, depth, elapsed, node_count, 
+			 value,
+			 codec->toUnicode(euc_pv.c_str(), euc_pv.length())+additional_message,
+			 root.turn());
+    for (int i=0; i<=3; ++i)
+    {
+      item->setTextAlignment(i, Qt::AlignRight);
+      pvList->resizeColumnToContents(i);
+    }
+
+    pvList->setSortingEnabled(true);
+    pvList->scrollToItem(item);
     pvList->setUpdatesEnabled(true);
   }
-  void showPV(const osl::HashKey& key,
-	      int depth, size_t node_count, double elapsed, int value,
-	      const std::vector<osl::Move>& pv, const char *additional_message="",
-	      const std::vector<char> *pv_threatmate=0)
+  this->node_count = node_count;
+  this->elapsed = elapsed;
+}
+
+void KifuViewer::AnalysisOnlineDialog::contextMenuEvent(QContextMenuEvent *event)
+{
+  QMenu menu(this);
+  QAction *copyToClipBoard = new QAction(tr("Copy to Clip Board"), this);
+  menu.addAction(copyToClipBoard);
+  connect(copyToClipBoard, SIGNAL(triggered()),
+	  this, SLOT(onCopyToClipBoard()));
+
+  menu.exec(event->globalPos());
+}
+
+void KifuViewer::AnalysisOnlineDialog::onCopyToClipBoard()
+{
+  QList<QTreeWidgetItem *> selected = pvList->selectedItems();
+  if (selected.empty())
+    return;
+
+  OnlineViewItem *item = (OnlineViewItem *)selected[0];
+  if (item)
   {
-    if (closed || key != root_key)
-      return;
-    std::string euc_pv = pv_threatmate
-      ? osl::record::ki2::show(&*pv.begin(), &*pv.end(),
-			       &*pv_threatmate->begin(), &*pv_threatmate->end(),
-			       root)
-      : osl::record::ki2::show(&*pv.begin(), &*pv.end(), root);
-    {
-      QMutexLocker lk(&analysisOnlineMutex);
-      pvList->setUpdatesEnabled(false);
-      Q3ListViewItem *item =
-	new OnlineViewItem(pvList, depth, elapsed, node_count, 
-			   value,
-			   codec->toUnicode(euc_pv.c_str(), euc_pv.length())+additional_message,
-			   root.turn());
-      pvList->sort();
-      pvList->setUpdatesEnabled(true);
-      pvList->ensureItemVisible(item);
-    }
-    this->node_count = node_count;
-    this->elapsed = elapsed;
-    updateStatus();
+    QClipboard *clipboard = QApplication::clipboard();
+
+    clipboard->setText(QString("[%1] %2").arg(item->text(3))
+                                         .arg(item->text(4)));
   }
-  void rootMove(const osl::HashKey& key, osl::Move cur)
-  {
-    if (closed || key != root_key)
-      return;
-    cur_move = cur;
-    // Too many rootMove() can be called in a short period.
-    // Thus, updateStatus() will be delayed until timeInfo() comes.
-    // updateStatus();
-  }
-  void rootForcedMove(const osl::HashKey& key, osl::Move the_move)
-  {
-    if (closed || key != root_key)
-      return;
-    std::vector<osl::Move> pv;
-    pv.push_back(the_move);
-    showPV(key, 100, this->node_count, this->elapsed, 0, pv, " (forced move)");
-  }
-  void rootLossByCheckmate(const osl::HashKey& key)
-  {
-    if (closed || key != root_key)
-      return;
-    std::vector<osl::Move> pv;
-    showPV(key, 100, this->node_count, this->elapsed, -10000000, pv, "(loss by checkmate)");
-  }	      
-  void timeInfo(const osl::HashKey& key, size_t node_count, double elapsed)
-  {
-    if (closed || key != root_key)
-      return;
-    this->node_count = node_count;
-    this->elapsed = elapsed;
-    updateStatus();
-  }
-  void hashInfo(const osl::HashKey& key, double ratio)
-  {
-    if (closed || key != root_key)
-      return;
-    memory = ratio*100;
-  }
-  void showEvent(QShowEvent *event)
-  {
-    setGeometry(lastGeometry);
-    if (geometry().width() < 100 || geometry().height() < 100)
-      resize(std::max(geometry().width(), 100), 
-	     std::max(geometry().height(),100));
-    QDialog::showEvent(event);
-  }
-  void hideEvent(QHideEvent *event)
-  {
-    lastGeometry = geometry();
-    QDialog::hideEvent(event);
-  }
-};
+}
+
+
+
 
 QRect KifuViewer::AnalysisOnlineDialog::lastGeometry(100, 100, 700, 300);
-class OnlineSearchMonitor : public osl::search::SearchMonitor
-{
-  KifuViewer::AnalysisOnlineDialog *dialog;
-  QTextCodec *codec;
-  osl::HashKey key;
-  int cur_depth;
-  enum { MinimumDepth = 4 };
-public:
-  OnlineSearchMonitor(KifuViewer::AnalysisOnlineDialog *d, 
-		      const osl::HashKey& k)
-    : dialog(d), codec(QTextCodec::codecForName("EUC-JP")), key(k),
-      cur_depth(0)
-  {
-  }
-  void showPV(int depth, size_t node_count, double elapsed, int value, osl::Move cur, const osl::Move *first, const osl::Move *last,
-	      const bool *threatmate_first, const bool *threatmate_last)
-  {
-    std::vector<osl::Move> pv;
-    std::vector<char> pv_threatmate;
-    if (first == 0 || *first != cur) {
-      pv.push_back(cur);
-      pv_threatmate.push_back(false);
-    }
-    while (first != last) {
-      pv.push_back(*first++);
-      if (threatmate_first != threatmate_last)
-	pv_threatmate.push_back(*threatmate_first++);
-    }
-    cur_depth = std::max(cur_depth, depth);
-    if (cur_depth >= MinimumDepth || abs(value) >= 1000000)
-      dialog->showPV(key, depth, node_count, elapsed, value, pv, "", &pv_threatmate);
-  }
-  void rootMove(osl::Move cur)
-  {
-    if (cur_depth >= MinimumDepth)
-      dialog->rootMove(key, cur);    
-  }
-  void rootFirstMove(osl::Move cur)
-  {
-    if (cur_depth >= MinimumDepth)
-      dialog->rootMove(key, cur);    
-  }
-  void timeInfo(size_t node_count, double elapsed)
-  {
-    if (cur_depth >= MinimumDepth)
-      dialog->timeInfo(key, node_count, elapsed);
-  }		      
-  void hashInfo(double ratio)
-  {
-    if (cur_depth >= MinimumDepth)
-      dialog->hashInfo(key, ratio);
-  }
-  void rootForcedMove(osl::Move the_move)
-  {
-    dialog->rootForcedMove(key, the_move);
-  }
-  void rootLossByCheckmate()
-  {
-    std::cerr << "rootLossByCheckmate\n";
-    dialog->rootLossByCheckmate(key);
-  }	      
-};
 
 struct KifuViewer::AnalysisOnlineThread : public QThread, public osl::misc::Align16New
 {
+  bool isUsiProxyAvailable;
   osl::NumEffectState input;
-  boost::scoped_ptr<osl::game_playing::AlphaBeta2OpenMidEndingEvalPlayer> player;
+  std::unique_ptr<osl::game_playing::SearchPlayer> player;
   QMutex mutex;
   volatile bool stop;
-  boost::shared_ptr<OnlineSearchMonitor> monitor;
+  std::shared_ptr<ViewerSearchMonitor> monitor;
   osl::HashKey key;
-  AnalysisOnlineThread(const osl::NumEffectState& initial) 
-    : input(initial), stop(false), key(initial)
+  AnalysisOnlineThread(bool _isUsiProxyAvailable, const osl::NumEffectState& initial) 
+    : isUsiProxyAvailable(_isUsiProxyAvailable), input(initial), stop(false), key(initial)
   {
   }
   void run()
   {
-    while (! stop) {
-      boost::scoped_ptr<osl::game_playing::GameState> state;
+    while (! stop)
+    {
+      std::unique_ptr<osl::game_playing::GameState> state;
       osl::HashKey last_key;
       {
 	QMutexLocker lk(&mutex);
 	state.reset(new osl::game_playing::GameState(input));
-	player.reset(new osl::game_playing::AlphaBeta2OpenMidEndingEvalPlayer);
-	monitor.reset(new OnlineSearchMonitor(analysisOnlineDialog, key));
+
+        if (isUsiProxyAvailable)
+        {
+          player.reset(new osl::game_playing::UsiProxyPlayer);
+        }
+        else
+        {
+          player.reset(new osl::game_playing::AlphaBeta2OpenMidEndingEvalPlayer);
+        }
+	monitor.reset(new ViewerSearchMonitor(input));
+
+        connect(monitor.get(), SIGNAL(updated(const QString&)),
+                analysisOnlineDialog, SLOT(updateStatus(const QString&)));
+        connect(monitor.get(), SIGNAL(showPVSignal(unsigned long, int, unsigned long, double, int, const std::vector<int>&)),
+                analysisOnlineDialog, SLOT(showPVInt(unsigned long, int, unsigned long, double, int, const std::vector<int>&)));
+        connect(monitor.get(), SIGNAL(rootMoveSignal(unsigned long, int)),
+                analysisOnlineDialog, SLOT(rootMove(unsigned long, int)));
+        connect(monitor.get(), SIGNAL(timeInfoSignal(unsigned long, unsigned long, double)),
+                analysisOnlineDialog, SLOT(timeInfo(unsigned long, unsigned long, double)));
+        connect(monitor.get(), SIGNAL(rootForcedMoveSignal(unsigned long, int)),
+                analysisOnlineDialog, SLOT(rootForcedMove(unsigned long, int)));
+        connect(monitor.get(), SIGNAL(rootLossByCheckmateSignal(unsigned long)),
+                analysisOnlineDialog, SLOT(rootLossByCheckmate(unsigned long)));
+
 	player->addMonitor(monitor);
 	player->setDepthLimit(2000, 400, 200);
 	player->setNodeLimit(std::numeric_limits<size_t>::max());
@@ -567,7 +502,7 @@ struct KifuViewer::AnalysisOnlineThread : public QThread, public osl::misc::Alig
       osl::MoveWithComment ret
 	= player->selectBestMove(*state, 0,0,3600);
       while (! stop && last_key == key)
-	boost::this_thread::sleep(boost::posix_time::milliseconds(500));
+	QThread::msleep(500);
     }
   }
   void setState(const osl::NumEffectState& state)
@@ -591,29 +526,22 @@ struct KifuViewer::AnalysisOnlineThread : public QThread, public osl::misc::Alig
   }
 };
 
-void KifuViewer::prepareUpdateForAnalysis(const osl::state::SimpleState &origin,
-					 const osl::stl::vector<osl::Move> &moves,
+void KifuViewer::prepareUpdateForAnalysis(const osl::SimpleState &origin,
+					 const std::vector<osl::Move> &moves,
 					 int /*limit*/, osl::Move /*next_move*/)
 {
   if (! analyzeOnlineEnabled)
     return;
-  osl::state::NumEffectState state(origin);
+  osl::NumEffectState state(origin);
   for (size_t i = 0; i < moves.size(); i++)
     state.makeMove(moves[i]);
-  QMutexLocker lk(&analysisOnlineMutex);
-  if (! stateForAnalysis)
-    stateForAnalysis.reset(new osl::NumEffectState(state));
-  else
-    *stateForAnalysis = state;
+  stateForAnalysis.reset(new osl::NumEffectState(state));
   stateForAnalysisChanged = true;
 }
 
 void KifuViewer::updateStatusForAnalysis()
 {
-  if (! analyzeOnlineEnabled)
-    return;
-  QMutexLocker lk(&analysisOnlineMutex);
-  if (! stateForAnalysisChanged)
+  if (!analyzeOnlineEnabled || !stateForAnalysisChanged)
     return;
   static time_t prev = 0;
   time_t now = time(0);
@@ -630,11 +558,13 @@ void KifuViewer::updateStatusForAnalysis()
   }
 
   if (! thread) {
-    thread.reset(new AnalysisOnlineThread(*stateForAnalysis));
+    thread.reset(new AnalysisOnlineThread(getMainWindow()->isUsiProxyAvailable(), *stateForAnalysis));
     thread->start();
   }
   else
+  {
     thread->setState(*stateForAnalysis);
+  }
   stateForAnalysisChanged = false;
 }
 
@@ -653,7 +583,6 @@ void KifuViewer::setAnalyzeOnline(bool enable)
     thread.reset();
   }
   if (analysisOnlineDialog && !enable) {
-    QMutexLocker lk(&analysisOnlineMutex);
     AnalysisOnlineDialog *dialog = analysisOnlineDialog;
     dialog->closed = true;
     analysisOnlineDialog = 0;
@@ -691,7 +620,8 @@ void KifuViewer::openEvalGraph(bool force)
   }
   if (force || move_info_count > 0)
   {
-    DualEvaluationDialog *eval = new DualEvaluationDialog(this);
+    DualEvaluationDialog *eval = new DualEvaluationDialog(); // no parent
+    eval->setAttribute(Qt::WA_DeleteOnClose); // delete the pointer on close
     eval->setInfo(move_info);
     eval->setRawValues(move_eval, move_progress);
 
@@ -702,10 +632,10 @@ void KifuViewer::openEvalGraph(bool force)
   }
 }
 
-void KifuViewer::open(const osl::state::SimpleState& state,
-		      const osl::stl::vector<osl::Move>& board_moves)
+void KifuViewer::open(const osl::SimpleState& state,
+		      const std::vector<osl::Move>& board_moves)
 {
-  osl::stl::vector<int> t(board_moves.size(), 1);
+  std::vector<int> t(board_moves.size(), 1);
   open(state, board_moves, t);
 }
 
@@ -735,7 +665,7 @@ void KifuViewer::open(KifuFile *file)
     osl::eval::ml::OpenMidEndingEval eval(state);
     const double scale = 200.0
       / eval.captureValue(osl::newPtypeO(osl::WHITE,osl::PAWN));
-    BOOST_FOREACH(osl::Move move, file->getMoves()) {
+    for (osl::Move move: file->getMoves()) {
       state.makeMove(move);
       eval.update(state, move);
       move_eval.push_back(eval.value()*scale);
@@ -750,15 +680,15 @@ void KifuViewer::open(KifuFile *file)
   openEvalGraph(false);
 }
 
-void KifuViewer::open(const osl::state::SimpleState& state,
-		      const osl::stl::vector<osl::Move>& board_moves,
-		      const osl::stl::vector<int>& consumed_time)
+void KifuViewer::open(const osl::SimpleState& state,
+		      const std::vector<osl::Move>& board_moves,
+		      const std::vector<int>& consumed_time)
 {
   clearState();
   initialState.copyFrom(osl::NumEffectState(state));
   filename = "";
   board->setState(initialState);
-  list->setState(initialState, board_moves, consumed_time, osl::vector<QString>());
+  list->setState(initialState, board_moves, consumed_time, std::vector<QString>());
   emit stateReset();
 }
 
@@ -768,7 +698,7 @@ void KifuViewer::watchFile(bool enable)
   watchFileEnabled = enable;
 }
 
-osl::NumEffectState KifuViewer::getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &m)
+osl::NumEffectState KifuViewer::getStateAndMovesToCurrent(std::vector<osl::Move> &m)
 {
   for (int i = 0; i <= index; i++)
   {
@@ -813,11 +743,11 @@ QWidget *KifuViewer::moveGenerateDialog()
   MoveGeneratorDialog *dialog
     = (MoveGeneratorDialog *)BoardTabChild::moveGenerateDialog();
   if (dialog)
-    connect(this, SIGNAL(statusChanged(const osl::state::SimpleState &,
-				       const osl::stl::vector<osl::Move> &,
+    connect(this, SIGNAL(statusChanged(const osl::SimpleState &,
+				       const std::vector<osl::Move> &,
 				       int, osl::Move)),
-	    dialog, SLOT(setStatus(const osl::state::SimpleState &,
-				   const osl::stl::vector<osl::Move> &,
+	    dialog, SLOT(setStatus(const osl::SimpleState &,
+				   const std::vector<osl::Move> &,
 				   int, osl::Move)));
   return dialog;
 }
@@ -829,7 +759,7 @@ osl::Move KifuViewer::getNextMove()
 
 void KifuViewer::analyze()
 {
-  osl::vector<osl::Move> moves;
+  std::vector<osl::Move> moves;
   for (size_t i = 0; i < list->numMoves(); i++)
   {
     moves.push_back(list->getMove(i));
@@ -862,7 +792,7 @@ void KifuViewer::doAutoSaveMoves()
   if (!autoSaveFile)
     return;
 
-  osl::stl::vector<osl::Move> moves;
+  std::vector<osl::Move> moves;
   getStateAndMovesToCurrent(moves);
 
   if (autoSaveFile->fileName().endsWith(".usi"))
@@ -872,9 +802,9 @@ void KifuViewer::doAutoSaveMoves()
     QStringList slist;
     for (size_t i=0; i<moves.size(); ++i)
     {
-      slist << (osl::record::usi::show(moves[i]).c_str());
+      slist << (osl::usi::show(moves[i]).c_str());
     }
-    autoSaveFile->write(slist.join(" "));
+    autoSaveFile->write(slist.join(" ").toStdString().c_str());
     autoSaveFile->write("\n");
     autoSaveFile->close();
   }
