@@ -53,16 +53,16 @@ QVariant KisenModel::data(const QModelIndex &index, int role) const {
     }
     QTextCodec *codec = QTextCodec::codecForName("euc-jp");
     if (index.column() == 1) {
-      std::string black_title = ipxFile->getTitle(index.row(), osl::BLACK);
+      std::string black_title = ipxFile->title(index.row(), osl::BLACK);
       return codec->toUnicode(black_title.c_str(), black_title.length());
     } else if (index.column() == 2) {
-      std::string black = ipxFile->getPlayer(index.row(), osl::BLACK);
+      std::string black = ipxFile->player(index.row(), osl::BLACK);
       return codec->toUnicode(black.c_str(), black.length());
     } else if (index.column() == 3) {
-      std::string white_title = ipxFile->getTitle(index.row(), osl::WHITE);
+      std::string white_title = ipxFile->title(index.row(), osl::WHITE);
       return codec->toUnicode(white_title.c_str(), white_title.length());
     } else if (index.column() == 4) {
-      std::string white = ipxFile->getPlayer(index.row(), osl::WHITE);
+      std::string white = ipxFile->player(index.row(), osl::WHITE);
       return codec->toUnicode(white.c_str(), white.length());
     }
   }
