@@ -1,20 +1,25 @@
 #include "mainwindow.h"
 #include "gpsshogi/revision.h"
+#include "osl/oslConfig.h"
 #include <qapplication.h>
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QTranslator>
+#include <QMetaType>
 #include <iostream>
 #include <string>
+#include <vector>
 
 int main(int argc, char **argv)
 {
   QApplication app(argc, argv);
   Q_INIT_RESOURCE(gui);
+
   QStringList opts = app.arguments();
   if (opts.contains("--version")) {
     std::cout << "viewer "  << gpsshogi::gpsshogi_revision << "\n\n"
        << gpsshogi::gpsshogi_copyright << "\n";
+    osl::OslConfig::healthCheck();
     return 0;
   } else if (opts.contains("--help")) {
     std::cout << 
@@ -23,6 +28,9 @@ int main(int argc, char **argv)
       " --help     show this help message\n";
     return 0;
   }
+
+  qRegisterMetaType<std::vector<int> >("std::vector<int>"); // to use vector in Signal-Slot
+
   QTranslator qtTranslator;
   qtTranslator.load("qt_" + QLocale::system().name(),
                     QLibraryInfo::location(QLibraryInfo::TranslationsPath));
@@ -32,7 +40,7 @@ int main(int argc, char **argv)
   translator.load("viewer_" + QLocale::system().name());
   app.installTranslator(&translator);
   MainWindow mainWin;
-  app.setMainWidget(&mainWin);
   mainWin.show();
+  osl::OslConfig::setUp();
   return app.exec();
 }
