@@ -13,297 +13,320 @@
 #include "copyLabel.h"
 #include "clickableLabel.h"
 #include "gpsshogi/revision.h"
-MainWindow::MainWindow(QWidget *parent, const char *name)
-  : QMainWindow(parent, name)
+#include "osl/search/usiProxy.h"
+
+#include <iostream>
+
+MainWindow::MainWindow(QWidget *parent)
+  : QMainWindow(parent), usiProxyAvailable(true)
 {
   viewer = new Viewer(this);
   setCentralWidget(viewer);
   resize(QSize(1000, 600));
-  for (int i = 0; i < qApp->argc(); i++)
+  std::string usi_proxy = "";
+
+  for (int i = 0; i < qApp->arguments().size(); i++)
   {
-    if (strcmp("-csa", qApp->argv()[i]) == 0)
+    if (qApp->arguments()[i] == "-csa")
     {
-      if (i + 1 < qApp->argc() && qApp->argv()[i + 1][0] != '-')
+      if (i + 1 < qApp->arguments().size() && qApp->arguments()[i + 1][0] != '-')
       {
-	std::string fileName(qApp->argv()[i + 1]);
+	const QString fileName(qApp->arguments()[i + 1]);
 	viewer->open(fileName);
       }
-      if (i + 2 < qApp->argc() && qApp->argv()[i + 2][0] != '-')
+      if (i + 2 < qApp->arguments().size() && qApp->arguments()[i + 2][0] != '-')
       {
 	bool ok;
-	int index = QString(qApp->argv()[i + 2]).toInt(&ok);
+	int index = QString(qApp->arguments()[i + 2]).toInt(&ok);
 	if (ok)
 	  viewer->moveTo(index - 1);
       }
     }
-    else if (strcmp("-kisen", qApp->argv()[i]) == 0)
+    else if (qApp->arguments()[i] == "-kisen")
     {
-      if (i + 2 < qApp->argc() && qApp->argv()[i + 2][0] != '-')
+      if (i + 2 < qApp->arguments().size() && qApp->arguments()[i + 2][0] != '-')
       {
-	std::string fileName(qApp->argv()[i + 1]);
+	const QString fileName(qApp->arguments()[i + 1]);
 	bool ok;
-	int index = QString(qApp->argv()[i + 2]).toInt(&ok);
+	int index = QString(qApp->arguments()[i + 2]).toInt(&ok);
 	if (ok)
 	  viewer->open(fileName, index);
       }
     }
-    else if (strcmp("-kif", qApp->argv()[i]) == 0)
+    else if (qApp->arguments()[i] == "-kif")
     {
-      if (i + 1 < qApp->argc() && qApp->argv()[i + 1][0] != '-')
+      if (i + 1 < qApp->arguments().size() && qApp->arguments()[i + 1][0] != '-')
       {
-	std::string fileName(qApp->argv()[i + 1]);
+	const QString fileName(qApp->arguments()[i + 1]);
 	viewer->openKakinoki(fileName);
       }
     }
-    else if (strcmp("-usi", qApp->argv()[i]) == 0)
+    else if (qApp->arguments()[i] == "-usi")
     {
-      if (i + 1 < qApp->argc() && qApp->argv()[i + 1][0] != '-')
+      if (i + 1 < qApp->arguments().size() && qApp->arguments()[i + 1][0] != '-')
       {
-	std::string fileName(qApp->argv()[i + 1]);
+	const QString fileName(qApp->arguments()[i + 1]);
 	viewer->openUsi(fileName);
       }
     }
-    else if (strcmp("-url", qApp->argv()[i]) == 0)
+    else if (qApp->arguments()[i] == "-url")
     {
-      if (i + 1 < qApp->argc() && qApp->argv()[i + 1][0] != '-')
+      if (i + 1 < qApp->arguments().size() && qApp->arguments()[i + 1][0] != '-')
       {
-	HttpWindow::setLastUrl(qApp->argv()[i + 1]);
+	HttpWindow::setLastUrl(qApp->arguments()[i + 1]);
 	viewer->reloadUrl();
       }
     }
+    else if (qApp->arguments()[i] == "-usi-proxy")
+    {
+      if (i + 1 < qApp->arguments().size() && qApp->arguments()[i + 1][0] != '-')
+      {
+	usi_proxy = qApp->arguments()[i + 1].toStdString();
+      }
+    }    
+  }
+
+  try
+  {
+    if (osl::search::UsiProxy::setUp(usi_proxy, {"setoption name OwnBook value false"}))
+    {
+      setUsiProxyAvailable(true);
+      std::cout << "Enable UsiProxy: " << osl::search::UsiProxy::getProgram() << std::endl; 
+    }
+    else
+    {
+      setUsiProxyAvailable(false);
+    }
+  }
+  catch (...)
+  {
+    setUsiProxyAvailable(false);
+    std::cerr << "Failed to set up UsiProxy\n";
   }
 
   QMenu *fileMenu = menuBar()->addMenu(tr("&File"));
   QAction *openAction = new QAction(tr("&Open"), this);
   openAction->setShortcut(tr("Ctrl+o"));
-  connect(openAction, SIGNAL(activated()), viewer, SLOT(open()));
+  connect(openAction, SIGNAL(triggered()), viewer, SLOT(open()));
   fileMenu->addAction(openAction);
 
   QAction *nextAction = new QAction(tr("Open &Next"), this);
-  connect(nextAction, SIGNAL(activated()), viewer, SLOT(nextFile()));
-  nextAction->addTo(fileMenu);
+  connect(nextAction, SIGNAL(triggered()), viewer, SLOT(nextFile()));
+  fileMenu->addAction(nextAction);
 
   QAction *prevAction = new QAction(tr("Open &Previous"), this);
-  connect(prevAction, SIGNAL(activated()), viewer, SLOT(prevFile()));
-  prevAction->addTo(fileMenu);
+  connect(prevAction, SIGNAL(triggered()), viewer, SLOT(prevFile()));
+  fileMenu->addAction(prevAction);
 
   QAction *urlAction = new QAction(tr("Open &Url"), this);
   urlAction->setShortcut(tr("Ctrl+u"));
-  connect(urlAction, SIGNAL(activated()), viewer, SLOT(openUrl()));
-  urlAction->addTo(fileMenu);
+  connect(urlAction, SIGNAL(triggered()), viewer, SLOT(openUrl()));
+  fileMenu->addAction(urlAction);
 
   QAction *reloadUrlAction = new QAction(tr("&Reload Url"), this);
   reloadUrlAction->setShortcut(tr("Ctrl+r"));
-  connect(reloadUrlAction, SIGNAL(activated()), viewer, SLOT(reloadUrl()));
-  reloadUrlAction->addTo(fileMenu);
+  connect(reloadUrlAction, SIGNAL(triggered()), viewer, SLOT(reloadUrl()));
+  fileMenu->addAction(reloadUrlAction);
 
   QAction *hirateAction = new QAction(tr("&Hirate"), this);
-  connect(hirateAction, SIGNAL(activated()), viewer, SLOT(hirate()));
-  hirateAction->addTo(fileMenu);
+  connect(hirateAction, SIGNAL(triggered()), viewer, SLOT(hirate()));
+  fileMenu->addAction(hirateAction);
 
   QAction *networkAction = new QAction(tr("Open Network &Connection"), this);
-  connect(networkAction, SIGNAL(activated()), viewer, SLOT(network()));
-  networkAction->addTo(fileMenu);
+  connect(networkAction, SIGNAL(triggered()), viewer, SLOT(network()));
+  fileMenu->addAction(networkAction);
 
   QAction *viewAction = new QAction(tr("&View"), this);
-  connect(viewAction, SIGNAL(activated()), viewer, SLOT(view()));
-  viewAction->addTo(fileMenu);
+  connect(viewAction, SIGNAL(triggered()), viewer, SLOT(view()));
+  fileMenu->addAction(viewAction);
 
   QAction *viewInNewTabAction = new QAction(tr("View In New &Tab"), this);
-  connect(viewInNewTabAction, SIGNAL(activated()), viewer, SLOT(viewInNewTab()));
-  viewInNewTabAction->addTo(fileMenu);
+  connect(viewInNewTabAction, SIGNAL(triggered()), viewer, SLOT(viewInNewTab()));
+  fileMenu->addAction(viewInNewTabAction);
 
   QAction *watchFileAction = new QAction(tr("&Watch File"), this);
-  watchFileAction->setToggleAction(true);
+  watchFileAction->setCheckable(true);
   connect(watchFileAction, SIGNAL(toggled(bool)), viewer, SLOT(watchFile(bool)));
-  watchFileAction->addTo(fileMenu);
+  fileMenu->addAction(watchFileAction);
 
   QAction *saveToAction = new QAction(tr("Save &Moves To Now"), this);
-  connect(saveToAction, SIGNAL(activated()), viewer, SLOT(saveMovesToCurrent()));
-  saveToAction->addTo(fileMenu);
+  connect(saveToAction, SIGNAL(triggered()), viewer, SLOT(saveMovesToCurrent()));
+  fileMenu->addAction(saveToAction);
 
   QAction *autoSaveMovesAction = new QAction(tr("&Auto Save Moves..."), this);
-  connect(autoSaveMovesAction, SIGNAL(activated()), viewer, SLOT(autoSaveMoves()));
-  autoSaveMovesAction->addTo(fileMenu);
+  connect(autoSaveMovesAction, SIGNAL(triggered()), viewer, SLOT(autoSaveMoves()));
+  fileMenu->addAction(autoSaveMovesAction);
   autoSaveMovesAction->setWhatsThis(tr("Select a file where moves played in the Kifu viewer are saved automatically."));
 
   QAction *exportAction = new QAction(tr("&Export"), this);
-  connect(exportAction, SIGNAL(activated()), viewer, SLOT(exportCurrent()));
-  exportAction->addTo(fileMenu);
+  connect(exportAction, SIGNAL(triggered()), viewer, SLOT(exportCurrent()));
+  fileMenu->addAction(exportAction);
 
   QAction *exitAction = new QAction(tr("&Quit"), this);
   exitAction->setShortcut(tr("Ctrl+q"));
-  connect(exitAction, SIGNAL(activated()), qApp, SLOT(quit()));
-  exitAction->addTo(fileMenu);
+  connect(exitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
+  fileMenu->addAction(exitAction);
 
-  QMenu *editMenu = new QMenu(this);
+  QMenu *editMenu = menuBar()->addMenu(tr("&Edit"));
   QAction *copyAction = new QAction(tr("&Copy"), this);
   copyAction->setShortcut(tr("Ctrl+c"));
-  connect(copyAction, SIGNAL(activated()), viewer, SLOT(copy()));
-  copyAction->addTo(editMenu);
+  connect(copyAction, SIGNAL(triggered()), viewer, SLOT(copy()));
+  editMenu->addAction(copyAction);
 
   QAction *copyBoardAndMovesAction =
     new QAction(tr("Copy &Board and Moves"), this);
-  connect(copyBoardAndMovesAction, SIGNAL(activated()),
+  connect(copyBoardAndMovesAction, SIGNAL(triggered()),
 	  viewer, SLOT(copyBoardAndMoves()));
-  copyBoardAndMovesAction->addTo(editMenu);
+  editMenu->addAction(copyBoardAndMovesAction);
 
   QAction *copyUsiAction = new QAction(tr("Copy &USI"), this);
-  connect(copyUsiAction, SIGNAL(activated()), viewer, SLOT(copyUsi()));
-  copyUsiAction->addTo(editMenu);
+  connect(copyUsiAction, SIGNAL(triggered()), viewer, SLOT(copyUsi()));
+  editMenu->addAction(copyUsiAction);
 
   QAction *copyBoardAndMovesUsiAction =
     new QAction(tr("Copy Board and Moves USI"), this);
-  connect(copyBoardAndMovesUsiAction, SIGNAL(activated()),
+  connect(copyBoardAndMovesUsiAction, SIGNAL(triggered()),
 	  viewer, SLOT(copyBoardAndMovesUsi()));
-  copyBoardAndMovesUsiAction->addTo(editMenu);
+  editMenu->addAction(copyBoardAndMovesUsiAction);
 
   QAction *pasteAction = new QAction(tr("&Paste"), this);
   pasteAction->setShortcut(tr("Ctrl+v"));
-  connect(pasteAction, SIGNAL(activated()), viewer, SLOT(paste()));
-  pasteAction->addTo(editMenu);
+  connect(pasteAction, SIGNAL(triggered()), viewer, SLOT(paste()));
+  editMenu->addAction(pasteAction);
 
   editMenu->addSeparator();
 
   QAction *editStateAction = new QAction(tr("Edit B&oard"), this);
-  connect(editStateAction, SIGNAL(activated()),
+  connect(editStateAction, SIGNAL(triggered()),
 	  viewer, SLOT(editState()));
-  editStateAction->addTo(editMenu);
+  editMenu->addAction(editStateAction);
 
-  QMenu *goMenu = new QMenu(this);
+  QMenu *goMenu = menuBar()->addMenu(tr("&Go"));
 
   QAction *initialAction = new QAction(tr("&Initial State"), this);
-  connect(initialAction, SIGNAL(activated()), viewer, SLOT(toInitialState()));
-  initialAction->setIconSet(loadPixmap("beginning.png"));
-  initialAction->addTo(goMenu);
+  connect(initialAction, SIGNAL(triggered()), viewer, SLOT(toInitialState()));
+  initialAction->setIcon(loadPixmap("beginning.png"));
+  goMenu->addAction(initialAction);
 
   QAction *forwardAction = new QAction(tr("&Forward"), this);
   forwardAction->setShortcut(tr("Ctrl+f"));
-  forwardAction->setIconSet(loadPixmap("forward.png"));
-  connect(forwardAction, SIGNAL(activated()), viewer, SLOT(forward()));
-  forwardAction->addTo(goMenu);
+  forwardAction->setIcon(loadPixmap("forward.png"));
+  connect(forwardAction, SIGNAL(triggered()), viewer, SLOT(forward()));
+  goMenu->addAction(forwardAction);
 
   QAction *backAction = new QAction(tr("&Backward"), this);
   backAction->setShortcut(tr("Ctrl+b"));
-  backAction->setIconSet(loadPixmap("backward.png"));
-  connect(backAction, SIGNAL(activated()), viewer, SLOT(backward()));
-  backAction->addTo(goMenu);
+  backAction->setIcon(loadPixmap("backward.png"));
+  connect(backAction, SIGNAL(triggered()), viewer, SLOT(backward()));
+  goMenu->addAction(backAction);
 
   QAction *lastAction = new QAction(tr("&Last"), this);
-  lastAction->setIconSet(loadPixmap("end.png"));
-  connect(lastAction, SIGNAL(activated()), viewer, SLOT(toLastState()));
-  lastAction->addTo(goMenu);
+  lastAction->setIcon(loadPixmap("end.png"));
+  connect(lastAction, SIGNAL(triggered()), viewer, SLOT(toLastState()));
+  goMenu->addAction(lastAction);
 
-  QMenu *analysisMenu = new QMenu(this);
+  QMenu *analysisMenu = menuBar()->addMenu(tr("&Analyze"));
 
   QAction *analyzeAction = new QAction(tr("&Search"), this);
-  connect(analyzeAction, SIGNAL(activated()), viewer, SLOT(analyze()));
-  analyzeAction->addTo(analysisMenu);
+  connect(analyzeAction, SIGNAL(triggered()), viewer, SLOT(analyze()));
+  analysisMenu->addAction(analyzeAction);
 
   QAction *analyzeInNewTabAction = new QAction(tr("Search In New &Tab"), this);
-  connect(analyzeInNewTabAction, SIGNAL(activated()), viewer,
+  connect(analyzeInNewTabAction, SIGNAL(triggered()), viewer,
 	  SLOT(analyzeInNewTab()));
-  analyzeInNewTabAction->addTo(analysisMenu);
+  analysisMenu->addAction(analyzeInNewTabAction);
   QAction *checkmateAction = new QAction(tr("&Checkmate Search"), this);
-  connect(checkmateAction, SIGNAL(activated()), viewer, SLOT(checkmateSearch()));
-  checkmateAction->addTo(analysisMenu);
+  connect(checkmateAction, SIGNAL(triggered()), viewer, SLOT(checkmateSearch()));
+  analysisMenu->addAction(checkmateAction);
 
   QAction *altCheckmateAction = new QAction(tr("C&heckmate Search (alt)"), this);
-  connect(altCheckmateAction, SIGNAL(activated()), viewer, SLOT(altCheckmateSearch()));
-  altCheckmateAction->addTo(analysisMenu);
+  connect(altCheckmateAction, SIGNAL(triggered()), viewer, SLOT(altCheckmateSearch()));
+  analysisMenu->addAction(altCheckmateAction);
 
 #ifndef OSL_PUBLIC_RELEASE
   QAction *quiescenceHalfAction = new QAction(tr("Q&uiescence Search Half Depth"), this);
-  connect(quiescenceHalfAction, SIGNAL(activated()), viewer, SLOT(quiescenceSearchHalf()));
-  quiescenceHalfAction->addTo(analysisMenu);
+  connect(quiescenceHalfAction, SIGNAL(triggered()), viewer, SLOT(quiescenceSearchHalf()));
+  analysisMenu->addAction(quiescenceHalfAction);
 
   analysisMenu->addSeparator();
 
   QAction *moveGenerateAction = new QAction(tr("Show &Moves"), this);
-  connect(moveGenerateAction, SIGNAL(activated()), viewer, SLOT(moveGenerateDialog()));
-  moveGenerateAction->addTo(analysisMenu);
+  connect(moveGenerateAction, SIGNAL(triggered()), viewer, SLOT(moveGenerateDialog()));
+  analysisMenu->addAction(moveGenerateAction);
 
   analysisMenu->addSeparator();
 
   QAction *kifuAnalyzeAction = new QAction(tr("Analyze &Kifu"), this);
-  connect(kifuAnalyzeAction, SIGNAL(activated()), viewer, SLOT(kifuAnalyze()));
-  kifuAnalyzeAction->addTo(analysisMenu);
+  connect(kifuAnalyzeAction, SIGNAL(triggered()), viewer, SLOT(kifuAnalyze()));
+  analysisMenu->addAction(kifuAnalyzeAction);
 
-  QMenu *evalDebugMenu = new QMenu(this);
+  QMenu *evalDebugMenu = menuBar()->addMenu(tr("&Debug"));
 
   QAction *evalDebugAction = new QAction(tr("Analyze Evaluation Function (OpenMidEndingEvavl)"),
 					 this);
-  connect(evalDebugAction, SIGNAL(activated()), viewer,
+  connect(evalDebugAction, SIGNAL(triggered()), viewer,
 	  SLOT(testEvalDebug()));
-  evalDebugAction->addTo(evalDebugMenu);
+  evalDebugMenu->addAction(evalDebugAction);
+
   QAction *progressDebugAction = new QAction(tr("Analyze Progress"), this);
-  progressDebugAction->addTo(evalDebugMenu);
-  connect(progressDebugAction, SIGNAL(activated()), viewer,
+  evalDebugMenu->addAction(progressDebugAction);
+  connect(progressDebugAction, SIGNAL(triggered()), viewer,
           SLOT(showProgressDebug()));
   evalDebugMenu->addSeparator();
 
   QAction *evalDebugSetStatus1Action = new QAction(tr("Set first status to be analyzed"), this);
   QAction *evalDebugSetStatus2Action = new QAction(tr("Set second status to be analyzed"), this);
   QAction *evalDebugDiffAction = new QAction(tr("Show Eval Diff"), this);
-  evalDebugSetStatus1Action->addTo(evalDebugMenu);
-  connect(evalDebugSetStatus1Action, SIGNAL(activated()), viewer,
+  evalDebugMenu->addAction(evalDebugSetStatus1Action);
+  connect(evalDebugSetStatus1Action, SIGNAL(triggered()), viewer,
           SLOT(setState1()));
-  evalDebugSetStatus2Action->addTo(evalDebugMenu);
-  connect(evalDebugSetStatus2Action, SIGNAL(activated()), viewer,
+  evalDebugMenu->addAction(evalDebugSetStatus2Action);
+  connect(evalDebugSetStatus2Action, SIGNAL(triggered()), viewer,
           SLOT(setState2()));
-  evalDebugDiffAction->addTo(evalDebugMenu);
-  connect(evalDebugDiffAction, SIGNAL(activated()), viewer,
+  evalDebugMenu->addAction(evalDebugDiffAction);
+  connect(evalDebugDiffAction, SIGNAL(triggered()), viewer,
           SLOT(showEvalDiff()));
 #endif
   analyzeOnlineAction = new QAction(tr("Analyze &Online"), this);
   connect(analyzeOnlineAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(setAnalyzeOnline(bool)));
-  analyzeOnlineAction->setToggleAction(true);
-  analyzeOnlineAction->addTo(analysisMenu);
+  analyzeOnlineAction->setCheckable(true);
+  analysisMenu->addAction(analyzeOnlineAction);
 
-  QMenu *viewMenu = new QMenu(this);
+  QMenu *viewMenu = menuBar()->addMenu(tr("&View"));
 
   flipAction = new QAction(tr("&Flip View"), this);
   connect(flipAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(setOrientation(bool)));
-  flipAction->setToggleAction(true);
-  flipAction->addTo(viewMenu);
+  flipAction->setCheckable(true);
+  viewMenu->addAction(flipAction);
   effectAction = new QAction(tr("Show &Effect"), this);
   connect(effectAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(enableEffect(bool)));
-  effectAction->setToggleAction(true);
-  effectAction->addTo(viewMenu);
+  effectAction->setCheckable(true);
+  viewMenu->addAction(effectAction);
   QAction *evalGraphAction = new QAction(tr("Evaluation &Graph"), this);
-  evalGraphAction->addTo(viewMenu);
-  connect(evalGraphAction, SIGNAL(activated()), viewer, SLOT(openEvalGraph()));  
+  viewMenu->addAction(evalGraphAction);
+  connect(evalGraphAction, SIGNAL(triggered()), viewer, SLOT(openEvalGraph()));
   lastMoveAction = new QAction(tr("Highlight &Last Move"), this);
   connect(lastMoveAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(highlightLastMove(bool)));
-  lastMoveAction->setToggleAction(true);
-  lastMoveAction->addTo(viewMenu);
+  lastMoveAction->setCheckable(true);
+  viewMenu->addAction(lastMoveAction);
   lastMoveAction->toggle();
 
   bookMoveAction = new QAction(tr("Highlight &Book Move"), this);
   connect(bookMoveAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(highlightBookMove(bool)));
-  bookMoveAction->setToggleAction(true);
-  bookMoveAction->addTo(viewMenu);
+  bookMoveAction->setCheckable(true);
+  viewMenu->addAction(bookMoveAction);
   bookMoveAction->toggle();
 
   arrowMoveAction = new QAction(tr("Show &Arrows for Moves"), this);
   connect(arrowMoveAction, SIGNAL(toggled(bool)), viewer,
 	  SLOT(showArrowMove(bool)));
-  arrowMoveAction->setToggleAction(true);
-  arrowMoveAction->addTo(viewMenu);
-
-  menuBar()->insertItem(tr("&File"), fileMenu);
-  menuBar()->insertItem(tr("&Edit"), editMenu);
-  menuBar()->insertItem(tr("&Go"), goMenu);
-  menuBar()->insertItem(tr("&Analyze"), analysisMenu);
-#ifndef OSL_PUBLIC_RELEASE
-  menuBar()->insertItem(tr("&Debug"), evalDebugMenu);
-#endif
-  menuBar()->insertItem(tr("&View"), viewMenu);
+  arrowMoveAction->setCheckable(true);
+  viewMenu->addAction(arrowMoveAction);
 
   QToolBar *toolbar = addToolBar(tr("Go"));
   toolbar->addAction(loadPixmap("beginning.png"),
@@ -391,7 +414,7 @@ void MainWindow::updateStatusBar()
 		     .arg(eval.total).arg(eval.opening).arg(eval.mid1)
 		     .arg(eval.mid2).arg(eval.ending).arg(eval.tension));
   evalLabel->setRate(eval.total / 3000.0);
-  osl::stl::vector<int> progress;
+  std::vector<int> progress;
   viewer->progressOfState(progress);
   progressLabel->setText(QString::fromUtf8("進行度: %1 (%2 %3)")
 			 .arg(progress[0]).arg(progress[1]).arg(progress[2]));
@@ -406,20 +429,31 @@ void MainWindow::updateStatusBar()
 
 void MainWindow::updateFlipButton(bool sente)
 {
-  flipAction->setOn(!sente);
+  flipAction->setChecked(!sente);
 }
 
 void MainWindow::updateEffectButton(bool on)
 {
-  effectAction->setOn(on);
+  effectAction->setChecked(on);
 }
 
 void MainWindow::turnOffAnalyzeOnlineButton()
 {
-  analyzeOnlineAction->setOn(false);
+  analyzeOnlineAction->setChecked(false);
 }
 
 QPixmap MainWindow::loadPixmap(const QString &name)
 {
   return QPixmap(":/images/" + name);
 }
+
+void MainWindow::setUsiProxyAvailable(bool b)
+{
+  usiProxyAvailable = b;
+}
+
+bool MainWindow::isUsiProxyAvailable() const
+{
+  return usiProxyAvailable;
+}
+
