@@ -13,7 +13,9 @@ class MainWindow : public QMainWindow
 {
 Q_OBJECT
 public:
-  MainWindow(QWidget *parent = 0, const char *name = 0);
+  MainWindow(QWidget *parent = 0);
+  void setUsiProxyAvailable(bool b);
+  bool isUsiProxyAvailable() const;
 private slots:
   void updateStatusBar();
   void updateFlipButton(bool sente);
@@ -31,6 +33,7 @@ private:
   QAction *effectAction, *lastMoveAction, *bookMoveAction, *arrowMoveAction, *analyzeOnlineAction;
   CopyLabel *filenameLabel;
   CopyRateLabel *proDBLabel, *blackGpsDBLabel, *whiteGpsDBLabel;
+  bool usiProxyAvailable;
 };
 
 #endif // _MAINWINDOW_H
