@@ -33,7 +33,7 @@ class MoveOrderModel : public QAbstractTableModel
 {
 public:
   MoveOrderModel(const osl::search::analyzer::CategoryMoveVector &moves,
-		 const osl::state::NumEffectState &s,
+		 const osl::NumEffectState &s,
 		 const osl::Move m,
 		 QObject *parent = 0);
   int rowCount(const QModelIndex &parent = QModelIndex()) const;
@@ -44,13 +44,13 @@ public:
 private:
   QStringList headers;
   QVector<MoveData> move_data;
-  osl::state::NumEffectState state;
+  osl::NumEffectState state;
   osl::Move correct_move;
 };
 
 MoveOrderModel::MoveOrderModel(
   const osl::search::analyzer::CategoryMoveVector &moves,
-  const osl::state::NumEffectState &s,
+  const osl::NumEffectState &s,
   const osl::Move m,
   QObject *parent) : QAbstractTableModel(parent), state(s),
 		     correct_move(m)
@@ -176,16 +176,16 @@ public:
   }
 };
 
-MoveGeneratorDialog::MoveGeneratorDialog(const osl::state::SimpleState &state,
-					 const osl::stl::vector<osl::Move> &moves,
+MoveGeneratorDialog::MoveGeneratorDialog(const osl::SimpleState &state,
+					 const std::vector<osl::Move> &moves,
 					 int limit, osl::Move next,
-					 QWidget *parent, const char *name)
-  : QDialog(parent, name), limit(limit), state(state), moves(moves),
+					 QWidget *parent)
+  : QDialog(parent), limit(limit), state(state), moves(moves),
     next_move(next)
 {
   osl::search::analyzer::CategoryMoveVector category_moves;
   QAbstractItemModel *model =
-    new MoveOrderModel(category_moves, osl::state::NumEffectState(state),
+    new MoveOrderModel(category_moves, osl::NumEffectState(state),
 		       osl::Move());
   view = new QTableView(this);
   view->setSortingEnabled(true);
@@ -211,8 +211,8 @@ MoveGeneratorDialog::MoveGeneratorDialog(const osl::state::SimpleState &state,
 void MoveGeneratorDialog::updateMoves()
 {
   spinBox->setValue(limit);
-  osl::container::MoveStack history;
-  osl::state::NumEffectState new_state(state);
+  osl::MoveStack history;
+  osl::NumEffectState new_state(state);
   osl::eval::ProgressEval eval(new_state);
   osl::search::SimpleHashRecord record;
 
@@ -250,8 +250,8 @@ void MoveGeneratorDialog::setLimit(int new_limit)
   updateMoves();
 }
 
-void MoveGeneratorDialog::setStatus(const osl::state::SimpleState &s,
-				    const osl::stl::vector<osl::Move> &m,
+void MoveGeneratorDialog::setStatus(const osl::SimpleState &s,
+				    const std::vector<osl::Move> &m,
 				    int l, osl::Move next)
 {
   state = s;
