@@ -1,8 +1,8 @@
 #ifndef _MOVE_GENERATOR_DIALOG_H
 #define _MOVE_GENERATOR_DIALOG_H
 #include <qdialog.h>
-#include "osl/state/simpleState.h"
-#include "osl/stl/vector.h"
+#include "osl/simpleState.h"
+#include <vector>
 
 class QSpinBox;
 class QTableView;
@@ -10,14 +10,14 @@ class MoveGeneratorDialog : public QDialog
 {
 Q_OBJECT
 public:
-  MoveGeneratorDialog(const osl::state::SimpleState &state,
-		      const osl::stl::vector<osl::Move> &moves,
+  MoveGeneratorDialog(const osl::SimpleState &state,
+		      const std::vector<osl::Move> &moves,
 		      int limit, 
 		      osl::Move next = osl::Move::INVALID(),
-		      QWidget *parent = 0, const char *name = 0);
+		      QWidget *parent = 0);
 public slots:
-  void setStatus(const osl::state::SimpleState &state,
-		 const osl::stl::vector<osl::Move> &moves,
+  void setStatus(const osl::SimpleState &state,
+		 const std::vector<osl::Move> &moves,
 		 int limit, osl::Move next_move);
 private slots:
   void setLimit(int limit);
@@ -26,8 +26,8 @@ private:
   QTableView *view;
   QSpinBox *spinBox;
   int limit;
-  osl::state::SimpleState state;
-  osl::stl::vector<osl::Move> moves;
+  osl::SimpleState state;
+  std::vector<osl::Move> moves;
   osl::Move next_move;
 };
 
