@@ -5,7 +5,7 @@
 #include <numeric>
 
 MoveList::MoveList(QWidget *parent)
-  : QListWidget(parent), state(osl::state::SimpleState(osl::HIRATE))
+  : QListWidget(parent), state(osl::SimpleState(osl::HIRATE))
 {
 }
 
@@ -30,10 +30,10 @@ int MoveList::getTime(unsigned int n) const
     return 0;
 }
 
-void MoveList::setState(const osl::state::SimpleState& initialState,
-			const osl::vector<osl::Move>& m,
-			const osl::vector<int>& t,
-			const osl::vector<QString>& c)
+void MoveList::setState(const osl::SimpleState& initialState,
+			const std::vector<osl::Move>& m,
+			const std::vector<int>& t,
+			const std::vector<QString>& c)
 {
   clear();
   state = initialState;
