@@ -2,26 +2,26 @@
 #define _MOVELIST_H
 #include <qglobal.h>
 #include <QListWidget>
-#include "osl/state/simpleState.h"
-#include "osl/stl/vector.h"
+#include "osl/simpleState.h"
+#include <vector>
 
 class MoveList : public QListWidget
 {
 Q_OBJECT
 public:
   MoveList(QWidget *parent = 0);
-  void setState(const osl::state::SimpleState& initialState,
-		const osl::vector<osl::Move>& m,
-		const osl::vector<int>& t,
-		const osl::vector<QString>&);
+  void setState(const osl::SimpleState& initialState,
+		const std::vector<osl::Move>& m,
+		const std::vector<int>& t,
+		const std::vector<QString>&);
   osl::Move getMove(unsigned int n) const;
   void pushMove(osl::Move move);
   int getTime(unsigned int n) const;
   size_t numMoves() const;
 private:
   osl::SimpleState state;
-  osl::vector<osl::Move> moves;
-  osl::vector<int> timeList;
+  std::vector<osl::Move> moves;
+  std::vector<int> timeList;
 };
 
 #endif // _MOVELIST_H
