@@ -17,7 +17,7 @@ class NetworkClient : public QWidget
   Q_OBJECT
 
  public:
-  NetworkClient(QWidget *parent);
+  NetworkClient(QWidget *parent = 0);
 
  public slots:
   void setHostname(QString);
