@@ -5,8 +5,6 @@
 #include "gpsshogi/gui/board.h"
 
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaString.h"
-#include "osl/record/csaIOError.h"
 
 #include <qmessagebox.h>
 #include <qlayout.h>
@@ -20,27 +18,29 @@ using gpsshogi::gui::Util;
  *  the viewer, with the board on the left and chat screen on the right
  */
 NetworkViewer::
-NetworkViewer(QWidget *parent, const char *name)
-  : BoardTabChild(parent, name), index(0)
+NetworkViewer(QWidget *parent)
+  : BoardTabChild(parent), index(0)
 {
   board->setManualMovement(false);
 
-  moveList = new MoveList(this);
-  QHBoxLayout *mainLayout = new QHBoxLayout(this);
+  QHBoxLayout *mainLayout = new QHBoxLayout();
+  moveList = new MoveList();
   mainLayout->addWidget(moveList);
   mainLayout->addWidget(board);
 
-  networkClient = new NetworkClient(this);
+  QVBoxLayout *sideLayout = new QVBoxLayout();
+  networkClient = new NetworkClient();
   QObject::connect(networkClient, SIGNAL(gotBoard(QString)),
 		   SLOT(receive_board(QString)));
   QObject::connect(networkClient, SIGNAL(gotLastMove(QString)),
 		   SLOT(receive_last_move(QString)));
   QObject::connect(networkClient, SIGNAL(chatReceived()),
 		   this, SIGNAL(chatReceived()));
-
-  QVBoxLayout *sideLayout = new QVBoxLayout(mainLayout);
-
   sideLayout->addWidget(networkClient);
+
+  mainLayout->addLayout(sideLayout);
+
+  setLayout(mainLayout);
 }
 
 void
@@ -76,16 +76,17 @@ NetworkViewer::
 receive_board(QString content)
 {
   try {
-    osl::record::csa::CsaString csa(content.ascii());
-    osl::stl::vector<osl::Move> moves;
-    osl::stl::vector<int> consumed_time;
-    csa.getRecord().getMoves(moves, consumed_time);
+    std::istringstream is(content.toStdString());
+    osl::CsaFile csa(is);
+    std::vector<osl::Move> moves;
+    std::vector<int> consumed_time;
+    csa.load().load(moves, consumed_time);
 
-    initialState = csa.getInitialState();
-    board->setState(csa.getInitialState());
-    moveList->setState(initialState, moves, consumed_time, osl::vector<QString>());
+    initialState = csa.initialState();
+    board->setState(csa.initialState());
+    moveList->setState(initialState, moves, consumed_time, std::vector<QString>());
   } catch (osl::CsaIOError& e) {
-    std::cerr << "receive_board " << e.what() << "\n" << content.ascii() << "\n";
+    std::cerr << "receive_board " << e.what() << "\n" << content.toStdString() << "\n";
   }
 }
 
@@ -93,7 +94,7 @@ void
 NetworkViewer::
 receive_last_move(QString content)
 {
-  osl::Move move = osl::record::csa::strToMove(content.ascii(), board->getState());
+  osl::Move move = osl::csa::strToMove(content.toStdString(), board->getState());
   moveList->pushMove(move);
   toLastState();
 }
@@ -136,7 +137,7 @@ int NetworkViewer::moveCount() const
 }
 
 osl::NumEffectState NetworkViewer::
-getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &moves)
+getStateAndMovesToCurrent(std::vector<osl::Move> &moves)
 {
   moves.reserve(index);
   for (int i = 0; i < index; i++)
