@@ -11,12 +11,12 @@ class NetworkViewer : public BoardTabChild
   NetworkClient* networkClient;
 
 public:
-  NetworkViewer(QWidget *parent = 0, const char *name = 0);
+  NetworkViewer(QWidget *parent = 0);
   void forward();
   void backward();
   void toLastState();
   int moveCount() const;
-  osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move>&);
+  osl::NumEffectState getStateAndMovesToCurrent(std::vector<osl::Move>&);
   MoveList *moveList;
 
 signals:
