@@ -1,8 +1,8 @@
 #ifndef _PROGRESS_DEBUG_H
 #define _PROGRESS_DEBUG_H
 
-#include "osl/progress/ml/newProgress.h"
-#include "osl/state/numEffectState.h"
+#include "osl/progress.h"
+#include "osl/numEffectState.h"
 #include <QDialog>
 
 namespace Ui
@@ -14,7 +14,7 @@ class NewProgressDebugModel;
 class NewProgressDebugDialog : public QDialog
 {
 public:
-  NewProgressDebugDialog(const osl::state::NumEffectState &state,
+  NewProgressDebugDialog(const osl::NumEffectState &state,
                          QWidget *parent = 0);
   virtual ~NewProgressDebugDialog();
 private:
