@@ -1,6 +1,5 @@
 #include "pvModel.h"
-#include "osl/move_generator/legalMoves.h"
-#include "osl/hash/hashKey.h"
+#include "osl/hashKey.h"
 #include "osl/search/fixedEval.h"
 #include "osl/search/simpleHashRecord.h"
 #include "gpsshogi/gui/util.h"
@@ -11,7 +10,7 @@ PvModel::PvModel(const osl::NumEffectState &state,
   turn = state.turn();
   const osl::hash::HashKey key(state);
   osl::MoveVector moves;
-  osl::move_generator::LegalMoves::generate(state, moves);
+  state.generateLegal(moves);
   moves.push_back(osl::Move::PASS(state.turn()));
   for (osl::MoveVector::const_iterator p = moves.begin();
        p != moves.end(); ++p) {
@@ -27,6 +26,7 @@ PvModel::PvModel(const osl::NumEffectState &state,
   }
 }
 
+// TODO: odd evaluation value
 int PvModel::getRecordValue(const osl::search::SimpleHashRecord *r,
                             osl::Player turn)
 {
