@@ -6,7 +6,7 @@
 #include <QSortFilterProxyModel>
 
 #include "osl/search/simpleHashTable.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 
 class PvModel : public QAbstractTableModel {
   Q_OBJECT
