@@ -2,11 +2,14 @@
 
 #include "osl/search/simpleHashRecord.h"
 #include "osl/search/simpleHashTable.h"
-#include "osl/move_generator/legalMoves.h"
 
 #include "gpsshogi/gui/util.h"
 
-#include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#else
+#  include <QtGui>
+#endif
 #include <qmessagebox.h>
 #include <sstream>
 
@@ -18,7 +21,7 @@ static bool hasChildAfterMove(const osl::SimpleState& state,
   osl::NumEffectState child_state(state);
   child_state.makeMove(move);
   osl::MoveVector moves;
-  osl::LegalMoves::generate(child_state, moves);
+  child_state.generateLegal(moves);
   for (size_t i=0; i<moves.size(); ++i)
     if (table.find(child_key.newHashWithMove(moves[i])))
       return true;
@@ -29,30 +32,31 @@ class QuiescenceItem : public MoveTreeItem
 {
 public:
   QuiescenceItem(QuiescenceTree *parent, osl::Move m,
-		 bool bestMove,
-		 const osl::search::SimpleHashRecord *record,
-		 const osl::hash::HashKey& key,
-		 const osl::search::SimpleHashTable *table)
+                 bool _bestMove,
+                 const osl::search::SimpleHashRecord *_record,
+                 const osl::hash::HashKey& _key,
+                 const osl::search::SimpleHashTable *_table)
     : MoveTreeItem(parent, m),
-      bestMove(bestMove), record(record), key(key), table(table),
+      bestMove(_bestMove), record(_record), key(_key), table(_table),
       parent_item(0), tree(parent)
   {
     setUpText(m, record);
+    setCellColor();
   }
   QuiescenceItem(QuiescenceItem *parent, osl::Move m,
-		 bool bestMove,
-		 const osl::search::SimpleHashRecord *record,
-		 const osl::hash::HashKey& key,
-		 const osl::search::SimpleHashTable *table)
+		 bool _bestMove,
+		 const osl::search::SimpleHashRecord *_record,
+		 const osl::hash::HashKey& _key,
+		 const osl::search::SimpleHashTable *_table)
     : MoveTreeItem(parent, m),
-      bestMove(bestMove), record(record), key(key), table(table),
+      bestMove(_bestMove), record(_record), key(_key), table(_table),
       parent_item(parent), tree(parent->tree)
   {
     setUpText(m, record);
+    setCellColor();
   }
-  void paintCell(QPainter *p, const QColorGroup &cg,
-		 int column, int width, int align);
-  void setOpen(bool);
+  void setCellColor();
+  void setNextMove();
   bool isBestMove() const {
     return bestMove;
   }
@@ -83,22 +87,16 @@ private:
   QuiescenceTree *tree;
 };
 
-void QuiescenceItem::paintCell(QPainter *p, const QColorGroup &cg,
-			       int column, int width, int align)
+void QuiescenceItem::setCellColor()
 {
-  if (column == 0)
+  static int column = 0;
+
+  QBrush brush(foreground(column));
+  if (bestMove)
   {
-    QColorGroup colorGroup(cg);
-    QColor bestColor(colorGroup.text());
-    if (bestMove)
-    {
-      bestColor =  QColor("blue");
-    }
-    colorGroup.setColor(QColorGroup::Text, bestColor);
-    MoveTreeItem::paintCell(p, colorGroup, column, width, align);
+    brush.setColor(QColor("blue"));
   }
-  else
-    MoveTreeItem::paintCell(p, cg, column, width, align);
+  setForeground(column, brush);
 }
 
 void QuiescenceItem::setUpText(osl::Move move,
@@ -117,10 +115,13 @@ void QuiescenceItem::setUpText(osl::Move move,
   setText(column++, QString("%1").arg(record->qrecord.upperDepth()));
   setText(column++, staticValueType());
   setText(column++, staticValue());
+
+  for (int i=1; i<columnCount(); ++i) {
+    setTextAlignment(i, Qt::AlignRight);
+  }
 }
 
-const char *QuiescenceItem::
-staticValueType()
+const char *QuiescenceItem::staticValueType()
 {
   if (! record)
     return "*";
@@ -128,8 +129,7 @@ staticValueType()
     toString(record->qrecord.staticValueType());
 }
 
-QString QuiescenceItem::
-staticValue()
+QString QuiescenceItem::staticValue()
 {
   if (! record)
     return "*";
@@ -138,17 +138,11 @@ staticValue()
 	  : "*");
 }
 
-void QuiescenceItem::setOpen(bool open)
+void QuiescenceItem::setNextMove()
 {
-  if (open && depth() >= 32)
+  if (!childCount() && record)
   {
-    setExpandable(false);
-    return;
-  }
-
-  if (open && ! childCount() && record)
-  {
-    listView()->setUpdatesEnabled(false);
+    treeWidget()->setUpdatesEnabled(false);
 
     const osl::search::QuiescenceRecord& qrecord = record->qrecord;
     osl::MoveVector history, moves;
@@ -156,13 +150,12 @@ void QuiescenceItem::setOpen(bool open)
     osl::NumEffectState state(tree->initialState());
     for (size_t i=0; i<history.size(); ++i)
       state.makeMove(history[i]);
-    osl::move_generator::LegalMoves::generate(state, moves);
+    state.generateLegal(moves);
   
     const osl::HashKey key(state);
 
     for (size_t i = 0; i < moves.size(); i++)
     {
-      QuiescenceItem *item;
       const osl::Move move = moves[i];
       const osl::hash::HashKey newKey = key.newHashWithMove(move);
       const osl::search::SimpleHashRecord *newRecord = table->find(newKey);
@@ -170,36 +163,37 @@ void QuiescenceItem::setOpen(bool open)
       if (! newRecord) 
 	continue;
       
-      item = new QuiescenceItem(this, move,
-				qrecord.bestMove() == move,
-				newRecord,
-				newKey,
-				table);
-      item->setExpandable(hasChildAfterMove(state, *table, 
-					    newKey, move));
+      new QuiescenceItem(this,
+                         move,
+                         qrecord.bestMove() == move,
+                         newRecord,
+                         newKey,
+                         table);
     }
-    listView()->setUpdatesEnabled(true);
+    treeWidget()->setUpdatesEnabled(true);
   }
-  Q3ListViewItem::setOpen(open);
 }
 
 
-QuiescenceTree::QuiescenceTree(QWidget *parent, const char *name)
-  : MoveTree(parent, name)
-{
-  addColumn("Move");
-  addColumn("Lower Bound");
-  addColumn("Upper Bound");
-  addColumn("Lower Limit");
-  addColumn("Upper Limit");
-  addColumn("Static Value Type");
-  addColumn("Static Value");
 
-  for (int i = 1; i < columns(); i++)
+QuiescenceTree::QuiescenceTree(QWidget *parent)
+  : MoveTree(parent)
+{
+  setColumnCount(7);
+  setHeaderLabels(QStringList() << "Move" <<
+                                   "Lower Bound" <<
+                                   "Upper Bound" <<
+                                   "Lower Limit" <<
+                                   "Upper Limit" <<
+                                   "Static Value Type" <<
+                                   "Static Value");
+  for (int i = 1; i < columnCount(); i++)
   {
-    setColumnAlignment(i, Qt::AlignRight);
     setColumnWidth(i, columnWidth(i) / 2);
   }
+
+  connect(this, SIGNAL(itemExpanded(QTreeWidgetItem*)),
+          this, SLOT(expandMove(QTreeWidgetItem*)));
 }
 
 void QuiescenceTree::showRecord(const osl::hash::HashKey& key, 
@@ -237,7 +231,7 @@ void QuiescenceTree::addItem(int depth, QuiescenceItem *parent,
   const osl::search::QuiescenceRecord& qrecord = record->qrecord;
   osl::MoveVector moves;
   osl::NumEffectState initial(initial_state);
-  osl::LegalMoves::generate(initial, moves);
+  initial.generateLegal(moves);
 
   for (size_t i = 0; i < moves.size(); i++)
   {
@@ -259,8 +253,8 @@ void QuiescenceTree::addItem(int depth, QuiescenceItem *parent,
 				newRecord,
 				newKey,
 				table);
-    item->setExpandable(hasChildAfterMove(state, *table, 
-					  newKey, move));
+    item->setNextMove();
+    item->setExpanded(hasChildAfterMove(state, *table, newKey, move));
   }
 }
 
@@ -269,14 +263,17 @@ void QuiescenceTree::contextMenuEvent(QContextMenuEvent *event)
   QMenu menu(this);
   QAction *showRecordAction = new QAction(tr("Dump Record Data"), this);
   menu.addAction(showRecordAction);
-  connect(showRecordAction, SIGNAL(activated()),
+  connect(showRecordAction, SIGNAL(triggered()),
 	  this, SLOT(showRecord()));
   menu.exec(event->globalPos());
 }
 
 void QuiescenceTree::showRecord()
 {
-  QuiescenceItem *item = (QuiescenceItem *) selectedItem();
+  QList<QTreeWidgetItem *> selected = selectedItems();
+  if (selected.empty())
+    return;
+  QuiescenceItem *item = (QuiescenceItem *)selected[0];
   if (!item || !item->getRecord())
     return;
 
@@ -287,6 +284,19 @@ void QuiescenceTree::showRecord()
   QMessageBox::information(this, "QuiescenceRecord Dump",
 			   QString(record_string.c_str()), QMessageBox::Ok);
 }
+
+void QuiescenceTree::expandMove(QTreeWidgetItem *item)
+{
+  setSortingEnabled(false);
+
+  for (int i=0; i<item->childCount(); ++i)
+  {
+    QuiescenceItem *c = (QuiescenceItem *)item->child(i);
+    c->setNextMove();
+  }
+
+  setSortingEnabled(true);
+}
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
