@@ -2,7 +2,7 @@
 #define _QUIESCENSE_TREE_H
 #include "moveTree.h"
 
-#include "osl/hash/hashKey.h"
+#include "osl/hashKey.h"
 
 namespace osl
 {
@@ -19,20 +19,21 @@ class QuiescenceTree : public MoveTree
 {
   Q_OBJECT
 public:
-  QuiescenceTree(QWidget *parent = 0, const char *name = 0);
-  const osl::state::SimpleState initialState() const { return initial_state; }
+  QuiescenceTree(QWidget *parent = 0);
+  const osl::SimpleState initialState() const { return initial_state; }
   void showRecord(const osl::hash::HashKey& key, const osl::SimpleState&,
 		  const osl::search::SimpleHashTable *table);
 protected:
   void contextMenuEvent(QContextMenuEvent *);
 private slots:
   void showRecord();
+  void expandMove(QTreeWidgetItem *item);
 private:
   void addItem(int depth, QuiescenceItem *parent,
 	       const osl::hash::HashKey& key, const osl::SimpleState&,
 	       const osl::search::SimpleHashTable *table,
 	       const osl::search::SimpleHashRecord *record);
-  osl::state::SimpleState initial_state;
+  osl::SimpleState initial_state;
 };
 
 
