@@ -3,15 +3,15 @@
 
 #include "gpsshogi/gui/board.h"
 
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/search/quiescenceSearch2.h"
 
 #include <qcombobox.h>
 #include <qlayout.h>
 #include <iostream>
 
-QuiescenceViewer::QuiescenceViewer(QWidget *parent, const char *name)
-  : BoardAndListTabChild(parent, name)
+QuiescenceViewer::QuiescenceViewer(QWidget *parent)
+  : BoardAndListTabChild(parent)
 {
   moveTree = new QuiescenceTree(this);
 
@@ -22,21 +22,21 @@ QuiescenceViewer::QuiescenceViewer(QWidget *parent, const char *name)
   init();
 }
 
-bool QuiescenceViewer::analyze(const osl::state::SimpleState& s,
-			       const osl::stl::vector<osl::Move>& moves)
+bool QuiescenceViewer::analyze(const osl::SimpleState& s,
+			       const std::vector<osl::Move>& moves)
 {
   return analyze(s, moves, osl::search::QSearchTraits::MaxDepth);
 }
 
 
-bool QuiescenceViewer::analyzeHalfDepth(const osl::state::SimpleState& s,
-					const osl::stl::vector<osl::Move>& moves)
+bool QuiescenceViewer::analyzeHalfDepth(const osl::SimpleState& s,
+					const std::vector<osl::Move>& moves)
 {
   return analyze(s, moves, osl::search::QSearchTraits::MaxDepth / 2);
 }
 
-bool QuiescenceViewer::analyze(const osl::state::SimpleState& s,
-			       const osl::stl::vector<osl::Move>& moves,
+bool QuiescenceViewer::analyze(const osl::SimpleState& s,
+			       const std::vector<osl::Move>& moves,
 			       int depth)
 {
   initialState.copyFrom(osl::NumEffectState(s));
@@ -55,12 +55,12 @@ bool QuiescenceViewer::analyze(const osl::state::SimpleState& s,
 }
 
 template <class Eval>
-void QuiescenceViewer::analyze(const osl::state::SimpleState& s,
+void QuiescenceViewer::analyze(const osl::SimpleState& s,
 			       const osl::Move last_move,
 			       int depth)
 {
   typedef osl::search::QuiescenceSearch2<Eval> qsearch_t;
-  osl::state::NumEffectState state(s);
+  osl::NumEffectState state(s);
   table.reset(new osl::search::SimpleHashTable(100000, -16, false));
   osl::search::SearchState2Core::checkmate_t checkmate_searcher;
   osl::search::SearchState2Core core(state, checkmate_searcher);
