@@ -12,8 +12,8 @@ SearchDialogImpl::SearchDialogImpl(const QStringList *list,
 				   int tableSizeLimit, int tableRecordLimit,
 				   int multiPVWidth,
 				   int searchTime,
-				   QWidget *parent, const char *name)
-  : QDialog(parent, name),
+				   QWidget *parent)
+  : QDialog(parent),
     algorithmIndex(algorithmIndex),
     depthLimit(depthLimit), initialDepthLimit(initialDepthLimit),
     deepningStep(deepningStep), nodeLimit(nodeLimit),
@@ -30,7 +30,7 @@ SearchDialogImpl::SearchDialogImpl(const QStringList *list,
 
 void SearchDialogImpl::setDefaultValue()
 {
-  searchPlayerComboBox->setCurrentItem(0);
+  searchPlayerComboBox->setCurrentIndex(0);
   depthLimitBox->setValue(DEFAULT_NODE_DEPTH_LIMIT);
   initialDepthLimitBox->setValue(DEFAULT_NODE_INITIAL_DEPTH_LIMIT);
   deepningStepBox->setValue(DEFAULT_NODE_DEEPNING_STEP);
@@ -43,7 +43,7 @@ void SearchDialogImpl::setDefaultValue()
 
 void SearchDialogImpl::resetValue()
 {
-  searchPlayerComboBox->setCurrentItem(algorithmIndex);
+  searchPlayerComboBox->setCurrentIndex(algorithmIndex);
   depthLimitBox->setValue(depthLimit);
   initialDepthLimitBox->setValue(initialDepthLimit);
   deepningStepBox->setValue(deepningStep);
