@@ -13,7 +13,7 @@ public:
 		   int tableSizeLimit, int tableRecordLimit,
 		   int checkmateNodeLimit,
 		   int searchTime,
-		   QWidget *parent = 0, const char *name = 0);
+		   QWidget *parent = 0);
 private slots:
   void setDefaultValue();
   void resetValue();
