@@ -1,15 +1,13 @@
 #ifndef _TABCHILD_H
 #define _TABCHILD_H
 #include <qwidget.h>
-#include "osl/player.h"
-#include "osl/state/numEffectState.h"
-#include "osl/stl/vector.h"
+#include "osl/numEffectState.h"
 
 class TabChild : public QWidget
 {
 public:
-  TabChild(QWidget *parent = 0, const char *name = 0) :
-    QWidget(parent, name) {
+  TabChild(QWidget *parent = 0) :
+    QWidget(parent) {
   }
   virtual void forward() = 0;
   virtual void backward() = 0;
@@ -19,7 +17,7 @@ public:
   virtual osl::Player turn() const = 0;
   virtual const osl::NumEffectState& getState() = 0;
   virtual void toggleOrientation() = 0;
-  virtual osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &moves) = 0;
+  virtual osl::NumEffectState getStateAndMovesToCurrent(std::vector<osl::Move> &moves) = 0;
   virtual QString getFilename() {
     return QString();
   }
