@@ -18,12 +18,11 @@
 
 #include "osl/search/simpleHashTable.h"
 #include "osl/eval/progressEval.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/progress/effect5x3.h"
 #include "osl/record/kisen.h"
 #include "osl/record/kakinoki.h"
-#include "osl/record/csa.h"
-#include "osl/record/csaString.h"
+#include "osl/csa.h"
 #include "osl/search/simpleHashRecord.h"
 #include "osl/threatmate/mlPredictor.h"
 #include "osl/threatmate/treePredictor.h"
@@ -37,12 +36,10 @@
 #include <qpushbutton.h>
 #include <QClipboard>
 
-#include <boost/scoped_ptr.hpp>
-
 #include <stdexcept>
 
-Viewer::Viewer(QWidget *parent, const char *name)
-  : QTabWidget(parent, name), chatIcon(false)
+Viewer::Viewer(QWidget *parent)
+  : QTabWidget(parent), chatIcon(false)
 {
   osl::eval::ProgressEval::setUp();
   osl::eval::ml::OpenMidEndingEval::setUp();
@@ -64,7 +61,7 @@ Viewer::Viewer(QWidget *parent, const char *name)
   QPushButton *closeButton = new QPushButton(close, "", this);
   setCornerWidget(closeButton);
 
-  connect(this, SIGNAL(currentChanged(QWidget *)),
+  connect(this, SIGNAL(currentChanged(int)),
 	  this, SIGNAL(statusChanged()));
   connect(kifuViewer, SIGNAL(statusChanged()),
 	  this, SIGNAL(statusChanged()));
@@ -78,10 +75,10 @@ Viewer::Viewer(QWidget *parent, const char *name)
 	  this, SIGNAL(statusChanged()));
   connect(closeButton, SIGNAL(clicked()),
 	  this, SLOT(closeTab()));
-  connect(this, SIGNAL(currentChanged(QWidget *)),
-	  this, SLOT(notifyOrientation(QWidget *)));
-  connect(this, SIGNAL(currentChanged(QWidget *)),
-	  this, SLOT(notifyEffect(QWidget *)));
+  connect(this, SIGNAL(currentChanged(int)),
+	  this, SLOT(notifyOrientation(int)));
+  connect(this, SIGNAL(currentChanged(int)),
+	  this, SLOT(notifyEffect(int)));
 
   connect(networkViewer, SIGNAL(chatReceived()),
 	  this, SLOT(chatReceived()));
@@ -94,8 +91,8 @@ Viewer::Viewer(QWidget *parent, const char *name)
 const viewer::EvalInfo Viewer::evalState()
 {
   viewer::EvalInfo result;
-  TabChild *child = (TabChild *)currentPage();
-  osl::state::NumEffectState nState(child->getState());
+  TabChild *child = (TabChild *)currentWidget();
+  osl::NumEffectState nState(child->getState());
   if (nState.kingPiece(osl::BLACK).isOnBoard() &&
       nState.kingPiece(osl::WHITE).isOnBoard())
   {
@@ -118,18 +115,18 @@ const viewer::EvalInfo Viewer::evalState()
   return result;
 }
 
-void Viewer::progressOfState(osl::stl::vector<int>& out)
+void Viewer::progressOfState(std::vector<int>& out)
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   out.clear();
   // TODO: better abstraction needed
-  if (currentPage() == editor)
+  if (currentWidget() == editor)
   {
     for (int i = 0; i < 3; i++)
       out.push_back(0);
     return;
   }
-  osl::state::NumEffectState nState(child->getState());
+  osl::NumEffectState nState(child->getState());
   if (nState.kingPiece(osl::BLACK).isOnBoard() &&
       nState.kingPiece(osl::WHITE).isOnBoard())
   {
@@ -147,9 +144,9 @@ void Viewer::progressOfState(osl::stl::vector<int>& out)
 
 std::pair<double,double> Viewer::checkmateProbability()
 {
-  TabChild *child = (TabChild *)currentPage();
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  TabChild *child = (TabChild *)currentWidget();
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
 
   if ((moves.size() == 0) || (! moves.back().isNormal()))
     return std::make_pair(0.0, 0.0);
@@ -158,7 +155,7 @@ std::pair<double,double> Viewer::checkmateProbability()
       !state.kingPiece(osl::WHITE).isOnBoard())
     return std::make_pair(0.0, 0.0);
 
-  osl::state::NumEffectState nState(state);
+  osl::NumEffectState nState(state);
   for (size_t i=0; i<moves.size(); ++i)
     nState.makeMove(moves[i]);
   osl::threatmate::MlPredictor predictor;
@@ -171,63 +168,63 @@ std::pair<double,double> Viewer::checkmateProbability()
 void Viewer::forward()
 {
   setChatIcon();
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->forward();
 }
 
 void Viewer::backward()
 {
   resetIcon();
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->backward();
 }
 
 void Viewer::toInitialState()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->toInitialState();
 }
 
 void Viewer::toLastState()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->toLastState();
 }
 
-void Viewer::open(const std::string &fileName)
+void Viewer::open(const QString& fileName)
 {
-  kifuViewer->open(new CsaFile(fileName.c_str()));
-  showPage(kifuViewer);
+  kifuViewer->open(new CsaFile(fileName.toLocal8Bit().constData()));
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
-void Viewer::openKakinoki(const std::string &fileName)
+void Viewer::openKakinoki(const QString& fileName)
 {
-  kifuViewer->open(new KakinokiFile(fileName.c_str()));
-  showPage(kifuViewer);
+  kifuViewer->open(new KakinokiFile(fileName.toLocal8Bit().constData()));
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
-void Viewer::openKi2(const std::string &fileName)
+void Viewer::openKi2(const QString& fileName)
 {
-  kifuViewer->open(new Ki2File(fileName.c_str()));
-  showPage(kifuViewer);
+  kifuViewer->open(new Ki2File(fileName.toLocal8Bit().constData()));
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
-void Viewer::openUsi(const std::string &fileName)
+void Viewer::openUsi(const QString& fileName)
 {
-  kifuViewer->open(new UsiFile(fileName.c_str()));
-  showPage(kifuViewer);
+  kifuViewer->open(new UsiFile(fileName.toLocal8Bit().constData()));
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
-void Viewer::open(const std::string &fileName, int index)
+void Viewer::open(const QString& fileName, int index)
 {
-  kifuViewer->open(new KisenFile(fileName.c_str(), index));
-  showPage(kifuViewer);
+  kifuViewer->open(new KisenFile(fileName.toLocal8Bit().constData(), index));
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
 void Viewer::openEvalGraph()
 {
   kifuViewer->openEvalGraph(true);
-  showPage(kifuViewer);
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
 void Viewer::open()
@@ -237,59 +234,59 @@ void Viewer::open()
   if (!filename.isNull())
   {
     QFileInfo fileInfo(filename);
-    dialog->setDir(fileInfo.dir());
+    dialog->setDirectory(fileInfo.dir());
   }
     
-  QStringList filters = dialog->filters();
-  filters << "Kisen (*.kpf *.kif)";
-  filters << "CSA (*.csa)";
-  filters << "Kakinoki (*.kif)";
-  filters << "Usi (*.usi)";
-  filters << "Shogi files (*.csa *.kpf *.kif *.ki2 *.usi)";
-  dialog->setFilters(filters);
+  dialog->setNameFilter("Kisen (*.kpf *.kif)");
+  dialog->setNameFilter("CSA (*.csa)");
+  dialog->setNameFilter("Kakinoki (*.kif)");
+  dialog->setNameFilter("Usi (*.usi)");
+  dialog->setNameFilter("Shogi files (*.csa *.kpf *.kif *.ki2 *.usi)");
   if (dialog->exec() == QDialog::Accepted)
   {
-    const QString& selectedFile = dialog->selectedFile();
-    std::string fileName(selectedFile.ascii());
-    if (selectedFile.endsWith(".csa"))
+    const QStringList files = dialog->selectedFiles();
+    QString selectedFile;
+    if (!files.isEmpty())
+      selectedFile = files[0];
+    if (selectedFile.endsWith(".csa", Qt::CaseInsensitive))
     {
-      open(fileName);
+      open(selectedFile);
     }
-    else if (selectedFile.endsWith(".usi"))
+    else if (selectedFile.endsWith(".usi", Qt::CaseInsensitive))
     {
-      openUsi(fileName);
+      openUsi(selectedFile);
     }
-    else if ( selectedFile.endsWith(".ki2") || selectedFile.endsWith(".KI2") )
+    else if (selectedFile.endsWith(".ki2", Qt::CaseInsensitive))
     {
-      openKi2(fileName);
+      openKi2(selectedFile);
     }
-    else if (selectedFile.endsWith(".kif")
-	     && osl::KakinokiFile::isKakinokiFile(fileName))
+    else if (selectedFile.endsWith(".kif", Qt::CaseInsensitive)
+	     && osl::KakinokiFile::isKakinokiFile(selectedFile.toLocal8Bit().constData()))
     {
-      openKakinoki(fileName);
+      openKakinoki(selectedFile);
     }
-    else if (selectedFile.endsWith(".kif") || selectedFile.endsWith(".kpf"))
+    else if (selectedFile.endsWith(".kif", Qt::CaseInsensitive))
     {
       QString ipxFile(selectedFile);
       ipxFile.replace(ipxFile.length() - 3, 3, "ipx");
-      osl::record::KisenIpxFile ipx(ipxFile.ascii());
+      osl::record::KisenIpxFile ipx(ipxFile.toStdString());
       if (ipx.size() > 1000)
       {
 	bool ok;
-	int index = QInputDialog::getInteger("Kisen Index",
-					     QString("Choose Kisen Index %1").arg(ipx.size()),
-					     0, 0, ipx.size(), 1, &ok, this);
+	int index = QInputDialog::getInt(this, "Kisen Index",
+					 QString("Choose Kisen Index %1").arg(ipx.size()),
+					 0, 0, ipx.size(), 1, &ok);
 	if (ok)
 	{
-	  open(fileName, index);
+	  open(selectedFile, index);
 	}
       }
       else
       {
-	boost::scoped_ptr<QDialog> qdialog(new QDialog(this));
-	boost::scoped_ptr<Ui_kisenDialog> dialog(new Ui_kisenDialog());
+	std::unique_ptr<QDialog> qdialog(new QDialog(this));
+	std::unique_ptr<Ui_kisenDialog> dialog(new Ui_kisenDialog());
         dialog->setupUi(qdialog.get());
-        boost::scoped_ptr<KisenModel> kisen_model(new KisenModel(&ipx, this));
+        std::unique_ptr<KisenModel> kisen_model(new KisenModel(&ipx, this));
         dialog->tableView->setModel(kisen_model.get());
         dialog->tableView->verticalHeader()->hide();
         dialog->tableView->resizeColumnsToContents();
@@ -301,7 +298,7 @@ void Viewer::open()
             dialog->tableView->selectionModel()->selection().indexes();
 	  if (!selected.empty())
 	  {
-	    open(fileName, selected.first().row());
+	    open(selectedFile, selected.first().row());
 	  }
 	}
       }
@@ -325,7 +322,7 @@ void Viewer::nextFile()
   if (next_file)
   {
     kifuViewer->open(next_file);
-    showPage(kifuViewer);
+    setCurrentIndex(indexOf(kifuViewer));
     emit statusChanged();
   }
 }
@@ -339,7 +336,7 @@ void Viewer::prevFile()
   if (prev_file)
   {
     kifuViewer->open(prev_file);
-    showPage(kifuViewer);
+    setCurrentIndex(indexOf(kifuViewer));
     emit statusChanged();
   }
 }
@@ -356,15 +353,14 @@ void Viewer::openUrl(bool reload)
   http->show();
   if (http->exec() == QDialog::Accepted)
   {
-    std::string filename = http->getFilename().toStdString();
-    if (http->getFilename().endsWith(".kif"))
-      openKakinoki(filename);
-    else if (http->getFilename().endsWith(".ki2") || http->getFilename().endsWith(".KI2"))
-      openKi2(filename);
-    else if (http->getFilename().endsWith(".usi"))
-      openUsi(filename);
+    if (http->getFilename().endsWith(".kif", Qt::CaseInsensitive))
+      openKakinoki(http->getFilename());
+    else if (http->getFilename().endsWith(".ki2", Qt::CaseInsensitive))
+      openKi2(http->getFilename());
+    else if (http->getFilename().endsWith(".usi", Qt::CaseInsensitive))
+      openUsi(http->getFilename());
     else
-      open(filename);
+      open(http->getFilename());
     kifuViewer->toLastState();
   }
 }
@@ -381,21 +377,21 @@ void Viewer::reloadUrl()
 
 void Viewer::hirate()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   if (!child->inherits("KifuViewer"))
     return;
   KifuViewer *kifu = (KifuViewer *)child;
 
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state(osl::HIRATE);
+  std::vector<osl::Move> moves;
+  osl::SimpleState state(osl::HIRATE);
   kifu->open(state, moves);
-  showPage(kifu);
+  setCurrentIndex(indexOf(kifu));
 }
 
 void Viewer::network()
 {
-  boost::scoped_ptr<QDialog> qdialog(new QDialog(this));
-  boost::scoped_ptr<Ui::NetworkDialog> dialog(new Ui::NetworkDialog());
+  std::unique_ptr<QDialog> qdialog(new QDialog(this));
+  std::unique_ptr<Ui::NetworkDialog> dialog(new Ui::NetworkDialog());
   dialog->setupUi(qdialog.get());
 
   qdialog->exec();
@@ -405,53 +401,53 @@ void Viewer::network()
   networkViewer->setPassword(dialog->password->text());
   networkViewer->connect();
 
-  showPage(networkViewer);
+  setCurrentIndex(indexOf(networkViewer));
 }
 
 void Viewer::view()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   if (child == kifuViewer)
     return;
 
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
   kifuViewer->open(state, moves);
   kifuViewer->toLastState();
-  showPage(kifuViewer);
+  setCurrentIndex(indexOf(kifuViewer));
 }
 
 void Viewer::viewInNewTab()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
 
   KifuViewer *viewer = new KifuViewer(this);
   connect(viewer, SIGNAL(statusChanged()), this, SIGNAL(statusChanged()));
   connect(viewer, SIGNAL(analyzeOnlineDisabled()),
 	  this, SIGNAL(analyzeOnlineDisabled()));
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
   viewer->open(state, moves);
   viewer->toLastState();
   addTab(viewer, "Kifu");
-  showPage(viewer);
+  setCurrentIndex(indexOf(viewer));
 }
 
 int Viewer::moveCount() const
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   return child->moveCount();
 }
 
 osl::Player Viewer::turn() const
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   return child->turn();
 }
 
-const osl::state::SimpleState& Viewer::getState()
+const osl::SimpleState& Viewer::getState()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   return child->getState();
 }
 
@@ -468,9 +464,9 @@ void Viewer::analyzeInNewTab()
 void Viewer::analyze(bool newTab)
 {
   bool tabCreated = false;
-  TabChild *child = (TabChild *)currentPage();
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  TabChild *child = (TabChild *)currentWidget();
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
   AnalysisViewer *av;
 
   if (!analysisViewer || newTab)
@@ -497,7 +493,7 @@ void Viewer::analyze(bool newTab)
 	analysisViewer = av;
       addTab(av, "Analyze position");
     }
-    showPage(av);
+    setCurrentIndex(indexOf(av));
   }
   else
   {
@@ -510,75 +506,74 @@ void Viewer::analyze(bool newTab)
 
 void Viewer::checkmateSearch()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   const int node_limit = 100000;
   bool success = checkmateViewer->analyze(child->getState(), node_limit);
   if (success)
-    showPage(checkmateViewer);
+    setCurrentIndex(indexOf(checkmateViewer));
 }
 
 void Viewer::altCheckmateSearch()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   const int node_limit = 100000;
   bool success = checkmateViewer->analyze(child->getState(), node_limit, true);
   if (success)
-    showPage(checkmateViewer);
+    setCurrentIndex(indexOf(checkmateViewer));
 }
 
 void Viewer::checkmateSimulation()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   bool success = checkmateViewer->analyze(child->getState(), 0);
   if (success)
-    showPage(checkmateViewer);
+    setCurrentIndex(indexOf(checkmateViewer));
 }
 
 void Viewer::quiescenceSearch()
 {
-  TabChild *child = (TabChild *)currentPage();
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  TabChild *child = (TabChild *)currentWidget();
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
   bool success = quiescenceViewer->analyze(state, moves);
   if (success)
-    showPage(quiescenceViewer);
+    setCurrentIndex(indexOf(quiescenceViewer));
 }
 
 void Viewer::quiescenceSearchHalf()
 {
-  TabChild *child = (TabChild *)currentPage();
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  TabChild *child = (TabChild *)currentWidget();
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
   bool success = quiescenceViewer->analyzeHalfDepth(state, moves);
   if (success)
-    showPage(quiescenceViewer);
+    setCurrentIndex(indexOf(quiescenceViewer));
 }
 
 void Viewer::moveGenerateDialog()
 {
-  if (currentPage()->inherits("BoardAndListTabChild"))
+  if (currentWidget()->inherits("BoardAndListTabChild"))
   {
-    ((BoardAndListTabChild *)currentPage())->moveGenerateDialog();
+    ((BoardAndListTabChild *)currentWidget())->moveGenerateDialog();
     return;
   }
 
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->moveGenerateDialog();
 }
 
 void Viewer::toggleOrientation()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->toggleOrientation();
 }
 
 QString Viewer::getFilenameToSave()
 {
-  QString s = QFileDialog::getSaveFileName(0,
-					   "CSA (*.csa)",
-					   this,
-					   "save file",
-					   "Save moves up to current state");
+  QString s = QFileDialog::getSaveFileName(this, 
+                                           "Save moves up to current state",
+                                           "",
+					   "CSA (*.csa)");
   return s;
 }
 
@@ -587,14 +582,14 @@ void Viewer::saveMovesToCurrent()
   QString s = getFilenameToSave();
   if (s.isNull())
     return;
-  TabChild *child = (TabChild *)currentPage();
-  osl::stl::vector<osl::Move> moves;
-  osl::state::SimpleState state = child->getStateAndMovesToCurrent(moves);
-  std::ofstream os(s.ascii());
+  TabChild *child = (TabChild *)currentWidget();
+  std::vector<osl::Move> moves;
+  osl::SimpleState state = child->getStateAndMovesToCurrent(moves);
+  std::ofstream os(s.toStdString().c_str());
   os << state;
   for (int i = 0; i < (int)moves.size(); i++)
   {
-    os << osl::record::csa::show(moves[i]) << std::endl;
+    os << osl::csa::show(moves[i]) << std::endl;
   }
 }
 
@@ -611,14 +606,14 @@ void Viewer::exportCurrent()
   QString s = getFilenameToSave();
   if (s.isNull())
     return;
-  TabChild *child = (TabChild *)currentPage();
-  std::ofstream os(s.ascii());
+  TabChild *child = (TabChild *)currentWidget();
+  std::ofstream os(s.toStdString().c_str());
   os << child->getState();
 }
 
 void Viewer::moveTo(int index)
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   if (child == kifuViewer)
   {
     kifuViewer->updateIndex(index);
@@ -627,31 +622,31 @@ void Viewer::moveTo(int index)
 
 void Viewer::copy()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->copy();
 }
 
 void Viewer::copyBoardAndMoves()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->copyBoardAndMoves();
 }
 
 void Viewer::copyUsi()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->copyUsi();
 }
 
 void Viewer::copyBoardAndMovesUsi()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   child->copyBoardAndMovesUsi();
 }
 
 void Viewer::paste()
 {
-  QWidget *widget = currentPage();
+  QWidget *widget = currentWidget();
   if (widget->inherits("KifuViewer"))
   {
     QClipboard *clipboard = QApplication::clipboard();
@@ -660,9 +655,9 @@ void Viewer::paste()
     {
       try
       {
-        osl::record::csa::CsaString csa(text.toUtf8());
-        osl::stl::vector<osl::Move> board_moves;
-        ((KifuViewer *)widget)->open(csa.getInitialState(), board_moves);
+        osl::CsaString csa(text.toUtf8().data());
+        std::vector<osl::Move> board_moves;
+        ((KifuViewer *)widget)->open(csa.initialState(), board_moves);
       }
       catch(...)
       {
@@ -673,7 +668,7 @@ void Viewer::paste()
 
 QString Viewer::getFilename()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   QString filename = child->getFilename();
   if (filename.isNull())
     return "";
@@ -684,16 +679,16 @@ QString Viewer::getFilename()
 
 void Viewer::closeTab()
 {
-  QWidget *widget = currentPage();
+  QWidget *widget = currentWidget();
   if (widget->inherits("AnalysisViewer"))
   {
-    removePage(widget);
+    removeTab(indexOf(widget));
     if (widget == analysisViewer)
     {
       analysisViewer = 0;
       for (int i = 0; i < count(); i++)
       {
-	QWidget *child = page(i);
+	QWidget *child = this->widget(i);
 	if (child->inherits("AnalysisViewer"))
 	{
 	  analysisViewer = (AnalysisViewer *)child;
@@ -705,25 +700,25 @@ void Viewer::closeTab()
   }
   else if (widget != kifuViewer && widget->inherits("KifuViewer"))
   {
-    removePage(widget);
+    removeTab(indexOf(widget));
     delete widget;
   }
 }
 
 bool Viewer::isSenteView() const
 {
-  if (currentPage()->inherits("BoardTabChild"))
+  if (currentWidget()->inherits("BoardTabChild"))
   {
-    return ((BoardTabChild *)currentPage())->isSenteView();
+    return ((BoardTabChild *)currentWidget())->isSenteView();
   }
   return true;
 }
 
 void Viewer::setOrientation(bool gote)
 {
-  if (currentPage()->inherits("BoardTabChild"))
+  if (currentWidget()->inherits("BoardTabChild"))
   {
-    return ((BoardTabChild *)currentPage())->setOrientation(!gote);
+    return ((BoardTabChild *)currentWidget())->setOrientation(!gote);
   }
 }
 
@@ -732,22 +727,23 @@ void Viewer::setAnalyzeOnline(bool enable)
   KifuViewer::setAnalyzeOnline(enable);
   if (enable)
   {
-    if (currentPage()->inherits("KifuViewer")) {
-      osl::state::SimpleState s;
-      osl::stl::vector<osl::Move> m;
-      s = ((KifuViewer *)currentPage())->getStateAndMovesToCurrent(m);
-      ((KifuViewer *)currentPage())->prepareUpdateForAnalysis(s, m, 0, osl::Move());
+    if (currentWidget()->inherits("KifuViewer")) {
+      osl::SimpleState s;
+      std::vector<osl::Move> m;
+      s = ((KifuViewer *)currentWidget())->getStateAndMovesToCurrent(m);
+      ((KifuViewer *)currentWidget())->prepareUpdateForAnalysis(s, m, 0, osl::Move());
     }
     else
-      showPage(kifuViewer);
+      setCurrentIndex(indexOf(kifuViewer));
   }
 }
 
-void Viewer::notifyOrientation(QWidget *widget)
+void Viewer::notifyOrientation(int index)
 {
+  QWidget *w = widget(index);
   bool sente;
-  if (widget->inherits("BoardTabChild"))
-    sente = ((BoardTabChild *)widget)->isSenteView();
+  if (w->inherits("BoardTabChild"))
+    sente = ((BoardTabChild *)w)->isSenteView();
   else
     sente = true;
 
@@ -756,33 +752,34 @@ void Viewer::notifyOrientation(QWidget *widget)
 
 void Viewer::enableEffect(bool on)
 {
-  ((TabChild *)currentPage())->enableEffect(on);
+  ((TabChild *)currentWidget())->enableEffect(on);
 }
 
 void Viewer::highlightLastMove(bool on)
 {
-  ((TabChild *)currentPage())->highlightLastMove(on);
+  ((TabChild *)currentWidget())->highlightLastMove(on);
 }
 void Viewer::highlightBookMove(bool on)
 {
-  ((TabChild *)currentPage())->highlightBookMove(on);
+  ((TabChild *)currentWidget())->highlightBookMove(on);
 }
 void Viewer::showArrowMove(bool on)
 {
-  ((TabChild *)currentPage())->showArrowMove(on);
+  ((TabChild *)currentWidget())->showArrowMove(on);
 }
 
-void Viewer::notifyEffect(QWidget *widget)
+void Viewer::notifyEffect(int index)
 {
-  if (widget->inherits("BoardTabChild"))
-    emit effectChanged(((BoardTabChild *)widget)->effectEnabled());
+  QWidget *w = widget(index);
+  if (w->inherits("BoardTabChild"))
+    emit effectChanged(((BoardTabChild *)w)->effectEnabled());
 }
 
 void Viewer::kifuAnalyze()
 {
-  if (((TabChild *)currentPage())->inherits("KifuViewer"))
+  if (((TabChild *)currentWidget())->inherits("KifuViewer"))
   {
-    ((KifuViewer *)currentPage())->analyze();
+    ((KifuViewer *)currentWidget())->analyze();
   }
 }
 
@@ -820,25 +817,25 @@ void Viewer::chatDisplayed()
 
 void Viewer::editState()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   editor->setState(child->getState());
-  showPage(editor);
+  setCurrentIndex(indexOf(editor));
 }
 
 void Viewer::testEvalDebug()
 {
-  TabChild *child = (TabChild *)currentPage();
+  TabChild *child = (TabChild *)currentWidget();
   OpenMidEndingEvalDebugDialog *dialog =
     new OpenMidEndingEvalDebugDialog(child->getState(), this);
   if (child->inherits("BoardTabChild"))
   {
     BoardTabChild *board_tab_child = (BoardTabChild *)child;
     connect(board_tab_child,
-	    SIGNAL(statusChanged(const osl::state::SimpleState &,
-				 const osl::stl::vector<osl::Move> &,
+	    SIGNAL(statusChanged(const osl::SimpleState &,
+				 const std::vector<osl::Move> &,
 				 int, osl::Move)),
-	    dialog, SLOT(setStatus(const osl::state::SimpleState &,
-				   const osl::stl::vector<osl::Move> &,
+	    dialog, SLOT(setStatus(const osl::SimpleState &,
+				   const std::vector<osl::Move> &,
 				   int, osl::Move)));
   }
   dialog->show();
@@ -847,14 +844,14 @@ void Viewer::testEvalDebug()
 
 void Viewer::setState1()
 {
-  TabChild *child = (TabChild *)currentPage();
-  state1.reset(new osl::state::SimpleState(child->getState()));
+  TabChild *child = (TabChild *)currentWidget();
+  state1.reset(new osl::SimpleState(child->getState()));
 }
 
 void Viewer::setState2()
 {
-  TabChild *child = (TabChild *)currentPage();
-  state2.reset(new osl::state::SimpleState(child->getState()));
+  TabChild *child = (TabChild *)currentWidget();
+  state2.reset(new osl::SimpleState(child->getState()));
 }
 
 void Viewer::showEvalDiff()
@@ -862,8 +859,8 @@ void Viewer::showEvalDiff()
   if (state1.get() != NULL && state2.get() != NULL)
   {
     OpenMidEndingEvalDiffDialog *dialog =
-      new OpenMidEndingEvalDiffDialog(osl::state::NumEffectState(*state1),
-                                      osl::state::NumEffectState(*state2), this);
+      new OpenMidEndingEvalDiffDialog(osl::NumEffectState(*state1),
+                                      osl::NumEffectState(*state2), this);
     dialog->show();
     dialog->raise();
   }
@@ -871,8 +868,8 @@ void Viewer::showEvalDiff()
 
 void Viewer::showProgressDebug()
 {
-  TabChild *child = (TabChild *)currentPage();
-  osl::state::NumEffectState state(child->getState());
+  TabChild *child = (TabChild *)currentWidget();
+  osl::NumEffectState state(child->getState());
   NewProgressDebugDialog *dialog = new NewProgressDebugDialog(state, this);
   dialog->setAttribute(Qt::WA_DeleteOnClose);
   dialog->show();
